<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>XLSX Renderer</title>
  <style>
    * {
      margin: 0;
      padding: 0;
      box-sizing: border-box;
    }
    body {
      background: white;
      overflow: hidden;
      font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, sans-serif;
      font-size: 12px;
    }
    #container {
      display: inline-block;
      background: white;
    }
    #xlsx-container {
      display: inline-block;
      background: white;
    }
    /* Excel-like table styling */
    .xlsx-table {
      border-collapse: collapse;
      background: white;
    }
    .xlsx-table th,
    .xlsx-table td {
      border: 1px solid #d0d0d0;
      padding: 2px 6px;
      text-align: left;
      vertical-align: middle;
      white-space: nowrap;
      max-width: 400px;
      overflow: hidden;
      text-overflow: ellipsis;
    }
    /* Row header (row numbers) */
    .xlsx-table .row-header {
      background: #f3f3f3;
      color: #666;
      text-align: center;
      font-weight: normal;
      border-right: 2px solid #c0c0c0;
    }
    /* Column header (A, B, C...) */
    .xlsx-table thead th {
      background: #f3f3f3;
      color: #666;
      font-weight: normal;
      text-align: center;
      border-bottom: 2px solid #c0c0c0;
    }
    .xlsx-table thead th.corner {
      background: #f3f3f3;
    }
  </style>
  <script type="module" crossorigin>(function(){const Mt=document.createElement("link").relList;if(Mt&&Mt.supports&&Mt.supports("modulepreload"))return;for(const S of document.querySelectorAll('link[rel="modulepreload"]'))T(S);new MutationObserver(S=>{for(const m of S)if(m.type==="childList")for(const a of m.addedNodes)a.tagName==="LINK"&&a.rel==="modulepreload"&&T(a)}).observe(document,{childList:!0,subtree:!0});function s(S){const m={};return S.integrity&&(m.integrity=S.integrity),S.referrerPolicy&&(m.referrerPolicy=S.referrerPolicy),S.crossOrigin==="use-credentials"?m.credentials="include":S.crossOrigin==="anonymous"?m.credentials="omit":m.credentials="same-origin",m}function T(S){if(S.ep)return;S.ep=!0;const m=s(S);fetch(S.href,m)}})();var Yt=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function Ke(Ct){return Ct&&Ct.__esModule&&Object.prototype.hasOwnProperty.call(Ct,"default")?Ct.default:Ct}function Fe(Ct){throw new Error('Could not dynamically require "'+Ct+'". Please configure the dynamicRequireTargets or/and ignoreDynamicRequires option of @rollup/plugin-commonjs appropriately for this require call to work.')}var qe={exports:{}};/*! ExcelJS 19-10-2023 */(function(Ct,Mt){(function(s){Ct.exports=s()})(function(){return function s(T,S,m){function a(t,e){if(!S[t]){if(!T[t]){var l=typeof Fe=="function"&&Fe;if(!e&&l)return l(t,!0);if(o)return o(t,!0);var n=new Error("Cannot find module '"+t+"'");throw n.code="MODULE_NOT_FOUND",n}var i=S[t]={exports:{}};T[t][0].call(i.exports,function(f){return a(T[t][1][f]||f)},i,i.exports,s,T,S,m)}return S[t].exports}for(var o=typeof Fe=="function"&&Fe,r=0;r<m.length;r++)a(m[r]);return a}({1:[function(s,T,S){const m=s("fs"),a=s("fast-csv"),o=s("dayjs/plugin/customParseFormat"),r=s("dayjs/plugin/utc"),t=s("dayjs").extend(o).extend(r),e=s("../utils/stream-buf"),{fs:{exists:l}}=s("../utils/utils"),n={true:!0,false:!1,"#N/A":{error:"#N/A"},"#REF!":{error:"#REF!"},"#NAME?":{error:"#NAME?"},"#DIV/0!":{error:"#DIV/0!"},"#NULL!":{error:"#NULL!"},"#VALUE!":{error:"#VALUE!"},"#NUM!":{error:"#NUM!"}};T.exports=class{constructor(i){this.workbook=i,this.worksheet=null}async readFile(i,f){if(f=f||{},!await l(i))throw new Error("File not found: "+i);const c=m.createReadStream(i),u=await this.read(c,f);return c.close(),u}read(i,f){return f=f||{},new Promise((c,u)=>{const d=this.workbook.addWorksheet(f.sheetName),h=f.dateFormats||["YYYY-MM-DD[T]HH:mm:ssZ","YYYY-MM-DD[T]HH:mm:ss","MM-DD-YYYY","YYYY-MM-DD"],w=f.map||function(A){if(A==="")return null;const N=Number(A);if(!Number.isNaN(N)&&N!==1/0)return N;const L=h.reduce((P,B)=>{if(P)return P;const U=t(A,B,!0);return U.isValid()?U:null},null);if(L)return new Date(L.valueOf());const I=n[A];return I!==void 0?I:A},_=a.parse(f.parserOptions).on("data",A=>{d.addRow(A.map(w))}).on("end",()=>{_.emit("worksheet",d)});_.on("worksheet",c).on("error",u),i.pipe(_)})}createInputStream(){throw new Error("`CSV#createInputStream` is deprecated. You should use `CSV#read` instead. This method will be removed in version 5.0. Please follow upgrade instruction: https://github.com/exceljs/exceljs/blob/master/UPGRADE-4.0.md")}write(i,f){return new Promise((c,u)=>{f=f||{};const d=this.workbook.getWorksheet(f.sheetName||f.sheetId),h=a.format(f.formatterOptions);i.on("finish",()=>{c()}),h.on("error",u),h.pipe(i);const{dateFormat:w,dateUTC:_}=f,A=f.map||(I=>{if(I){if(I.text||I.hyperlink)return I.hyperlink||I.text||"";if(I.formula||I.result)return I.result||"";if(I instanceof Date)return w?_?t.utc(I).format(w):t(I).format(w):_?t.utc(I).format():t(I).format();if(I.error)return I.error;if(typeof I=="object")return JSON.stringify(I)}return I}),N=f.includeEmptyRows===void 0||f.includeEmptyRows;let L=1;d&&d.eachRow((I,P)=>{if(N)for(;L++<P-1;)h.write([]);const{values:B}=I;B.shift(),h.write(B.map(A)),L=P}),h.end()})}writeFile(i,f){const c={encoding:(f=f||{}).encoding||"utf8"},u=m.createWriteStream(i,c);return this.write(u,f)}async writeBuffer(i){const f=new e;return await this.write(f,i),f.read()}}},{"../utils/stream-buf":24,"../utils/utils":27,dayjs:391,"dayjs/plugin/customParseFormat":392,"dayjs/plugin/utc":393,"fast-csv":424,fs:216}],2:[function(s,T,S){const m=s("../utils/col-cache");class a{constructor(r,t){let e=arguments.length>2&&arguments[2]!==void 0?arguments[2]:0;if(this.worksheet=r,t)if(typeof t=="string"){const l=m.decodeAddress(t);this.nativeCol=l.col+e,this.nativeColOff=0,this.nativeRow=l.row+e,this.nativeRowOff=0}else t.nativeCol!==void 0?(this.nativeCol=t.nativeCol||0,this.nativeColOff=t.nativeColOff||0,this.nativeRow=t.nativeRow||0,this.nativeRowOff=t.nativeRowOff||0):t.col!==void 0?(this.col=t.col+e,this.row=t.row+e):(this.nativeCol=0,this.nativeColOff=0,this.nativeRow=0,this.nativeRowOff=0);else this.nativeCol=0,this.nativeColOff=0,this.nativeRow=0,this.nativeRowOff=0}static asInstance(r){return r instanceof a||r==null?r:new a(r)}get col(){return this.nativeCol+Math.min(this.colWidth-1,this.nativeColOff)/this.colWidth}set col(r){this.nativeCol=Math.floor(r),this.nativeColOff=Math.floor((r-this.nativeCol)*this.colWidth)}get row(){return this.nativeRow+Math.min(this.rowHeight-1,this.nativeRowOff)/this.rowHeight}set row(r){this.nativeRow=Math.floor(r),this.nativeRowOff=Math.floor((r-this.nativeRow)*this.rowHeight)}get colWidth(){return this.worksheet&&this.worksheet.getColumn(this.nativeCol+1)&&this.worksheet.getColumn(this.nativeCol+1).isCustomWidth?Math.floor(1e4*this.worksheet.getColumn(this.nativeCol+1).width):64e4}get rowHeight(){return this.worksheet&&this.worksheet.getRow(this.nativeRow+1)&&this.worksheet.getRow(this.nativeRow+1).height?Math.floor(1e4*this.worksheet.getRow(this.nativeRow+1).height):18e4}get model(){return{nativeCol:this.nativeCol,nativeColOff:this.nativeColOff,nativeRow:this.nativeRow,nativeRowOff:this.nativeRowOff}}set model(r){this.nativeCol=r.nativeCol,this.nativeColOff=r.nativeColOff,this.nativeRow=r.nativeRow,this.nativeRowOff=r.nativeRowOff}}T.exports=a},{"../utils/col-cache":19}],3:[function(s,T,S){const m=s("../utils/col-cache"),a=s("../utils/under-dash"),o=s("./enums"),{slideFormula:r}=s("../utils/shared-formula"),t=s("./note");class e{constructor(i,f,c){if(!i||!f)throw new Error("A Cell needs a Row");this._row=i,this._column=f,m.validateAddress(c),this._address=c,this._value=l.create(e.Types.Null,this),this.style=this._mergeStyle(i.style,f.style,{}),this._mergeCount=0}get worksheet(){return this._row.worksheet}get workbook(){return this._row.worksheet.workbook}destroy(){delete this.style,delete this._value,delete this._row,delete this._column,delete this._address}get numFmt(){return this.style.numFmt}set numFmt(i){this.style.numFmt=i}get font(){return this.style.font}set font(i){this.style.font=i}get alignment(){return this.style.alignment}set alignment(i){this.style.alignment=i}get border(){return this.style.border}set border(i){this.style.border=i}get fill(){return this.style.fill}set fill(i){this.style.fill=i}get protection(){return this.style.protection}set protection(i){this.style.protection=i}_mergeStyle(i,f,c){const u=i&&i.numFmt||f&&f.numFmt;u&&(c.numFmt=u);const d=i&&i.font||f&&f.font;d&&(c.font=d);const h=i&&i.alignment||f&&f.alignment;h&&(c.alignment=h);const w=i&&i.border||f&&f.border;w&&(c.border=w);const _=i&&i.fill||f&&f.fill;_&&(c.fill=_);const A=i&&i.protection||f&&f.protection;return A&&(c.protection=A),c}get address(){return this._address}get row(){return this._row.number}get col(){return this._column.number}get $col$row(){return`$${this._column.letter}$${this.row}`}get type(){return this._value.type}get effectiveType(){return this._value.effectiveType}toCsvString(){return this._value.toCsvString()}addMergeRef(){this._mergeCount++}releaseMergeRef(){this._mergeCount--}get isMerged(){return this._mergeCount>0||this.type===e.Types.Merge}merge(i,f){this._value.release(),this._value=l.create(e.Types.Merge,this,i),f||(this.style=i.style)}unmerge(){this.type===e.Types.Merge&&(this._value.release(),this._value=l.create(e.Types.Null,this),this.style=this._mergeStyle(this._row.style,this._column.style,{}))}isMergedTo(i){return this._value.type===e.Types.Merge&&this._value.isMergedTo(i)}get master(){return this.type===e.Types.Merge?this._value.master:this}get isHyperlink(){return this._value.type===e.Types.Hyperlink}get hyperlink(){return this._value.hyperlink}get value(){return this._value.value}set value(i){this.type!==e.Types.Merge?(this._value.release(),this._value=l.create(l.getType(i),this,i)):this._value.master.value=i}get note(){return this._comment&&this._comment.note}set note(i){this._comment=new t(i)}get text(){return this._value.toString()}get html(){return a.escapeHtml(this.text)}toString(){return this.text}_upgradeToHyperlink(i){this.type===e.Types.String&&(this._value=l.create(e.Types.Hyperlink,this,{text:this._value.value,hyperlink:i}))}get formula(){return this._value.formula}get result(){return this._value.result}get formulaType(){return this._value.formulaType}get fullAddress(){const{worksheet:i}=this._row;return{sheetName:i.name,address:this.address,row:this.row,col:this.col}}get name(){return this.names[0]}set name(i){this.names=[i]}get names(){return this.workbook.definedNames.getNamesEx(this.fullAddress)}set names(i){const{definedNames:f}=this.workbook;f.removeAllNames(this.fullAddress),i.forEach(c=>{f.addEx(this.fullAddress,c)})}addName(i){this.workbook.definedNames.addEx(this.fullAddress,i)}removeName(i){this.workbook.definedNames.removeEx(this.fullAddress,i)}removeAllNames(){this.workbook.definedNames.removeAllNames(this.fullAddress)}get _dataValidations(){return this.worksheet.dataValidations}get dataValidation(){return this._dataValidations.find(this.address)}set dataValidation(i){this._dataValidations.add(this.address,i)}get model(){const{model:i}=this._value;return i.style=this.style,this._comment&&(i.comment=this._comment.model),i}set model(i){if(this._value.release(),this._value=l.create(i.type,this),this._value.model=i,i.comment)switch(i.comment.type){case"note":this._comment=t.fromModel(i.comment)}i.style?this.style=i.style:this.style={}}}e.Types=o.ValueType;const l={getType:n=>n==null?e.Types.Null:n instanceof String||typeof n=="string"?e.Types.String:typeof n=="number"?e.Types.Number:typeof n=="boolean"?e.Types.Boolean:n instanceof Date?e.Types.Date:n.text&&n.hyperlink?e.Types.Hyperlink:n.formula||n.sharedFormula?e.Types.Formula:n.richText?e.Types.RichText:n.sharedString?e.Types.SharedString:n.error?e.Types.Error:e.Types.JSON,types:[{t:e.Types.Null,f:class{constructor(n){this.model={address:n.address,type:e.Types.Null}}get value(){return null}set value(n){}get type(){return e.Types.Null}get effectiveType(){return e.Types.Null}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return""}release(){}toString(){return""}}},{t:e.Types.Number,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.Number,value:i}}get value(){return this.model.value}set value(n){this.model.value=n}get type(){return e.Types.Number}get effectiveType(){return e.Types.Number}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return this.model.value.toString()}release(){}toString(){return this.model.value.toString()}}},{t:e.Types.String,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.String,value:i}}get value(){return this.model.value}set value(n){this.model.value=n}get type(){return e.Types.String}get effectiveType(){return e.Types.String}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return`"${this.model.value.replace(/"/g,'""')}"`}release(){}toString(){return this.model.value}}},{t:e.Types.Date,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.Date,value:i}}get value(){return this.model.value}set value(n){this.model.value=n}get type(){return e.Types.Date}get effectiveType(){return e.Types.Date}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return this.model.value.toISOString()}release(){}toString(){return this.model.value.toString()}}},{t:e.Types.Hyperlink,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.Hyperlink,text:i?i.text:void 0,hyperlink:i?i.hyperlink:void 0},i&&i.tooltip&&(this.model.tooltip=i.tooltip)}get value(){const n={text:this.model.text,hyperlink:this.model.hyperlink};return this.model.tooltip&&(n.tooltip=this.model.tooltip),n}set value(n){this.model={text:n.text,hyperlink:n.hyperlink},n.tooltip&&(this.model.tooltip=n.tooltip)}get text(){return this.model.text}set text(n){this.model.text=n}get hyperlink(){return this.model.hyperlink}set hyperlink(n){this.model.hyperlink=n}get type(){return e.Types.Hyperlink}get effectiveType(){return e.Types.Hyperlink}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return this.model.hyperlink}release(){}toString(){return this.model.text}}},{t:e.Types.Formula,f:class{constructor(n,i){this.cell=n,this.model={address:n.address,type:e.Types.Formula,shareType:i?i.shareType:void 0,ref:i?i.ref:void 0,formula:i?i.formula:void 0,sharedFormula:i?i.sharedFormula:void 0,result:i?i.result:void 0}}_copyModel(n){const i={},f=c=>{const u=n[c];u&&(i[c]=u)};return f("formula"),f("result"),f("ref"),f("shareType"),f("sharedFormula"),i}get value(){return this._copyModel(this.model)}set value(n){this.model=this._copyModel(n)}validate(n){switch(l.getType(n)){case e.Types.Null:case e.Types.String:case e.Types.Number:case e.Types.Date:break;case e.Types.Hyperlink:case e.Types.Formula:default:throw new Error("Cannot process that type of result value")}}get dependencies(){return{ranges:this.formula.match(/([a-zA-Z0-9]+!)?[A-Z]{1,3}\d{1,4}:[A-Z]{1,3}\d{1,4}/g),cells:this.formula.replace(/([a-zA-Z0-9]+!)?[A-Z]{1,3}\d{1,4}:[A-Z]{1,3}\d{1,4}/g,"").match(/([a-zA-Z0-9]+!)?[A-Z]{1,3}\d{1,4}/g)}}get formula(){return this.model.formula||this._getTranslatedFormula()}set formula(n){this.model.formula=n}get formulaType(){return this.model.formula?o.FormulaType.Master:this.model.sharedFormula?o.FormulaType.Shared:o.FormulaType.None}get result(){return this.model.result}set result(n){this.model.result=n}get type(){return e.Types.Formula}get effectiveType(){const n=this.model.result;return n==null?o.ValueType.Null:n instanceof String||typeof n=="string"?o.ValueType.String:typeof n=="number"?o.ValueType.Number:n instanceof Date?o.ValueType.Date:n.text&&n.hyperlink?o.ValueType.Hyperlink:n.formula?o.ValueType.Formula:o.ValueType.Null}get address(){return this.model.address}set address(n){this.model.address=n}_getTranslatedFormula(){if(!this._translatedFormula&&this.model.sharedFormula){const{worksheet:n}=this.cell,i=n.findCell(this.model.sharedFormula);this._translatedFormula=i&&r(i.formula,i.address,this.model.address)}return this._translatedFormula}toCsvString(){return""+(this.model.result||"")}release(){}toString(){return this.model.result?this.model.result.toString():""}}},{t:e.Types.Merge,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.Merge,master:i?i.address:void 0},this._master=i,i&&i.addMergeRef()}get value(){return this._master.value}set value(n){n instanceof e?(this._master&&this._master.releaseMergeRef(),n.addMergeRef(),this._master=n):this._master.value=n}isMergedTo(n){return n===this._master}get master(){return this._master}get type(){return e.Types.Merge}get effectiveType(){return this._master.effectiveType}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return""}release(){this._master.releaseMergeRef()}toString(){return this.value.toString()}}},{t:e.Types.JSON,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.String,value:JSON.stringify(i),rawValue:i}}get value(){return this.model.rawValue}set value(n){this.model.rawValue=n,this.model.value=JSON.stringify(n)}get type(){return e.Types.String}get effectiveType(){return e.Types.String}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return this.model.value}release(){}toString(){return this.model.value}}},{t:e.Types.SharedString,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.SharedString,value:i}}get value(){return this.model.value}set value(n){this.model.value=n}get type(){return e.Types.SharedString}get effectiveType(){return e.Types.SharedString}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return this.model.value.toString()}release(){}toString(){return this.model.value.toString()}}},{t:e.Types.RichText,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.String,value:i}}get value(){return this.model.value}set value(n){this.model.value=n}toString(){return this.model.value.richText.map(n=>n.text).join("")}get type(){return e.Types.RichText}get effectiveType(){return e.Types.RichText}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return`"${this.text.replace(/"/g,'""')}"`}release(){}}},{t:e.Types.Boolean,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.Boolean,value:i}}get value(){return this.model.value}set value(n){this.model.value=n}get type(){return e.Types.Boolean}get effectiveType(){return e.Types.Boolean}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return this.model.value?1:0}release(){}toString(){return this.model.value.toString()}}},{t:e.Types.Error,f:class{constructor(n,i){this.model={address:n.address,type:e.Types.Error,value:i}}get value(){return this.model.value}set value(n){this.model.value=n}get type(){return e.Types.Error}get effectiveType(){return e.Types.Error}get address(){return this.model.address}set address(n){this.model.address=n}toCsvString(){return this.toString()}release(){}toString(){return this.model.value.error.toString()}}}].reduce((n,i)=>(n[i.t]=i.f,n),[]),create(n,i,f){const c=this.types[n];if(!c)throw new Error("Could not create Value of type "+n);return new c(i,f)}};T.exports=e},{"../utils/col-cache":19,"../utils/shared-formula":23,"../utils/under-dash":26,"./enums":7,"./note":9}],4:[function(s,T,S){const m=s("../utils/under-dash"),a=s("./enums"),o=s("../utils/col-cache");class r{constructor(e,l,n){this._worksheet=e,this._number=l,n!==!1&&(this.defn=n)}get number(){return this._number}get worksheet(){return this._worksheet}get letter(){return o.n2l(this._number)}get isCustomWidth(){return this.width!==void 0&&this.width!==9}get defn(){return{header:this._header,key:this.key,width:this.width,style:this.style,hidden:this.hidden,outlineLevel:this.outlineLevel}}set defn(e){e?(this.key=e.key,this.width=e.width!==void 0?e.width:9,this.outlineLevel=e.outlineLevel,e.style?this.style=e.style:this.style={},this.header=e.header,this._hidden=!!e.hidden):(delete this._header,delete this._key,delete this.width,this.style={},this.outlineLevel=0)}get headers(){return this._header&&this._header instanceof Array?this._header:[this._header]}get header(){return this._header}set header(e){e!==void 0?(this._header=e,this.headers.forEach((l,n)=>{this._worksheet.getCell(n+1,this.number).value=l})):this._header=void 0}get key(){return this._key}set key(e){(this._key&&this._worksheet.getColumnKey(this._key))===this&&this._worksheet.deleteColumnKey(this._key),this._key=e,e&&this._worksheet.setColumnKey(this._key,this)}get hidden(){return!!this._hidden}set hidden(e){this._hidden=e}get outlineLevel(){return this._outlineLevel||0}set outlineLevel(e){this._outlineLevel=e}get collapsed(){return!!(this._outlineLevel&&this._outlineLevel>=this._worksheet.properties.outlineLevelCol)}toString(){return JSON.stringify({key:this.key,width:this.width,headers:this.headers.length?this.headers:void 0})}equivalentTo(e){return this.width===e.width&&this.hidden===e.hidden&&this.outlineLevel===e.outlineLevel&&m.isEqual(this.style,e.style)}get isDefault(){if(this.isCustomWidth||this.hidden||this.outlineLevel)return!1;const e=this.style;return!e||!(e.font||e.numFmt||e.alignment||e.border||e.fill||e.protection)}get headerCount(){return this.headers.length}eachCell(e,l){const n=this.number;l||(l=e,e=null),this._worksheet.eachRow(e,(i,f)=>{l(i.getCell(n),f)})}get values(){const e=[];return this.eachCell((l,n)=>{l&&l.type!==a.ValueType.Null&&(e[n]=l.value)}),e}set values(e){if(!e)return;const l=this.number;let n=0;e.hasOwnProperty("0")&&(n=1),e.forEach((i,f)=>{this._worksheet.getCell(f+n,l).value=i})}_applyStyle(e,l){return this.style[e]=l,this.eachCell(n=>{n[e]=l}),l}get numFmt(){return this.style.numFmt}set numFmt(e){this._applyStyle("numFmt",e)}get font(){return this.style.font}set font(e){this._applyStyle("font",e)}get alignment(){return this.style.alignment}set alignment(e){this._applyStyle("alignment",e)}get protection(){return this.style.protection}set protection(e){this._applyStyle("protection",e)}get border(){return this.style.border}set border(e){this._applyStyle("border",e)}get fill(){return this.style.fill}set fill(e){this._applyStyle("fill",e)}static toModel(e){const l=[];let n=null;return e&&e.forEach((i,f)=>{i.isDefault?n&&(n=null):n&&i.equivalentTo(n)?n.max=f+1:(n={min:f+1,max:f+1,width:i.width!==void 0?i.width:9,style:i.style,isCustomWidth:i.isCustomWidth,hidden:i.hidden,outlineLevel:i.outlineLevel,collapsed:i.collapsed},l.push(n))}),l.length?l:void 0}static fromModel(e,l){const n=[];let i=1,f=0;for(l=(l=l||[]).sort(function(c,u){return c.min-u.min});f<l.length;){const c=l[f++];for(;i<c.min;)n.push(new r(e,i++));for(;i<=c.max;)n.push(new r(e,i++,c))}return n.length?n:null}}T.exports=r},{"../utils/col-cache":19,"../utils/under-dash":26,"./enums":7}],5:[function(s,T,S){T.exports=class{constructor(m){this.model=m||{}}add(m,a){return this.model[m]=a}find(m){return this.model[m]}remove(m){this.model[m]=void 0}}},{}],6:[function(s,T,S){const m=s("../utils/under-dash"),a=s("../utils/col-cache"),o=s("../utils/cell-matrix"),r=s("./range"),t=/[$](\w+)[$](\d+)(:[$](\w+)[$](\d+))?/;T.exports=class{constructor(){this.matrixMap={}}getMatrix(e){return this.matrixMap[e]||(this.matrixMap[e]=new o)}add(e,l){const n=a.decodeEx(e);this.addEx(n,l)}addEx(e,l){const n=this.getMatrix(l);if(e.top)for(let i=e.left;i<=e.right;i++)for(let f=e.top;f<=e.bottom;f++){const c={sheetName:e.sheetName,address:a.n2l(i)+f,row:f,col:i};n.addCellEx(c)}else n.addCellEx(e)}remove(e,l){const n=a.decodeEx(e);this.removeEx(n,l)}removeEx(e,l){this.getMatrix(l).removeCellEx(e)}removeAllNames(e){m.each(this.matrixMap,l=>{l.removeCellEx(e)})}forEach(e){m.each(this.matrixMap,(l,n)=>{l.forEach(i=>{e(n,i)})})}getNames(e){return this.getNamesEx(a.decodeEx(e))}getNamesEx(e){return m.map(this.matrixMap,(l,n)=>l.findCellEx(e)&&n).filter(Boolean)}_explore(e,l){l.mark=!1;const{sheetName:n}=l,i=new r(l.row,l.col,l.row,l.col,n);let f,c;function u(h,w){const _=e.findCellAt(n,h,l.col);return!(!_||!_.mark)&&(i[w]=h,_.mark=!1,!0)}for(c=l.row-1;u(c,"top");c--);for(c=l.row+1;u(c,"bottom");c++);function d(h,w){const _=[];for(c=i.top;c<=i.bottom;c++){const A=e.findCellAt(n,c,h);if(!A||!A.mark)return!1;_.push(A)}i[w]=h;for(let A=0;A<_.length;A++)_[A].mark=!1;return!0}for(f=l.col-1;d(f,"left");f--);for(f=l.col+1;d(f,"right");f++);return i}getRanges(e,l){return(l=l||this.matrixMap[e])?(l.forEach(n=>{n.mark=!0}),{name:e,ranges:l.map(n=>n.mark&&this._explore(l,n)).filter(Boolean).map(n=>n.$shortRange)}):{name:e,ranges:[]}}normaliseMatrix(e,l){e.forEachInSheet(l,(n,i,f)=>{n&&(n.row===i&&n.col===f||(n.row=i,n.col=f,n.address=a.n2l(f)+i))})}spliceRows(e,l,n,i){m.each(this.matrixMap,f=>{f.spliceRows(e,l,n,i),this.normaliseMatrix(f,e)})}spliceColumns(e,l,n,i){m.each(this.matrixMap,f=>{f.spliceColumns(e,l,n,i),this.normaliseMatrix(f,e)})}get model(){return m.map(this.matrixMap,(e,l)=>this.getRanges(l,e)).filter(e=>e.ranges.length)}set model(e){const l=this.matrixMap={};e.forEach(n=>{const i=l[n.name]=new o;n.ranges.forEach(f=>{t.test(f.split("!").pop()||"")&&i.addCell(f)})})}}},{"../utils/cell-matrix":18,"../utils/col-cache":19,"../utils/under-dash":26,"./range":10}],7:[function(s,T,S){T.exports={ValueType:{Null:0,Merge:1,Number:2,String:3,Date:4,Hyperlink:5,Formula:6,SharedString:7,RichText:8,Boolean:9,Error:10},FormulaType:{None:0,Master:1,Shared:2},RelationshipType:{None:0,OfficeDocument:1,Worksheet:2,CalcChain:3,SharedStrings:4,Styles:5,Theme:6,Hyperlink:7},DocumentType:{Xlsx:1},ReadingOrder:{LeftToRight:1,RightToLeft:2},ErrorValue:{NotApplicable:"#N/A",Ref:"#REF!",Name:"#NAME?",DivZero:"#DIV/0!",Null:"#NULL!",Value:"#VALUE!",Num:"#NUM!"}}},{}],8:[function(s,T,S){const m=s("../utils/col-cache"),a=s("./anchor");T.exports=class{constructor(o,r){this.worksheet=o,this.model=r}get model(){switch(this.type){case"background":return{type:this.type,imageId:this.imageId};case"image":return{type:this.type,imageId:this.imageId,hyperlinks:this.range.hyperlinks,range:{tl:this.range.tl.model,br:this.range.br&&this.range.br.model,ext:this.range.ext,editAs:this.range.editAs}};default:throw new Error("Invalid Image Type")}}set model(o){let{type:r,imageId:t,range:e,hyperlinks:l}=o;if(this.type=r,this.imageId=t,r==="image")if(typeof e=="string"){const n=m.decode(e);this.range={tl:new a(this.worksheet,{col:n.left,row:n.top},-1),br:new a(this.worksheet,{col:n.right,row:n.bottom},0),editAs:"oneCell"}}else this.range={tl:new a(this.worksheet,e.tl,0),br:e.br&&new a(this.worksheet,e.br,0),ext:e.ext,editAs:e.editAs,hyperlinks:l||e.hyperlinks}}}},{"../utils/col-cache":19,"./anchor":2}],9:[function(s,T,S){const m=s("../utils/under-dash");class a{constructor(r){this.note=r}get model(){let r=null;switch(typeof this.note){case"string":r={type:"note",note:{texts:[{text:this.note}]}};break;default:r={type:"note",note:this.note}}return m.deepMerge({},a.DEFAULT_CONFIGS,r)}set model(r){const{note:t}=r,{texts:e}=t;e.length===1&&Object.keys(e[0]).length===1?this.note=e[0].text:this.note=t}static fromModel(r){const t=new a;return t.model=r,t}}a.DEFAULT_CONFIGS={note:{margins:{insetmode:"auto",inset:[.13,.13,.25,.25]},protection:{locked:"True",lockText:"True"},editAs:"absolute"}},T.exports=a},{"../utils/under-dash":26}],10:[function(s,T,S){const m=s("../utils/col-cache");class a{constructor(){this.decode(arguments)}setTLBR(r,t,e,l,n){if(arguments.length<4){const i=m.decodeAddress(r),f=m.decodeAddress(t);this.model={top:Math.min(i.row,f.row),left:Math.min(i.col,f.col),bottom:Math.max(i.row,f.row),right:Math.max(i.col,f.col),sheetName:e},this.setTLBR(i.row,i.col,f.row,f.col,n)}else this.model={top:Math.min(r,e),left:Math.min(t,l),bottom:Math.max(r,e),right:Math.max(t,l),sheetName:n}}decode(r){switch(r.length){case 5:this.setTLBR(r[0],r[1],r[2],r[3],r[4]);break;case 4:this.setTLBR(r[0],r[1],r[2],r[3]);break;case 3:this.setTLBR(r[0],r[1],r[2]);break;case 2:this.setTLBR(r[0],r[1]);break;case 1:{const t=r[0];if(t instanceof a)this.model={top:t.model.top,left:t.model.left,bottom:t.model.bottom,right:t.model.right,sheetName:t.sheetName};else if(t instanceof Array)this.decode(t);else if(t.top&&t.left&&t.bottom&&t.right)this.model={top:t.top,left:t.left,bottom:t.bottom,right:t.right,sheetName:t.sheetName};else{const e=m.decodeEx(t);e.top?this.model={top:e.top,left:e.left,bottom:e.bottom,right:e.right,sheetName:e.sheetName}:this.model={top:e.row,left:e.col,bottom:e.row,right:e.col,sheetName:e.sheetName}}break}case 0:this.model={top:0,left:0,bottom:0,right:0};break;default:throw new Error("Invalid number of arguments to _getDimensions() - "+r.length)}}get top(){return this.model.top||1}set top(r){this.model.top=r}get left(){return this.model.left||1}set left(r){this.model.left=r}get bottom(){return this.model.bottom||1}set bottom(r){this.model.bottom=r}get right(){return this.model.right||1}set right(r){this.model.right=r}get sheetName(){return this.model.sheetName}set sheetName(r){this.model.sheetName=r}get _serialisedSheetName(){const{sheetName:r}=this.model;return r?/^[a-zA-Z0-9]*$/.test(r)?r+"!":`'${r}'!`:""}expand(r,t,e,l){(!this.model.top||r<this.top)&&(this.top=r),(!this.model.left||t<this.left)&&(this.left=t),(!this.model.bottom||e>this.bottom)&&(this.bottom=e),(!this.model.right||l>this.right)&&(this.right=l)}expandRow(r){if(r){const{dimensions:t,number:e}=r;t&&this.expand(e,t.min,e,t.max)}}expandToAddress(r){const t=m.decodeEx(r);this.expand(t.row,t.col,t.row,t.col)}get tl(){return m.n2l(this.left)+this.top}get $t$l(){return`$${m.n2l(this.left)}$${this.top}`}get br(){return m.n2l(this.right)+this.bottom}get $b$r(){return`$${m.n2l(this.right)}$${this.bottom}`}get range(){return`${this._serialisedSheetName+this.tl}:${this.br}`}get $range(){return`${this._serialisedSheetName+this.$t$l}:${this.$b$r}`}get shortRange(){return this.count>1?this.range:this._serialisedSheetName+this.tl}get $shortRange(){return this.count>1?this.$range:this._serialisedSheetName+this.$t$l}get count(){return(1+this.bottom-this.top)*(1+this.right-this.left)}toString(){return this.range}intersects(r){return(!r.sheetName||!this.sheetName||r.sheetName===this.sheetName)&&!(r.bottom<this.top)&&!(r.top>this.bottom)&&!(r.right<this.left)&&!(r.left>this.right)}contains(r){const t=m.decodeEx(r);return this.containsEx(t)}containsEx(r){return(!r.sheetName||!this.sheetName||r.sheetName===this.sheetName)&&r.row>=this.top&&r.row<=this.bottom&&r.col>=this.left&&r.col<=this.right}forEachAddress(r){for(let t=this.left;t<=this.right;t++)for(let e=this.top;e<=this.bottom;e++)r(m.encodeAddress(e,t),e,t)}}T.exports=a},{"../utils/col-cache":19}],11:[function(s,T,S){const m=s("../utils/under-dash"),a=s("./enums"),o=s("../utils/col-cache"),r=s("./cell");T.exports=class{constructor(t,e){this._worksheet=t,this._number=e,this._cells=[],this.style={},this.outlineLevel=0}get number(){return this._number}get worksheet(){return this._worksheet}commit(){this._worksheet._commitRow(this)}destroy(){delete this._worksheet,delete this._cells,delete this.style}findCell(t){return this._cells[t-1]}getCellEx(t){let e=this._cells[t.col-1];if(!e){const l=this._worksheet.getColumn(t.col);e=new r(this,l,t.address),this._cells[t.col-1]=e}return e}getCell(t){if(typeof t=="string"){const e=this._worksheet.getColumnKey(t);t=e?e.number:o.l2n(t)}return this._cells[t-1]||this.getCellEx({address:o.encodeAddress(this._number,t),row:this._number,col:t})}splice(t,e){const l=t+e;for(var n=arguments.length,i=new Array(n>2?n-2:0),f=2;f<n;f++)i[f-2]=arguments[f];const c=i.length-e,u=this._cells.length;let d,h,w;if(c<0)for(d=t+i.length;d<=u;d++)w=this._cells[d-1],h=this._cells[d-c-1],h?(w=this.getCell(d),w.value=h.value,w.style=h.style,w._comment=h._comment):w&&(w.value=null,w.style={},w._comment=void 0);else if(c>0)for(d=u;d>=l;d--)h=this._cells[d-1],h?(w=this.getCell(d+c),w.value=h.value,w.style=h.style,w._comment=h._comment):this._cells[d+c-1]=void 0;for(d=0;d<i.length;d++)w=this.getCell(t+d),w.value=i[d],w.style={},w._comment=void 0}eachCell(t,e){if(e||(e=t,t=null),t&&t.includeEmpty){const l=this._cells.length;for(let n=1;n<=l;n++)e(this.getCell(n),n)}else this._cells.forEach((l,n)=>{l&&l.type!==a.ValueType.Null&&e(l,n+1)})}addPageBreak(t,e){const l=this._worksheet,n=Math.max(0,t-1)||0,i=Math.max(0,e-1)||16838,f={id:this._number,max:i,man:1};n&&(f.min=n),l.rowBreaks.push(f)}get values(){const t=[];return this._cells.forEach(e=>{e&&e.type!==a.ValueType.Null&&(t[e.col]=e.value)}),t}set values(t){if(this._cells=[],t)if(t instanceof Array){let e=0;t.hasOwnProperty("0")&&(e=1),t.forEach((l,n)=>{l!==void 0&&(this.getCellEx({address:o.encodeAddress(this._number,n+e),row:this._number,col:n+e}).value=l)})}else this._worksheet.eachColumnKey((e,l)=>{t[l]!==void 0&&(this.getCellEx({address:o.encodeAddress(this._number,e.number),row:this._number,col:e.number}).value=t[l])})}get hasValues(){return m.some(this._cells,t=>t&&t.type!==a.ValueType.Null)}get cellCount(){return this._cells.length}get actualCellCount(){let t=0;return this.eachCell(()=>{t++}),t}get dimensions(){let t=0,e=0;return this._cells.forEach(l=>{l&&l.type!==a.ValueType.Null&&((!t||t>l.col)&&(t=l.col),e<l.col&&(e=l.col))}),t>0?{min:t,max:e}:null}_applyStyle(t,e){return this.style[t]=e,this._cells.forEach(l=>{l&&(l[t]=e)}),e}get numFmt(){return this.style.numFmt}set numFmt(t){this._applyStyle("numFmt",t)}get font(){return this.style.font}set font(t){this._applyStyle("font",t)}get alignment(){return this.style.alignment}set alignment(t){this._applyStyle("alignment",t)}get protection(){return this.style.protection}set protection(t){this._applyStyle("protection",t)}get border(){return this.style.border}set border(t){this._applyStyle("border",t)}get fill(){return this.style.fill}set fill(t){this._applyStyle("fill",t)}get hidden(){return!!this._hidden}set hidden(t){this._hidden=t}get outlineLevel(){return this._outlineLevel||0}set outlineLevel(t){this._outlineLevel=t}get collapsed(){return!!(this._outlineLevel&&this._outlineLevel>=this._worksheet.properties.outlineLevelRow)}get model(){const t=[];let e=0,l=0;return this._cells.forEach(n=>{if(n){const i=n.model;i&&((!e||e>n.col)&&(e=n.col),l<n.col&&(l=n.col),t.push(i))}}),this.height||t.length?{cells:t,number:this.number,min:e,max:l,height:this.height,style:this.style,hidden:this.hidden,outlineLevel:this.outlineLevel,collapsed:this.collapsed}:null}set model(t){if(t.number!==this._number)throw new Error("Invalid row number in model");let e;this._cells=[],t.cells.forEach(l=>{switch(l.type){case r.Types.Merge:break;default:{let n;if(l.address)n=o.decodeAddress(l.address);else if(e){const{row:i}=e,f=e.col+1;n={row:i,col:f,address:o.encodeAddress(i,f),$col$row:`$${o.n2l(f)}$${i}`}}e=n,this.getCellEx(n).model=l;break}}}),t.height?this.height=t.height:delete this.height,this.hidden=t.hidden,this.outlineLevel=t.outlineLevel||0,this.style=t.style&&JSON.parse(JSON.stringify(t.style))||{}}}},{"../utils/col-cache":19,"../utils/under-dash":26,"./cell":3,"./enums":7}],12:[function(s,T,S){const m=s("../utils/col-cache");class a{constructor(r,t,e){this.table=r,this.column=t,this.index=e}_set(r,t){this.table.cacheState(),this.column[r]=t}get name(){return this.column.name}set name(r){this._set("name",r)}get filterButton(){return this.column.filterButton}set filterButton(r){this.column.filterButton=r}get style(){return this.column.style}set style(r){this.column.style=r}get totalsRowLabel(){return this.column.totalsRowLabel}set totalsRowLabel(r){this._set("totalsRowLabel",r)}get totalsRowFunction(){return this.column.totalsRowFunction}set totalsRowFunction(r){this._set("totalsRowFunction",r)}get totalsRowResult(){return this.column.totalsRowResult}set totalsRowResult(r){this._set("totalsRowResult",r)}get totalsRowFormula(){return this.column.totalsRowFormula}set totalsRowFormula(r){this._set("totalsRowFormula",r)}}T.exports=class{constructor(o,r){this.worksheet=o,r&&(this.table=r,this.validate(),this.store())}getFormula(o){switch(o.totalsRowFunction){case"none":return null;case"average":return`SUBTOTAL(101,${this.table.name}[${o.name}])`;case"countNums":return`SUBTOTAL(102,${this.table.name}[${o.name}])`;case"count":return`SUBTOTAL(103,${this.table.name}[${o.name}])`;case"max":return`SUBTOTAL(104,${this.table.name}[${o.name}])`;case"min":return`SUBTOTAL(105,${this.table.name}[${o.name}])`;case"stdDev":return`SUBTOTAL(106,${this.table.name}[${o.name}])`;case"var":return`SUBTOTAL(107,${this.table.name}[${o.name}])`;case"sum":return`SUBTOTAL(109,${this.table.name}[${o.name}])`;case"custom":return o.totalsRowFormula;default:throw new Error("Invalid Totals Row Function: "+o.totalsRowFunction)}}get width(){return this.table.columns.length}get height(){return this.table.rows.length}get filterHeight(){return this.height+(this.table.headerRow?1:0)}get tableHeight(){return this.filterHeight+(this.table.totalsRow?1:0)}validate(){const{table:o}=this,r=(c,u,d)=>{c[u]===void 0&&(c[u]=d)};r(o,"headerRow",!0),r(o,"totalsRow",!1),r(o,"style",{}),r(o.style,"theme","TableStyleMedium2"),r(o.style,"showFirstColumn",!1),r(o.style,"showLastColumn",!1),r(o.style,"showRowStripes",!1),r(o.style,"showColumnStripes",!1);const t=(c,u)=>{if(!c)throw new Error(u)};t(o.ref,"Table must have ref"),t(o.columns,"Table must have column definitions"),t(o.rows,"Table must have row definitions"),o.tl=m.decodeAddress(o.ref);const{row:e,col:l}=o.tl;t(e>0,"Table must be on valid row"),t(l>0,"Table must be on valid col");const{width:n,filterHeight:i,tableHeight:f}=this;o.autoFilterRef=m.encode(e,l,e+i-1,l+n-1),o.tableRef=m.encode(e,l,e+f-1,l+n-1),o.columns.forEach((c,u)=>{t(c.name,`Column ${u} must have a name`),u===0?r(c,"totalsRowLabel","Total"):(r(c,"totalsRowFunction","none"),c.totalsRowFormula=this.getFormula(c))})}store(){const o=(i,f)=>{f&&Object.keys(f).forEach(c=>{i[c]=f[c]})},{worksheet:r,table:t}=this,{row:e,col:l}=t.tl;let n=0;if(t.headerRow){const i=r.getRow(e+n++);t.columns.forEach((f,c)=>{const{style:u,name:d}=f,h=i.getCell(l+c);h.value=d,o(h,u)})}if(t.rows.forEach(i=>{const f=r.getRow(e+n++);i.forEach((c,u)=>{const d=f.getCell(l+u);d.value=c,o(d,t.columns[u].style)})}),t.totalsRow){const i=r.getRow(e+n++);t.columns.forEach((f,c)=>{const u=i.getCell(l+c);if(c===0)u.value=f.totalsRowLabel;else{const d=this.getFormula(f);u.value=d?{formula:f.totalsRowFormula,result:f.totalsRowResult}:null}o(u,f.style)})}}load(o){const{table:r}=this,{row:t,col:e}=r.tl;let l=0;if(r.headerRow){const n=o.getRow(t+l++);r.columns.forEach((i,f)=>{n.getCell(e+f).value=i.name})}if(r.rows.forEach(n=>{const i=o.getRow(t+l++);n.forEach((f,c)=>{i.getCell(e+c).value=f})}),r.totalsRow){const n=o.getRow(t+l++);r.columns.forEach((i,f)=>{const c=n.getCell(e+f);f===0?c.value=i.totalsRowLabel:this.getFormula(i)&&(c.value={formula:i.totalsRowFormula,result:i.totalsRowResult})})}}get model(){return this.table}set model(o){this.table=o}cacheState(){this._cache||(this._cache={ref:this.ref,width:this.width,tableHeight:this.tableHeight})}commit(){if(!this._cache)return;this.validate();const o=m.decodeAddress(this._cache.ref);if(this.ref!==this._cache.ref)for(let r=0;r<this._cache.tableHeight;r++){const t=this.worksheet.getRow(o.row+r);for(let e=0;e<this._cache.width;e++)t.getCell(o.col+e).value=null}else{for(let r=this.tableHeight;r<this._cache.tableHeight;r++){const t=this.worksheet.getRow(o.row+r);for(let e=0;e<this._cache.width;e++)t.getCell(o.col+e).value=null}for(let r=0;r<this.tableHeight;r++){const t=this.worksheet.getRow(o.row+r);for(let e=this.width;e<this._cache.width;e++)t.getCell(o.col+e).value=null}}this.store()}addRow(o,r){this.cacheState(),r===void 0?this.table.rows.push(o):this.table.rows.splice(r,0,o)}removeRows(o){let r=arguments.length>1&&arguments[1]!==void 0?arguments[1]:1;this.cacheState(),this.table.rows.splice(o,r)}getColumn(o){const r=this.table.columns[o];return new a(this,r,o)}addColumn(o,r,t){this.cacheState(),t===void 0?(this.table.columns.push(o),this.table.rows.forEach((e,l)=>{e.push(r[l])})):(this.table.columns.splice(t,0,o),this.table.rows.forEach((e,l)=>{e.splice(t,0,r[l])}))}removeColumns(o){let r=arguments.length>1&&arguments[1]!==void 0?arguments[1]:1;this.cacheState(),this.table.columns.splice(o,r),this.table.rows.forEach(t=>{t.splice(o,r)})}_assign(o,r,t){this.cacheState(),o[r]=t}get ref(){return this.table.ref}set ref(o){this._assign(this.table,"ref",o)}get name(){return this.table.name}set name(o){this.table.name=o}get displayName(){return this.table.displyName||this.table.name}set displayNamename(o){this.table.displayName=o}get headerRow(){return this.table.headerRow}set headerRow(o){this._assign(this.table,"headerRow",o)}get totalsRow(){return this.table.totalsRow}set totalsRow(o){this._assign(this.table,"totalsRow",o)}get theme(){return this.table.style.name}set theme(o){this.table.style.name=o}get showFirstColumn(){return this.table.style.showFirstColumn}set showFirstColumn(o){this.table.style.showFirstColumn=o}get showLastColumn(){return this.table.style.showLastColumn}set showLastColumn(o){this.table.style.showLastColumn=o}get showRowStripes(){return this.table.style.showRowStripes}set showRowStripes(o){this.table.style.showRowStripes=o}get showColumnStripes(){return this.table.style.showColumnStripes}set showColumnStripes(o){this.table.style.showColumnStripes=o}}},{"../utils/col-cache":19}],13:[function(s,T,S){const m=s("./worksheet"),a=s("./defined-names"),o=s("../xlsx/xlsx"),r=s("../csv/csv");T.exports=class{constructor(){this.category="",this.company="",this.created=new Date,this.description="",this.keywords="",this.manager="",this.modified=this.created,this.properties={},this.calcProperties={},this._worksheets=[],this.subject="",this.title="",this.views=[],this.media=[],this._definedNames=new a}get xlsx(){return this._xlsx||(this._xlsx=new o(this)),this._xlsx}get csv(){return this._csv||(this._csv=new r(this)),this._csv}get nextId(){for(let t=1;t<this._worksheets.length;t++)if(!this._worksheets[t])return t;return this._worksheets.length||1}addWorksheet(t,e){const l=this.nextId;e&&(typeof e=="string"?(console.trace('tabColor argument is now deprecated. Please use workbook.addWorksheet(name, {properties: { tabColor: { argb: "rbg value" } }'),e={properties:{tabColor:{argb:e}}}):(e.argb||e.theme||e.indexed)&&(console.trace("tabColor argument is now deprecated. Please use workbook.addWorksheet(name, {properties: { tabColor: { ... } }"),e={properties:{tabColor:e}}));const n=this._worksheets.reduce((c,u)=>(u&&u.orderNo)>c?u.orderNo:c,0),i=Object.assign({},e,{id:l,name:t,orderNo:n+1,workbook:this}),f=new m(i);return this._worksheets[l]=f,f}removeWorksheetEx(t){delete this._worksheets[t.id]}removeWorksheet(t){const e=this.getWorksheet(t);e&&e.destroy()}getWorksheet(t){return t===void 0?this._worksheets.find(Boolean):typeof t=="number"?this._worksheets[t]:typeof t=="string"?this._worksheets.find(e=>e&&e.name===t):void 0}get worksheets(){return this._worksheets.slice(1).sort((t,e)=>t.orderNo-e.orderNo).filter(Boolean)}eachSheet(t){this.worksheets.forEach(e=>{t(e,e.id)})}get definedNames(){return this._definedNames}clearThemes(){this._themes=void 0}addImage(t){const e=this.media.length;return this.media.push(Object.assign({},t,{type:"image"})),e}getImage(t){return this.media[t]}get model(){return{creator:this.creator||"Unknown",lastModifiedBy:this.lastModifiedBy||"Unknown",lastPrinted:this.lastPrinted,created:this.created,modified:this.modified,properties:this.properties,worksheets:this.worksheets.map(t=>t.model),sheets:this.worksheets.map(t=>t.model).filter(Boolean),definedNames:this._definedNames.model,views:this.views,company:this.company,manager:this.manager,title:this.title,subject:this.subject,keywords:this.keywords,category:this.category,description:this.description,language:this.language,revision:this.revision,contentStatus:this.contentStatus,themes:this._themes,media:this.media,calcProperties:this.calcProperties}}set model(t){this.creator=t.creator,this.lastModifiedBy=t.lastModifiedBy,this.lastPrinted=t.lastPrinted,this.created=t.created,this.modified=t.modified,this.company=t.company,this.manager=t.manager,this.title=t.title,this.subject=t.subject,this.keywords=t.keywords,this.category=t.category,this.description=t.description,this.language=t.language,this.revision=t.revision,this.contentStatus=t.contentStatus,this.properties=t.properties,this.calcProperties=t.calcProperties,this._worksheets=[],t.worksheets.forEach(e=>{const{id:l,name:n,state:i}=e,f=t.sheets&&t.sheets.findIndex(c=>c.id===l);(this._worksheets[l]=new m({id:l,name:n,orderNo:f,state:i,workbook:this})).model=e}),this._definedNames.model=t.definedNames,this.views=t.views,this._themes=t.themes,this.media=t.media||[]}}},{"../csv/csv":1,"../xlsx/xlsx":144,"./defined-names":6,"./worksheet":14}],14:[function(s,T,S){const m=s("../utils/under-dash"),a=s("../utils/col-cache"),o=s("./range"),r=s("./row"),t=s("./column"),e=s("./enums"),l=s("./image"),n=s("./table"),i=s("./data-validations"),f=s("../utils/encryptor"),{copyStyle:c}=s("../utils/copy-style");T.exports=class{constructor(u){u=u||{},this._workbook=u.workbook,this.id=u.id,this.orderNo=u.orderNo,this.name=u.name,this.state=u.state||"visible",this._rows=[],this._columns=null,this._keys={},this._merges={},this.rowBreaks=[],this.properties=Object.assign({},{defaultRowHeight:15,dyDescent:55,outlineLevelCol:0,outlineLevelRow:0},u.properties),this.pageSetup=Object.assign({},{margins:{left:.7,right:.7,top:.75,bottom:.75,header:.3,footer:.3},orientation:"portrait",horizontalDpi:4294967295,verticalDpi:4294967295,fitToPage:!(!u.pageSetup||!u.pageSetup.fitToWidth&&!u.pageSetup.fitToHeight||u.pageSetup.scale),pageOrder:"downThenOver",blackAndWhite:!1,draft:!1,cellComments:"None",errors:"displayed",scale:100,fitToWidth:1,fitToHeight:1,paperSize:void 0,showRowColHeaders:!1,showGridLines:!1,firstPageNumber:void 0,horizontalCentered:!1,verticalCentered:!1,rowBreaks:null,colBreaks:null},u.pageSetup),this.headerFooter=Object.assign({},{differentFirst:!1,differentOddEven:!1,oddHeader:null,oddFooter:null,evenHeader:null,evenFooter:null,firstHeader:null,firstFooter:null},u.headerFooter),this.dataValidations=new i,this.views=u.views||[],this.autoFilter=u.autoFilter||null,this._media=[],this.sheetProtection=null,this.tables={},this.conditionalFormattings=[]}get name(){return this._name}set name(u){if(u===void 0&&(u="sheet"+this.id),this._name!==u){if(typeof u!="string")throw new Error("The name has to be a string.");if(u==="")throw new Error("The name can't be empty.");if(u==="History")throw new Error('The name "History" is protected. Please use a different name.');if(/[*?:/\\[\]]/.test(u))throw new Error(`Worksheet name ${u} cannot include any of the following characters: * ? : \\ / [ ]`);if(/(^')|('$)/.test(u))throw new Error("The first or last character of worksheet name cannot be a single quotation mark: "+u);if(u&&u.length>31&&(console.warn(`Worksheet name ${u} exceeds 31 chars. This will be truncated`),u=u.substring(0,31)),this._workbook._worksheets.find(d=>d&&d.name.toLowerCase()===u.toLowerCase()))throw new Error("Worksheet name already exists: "+u);this._name=u}}get workbook(){return this._workbook}destroy(){this._workbook.removeWorksheetEx(this)}get dimensions(){const u=new o;return this._rows.forEach(d=>{if(d){const h=d.dimensions;h&&u.expand(d.number,h.min,d.number,h.max)}}),u}get columns(){return this._columns}set columns(u){this._headerRowCount=u.reduce((w,_)=>{const A=(_.header?1:_.headers&&_.headers.length)||0;return Math.max(w,A)},0);let d=1;const h=this._columns=[];u.forEach(w=>{const _=new t(this,d++,!1);h.push(_),_.defn=w})}getColumnKey(u){return this._keys[u]}setColumnKey(u,d){this._keys[u]=d}deleteColumnKey(u){delete this._keys[u]}eachColumnKey(u){m.each(this._keys,u)}getColumn(u){if(typeof u=="string"){const d=this._keys[u];if(d)return d;u=a.l2n(u)}if(this._columns||(this._columns=[]),u>this._columns.length){let d=this._columns.length+1;for(;d<=u;)this._columns.push(new t(this,d++))}return this._columns[u-1]}spliceColumns(u,d){const h=this._rows.length;for(var w=arguments.length,_=new Array(w>2?w-2:0),A=2;A<w;A++)_[A-2]=arguments[A];if(_.length>0)for(let P=0;P<h;P++){const B=[u,d];_.forEach(D=>{B.push(D[P]||null)});const U=this.getRow(P+1);U.splice.apply(U,B)}else this._rows.forEach(P=>{P&&P.splice(u,d)});const N=_.length-d,L=u+d,I=this._columns.length;if(N<0)for(let P=u+_.length;P<=I;P++)this.getColumn(P).defn=this.getColumn(P-N).defn;else if(N>0)for(let P=I;P>=L;P--)this.getColumn(P+N).defn=this.getColumn(P).defn;for(let P=u;P<u+_.length;P++)this.getColumn(P).defn=null;this.workbook.definedNames.spliceColumns(this.name,u,d,_.length)}get lastColumn(){return this.getColumn(this.columnCount)}get columnCount(){let u=0;return this.eachRow(d=>{u=Math.max(u,d.cellCount)}),u}get actualColumnCount(){const u=[];let d=0;return this.eachRow(h=>{h.eachCell(w=>{let{col:_}=w;u[_]||(u[_]=!0,d++)})}),d}_commitRow(){}get _lastRowNumber(){const u=this._rows;let d=u.length;for(;d>0&&u[d-1]===void 0;)d--;return d}get _nextRow(){return this._lastRowNumber+1}get lastRow(){if(this._rows.length)return this._rows[this._rows.length-1]}findRow(u){return this._rows[u-1]}findRows(u,d){return this._rows.slice(u-1,u-1+d)}get rowCount(){return this._lastRowNumber}get actualRowCount(){let u=0;return this.eachRow(()=>{u++}),u}getRow(u){let d=this._rows[u-1];return d||(d=this._rows[u-1]=new r(this,u)),d}getRows(u,d){if(d<1)return;const h=[];for(let w=u;w<u+d;w++)h.push(this.getRow(w));return h}addRow(u){let d=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"n";const h=this._nextRow,w=this.getRow(h);return w.values=u,this._setStyleOption(h,d[0]==="i"?d:"n"),w}addRows(u){let d=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"n";const h=[];return u.forEach(w=>{h.push(this.addRow(w,d))}),h}insertRow(u,d){let h=arguments.length>2&&arguments[2]!==void 0?arguments[2]:"n";return this.spliceRows(u,0,d),this._setStyleOption(u,h),this.getRow(u)}insertRows(u,d){let h=arguments.length>2&&arguments[2]!==void 0?arguments[2]:"n";if(this.spliceRows(u,0,...d),h!=="n")for(let w=0;w<d.length;w++)h[0]==="o"&&this.findRow(d.length+u+w)!==void 0?this._copyStyle(d.length+u+w,u+w,h[1]==="+"):h[0]==="i"&&this.findRow(u-1)!==void 0&&this._copyStyle(u-1,u+w,h[1]==="+");return this.getRows(u,d.length)}_setStyleOption(u){let d=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"n";d[0]==="o"&&this.findRow(u+1)!==void 0?this._copyStyle(u+1,u,d[1]==="+"):d[0]==="i"&&this.findRow(u-1)!==void 0&&this._copyStyle(u-1,u,d[1]==="+")}_copyStyle(u,d){let h=arguments.length>2&&arguments[2]!==void 0&&arguments[2];const w=this.getRow(u),_=this.getRow(d);_.style=c(w.style),w.eachCell({includeEmpty:h},(A,N)=>{_.getCell(N).style=c(A.style)}),_.height=w.height}duplicateRow(u,d){let h=arguments.length>2&&arguments[2]!==void 0&&arguments[2];const w=this._rows[u-1],_=new Array(d).fill(w.values);this.spliceRows(u+1,h?0:d,..._);for(let A=0;A<d;A++){const N=this._rows[u+A];N.style=w.style,N.height=w.height,w.eachCell({includeEmpty:!0},(L,I)=>{N.getCell(I).style=L.style})}}spliceRows(u,d){const h=u+d;for(var w=arguments.length,_=new Array(w>2?w-2:0),A=2;A<w;A++)_[A-2]=arguments[A];const N=_.length,L=N-d,I=this._rows.length;let P,B;if(L<0)for(u===I&&(this._rows[I-1]=void 0),P=h;P<=I;P++)if(B=this._rows[P-1],B){const U=this.getRow(P+L);U.values=B.values,U.style=B.style,U.height=B.height,B.eachCell({includeEmpty:!0},(D,x)=>{U.getCell(x).style=D.style}),this._rows[P-1]=void 0}else this._rows[P+L-1]=void 0;else if(L>0)for(P=I;P>=h;P--)if(B=this._rows[P-1],B){const U=this.getRow(P+L);U.values=B.values,U.style=B.style,U.height=B.height,B.eachCell({includeEmpty:!0},(D,x)=>{if(U.getCell(x).style=D.style,D._value.constructor.name==="MergeValue"){const M=this.getRow(D._row._number+N).getCell(x),v=D._value._master,p=this.getRow(v._row._number+N).getCell(v._column._number);M.merge(p)}})}else this._rows[P+L-1]=void 0;for(P=0;P<N;P++){const U=this.getRow(u+P);U.style={},U.values=_[P]}this.workbook.definedNames.spliceRows(this.name,u,d,N)}eachRow(u,d){if(d||(d=u,u=void 0),u&&u.includeEmpty){const h=this._rows.length;for(let w=1;w<=h;w++)d(this.getRow(w),w)}else this._rows.forEach(h=>{h&&h.hasValues&&d(h,h.number)})}getSheetValues(){const u=[];return this._rows.forEach(d=>{d&&(u[d.number]=d.values)}),u}findCell(u,d){const h=a.getAddress(u,d),w=this._rows[h.row-1];return w?w.findCell(h.col):void 0}getCell(u,d){const h=a.getAddress(u,d);return this.getRow(h.row).getCellEx(h)}mergeCells(){for(var u=arguments.length,d=new Array(u),h=0;h<u;h++)d[h]=arguments[h];const w=new o(d);this._mergeCellsInternal(w)}mergeCellsWithoutStyle(){for(var u=arguments.length,d=new Array(u),h=0;h<u;h++)d[h]=arguments[h];const w=new o(d);this._mergeCellsInternal(w,!0)}_mergeCellsInternal(u,d){m.each(this._merges,w=>{if(w.intersects(u))throw new Error("Cannot merge already merged cells")});const h=this.getCell(u.top,u.left);for(let w=u.top;w<=u.bottom;w++)for(let _=u.left;_<=u.right;_++)(w>u.top||_>u.left)&&this.getCell(w,_).merge(h,d);this._merges[h.address]=u}_unMergeMaster(u){const d=this._merges[u.address];if(d){for(let h=d.top;h<=d.bottom;h++)for(let w=d.left;w<=d.right;w++)this.getCell(h,w).unmerge();delete this._merges[u.address]}}get hasMerges(){return m.some(this._merges,Boolean)}unMergeCells(){for(var u=arguments.length,d=new Array(u),h=0;h<u;h++)d[h]=arguments[h];const w=new o(d);for(let _=w.top;_<=w.bottom;_++)for(let A=w.left;A<=w.right;A++){const N=this.findCell(_,A);N&&(N.type===e.ValueType.Merge?this._unMergeMaster(N.master):this._merges[N.address]&&this._unMergeMaster(N))}}fillFormula(u,d,h){let w=arguments.length>3&&arguments[3]!==void 0?arguments[3]:"shared";const _=a.decode(u),{top:A,left:N,bottom:L,right:I}=_,P=I-N+1,B=a.encodeAddress(A,N),U=w==="shared";let D;D=typeof h=="function"?h:Array.isArray(h)?Array.isArray(h[0])?(M,v)=>h[M-A][v-N]:(M,v)=>h[(M-A)*P+(v-N)]:()=>{};let x=!0;for(let M=A;M<=L;M++)for(let v=N;v<=I;v++)x?(this.getCell(M,v).value={shareType:w,formula:d,ref:u,result:D(M,v)},x=!1):this.getCell(M,v).value=U?{sharedFormula:B,result:D(M,v)}:D(M,v)}addImage(u,d){const h={type:"image",imageId:u,range:d};this._media.push(new l(this,h))}getImages(){return this._media.filter(u=>u.type==="image")}addBackgroundImage(u){const d={type:"background",imageId:u};this._media.push(new l(this,d))}getBackgroundImageId(){const u=this._media.find(d=>d.type==="background");return u&&u.imageId}protect(u,d){return new Promise(h=>{this.sheetProtection={sheet:!0},d&&"spinCount"in d&&(d.spinCount=Number.isFinite(d.spinCount)?Math.round(Math.max(0,d.spinCount)):1e5),u&&(this.sheetProtection.algorithmName="SHA-512",this.sheetProtection.saltValue=f.randomBytes(16).toString("base64"),this.sheetProtection.spinCount=d&&"spinCount"in d?d.spinCount:1e5,this.sheetProtection.hashValue=f.convertPasswordToHash(u,"SHA512",this.sheetProtection.saltValue,this.sheetProtection.spinCount)),d&&(this.sheetProtection=Object.assign(this.sheetProtection,d),!u&&"spinCount"in d&&delete this.sheetProtection.spinCount),h()})}unprotect(){this.sheetProtection=null}addTable(u){const d=new n(this,u);return this.tables[u.name]=d,d}getTable(u){return this.tables[u]}removeTable(u){delete this.tables[u]}getTables(){return Object.values(this.tables)}addConditionalFormatting(u){this.conditionalFormattings.push(u)}removeConditionalFormatting(u){typeof u=="number"?this.conditionalFormattings.splice(u,1):this.conditionalFormattings=u instanceof Function?this.conditionalFormattings.filter(u):[]}get tabColor(){return console.trace("worksheet.tabColor property is now deprecated. Please use worksheet.properties.tabColor"),this.properties.tabColor}set tabColor(u){console.trace("worksheet.tabColor property is now deprecated. Please use worksheet.properties.tabColor"),this.properties.tabColor=u}get model(){const u={id:this.id,name:this.name,dataValidations:this.dataValidations.model,properties:this.properties,state:this.state,pageSetup:this.pageSetup,headerFooter:this.headerFooter,rowBreaks:this.rowBreaks,views:this.views,autoFilter:this.autoFilter,media:this._media.map(w=>w.model),sheetProtection:this.sheetProtection,tables:Object.values(this.tables).map(w=>w.model),conditionalFormattings:this.conditionalFormattings};u.cols=t.toModel(this.columns);const d=u.rows=[],h=u.dimensions=new o;return this._rows.forEach(w=>{const _=w&&w.model;_&&(h.expand(_.number,_.min,_.number,_.max),d.push(_))}),u.merges=[],m.each(this._merges,w=>{u.merges.push(w.range)}),u}_parseRows(u){this._rows=[],u.rows.forEach(d=>{const h=new r(this,d.number);this._rows[h.number-1]=h,h.model=d})}_parseMergeCells(u){m.each(u.mergeCells,d=>{this.mergeCellsWithoutStyle(d)})}set model(u){this.name=u.name,this._columns=t.fromModel(this,u.cols),this._parseRows(u),this._parseMergeCells(u),this.dataValidations=new i(u.dataValidations),this.properties=u.properties,this.pageSetup=u.pageSetup,this.headerFooter=u.headerFooter,this.views=u.views,this.autoFilter=u.autoFilter,this._media=u.media.map(d=>new l(this,d)),this.sheetProtection=u.sheetProtection,this.tables=u.tables.reduce((d,h)=>{const w=new n;return w.model=h,d[h.name]=w,d},{}),this.conditionalFormattings=u.conditionalFormattings}}},{"../utils/col-cache":19,"../utils/copy-style":20,"../utils/encryptor":21,"../utils/under-dash":26,"./column":4,"./data-validations":5,"./enums":7,"./image":8,"./range":10,"./row":11,"./table":12}],15:[function(s,T,S){s("core-js/modules/es.promise"),s("core-js/modules/es.promise.finally"),s("core-js/modules/es.object.assign"),s("core-js/modules/es.object.keys"),s("core-js/modules/es.object.values"),s("core-js/modules/es.symbol"),s("core-js/modules/es.symbol.async-iterator"),s("core-js/modules/es.array.iterator"),s("core-js/modules/es.array.includes"),s("core-js/modules/es.array.find-index"),s("core-js/modules/es.array.find"),s("core-js/modules/es.string.from-code-point"),s("core-js/modules/es.string.includes"),s("core-js/modules/es.number.is-nan"),s("regenerator-runtime/runtime");const m={Workbook:s("./doc/workbook")},a=s("./doc/enums");Object.keys(a).forEach(o=>{m[o]=a[o]}),T.exports=m},{"./doc/enums":7,"./doc/workbook":13,"core-js/modules/es.array.find":359,"core-js/modules/es.array.find-index":358,"core-js/modules/es.array.includes":360,"core-js/modules/es.array.iterator":361,"core-js/modules/es.number.is-nan":363,"core-js/modules/es.object.assign":364,"core-js/modules/es.object.keys":366,"core-js/modules/es.object.values":367,"core-js/modules/es.promise":372,"core-js/modules/es.promise.finally":371,"core-js/modules/es.string.from-code-point":376,"core-js/modules/es.string.includes":377,"core-js/modules/es.symbol":381,"core-js/modules/es.symbol.async-iterator":378,"regenerator-runtime/runtime":492}],16:[function(s,T,S){const m=typeof TextDecoder>"u"?null:new TextDecoder("utf-8");S.bufferToString=function(a){return typeof a=="string"?a:m?m.decode(a):a.toString()}},{}],17:[function(s,T,S){const m=typeof TextEncoder>"u"?null:new TextEncoder("utf-8"),{Buffer:a}=s("buffer");S.stringToBuffer=function(o){return typeof o!="string"?o:m?a.from(m.encode(o).buffer):a.from(o)}},{buffer:220}],18:[function(s,T,S){const m=s("./under-dash"),a=s("./col-cache");T.exports=class{constructor(o){this.template=o,this.sheets={}}addCell(o){this.addCellEx(a.decodeEx(o))}getCell(o){return this.findCellEx(a.decodeEx(o),!0)}findCell(o){return this.findCellEx(a.decodeEx(o),!1)}findCellAt(o,r,t){const e=this.sheets[o],l=e&&e[r];return l&&l[t]}addCellEx(o){if(o.top)for(let r=o.top;r<=o.bottom;r++)for(let t=o.left;t<=o.right;t++)this.getCellAt(o.sheetName,r,t);else this.findCellEx(o,!0)}getCellEx(o){return this.findCellEx(o,!0)}findCellEx(o,r){const t=this.findSheet(o,r),e=this.findSheetRow(t,o,r);return this.findRowCell(e,o,r)}getCellAt(o,r,t){const e=this.sheets[o]||(this.sheets[o]=[]),l=e[r]||(e[r]=[]);return l[t]||(l[t]={sheetName:o,address:a.n2l(t)+r,row:r,col:t})}removeCellEx(o){const r=this.findSheet(o);if(!r)return;const t=this.findSheetRow(r,o);t&&delete t[o.col]}forEachInSheet(o,r){const t=this.sheets[o];t&&t.forEach((e,l)=>{e&&e.forEach((n,i)=>{n&&r(n,l,i)})})}forEach(o){m.each(this.sheets,(r,t)=>{this.forEachInSheet(t,o)})}map(o){const r=[];return this.forEach(t=>{r.push(o(t))}),r}findSheet(o,r){const t=o.sheetName;return this.sheets[t]?this.sheets[t]:r?this.sheets[t]=[]:void 0}findSheetRow(o,r,t){const{row:e}=r;return o&&o[e]?o[e]:t?o[e]=[]:void 0}findRowCell(o,r,t){const{col:e}=r;return o&&o[e]?o[e]:t?o[e]=this.template?Object.assign(r,JSON.parse(JSON.stringify(this.template))):r:void 0}spliceRows(o,r,t,e){const l=this.sheets[o];if(l){const n=[];for(let i=0;i<e;i++)n.push([]);l.splice(r,t,...n)}}spliceColumns(o,r,t,e){const l=this.sheets[o];if(l){const n=[];for(let i=0;i<e;i++)n.push(null);m.each(l,i=>{i.splice(r,t,...n)})}}}},{"./col-cache":19,"./under-dash":26}],19:[function(s,T,S){const m=/^[A-Z]+\d+$/,a={_dictionary:["A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z"],_l2nFill:0,_l2n:{},_n2l:[],_level:o=>o<=26?1:o<=676?2:3,_fill(o){let r,t,e,l,n,i=1;if(o>=4)throw new Error("Out of bounds. Excel supports columns from 1 to 16384");if(this._l2nFill<1&&o>=1){for(;i<=26;)r=this._dictionary[i-1],this._n2l[i]=r,this._l2n[r]=i,i++;this._l2nFill=1}if(this._l2nFill<2&&o>=2){for(i=27;i<=702;)t=i-27,e=t%26,l=Math.floor(t/26),r=this._dictionary[l]+this._dictionary[e],this._n2l[i]=r,this._l2n[r]=i,i++;this._l2nFill=2}if(this._l2nFill<3&&o>=3){for(i=703;i<=16384;)t=i-703,e=t%26,l=Math.floor(t/26)%26,n=Math.floor(t/676),r=this._dictionary[n]+this._dictionary[l]+this._dictionary[e],this._n2l[i]=r,this._l2n[r]=i,i++;this._l2nFill=3}},l2n(o){if(this._l2n[o]||this._fill(o.length),!this._l2n[o])throw new Error("Out of bounds. Invalid column letter: "+o);return this._l2n[o]},n2l(o){if(o<1||o>16384)throw new Error(o+" is out of bounds. Excel supports columns from 1 to 16384");return this._n2l[o]||this._fill(this._level(o)),this._n2l[o]},_hash:{},validateAddress(o){if(!m.test(o))throw new Error("Invalid Address: "+o);return!0},decodeAddress(o){const r=o.length<5&&this._hash[o];if(r)return r;let t=!1,e="",l=0,n=!1,i="",f=0;for(let u,d=0;d<o.length;d++)if(u=o.charCodeAt(d),!n&&u>=65&&u<=90)t=!0,e+=o[d],l=26*l+u-64;else if(u>=48&&u<=57)n=!0,i+=o[d],f=10*f+u-48;else if(n&&t&&u!==36)break;if(t){if(l>16384)throw new Error("Out of bounds. Invalid column letter: "+e)}else l=void 0;n||(f=void 0);const c={address:o=e+i,col:l,row:f,$col$row:`$${e}$${i}`};return l<=100&&f<=100&&(this._hash[o]=c,this._hash[c.$col$row]=c),c},getAddress(o,r){if(r){const t=this.n2l(r)+o;return this.decodeAddress(t)}return this.decodeAddress(o)},decode(o){const r=o.split(":");if(r.length===2){const t=this.decodeAddress(r[0]),e=this.decodeAddress(r[1]),l={top:Math.min(t.row,e.row),left:Math.min(t.col,e.col),bottom:Math.max(t.row,e.row),right:Math.max(t.col,e.col)};return l.tl=this.n2l(l.left)+l.top,l.br=this.n2l(l.right)+l.bottom,l.dimensions=`${l.tl}:${l.br}`,l}return this.decodeAddress(o)},decodeEx(o){const r=o.match(/(?:(?:(?:'((?:[^']|'')*)')|([^'^ !]*))!)?(.*)/),t=r[1]||r[2],e=r[3],l=e.split(":");if(l.length>1){let i=this.decodeAddress(l[0]),f=this.decodeAddress(l[1]);const c=Math.min(i.row,f.row),u=Math.min(i.col,f.col),d=Math.max(i.row,f.row),h=Math.max(i.col,f.col);return i=this.n2l(u)+c,f=this.n2l(h)+d,{top:c,left:u,bottom:d,right:h,sheetName:t,tl:{address:i,col:u,row:c,$col$row:`$${this.n2l(u)}$${c}`,sheetName:t},br:{address:f,col:h,row:d,$col$row:`$${this.n2l(h)}$${d}`,sheetName:t},dimensions:`${i}:${f}`}}if(e.startsWith("#"))return t?{sheetName:t,error:e}:{error:e};const n=this.decodeAddress(e);return t?{sheetName:t,...n}:n},encodeAddress:(o,r)=>a.n2l(r)+o,encode(){switch(arguments.length){case 2:return a.encodeAddress(arguments[0],arguments[1]);case 4:return`${a.encodeAddress(arguments[0],arguments[1])}:${a.encodeAddress(arguments[2],arguments[3])}`;default:throw new Error("Can only encode with 2 or 4 arguments")}},inRange(o,r){const[t,e,,l,n]=o,[i,f]=r;return i>=t&&i<=l&&f>=e&&f<=n}};T.exports=a},{}],20:[function(s,T,S){const m=(o,r)=>({...o,...r.reduce((t,e)=>(o[e]&&(t[e]={...o[e]}),t),{})}),a=function(o,r,t){let e=arguments.length>3&&arguments[3]!==void 0?arguments[3]:[];o[t]&&(r[t]=m(o[t],e))};S.copyStyle=o=>{if(!o)return o;if(r=o,Object.keys(r).length===0)return{};var r;const t={...o};return a(o,t,"font",["color"]),a(o,t,"alignment"),a(o,t,"protection"),o.border&&(a(o,t,"border"),a(o.border,t.border,"top",["color"]),a(o.border,t.border,"left",["color"]),a(o.border,t.border,"bottom",["color"]),a(o.border,t.border,"right",["color"]),a(o.border,t.border,"diagonal",["color"])),o.fill&&(a(o,t,"fill",["fgColor","bgColor","center"]),o.fill.stops&&(t.fill.stops=o.fill.stops.map(e=>m(e,["color"])))),t}},{}],21:[function(s,T,S){(function(m){(function(){const a=s("crypto"),o={hash(r){const t=a.createHash(r);for(var e=arguments.length,l=new Array(e>1?e-1:0),n=1;n<e;n++)l[n-1]=arguments[n];return t.update(m.concat(l)),t.digest()},convertPasswordToHash(r,t,e,l){if(t=t.toLowerCase(),a.getHashes().indexOf(t)<0)throw new Error(`Hash algorithm '${t}' not supported!`);const n=m.from(r,"utf16le");let i=this.hash(t,m.from(e,"base64"),n);for(let f=0;f<l;f++){const c=m.alloc(4);c.writeUInt32LE(f,0),i=this.hash(t,i,c)}return i.toString("base64")},randomBytes:r=>a.randomBytes(r)};T.exports=o}).call(this)}).call(this,s("buffer").Buffer)},{buffer:220,crypto:390}],22:[function(s,T,S){const{SaxesParser:m}=s("saxes"),{PassThrough:a}=s("readable-stream"),{bufferToString:o}=s("./browser-buffer-decode");T.exports=async function*(r){r.pipe&&!r[Symbol.asyncIterator]&&(r=r.pipe(new a));const t=new m;let e;t.on("error",n=>{e=n});let l=[];t.on("opentag",n=>l.push({eventType:"opentag",value:n})),t.on("text",n=>l.push({eventType:"text",value:n})),t.on("closetag",n=>l.push({eventType:"closetag",value:n}));for await(const n of r){if(t.write(o(n)),e)throw e;yield l,l=[]}}},{"./browser-buffer-decode":16,"readable-stream":491,saxes:496}],23:[function(s,T,S){const m=s("./col-cache"),a=/(([a-z_\-0-9]*)!)?([a-z0-9_$]{2,})([(])?/gi,o=/^([$])?([a-z]+)([$])?([1-9][0-9]*)$/i;T.exports={slideFormula:function(r,t,e){const l=m.decode(t),n=m.decode(e);return r.replace(a,(i,f,c,u,d)=>{if(d)return i;const h=o.exec(u);if(h){const w=h[1],_=h[2].toUpperCase(),A=h[3],N=h[4];if(_.length>3||_.length===3&&_>"XFD")return i;let L=m.l2n(_),I=parseInt(N,10);return w||(L+=n.col-l.col),A||(I+=n.row-l.row),(f||"")+(w||"")+m.n2l(L)+(A||"")+I}return i})}}},{"./col-cache":19}],24:[function(s,T,S){(function(m,a){(function(){const o=s("readable-stream"),r=s("./utils"),t=s("./string-buf");class e{constructor(u,d){this._data=u,this._encoding=d}get length(){return this.toBuffer().length}copy(u,d,h,w){return this.toBuffer().copy(u,d,h,w)}toBuffer(){return this._buffer||(this._buffer=a.from(this._data,this._encoding)),this._buffer}}class l{constructor(u){this._data=u}get length(){return this._data.length}copy(u,d,h,w){return this._data._buf.copy(u,d,h,w)}toBuffer(){return this._data.toBuffer()}}class n{constructor(u){this._data=u}get length(){return this._data.length}copy(u,d,h,w){this._data.copy(u,d,h,w)}toBuffer(){return this._data}}class i{constructor(u){this.size=u,this.buffer=a.alloc(u),this.iRead=0,this.iWrite=0}toBuffer(){if(this.iRead===0&&this.iWrite===this.size)return this.buffer;const u=a.alloc(this.iWrite-this.iRead);return this.buffer.copy(u,0,this.iRead,this.iWrite),u}get length(){return this.iWrite-this.iRead}get eod(){return this.iRead===this.iWrite}get full(){return this.iWrite===this.size}read(u){let d;return u===0?null:u===void 0||u>=this.length?(d=this.toBuffer(),this.iRead=this.iWrite,d):(d=a.alloc(u),this.buffer.copy(d,0,this.iRead,u),this.iRead+=u,d)}write(u,d,h){const w=Math.min(h,this.size-this.iWrite);return u.copy(this.buffer,this.iWrite,d,d+w),this.iWrite+=w,w}}const f=function(c){c=c||{},this.bufSize=c.bufSize||1048576,this.buffers=[],this.batch=c.batch||!1,this.corked=!1,this.inPos=0,this.outPos=0,this.pipes=[],this.paused=!1,this.encoding=null};r.inherits(f,o.Duplex,{toBuffer(){switch(this.buffers.length){case 0:return null;case 1:return this.buffers[0].toBuffer();default:return a.concat(this.buffers.map(c=>c.toBuffer()))}},_getWritableBuffer(){if(this.buffers.length){const u=this.buffers[this.buffers.length-1];if(!u.full)return u}const c=new i(this.bufSize);return this.buffers.push(c),c},async _pipe(c){await Promise.all(this.pipes.map(function(u){return new Promise(d=>{u.write(c.toBuffer(),()=>{d()})})}))},_writeToBuffers(c){let u=0;const d=c.length;for(;u<d;)u+=this._getWritableBuffer().write(c,u,d-u)},async write(c,u,d){let h;if(u instanceof Function&&(d=u,u="utf8"),d=d||r.nop,c instanceof t)h=new l(c);else if(c instanceof a)h=new n(c);else{if(!(typeof c=="string"||c instanceof String||c instanceof ArrayBuffer))throw new Error("Chunk must be one of type String, Buffer or StringBuf.");h=new e(c,u)}if(this.pipes.length)if(this.batch)for(this._writeToBuffers(h);!this.corked&&this.buffers.length>1;)this._pipe(this.buffers.shift());else this.corked?(this._writeToBuffers(h),m.nextTick(d)):(await this._pipe(h),d());else this.paused||this.emit("data",h.toBuffer()),this._writeToBuffers(h),this.emit("readable");return!0},cork(){this.corked=!0},_flush(){if(this.pipes.length)for(;this.buffers.length;)this._pipe(this.buffers.shift())},uncork(){this.corked=!1,this._flush()},end(c,u,d){const h=w=>{w?d(w):(this._flush(),this.pipes.forEach(_=>{_.end()}),this.emit("finish"))};c?this.write(c,u,h):h()},read(c){let u;if(c){for(u=[];c&&this.buffers.length&&!this.buffers[0].eod;){const d=this.buffers[0],h=d.read(c);c-=h.length,u.push(h),d.eod&&d.full&&this.buffers.shift()}return a.concat(u)}return u=this.buffers.map(d=>d.toBuffer()).filter(Boolean),this.buffers=[],a.concat(u)},setEncoding(c){this.encoding=c},pause(){this.paused=!0},resume(){this.paused=!1},isPaused(){return!!this.paused},pipe(c){this.pipes.push(c),!this.paused&&this.buffers.length&&this.end()},unpipe(c){this.pipes=this.pipes.filter(u=>u!==c)},unshift(){throw new Error("Not Implemented")},wrap(){throw new Error("Not Implemented")}}),T.exports=f}).call(this)}).call(this,s("_process"),s("buffer").Buffer)},{"./string-buf":25,"./utils":27,_process:467,buffer:220,"readable-stream":491}],25:[function(s,T,S){(function(m){(function(){T.exports=class{constructor(a){this._buf=m.alloc(a&&a.size||16384),this._encoding=a&&a.encoding||"utf8",this._inPos=0,this._buffer=void 0}get length(){return this._inPos}get capacity(){return this._buf.length}get buffer(){return this._buf}toBuffer(){return this._buffer||(this._buffer=m.alloc(this.length),this._buf.copy(this._buffer,0,0,this.length)),this._buffer}reset(a){a=a||0,this._buffer=void 0,this._inPos=a}_grow(a){let o=2*this._buf.length;for(;o<a;)o*=2;const r=m.alloc(o);this._buf.copy(r,0),this._buf=r}addText(a){this._buffer=void 0;let o=this._inPos+this._buf.write(a,this._inPos,this._encoding);for(;o>=this._buf.length-4;)this._grow(this._inPos+a.length),o=this._inPos+this._buf.write(a,this._inPos,this._encoding);this._inPos=o}addStringBuf(a){a.length&&(this._buffer=void 0,this.length+a.length>this.capacity&&this._grow(this.length+a.length),a._buf.copy(this._buf,this._inPos,0,a.length),this._inPos+=a.length)}}}).call(this)}).call(this,s("buffer").Buffer)},{buffer:220}],26:[function(s,T,S){const{toString:m}=Object.prototype,a=/["&<>]/,o={each:function(r,t){r&&(Array.isArray(r)?r.forEach(t):Object.keys(r).forEach(e=>{t(r[e],e)}))},some:function(r,t){return!!r&&(Array.isArray(r)?r.some(t):Object.keys(r).some(e=>t(r[e],e)))},every:function(r,t){return!r||(Array.isArray(r)?r.every(t):Object.keys(r).every(e=>t(r[e],e)))},map:function(r,t){return r?Array.isArray(r)?r.map(t):Object.keys(r).map(e=>t(r[e],e)):[]},keyBy:(r,t)=>r.reduce((e,l)=>(e[l[t]]=l,e),{}),isEqual:function(r,t){const e=typeof r,l=typeof t,n=Array.isArray(r),i=Array.isArray(t);let f;if(e!==l)return!1;switch(typeof r){case"object":if(n||i)return!(!n||!i)&&r.length===t.length&&r.every((c,u)=>{const d=t[u];return o.isEqual(c,d)});if(r===null||t===null)return r===t;if(f=Object.keys(r),Object.keys(t).length!==f.length)return!1;for(const c of f)if(!t.hasOwnProperty(c))return!1;return o.every(r,(c,u)=>{const d=t[u];return o.isEqual(c,d)});default:return r===t}},escapeHtml(r){const t=a.exec(r);if(!t)return r;let e="",l="",n=0,i=t.index;for(;i<r.length;i++){switch(r.charAt(i)){case'"':l="&quot;";break;case"&":l="&amp;";break;case"'":l="&apos;";break;case"<":l="&lt;";break;case">":l="&gt;";break;default:continue}n!==i&&(e+=r.substring(n,i)),n=i+1,e+=l}return n!==i?e+r.substring(n,i):e},strcmp:(r,t)=>r<t?-1:r>t?1:0,isUndefined:r=>m.call(r)==="[object Undefined]",isObject:r=>m.call(r)==="[object Object]",deepMerge(){const r=arguments[0]||{},{length:t}=arguments;let e,l,n;function i(f,c){e=r[c],n=Array.isArray(f),o.isObject(f)||n?(n?(n=!1,l=e&&Array.isArray(e)?e:[]):l=e&&o.isObject(e)?e:{},r[c]=o.deepMerge(l,f)):o.isUndefined(f)||(r[c]=f)}for(let f=0;f<t;f++)o.each(arguments[f],i);return r}};T.exports=o},{}],27:[function(s,T,S){(function(m,a){(function(){const o=s("fs"),r=/[<>&'"\x7F\x00-\x08\x0B-\x0C\x0E-\x1F]/,t={nop(){},promiseImmediate:e=>new Promise(l=>{m.setImmediate?a(()=>{l(e)}):setTimeout(()=>{l(e)},1)}),inherits:function(e,l,n,i){e.super_=l,i||(i=n,n=null),n&&Object.keys(n).forEach(c=>{Object.defineProperty(e,c,Object.getOwnPropertyDescriptor(n,c))});const f={constructor:{value:e,enumerable:!1,writable:!1,configurable:!0}};i&&Object.keys(i).forEach(c=>{f[c]=Object.getOwnPropertyDescriptor(i,c)}),e.prototype=Object.create(l.prototype,f)},dateToExcel:(e,l)=>25569+e.getTime()/864e5-(l?1462:0),excelToDate(e,l){const n=Math.round(24*(e-25569+(l?1462:0))*3600*1e3);return new Date(n)},parsePath(e){const l=e.lastIndexOf("/");return{path:e.substring(0,l),name:e.substring(l+1)}},getRelsPath(e){const l=t.parsePath(e);return`${l.path}/_rels/${l.name}.rels`},xmlEncode(e){const l=r.exec(e);if(!l)return e;let n="",i="",f=0,c=l.index;for(;c<e.length;c++){const u=e.charCodeAt(c);switch(u){case 34:i="&quot;";break;case 38:i="&amp;";break;case 39:i="&apos;";break;case 60:i="&lt;";break;case 62:i="&gt;";break;case 127:i="";break;default:if(u<=31&&(u<=8||u>=11&&u!==13)){i="";break}continue}f!==c&&(n+=e.substring(f,c)),f=c+1,i&&(n+=i)}return f!==c?n+e.substring(f,c):n},xmlDecode:e=>e.replace(/&([a-z]*);/g,l=>{switch(l){case"&lt;":return"<";case"&gt;":return">";case"&amp;":return"&";case"&apos;":return"'";case"&quot;":return'"';default:return l}}),validInt(e){const l=parseInt(e,10);return Number.isNaN(l)?0:l},isDateFmt(e){return e?(e=(e=e.replace(/\[[^\]]*]/g,"")).replace(/"[^"]*"/g,"")).match(/[ymdhMsb]+/)!==null:!1},fs:{exists:e=>new Promise(l=>{o.access(e,o.constants.F_OK,n=>{l(!n)})})},toIsoDateString:e=>e.toIsoString().subsstr(0,10),parseBoolean:e=>e===!0||e==="true"||e===1||e==="1"};T.exports=t}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{},s("timers").setImmediate)},{fs:216,timers:523}],28:[function(s,T,S){const m=s("./under-dash"),a=s("./utils");function o(e,l,n){e.push(` ${l}="${a.xmlEncode(n.toString())}"`)}function r(e,l){if(l){const n=[];m.each(l,(i,f)=>{i!==void 0&&o(n,f,i)}),e.push(n.join(""))}}class t{constructor(){this._xml=[],this._stack=[],this._rollbacks=[]}get tos(){return this._stack.length?this._stack[this._stack.length-1]:void 0}get cursor(){return this._xml.length}openXml(l){const n=this._xml;n.push("<?xml"),r(n,l),n.push(`?>
`)}openNode(l,n){const i=this.tos,f=this._xml;i&&this.open&&f.push(">"),this._stack.push(l),f.push("<"),f.push(l),r(f,n),this.leaf=!0,this.open=!0}addAttribute(l,n){if(!this.open)throw new Error("Cannot write attributes to node if it is not open");n!==void 0&&o(this._xml,l,n)}addAttributes(l){if(!this.open)throw new Error("Cannot write attributes to node if it is not open");r(this._xml,l)}writeText(l){const n=this._xml;this.open&&(n.push(">"),this.open=!1),this.leaf=!1,n.push(a.xmlEncode(l.toString()))}writeXml(l){this.open&&(this._xml.push(">"),this.open=!1),this.leaf=!1,this._xml.push(l)}closeNode(){const l=this._stack.pop(),n=this._xml;this.leaf?n.push("/>"):(n.push("</"),n.push(l),n.push(">")),this.open=!1,this.leaf=!1}leafNode(l,n,i){this.openNode(l,n),i!==void 0&&this.writeText(i),this.closeNode()}closeAll(){for(;this._stack.length;)this.closeNode()}addRollback(){return this._rollbacks.push({xml:this._xml.length,stack:this._stack.length,leaf:this.leaf,open:this.open}),this.cursor}commit(){this._rollbacks.pop()}rollback(){const l=this._rollbacks.pop();this._xml.length>l.xml&&this._xml.splice(l.xml,this._xml.length-l.xml),this._stack.length>l.stack&&this._stack.splice(l.stack,this._stack.length-l.stack),this.leaf=l.leaf,this.open=l.open}get xml(){return this.closeAll(),this._xml.join("")}}t.StdDocAttributes={version:"1.0",encoding:"UTF-8",standalone:"yes"},T.exports=t},{"./under-dash":26,"./utils":27}],29:[function(s,T,S){(function(m){(function(){const a=s("events"),o=s("jszip"),r=s("./stream-buf"),{stringToBuffer:t}=s("./browser-buffer-encode");class e extends a.EventEmitter{constructor(n){super(),this.options=Object.assign({type:"nodebuffer",compression:"DEFLATE"},n),this.zip=new o,this.stream=new r}append(n,i){i.hasOwnProperty("base64")&&i.base64?this.zip.file(i.name,n,{base64:!0}):(m.browser&&typeof n=="string"&&(n=t(n)),this.zip.file(i.name,n))}async finalize(){const n=await this.zip.generateAsync(this.options);this.stream.end(n),this.emit("finish")}read(n){return this.stream.read(n)}setEncoding(n){return this.stream.setEncoding(n)}pause(){return this.stream.pause()}resume(){return this.stream.resume()}isPaused(){return this.stream.isPaused()}pipe(n,i){return this.stream.pipe(n,i)}unpipe(n){return this.stream.unpipe(n)}unshift(n){return this.stream.unshift(n)}wrap(n){return this.stream.wrap(n)}}T.exports={ZipWriter:e}}).call(this)}).call(this,s("_process"))},{"./browser-buffer-encode":17,"./stream-buf":24,_process:467,events:422,jszip:441}],30:[function(s,T,S){T.exports={0:{f:"General"},1:{f:"0"},2:{f:"0.00"},3:{f:"#,##0"},4:{f:"#,##0.00"},9:{f:"0%"},10:{f:"0.00%"},11:{f:"0.00E+00"},12:{f:"# ?/?"},13:{f:"# ??/??"},14:{f:"mm-dd-yy"},15:{f:"d-mmm-yy"},16:{f:"d-mmm"},17:{f:"mmm-yy"},18:{f:"h:mm AM/PM"},19:{f:"h:mm:ss AM/PM"},20:{f:"h:mm"},21:{f:"h:mm:ss"},22:{f:'m/d/yy "h":mm'},27:{"zh-tw":"[$-404]e/m/d","zh-cn":'yyyy"年"m"月"',"ja-jp":"[$-411]ge.m.d","ko-kr":'yyyy"年" mm"月" dd"日"'},28:{"zh-tw":'[$-404]e"年"m"月"d"日"',"zh-cn":'m"月"d"日"',"ja-jp":'[$-411]ggge"年"m"月"d"日"',"ko-kr":"mm-dd"},29:{"zh-tw":'[$-404]e"年"m"月"d"日"',"zh-cn":'m"月"d"日"',"ja-jp":'[$-411]ggge"年"m"月"d"日"',"ko-kr":"mm-dd"},30:{"zh-tw":"m/d/yy ","zh-cn":"m-d-yy","ja-jp":"m/d/yy","ko-kr":"mm-dd-yy"},31:{"zh-tw":'yyyy"年"m"月"d"日"',"zh-cn":'yyyy"年"m"月"d"日"',"ja-jp":'yyyy"年"m"月"d"日"',"ko-kr":'yyyy"년" mm"월" dd"일"'},32:{"zh-tw":'hh"時"mm"分"',"zh-cn":'h"时"mm"分"',"ja-jp":'h"時"mm"分"',"ko-kr":'h"시" mm"분"'},33:{"zh-tw":'hh"時"mm"分"ss"秒"',"zh-cn":'h"时"mm"分"ss"秒"',"ja-jp":'h"時"mm"分"ss"秒"',"ko-kr":'h"시" mm"분" ss"초"'},34:{"zh-tw":'上午/下午 hh"時"mm"分"',"zh-cn":'上午/下午 h"时"mm"分"',"ja-jp":'yyyy"年"m"月"',"ko-kr":"yyyy-mm-dd"},35:{"zh-tw":'上午/下午 hh"時"mm"分"ss"秒"',"zh-cn":'上午/下午 h"时"mm"分"ss"秒"',"ja-jp":'m"月"d"日"',"ko-kr":"yyyy-mm-dd"},36:{"zh-tw":"[$-404]e/m/d","zh-cn":'yyyy"年"m"月"',"ja-jp":"[$-411]ge.m.d","ko-kr":'yyyy"年" mm"月" dd"日"'},37:{f:"#,##0 ;(#,##0)"},38:{f:"#,##0 ;[Red](#,##0)"},39:{f:"#,##0.00 ;(#,##0.00)"},40:{f:"#,##0.00 ;[Red](#,##0.00)"},45:{f:"mm:ss"},46:{f:"[h]:mm:ss"},47:{f:"mmss.0"},48:{f:"##0.0E+0"},49:{f:"@"},50:{"zh-tw":"[$-404]e/m/d","zh-cn":'yyyy"年"m"月"',"ja-jp":"[$-411]ge.m.d","ko-kr":'yyyy"年" mm"月" dd"日"'},51:{"zh-tw":'[$-404]e"年"m"月"d"日"',"zh-cn":'m"月"d"日"',"ja-jp":'[$-411]ggge"年"m"月"d"日"',"ko-kr":"mm-dd"},52:{"zh-tw":'上午/下午 hh"時"mm"分"',"zh-cn":'yyyy"年"m"月"',"ja-jp":'yyyy"年"m"月"',"ko-kr":"yyyy-mm-dd"},53:{"zh-tw":'上午/下午 hh"時"mm"分"ss"秒"',"zh-cn":'m"月"d"日"',"ja-jp":'m"月"d"日"',"ko-kr":"yyyy-mm-dd"},54:{"zh-tw":'[$-404]e"年"m"月"d"日"',"zh-cn":'m"月"d"日"',"ja-jp":'[$-411]ggge"年"m"月"d"日"',"ko-kr":"mm-dd"},55:{"zh-tw":'上午/下午 hh"時"mm"分"',"zh-cn":'上午/下午 h"时"mm"分"',"ja-jp":'yyyy"年"m"月"',"ko-kr":"yyyy-mm-dd"},56:{"zh-tw":'上午/下午 hh"時"mm"分"ss"秒"',"zh-cn":'上午/下午 h"时"mm"分"ss"秒"',"ja-jp":'m"月"d"日"',"ko-kr":"yyyy-mm-dd"},57:{"zh-tw":"[$-404]e/m/d","zh-cn":'yyyy"年"m"月"',"ja-jp":"[$-411]ge.m.d","ko-kr":'yyyy"年" mm"月" dd"日"'},58:{"zh-tw":'[$-404]e"年"m"月"d"日"',"zh-cn":'m"月"d"日"',"ja-jp":'[$-411]ggge"年"m"月"d"日"',"ko-kr":"mm-dd"},59:{"th-th":"t0"},60:{"th-th":"t0.00"},61:{"th-th":"t#,##0"},62:{"th-th":"t#,##0.00"},67:{"th-th":"t0%"},68:{"th-th":"t0.00%"},69:{"th-th":"t# ?/?"},70:{"th-th":"t# ??/??"},81:{"th-th":"d/m/bb"}}},{}],31:[function(s,T,S){T.exports={OfficeDocument:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument",Worksheet:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet",CalcChain:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/calcChain",SharedStrings:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/sharedStrings",Styles:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/styles",Theme:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/theme",Hyperlink:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/hyperlink",Image:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image",CoreProperties:"http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties",ExtenderProperties:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/extended-properties",Comments:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments",VmlDrawing:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/vmlDrawing",Table:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/table"}},{}],32:[function(s,T,S){const m=s("../../utils/parse-sax"),a=s("../../utils/xml-stream");class o{prepare(){}render(){}parseOpen(t){}parseText(t){}parseClose(t){}reconcile(t,e){}reset(){this.model=null,this.map&&Object.values(this.map).forEach(t=>{t instanceof o?t.reset():t.xform&&t.xform.reset()})}mergeModel(t){this.model=Object.assign(this.model||{},t)}async parse(t){for await(const e of t)for(const{eventType:l,value:n}of e)if(l==="opentag")this.parseOpen(n);else if(l==="text")this.parseText(n);else if(l==="closetag"&&!this.parseClose(n.name))return this.model;return this.model}async parseStream(t){return this.parse(m(t))}get xml(){return this.toXml(this.model)}toXml(t){const e=new a;return this.render(e,t),e.xml}static toAttribute(t,e){let l=arguments.length>2&&arguments[2]!==void 0&&arguments[2];if(t===void 0){if(l)return e}else if(l||t!==e)return t.toString()}static toStringAttribute(t,e){let l=arguments.length>2&&arguments[2]!==void 0&&arguments[2];return o.toAttribute(t,e,l)}static toStringValue(t,e){return t===void 0?e:t}static toBoolAttribute(t,e){let l=arguments.length>2&&arguments[2]!==void 0&&arguments[2];if(t===void 0){if(l)return e}else if(l||t!==e)return t?"1":"0"}static toBoolValue(t,e){return t===void 0?e:t==="1"}static toIntAttribute(t,e){let l=arguments.length>2&&arguments[2]!==void 0&&arguments[2];return o.toAttribute(t,e,l)}static toIntValue(t,e){return t===void 0?e:parseInt(t,10)}static toFloatAttribute(t,e){let l=arguments.length>2&&arguments[2]!==void 0&&arguments[2];return o.toAttribute(t,e,l)}static toFloatValue(t,e){return t===void 0?e:parseFloat(t)}}T.exports=o},{"../../utils/parse-sax":22,"../../utils/xml-stream":28}],33:[function(s,T,S){const m=s("../base-xform"),a=s("../../../utils/col-cache");function o(t){try{return a.decodeEx(t),!0}catch{return!1}}function r(t){const e=[];let l=!1,n="";return t.split(",").forEach(i=>{if(!i)return;const f=(i.match(/'/g)||[]).length;if(!f)return void(l?n+=i+",":o(i)&&e.push(i));const c=f%2==0;!l&&c&&o(i)?e.push(i):l&&!c?(l=!1,o(n+i)&&e.push(n+i),n=""):(l=!0,n+=i+",")}),e}T.exports=class extends m{render(t,e){t.openNode("definedName",{name:e.name,localSheetId:e.localSheetId}),t.writeText(e.ranges.join(",")),t.closeNode()}parseOpen(t){switch(t.name){case"definedName":return this._parsedName=t.attributes.name,this._parsedLocalSheetId=t.attributes.localSheetId,this._parsedText=[],!0;default:return!1}}parseText(t){this._parsedText.push(t)}parseClose(){return this.model={name:this._parsedName,ranges:r(this._parsedText.join(""))},this._parsedLocalSheetId!==void 0&&(this.model.localSheetId=parseInt(this._parsedLocalSheetId,10)),!1}}},{"../../../utils/col-cache":19,"../base-xform":32}],34:[function(s,T,S){const m=s("../../../utils/utils"),a=s("../base-xform");T.exports=class extends a{render(o,r){o.leafNode("sheet",{sheetId:r.id,name:r.name,state:r.state,"r:id":r.rId})}parseOpen(o){return o.name==="sheet"&&(this.model={name:m.xmlDecode(o.attributes.name),id:parseInt(o.attributes.sheetId,10),state:o.attributes.state,rId:o.attributes["r:id"]},!0)}parseText(){}parseClose(){return!1}}},{"../../../utils/utils":27,"../base-xform":32}],35:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{render(a,o){a.leafNode("calcPr",{calcId:171027,fullCalcOnLoad:o.fullCalcOnLoad?1:void 0})}parseOpen(a){return a.name==="calcPr"&&(this.model={},!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],36:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{render(a,o){a.leafNode("workbookPr",{date1904:o.date1904?1:void 0,defaultThemeVersion:164011,filterPrivacy:1})}parseOpen(a){return a.name==="workbookPr"&&(this.model={date1904:a.attributes.date1904==="1"},!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],37:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{render(a,o){const r={xWindow:o.x||0,yWindow:o.y||0,windowWidth:o.width||12e3,windowHeight:o.height||24e3,firstSheet:o.firstSheet,activeTab:o.activeTab};o.visibility&&o.visibility!=="visible"&&(r.visibility=o.visibility),a.leafNode("workbookView",r)}parseOpen(a){if(a.name==="workbookView"){const o=this.model={},r=function(e,l,n){const i=l!==void 0?o[e]=l:n;i!==void 0&&(o[e]=i)},t=function(e,l,n){const i=l!==void 0?o[e]=parseInt(l,10):n;i!==void 0&&(o[e]=i)};return t("x",a.attributes.xWindow,0),t("y",a.attributes.yWindow,0),t("width",a.attributes.windowWidth,25e3),t("height",a.attributes.windowHeight,1e4),r("visibility",a.attributes.visibility,"visible"),t("activeTab",a.attributes.activeTab,void 0),t("firstSheet",a.attributes.firstSheet,void 0),!0}return!1}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],38:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../../../utils/col-cache"),o=s("../../../utils/xml-stream"),r=s("../base-xform"),t=s("../static-xform"),e=s("../list-xform"),l=s("./defined-name-xform"),n=s("./sheet-xform"),i=s("./workbook-view-xform"),f=s("./workbook-properties-xform"),c=s("./workbook-calc-properties-xform");class u extends r{constructor(){super(),this.map={fileVersion:u.STATIC_XFORMS.fileVersion,workbookPr:new f,bookViews:new e({tag:"bookViews",count:!1,childXform:new i}),sheets:new e({tag:"sheets",count:!1,childXform:new n}),definedNames:new e({tag:"definedNames",count:!1,childXform:new l}),calcPr:new c}}prepare(h){h.sheets=h.worksheets;const w=[];let _=0;h.sheets.forEach(A=>{if(A.pageSetup&&A.pageSetup.printArea&&A.pageSetup.printArea.split("&&").forEach(N=>{const L=N.split(":"),I={name:"_xlnm.Print_Area",ranges:[`'${A.name}'!$${L[0]}:$${L[1]}`],localSheetId:_};w.push(I)}),A.pageSetup&&(A.pageSetup.printTitlesRow||A.pageSetup.printTitlesColumn)){const N=[];if(A.pageSetup.printTitlesColumn){const I=A.pageSetup.printTitlesColumn.split(":");N.push(`'${A.name}'!$${I[0]}:$${I[1]}`)}if(A.pageSetup.printTitlesRow){const I=A.pageSetup.printTitlesRow.split(":");N.push(`'${A.name}'!$${I[0]}:$${I[1]}`)}const L={name:"_xlnm.Print_Titles",ranges:N,localSheetId:_};w.push(L)}_++}),w.length&&(h.definedNames=h.definedNames.concat(w)),(h.media||[]).forEach((A,N)=>{A.name=A.type+(N+1)})}render(h,w){h.openXml(o.StdDocAttributes),h.openNode("workbook",u.WORKBOOK_ATTRIBUTES),this.map.fileVersion.render(h),this.map.workbookPr.render(h,w.properties),this.map.bookViews.render(h,w.views),this.map.sheets.render(h,w.sheets),this.map.definedNames.render(h,w.definedNames),this.map.calcPr.render(h,w.calcProperties),h.closeNode()}parseOpen(h){if(this.parser)return this.parser.parseOpen(h),!0;switch(h.name){case"workbook":return!0;default:return this.parser=this.map[h.name],this.parser&&this.parser.parseOpen(h),!0}}parseText(h){this.parser&&this.parser.parseText(h)}parseClose(h){if(this.parser)return this.parser.parseClose(h)||(this.parser=void 0),!0;switch(h){case"workbook":return this.model={sheets:this.map.sheets.model,properties:this.map.workbookPr.model||{},views:this.map.bookViews.model,calcProperties:{}},this.map.definedNames.model&&(this.model.definedNames=this.map.definedNames.model),!1;default:return!0}}reconcile(h){const w=(h.workbookRels||[]).reduce((I,P)=>(I[P.Id]=P,I),{}),_=[];let A,N=0;(h.sheets||[]).forEach(I=>{const P=w[I.rId];P&&(A=h.worksheetHash["xl/"+P.Target.replace(/^(\s|\/xl\/)+/,"")],A&&(A.name=I.name,A.id=I.id,A.state=I.state,_[N++]=A))});const L=[];m.each(h.definedNames,I=>{if(I.name==="_xlnm.Print_Area"){if(A=_[I.localSheetId],A){A.pageSetup||(A.pageSetup={});const P=a.decodeEx(I.ranges[0]);A.pageSetup.printArea=A.pageSetup.printArea?`${A.pageSetup.printArea}&&${P.dimensions}`:P.dimensions}}else if(I.name==="_xlnm.Print_Titles"){if(A=_[I.localSheetId],A){A.pageSetup||(A.pageSetup={});const P=I.ranges.join(","),B=/\$/g,U=/\$\d+:\$\d+/,D=P.match(U);if(D&&D.length){const v=D[0];A.pageSetup.printTitlesRow=v.replace(B,"")}const x=/\$[A-Z]+:\$[A-Z]+/,M=P.match(x);if(M&&M.length){const v=M[0];A.pageSetup.printTitlesColumn=v.replace(B,"")}}}else L.push(I)}),h.definedNames=L,h.media.forEach((I,P)=>{I.index=P})}}u.WORKBOOK_ATTRIBUTES={xmlns:"http://schemas.openxmlformats.org/spreadsheetml/2006/main","xmlns:r":"http://schemas.openxmlformats.org/officeDocument/2006/relationships","xmlns:mc":"http://schemas.openxmlformats.org/markup-compatibility/2006","mc:Ignorable":"x15","xmlns:x15":"http://schemas.microsoft.com/office/spreadsheetml/2010/11/main"},u.STATIC_XFORMS={fileVersion:new t({tag:"fileVersion",$:{appName:"xl",lastEdited:5,lowestEdited:5,rupBuild:9303}})},T.exports=u},{"../../../utils/col-cache":19,"../../../utils/under-dash":26,"../../../utils/xml-stream":28,"../base-xform":32,"../list-xform":71,"../static-xform":120,"./defined-name-xform":33,"./sheet-xform":34,"./workbook-calc-properties-xform":35,"./workbook-properties-xform":36,"./workbook-view-xform":37}],39:[function(s,T,S){const m=s("../strings/rich-text-xform"),a=s("../../../utils/utils"),o=s("../base-xform"),r=T.exports=function(t){this.model=t};a.inherits(r,o,{get tag(){return"r"},get richTextXform(){return this._richTextXform||(this._richTextXform=new m),this._richTextXform},render(t,e){e=e||this.model,t.openNode("comment",{ref:e.ref,authorId:0}),t.openNode("text"),e&&e.note&&e.note.texts&&e.note.texts.forEach(l=>{this.richTextXform.render(t,l)}),t.closeNode(),t.closeNode()},parseOpen(t){if(this.parser)return this.parser.parseOpen(t),!0;switch(t.name){case"comment":return this.model={type:"note",note:{texts:[]},...t.attributes},!0;case"r":return this.parser=this.richTextXform,this.parser.parseOpen(t),!0;default:return!1}},parseText(t){this.parser&&this.parser.parseText(t)},parseClose(t){switch(t){case"comment":return!1;case"r":return this.model.note.texts.push(this.parser.model),this.parser=void 0,!0;default:return this.parser&&this.parser.parseClose(t),!0}}})},{"../../../utils/utils":27,"../base-xform":32,"../strings/rich-text-xform":122}],40:[function(s,T,S){const m=s("../../../utils/xml-stream"),a=s("../../../utils/utils"),o=s("../base-xform"),r=s("./comment-xform"),t=T.exports=function(){this.map={comment:new r}};a.inherits(t,o,{COMMENTS_ATTRIBUTES:{xmlns:"http://schemas.openxmlformats.org/spreadsheetml/2006/main"}},{render(e,l){l=l||this.model,e.openXml(m.StdDocAttributes),e.openNode("comments",t.COMMENTS_ATTRIBUTES),e.openNode("authors"),e.leafNode("author",null,"Author"),e.closeNode(),e.openNode("commentList"),l.comments.forEach(n=>{this.map.comment.render(e,n)}),e.closeNode(),e.closeNode()},parseOpen(e){if(this.parser)return this.parser.parseOpen(e),!0;switch(e.name){case"commentList":return this.model={comments:[]},!0;case"comment":return this.parser=this.map.comment,this.parser.parseOpen(e),!0;default:return!1}},parseText(e){this.parser&&this.parser.parseText(e)},parseClose(e){switch(e){case"commentList":return!1;case"comment":return this.model.comments.push(this.parser.model),this.parser=void 0,!0;default:return this.parser&&this.parser.parseClose(e),!0}}})},{"../../../utils/utils":27,"../../../utils/xml-stream":28,"../base-xform":32,"./comment-xform":39}],41:[function(s,T,S){const m=s("../../base-xform");T.exports=class extends m{constructor(a){super(),this._model=a}get tag(){return this._model&&this._model.tag}render(a,o,r){(o===r[2]||this.tag==="x:SizeWithCells"&&o===r[1])&&a.leafNode(this.tag)}parseOpen(a){switch(a.name){case this.tag:return this.model={},this.model[this.tag]=!0,!0;default:return!1}}parseText(){}parseClose(){return!1}}},{"../../base-xform":32}],42:[function(s,T,S){const m=s("../../base-xform");T.exports=class extends m{constructor(a){super(),this._model=a}get tag(){return this._model&&this._model.tag}render(a,o){a.leafNode(this.tag,null,o)}parseOpen(a){switch(a.name){case this.tag:return this.text="",!0;default:return!1}}parseText(a){this.text=a}parseClose(){return!1}}},{"../../base-xform":32}],43:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"x:Anchor"}getAnchorRect(a){const o=Math.floor(a.left),r=Math.floor(68*(a.left-o)),t=Math.floor(a.top),e=Math.floor(18*(a.top-t)),l=Math.floor(a.right),n=Math.floor(68*(a.right-l)),i=Math.floor(a.bottom);return[o,r,t,e,l,n,i,Math.floor(18*(a.bottom-i))]}getDefaultRect(a){const o=a.col,r=Math.max(a.row-2,0);return[o,6,r,14,o+2,2,r+4,16]}render(a,o){const r=o.anchor?this.getAnchorRect(o.anchor):this.getDefaultRect(o.refAddress);a.leafNode("x:Anchor",null,r.join(", "))}parseOpen(a){switch(a.name){case this.tag:return this.text="",!0;default:return!1}}parseText(a){this.text=a}parseClose(){return!1}}},{"../base-xform":32}],44:[function(s,T,S){const m=s("../base-xform"),a=s("./vml-anchor-xform"),o=s("./style/vml-protection-xform"),r=s("./style/vml-position-xform"),t=["twoCells","oneCells","absolute"];T.exports=class extends m{constructor(){super(),this.map={"x:Anchor":new a,"x:Locked":new o({tag:"x:Locked"}),"x:LockText":new o({tag:"x:LockText"}),"x:SizeWithCells":new r({tag:"x:SizeWithCells"}),"x:MoveWithCells":new r({tag:"x:MoveWithCells"})}}get tag(){return"x:ClientData"}render(e,l){const{protection:n,editAs:i}=l.note;e.openNode(this.tag,{ObjectType:"Note"}),this.map["x:MoveWithCells"].render(e,i,t),this.map["x:SizeWithCells"].render(e,i,t),this.map["x:Anchor"].render(e,l),this.map["x:Locked"].render(e,n.locked),e.leafNode("x:AutoFill",null,"False"),this.map["x:LockText"].render(e,n.lockText),e.leafNode("x:Row",null,l.refAddress.row-1),e.leafNode("x:Column",null,l.refAddress.col-1),e.closeNode()}parseOpen(e){switch(e.name){case this.tag:this.reset(),this.model={anchor:[],protection:{},editAs:""};break;default:this.parser=this.map[e.name],this.parser&&this.parser.parseOpen(e)}return!0}parseText(e){this.parser&&this.parser.parseText(e)}parseClose(e){if(this.parser)return this.parser.parseClose(e)||(this.parser=void 0),!0;switch(e){case this.tag:return this.normalizeModel(),!1;default:return!0}}normalizeModel(){const e=Object.assign({},this.map["x:MoveWithCells"].model,this.map["x:SizeWithCells"].model),l=Object.keys(e).length;this.model.editAs=t[l],this.model.anchor=this.map["x:Anchor"].text,this.model.protection.locked=this.map["x:Locked"].text,this.model.protection.lockText=this.map["x:LockText"].text}}},{"../base-xform":32,"./style/vml-position-xform":41,"./style/vml-protection-xform":42,"./vml-anchor-xform":43}],45:[function(s,T,S){const m=s("../../../utils/xml-stream"),a=s("../base-xform"),o=s("./vml-shape-xform");class r extends a{constructor(){super(),this.map={"v:shape":new o}}get tag(){return"xml"}render(e,l){e.openXml(m.StdDocAttributes),e.openNode(this.tag,r.DRAWING_ATTRIBUTES),e.openNode("o:shapelayout",{"v:ext":"edit"}),e.leafNode("o:idmap",{"v:ext":"edit",data:1}),e.closeNode(),e.openNode("v:shapetype",{id:"_x0000_t202",coordsize:"21600,21600","o:spt":202,path:"m,l,21600r21600,l21600,xe"}),e.leafNode("v:stroke",{joinstyle:"miter"}),e.leafNode("v:path",{gradientshapeok:"t","o:connecttype":"rect"}),e.closeNode(),l.comments.forEach((n,i)=>{this.map["v:shape"].render(e,n,i)}),e.closeNode()}parseOpen(e){if(this.parser)return this.parser.parseOpen(e),!0;switch(e.name){case this.tag:this.reset(),this.model={comments:[]};break;default:this.parser=this.map[e.name],this.parser&&this.parser.parseOpen(e)}return!0}parseText(e){this.parser&&this.parser.parseText(e)}parseClose(e){if(this.parser)return this.parser.parseClose(e)||(this.model.comments.push(this.parser.model),this.parser=void 0),!0;switch(e){case this.tag:return!1;default:return!0}}reconcile(e,l){e.anchors.forEach(n=>{n.br?this.map["xdr:twoCellAnchor"].reconcile(n,l):this.map["xdr:oneCellAnchor"].reconcile(n,l)})}}r.DRAWING_ATTRIBUTES={"xmlns:v":"urn:schemas-microsoft-com:vml","xmlns:o":"urn:schemas-microsoft-com:office:office","xmlns:x":"urn:schemas-microsoft-com:office:excel"},T.exports=r},{"../../../utils/xml-stream":28,"../base-xform":32,"./vml-shape-xform":46}],46:[function(s,T,S){const m=s("../base-xform"),a=s("./vml-textbox-xform"),o=s("./vml-client-data-xform");class r extends m{constructor(){super(),this.map={"v:textbox":new a,"x:ClientData":new o}}get tag(){return"v:shape"}render(e,l,n){e.openNode("v:shape",r.V_SHAPE_ATTRIBUTES(l,n)),e.leafNode("v:fill",{color2:"infoBackground [80]"}),e.leafNode("v:shadow",{color:"none [81]",obscured:"t"}),e.leafNode("v:path",{"o:connecttype":"none"}),this.map["v:textbox"].render(e,l),this.map["x:ClientData"].render(e,l),e.closeNode()}parseOpen(e){if(this.parser)return this.parser.parseOpen(e),!0;switch(e.name){case this.tag:this.reset(),this.model={margins:{insetmode:e.attributes["o:insetmode"]},anchor:"",editAs:"",protection:{}};break;default:this.parser=this.map[e.name],this.parser&&this.parser.parseOpen(e)}return!0}parseText(e){this.parser&&this.parser.parseText(e)}parseClose(e){if(this.parser)return this.parser.parseClose(e)||(this.parser=void 0),!0;switch(e){case this.tag:return this.model.margins.inset=this.map["v:textbox"].model&&this.map["v:textbox"].model.inset,this.model.protection=this.map["x:ClientData"].model&&this.map["x:ClientData"].model.protection,this.model.anchor=this.map["x:ClientData"].model&&this.map["x:ClientData"].model.anchor,this.model.editAs=this.map["x:ClientData"].model&&this.map["x:ClientData"].model.editAs,!1;default:return!0}}}r.V_SHAPE_ATTRIBUTES=(t,e)=>({id:"_x0000_s"+(1025+e),type:"#_x0000_t202",style:"position:absolute; margin-left:105.3pt;margin-top:10.5pt;width:97.8pt;height:59.1pt;z-index:1;visibility:hidden",fillcolor:"infoBackground [80]",strokecolor:"none [81]","o:insetmode":t.note.margins&&t.note.margins.insetmode}),T.exports=r},{"../base-xform":32,"./vml-client-data-xform":44,"./vml-textbox-xform":47}],47:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"v:textbox"}conversionUnit(a,o,r){return`${parseFloat(a)*o.toFixed(2)}${r}`}reverseConversionUnit(a){return(a||"").split(",").map(o=>Number(parseFloat(this.conversionUnit(parseFloat(o),.1,"")).toFixed(2)))}render(a,o){const r={style:"mso-direction-alt:auto"};if(o&&o.note){let{inset:t}=o.note&&o.note.margins;Array.isArray(t)&&(t=t.map(e=>this.conversionUnit(e,10,"mm")).join(",")),t&&(r.inset=t)}a.openNode("v:textbox",r),a.leafNode("div",{style:"text-align:left"}),a.closeNode()}parseOpen(a){switch(a.name){case this.tag:return this.model={inset:this.reverseConversionUnit(a.attributes.inset)},!0;default:return!0}}parseText(){}parseClose(a){switch(a){case this.tag:return!1;default:return!0}}}},{"../base-xform":32}],48:[function(s,T,S){const m=s("./base-xform");T.exports=class extends m{createNewModel(a){return{}}parseOpen(a){return this.parser=this.parser||this.map[a.name],this.parser?(this.parser.parseOpen(a),!0):a.name===this.tag&&(this.model=this.createNewModel(a),!0)}parseText(a){this.parser&&this.parser.parseText(a)}onParserClose(a,o){this.model[a]=o.model}parseClose(a){return this.parser?(this.parser.parseClose(a)||(this.onParserClose(a,this.parser),this.parser=void 0),!0):a!==this.tag}}},{"./base-xform":32}],49:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{render(a,o){a.openNode("HeadingPairs"),a.openNode("vt:vector",{size:2,baseType:"variant"}),a.openNode("vt:variant"),a.leafNode("vt:lpstr",void 0,"Worksheets"),a.closeNode(),a.openNode("vt:variant"),a.leafNode("vt:i4",void 0,o.length),a.closeNode(),a.closeNode(),a.closeNode()}parseOpen(a){return a.name==="HeadingPairs"}parseText(){}parseClose(a){return a!=="HeadingPairs"}}},{"../base-xform":32}],50:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{render(a,o){a.openNode("TitlesOfParts"),a.openNode("vt:vector",{size:o.length,baseType:"lpstr"}),o.forEach(r=>{a.leafNode("vt:lpstr",void 0,r.name)}),a.closeNode(),a.closeNode()}parseOpen(a){return a.name==="TitlesOfParts"}parseText(){}parseClose(a){return a!=="TitlesOfParts"}}},{"../base-xform":32}],51:[function(s,T,S){const m=s("../../../utils/xml-stream"),a=s("../base-xform"),o=s("../simple/string-xform"),r=s("./app-heading-pairs-xform"),t=s("./app-titles-of-parts-xform");class e extends a{constructor(){super(),this.map={Company:new o({tag:"Company"}),Manager:new o({tag:"Manager"}),HeadingPairs:new r,TitleOfParts:new t}}render(n,i){n.openXml(m.StdDocAttributes),n.openNode("Properties",e.PROPERTY_ATTRIBUTES),n.leafNode("Application",void 0,"Microsoft Excel"),n.leafNode("DocSecurity",void 0,"0"),n.leafNode("ScaleCrop",void 0,"false"),this.map.HeadingPairs.render(n,i.worksheets),this.map.TitleOfParts.render(n,i.worksheets),this.map.Company.render(n,i.company||""),this.map.Manager.render(n,i.manager),n.leafNode("LinksUpToDate",void 0,"false"),n.leafNode("SharedDoc",void 0,"false"),n.leafNode("HyperlinksChanged",void 0,"false"),n.leafNode("AppVersion",void 0,"16.0300"),n.closeNode()}parseOpen(n){if(this.parser)return this.parser.parseOpen(n),!0;switch(n.name){case"Properties":return!0;default:return this.parser=this.map[n.name],!!this.parser&&(this.parser.parseOpen(n),!0)}}parseText(n){this.parser&&this.parser.parseText(n)}parseClose(n){if(this.parser)return this.parser.parseClose(n)||(this.parser=void 0),!0;switch(n){case"Properties":return this.model={worksheets:this.map.TitleOfParts.model,company:this.map.Company.model,manager:this.map.Manager.model},!1;default:return!0}}}e.DateFormat=function(l){return l.toISOString().replace(/[.]\d{3,6}/,"")},e.DateAttrs={"xsi:type":"dcterms:W3CDTF"},e.PROPERTY_ATTRIBUTES={xmlns:"http://schemas.openxmlformats.org/officeDocument/2006/extended-properties","xmlns:vt":"http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes"},T.exports=e},{"../../../utils/xml-stream":28,"../base-xform":32,"../simple/string-xform":119,"./app-heading-pairs-xform":49,"./app-titles-of-parts-xform":50}],52:[function(s,T,S){const m=s("../../../utils/xml-stream"),a=s("../base-xform");class o extends a{render(t,e){t.openXml(m.StdDocAttributes),t.openNode("Types",o.PROPERTY_ATTRIBUTES);const l={};(e.media||[]).forEach(n=>{if(n.type==="image"){const i=n.extension;l[i]||(l[i]=!0,t.leafNode("Default",{Extension:i,ContentType:"image/"+i}))}}),t.leafNode("Default",{Extension:"rels",ContentType:"application/vnd.openxmlformats-package.relationships+xml"}),t.leafNode("Default",{Extension:"xml",ContentType:"application/xml"}),t.leafNode("Override",{PartName:"/xl/workbook.xml",ContentType:"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml"}),e.worksheets.forEach(n=>{const i=`/xl/worksheets/sheet${n.id}.xml`;t.leafNode("Override",{PartName:i,ContentType:"application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml"})}),t.leafNode("Override",{PartName:"/xl/theme/theme1.xml",ContentType:"application/vnd.openxmlformats-officedocument.theme+xml"}),t.leafNode("Override",{PartName:"/xl/styles.xml",ContentType:"application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml"}),e.sharedStrings&&e.sharedStrings.count&&t.leafNode("Override",{PartName:"/xl/sharedStrings.xml",ContentType:"application/vnd.openxmlformats-officedocument.spreadsheetml.sharedStrings+xml"}),e.tables&&e.tables.forEach(n=>{t.leafNode("Override",{PartName:"/xl/tables/"+n.target,ContentType:"application/vnd.openxmlformats-officedocument.spreadsheetml.table+xml"})}),e.drawings&&e.drawings.forEach(n=>{t.leafNode("Override",{PartName:`/xl/drawings/${n.name}.xml`,ContentType:"application/vnd.openxmlformats-officedocument.drawing+xml"})}),e.commentRefs&&(t.leafNode("Default",{Extension:"vml",ContentType:"application/vnd.openxmlformats-officedocument.vmlDrawing"}),e.commentRefs.forEach(n=>{let{commentName:i}=n;t.leafNode("Override",{PartName:`/xl/${i}.xml`,ContentType:"application/vnd.openxmlformats-officedocument.spreadsheetml.comments+xml"})})),t.leafNode("Override",{PartName:"/docProps/core.xml",ContentType:"application/vnd.openxmlformats-package.core-properties+xml"}),t.leafNode("Override",{PartName:"/docProps/app.xml",ContentType:"application/vnd.openxmlformats-officedocument.extended-properties+xml"}),t.closeNode()}parseOpen(){return!1}parseText(){}parseClose(){return!1}}o.PROPERTY_ATTRIBUTES={xmlns:"http://schemas.openxmlformats.org/package/2006/content-types"},T.exports=o},{"../../../utils/xml-stream":28,"../base-xform":32}],53:[function(s,T,S){const m=s("../../../utils/xml-stream"),a=s("../base-xform"),o=s("../simple/date-xform"),r=s("../simple/string-xform"),t=s("../simple/integer-xform");class e extends a{constructor(){super(),this.map={"dc:creator":new r({tag:"dc:creator"}),"dc:title":new r({tag:"dc:title"}),"dc:subject":new r({tag:"dc:subject"}),"dc:description":new r({tag:"dc:description"}),"dc:identifier":new r({tag:"dc:identifier"}),"dc:language":new r({tag:"dc:language"}),"cp:keywords":new r({tag:"cp:keywords"}),"cp:category":new r({tag:"cp:category"}),"cp:lastModifiedBy":new r({tag:"cp:lastModifiedBy"}),"cp:lastPrinted":new o({tag:"cp:lastPrinted",format:e.DateFormat}),"cp:revision":new t({tag:"cp:revision"}),"cp:version":new r({tag:"cp:version"}),"cp:contentStatus":new r({tag:"cp:contentStatus"}),"cp:contentType":new r({tag:"cp:contentType"}),"dcterms:created":new o({tag:"dcterms:created",attrs:e.DateAttrs,format:e.DateFormat}),"dcterms:modified":new o({tag:"dcterms:modified",attrs:e.DateAttrs,format:e.DateFormat})}}render(n,i){n.openXml(m.StdDocAttributes),n.openNode("cp:coreProperties",e.CORE_PROPERTY_ATTRIBUTES),this.map["dc:creator"].render(n,i.creator),this.map["dc:title"].render(n,i.title),this.map["dc:subject"].render(n,i.subject),this.map["dc:description"].render(n,i.description),this.map["dc:identifier"].render(n,i.identifier),this.map["dc:language"].render(n,i.language),this.map["cp:keywords"].render(n,i.keywords),this.map["cp:category"].render(n,i.category),this.map["cp:lastModifiedBy"].render(n,i.lastModifiedBy),this.map["cp:lastPrinted"].render(n,i.lastPrinted),this.map["cp:revision"].render(n,i.revision),this.map["cp:version"].render(n,i.version),this.map["cp:contentStatus"].render(n,i.contentStatus),this.map["cp:contentType"].render(n,i.contentType),this.map["dcterms:created"].render(n,i.created),this.map["dcterms:modified"].render(n,i.modified),n.closeNode()}parseOpen(n){if(this.parser)return this.parser.parseOpen(n),!0;switch(n.name){case"cp:coreProperties":case"coreProperties":return!0;default:if(this.parser=this.map[n.name],this.parser)return this.parser.parseOpen(n),!0;throw new Error("Unexpected xml node in parseOpen: "+JSON.stringify(n))}}parseText(n){this.parser&&this.parser.parseText(n)}parseClose(n){if(this.parser)return this.parser.parseClose(n)||(this.parser=void 0),!0;switch(n){case"cp:coreProperties":case"coreProperties":return this.model={creator:this.map["dc:creator"].model,title:this.map["dc:title"].model,subject:this.map["dc:subject"].model,description:this.map["dc:description"].model,identifier:this.map["dc:identifier"].model,language:this.map["dc:language"].model,keywords:this.map["cp:keywords"].model,category:this.map["cp:category"].model,lastModifiedBy:this.map["cp:lastModifiedBy"].model,lastPrinted:this.map["cp:lastPrinted"].model,revision:this.map["cp:revision"].model,contentStatus:this.map["cp:contentStatus"].model,contentType:this.map["cp:contentType"].model,created:this.map["dcterms:created"].model,modified:this.map["dcterms:modified"].model},!1;default:throw new Error("Unexpected xml node in parseClose: "+n)}}}e.DateFormat=function(l){return l.toISOString().replace(/[.]\d{3}/,"")},e.DateAttrs={"xsi:type":"dcterms:W3CDTF"},e.CORE_PROPERTY_ATTRIBUTES={"xmlns:cp":"http://schemas.openxmlformats.org/package/2006/metadata/core-properties","xmlns:dc":"http://purl.org/dc/elements/1.1/","xmlns:dcterms":"http://purl.org/dc/terms/","xmlns:dcmitype":"http://purl.org/dc/dcmitype/","xmlns:xsi":"http://www.w3.org/2001/XMLSchema-instance"},T.exports=e},{"../../../utils/xml-stream":28,"../base-xform":32,"../simple/date-xform":117,"../simple/integer-xform":118,"../simple/string-xform":119}],54:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{render(a,o){a.leafNode("Relationship",o)}parseOpen(a){switch(a.name){case"Relationship":return this.model=a.attributes,!0;default:return!1}}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],55:[function(s,T,S){const m=s("../../../utils/xml-stream"),a=s("../base-xform"),o=s("./relationship-xform");class r extends a{constructor(){super(),this.map={Relationship:new o}}render(e,l){l=l||this._values,e.openXml(m.StdDocAttributes),e.openNode("Relationships",r.RELATIONSHIPS_ATTRIBUTES),l.forEach(n=>{this.map.Relationship.render(e,n)}),e.closeNode()}parseOpen(e){if(this.parser)return this.parser.parseOpen(e),!0;switch(e.name){case"Relationships":return this.model=[],!0;default:if(this.parser=this.map[e.name],this.parser)return this.parser.parseOpen(e),!0;throw new Error("Unexpected xml node in parseOpen: "+JSON.stringify(e))}}parseText(e){this.parser&&this.parser.parseText(e)}parseClose(e){if(this.parser)return this.parser.parseClose(e)||(this.model.push(this.parser.model),this.parser=void 0),!0;switch(e){case"Relationships":return!1;default:throw new Error("Unexpected xml node in parseClose: "+e)}}}r.RELATIONSHIPS_ATTRIBUTES={xmlns:"http://schemas.openxmlformats.org/package/2006/relationships"},T.exports=r},{"../../../utils/xml-stream":28,"../base-xform":32,"./relationship-xform":54}],56:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{parseOpen(a){if(this.parser)return this.parser.parseOpen(a),!0;switch(a.name){case this.tag:this.reset(),this.model={range:{editAs:a.attributes.editAs||"oneCell"}};break;default:this.parser=this.map[a.name],this.parser&&this.parser.parseOpen(a)}return!0}parseText(a){this.parser&&this.parser.parseText(a)}reconcilePicture(a,o){if(a&&a.rId){const r=o.rels[a.rId].Target.match(/.*\/media\/(.+[.][a-zA-Z]{3,4})/);if(r){const t=r[1],e=o.mediaIndex[t];return o.media[e]}}}}},{"../base-xform":32}],57:[function(s,T,S){const m=s("../base-xform"),a=s("./blip-xform");T.exports=class extends m{constructor(){super(),this.map={"a:blip":new a}}get tag(){return"xdr:blipFill"}render(o,r){o.openNode(this.tag),this.map["a:blip"].render(o,r),o.openNode("a:stretch"),o.leafNode("a:fillRect"),o.closeNode(),o.closeNode()}parseOpen(o){if(this.parser)return this.parser.parseOpen(o),!0;switch(o.name){case this.tag:this.reset();break;default:this.parser=this.map[o.name],this.parser&&this.parser.parseOpen(o)}return!0}parseText(){}parseClose(o){if(this.parser)return this.parser.parseClose(o)||(this.parser=void 0),!0;switch(o){case this.tag:return this.model=this.map["a:blip"].model,!1;default:return!0}}}},{"../base-xform":32,"./blip-xform":58}],58:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"a:blip"}render(a,o){a.leafNode(this.tag,{"xmlns:r":"http://schemas.openxmlformats.org/officeDocument/2006/relationships","r:embed":o.rId,cstate:"print"})}parseOpen(a){switch(a.name){case this.tag:return this.model={rId:a.attributes["r:embed"]},!0;default:return!0}}parseText(){}parseClose(a){switch(a){case this.tag:return!1;default:return!0}}}},{"../base-xform":32}],59:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"xdr:cNvPicPr"}render(a){a.openNode(this.tag),a.leafNode("a:picLocks",{noChangeAspect:"1"}),a.closeNode()}parseOpen(a){switch(a.name){case this.tag:default:return!0}}parseText(){}parseClose(a){switch(a){case this.tag:return!1;default:return!0}}}},{"../base-xform":32}],60:[function(s,T,S){const m=s("../base-xform"),a=s("./hlink-click-xform"),o=s("./ext-lst-xform");T.exports=class extends m{constructor(){super(),this.map={"a:hlinkClick":new a,"a:extLst":new o}}get tag(){return"xdr:cNvPr"}render(r,t){r.openNode(this.tag,{id:t.index,name:"Picture "+t.index}),this.map["a:hlinkClick"].render(r,t),this.map["a:extLst"].render(r,t),r.closeNode()}parseOpen(r){if(this.parser)return this.parser.parseOpen(r),!0;switch(r.name){case this.tag:this.reset();break;default:this.parser=this.map[r.name],this.parser&&this.parser.parseOpen(r)}return!0}parseText(){}parseClose(r){if(this.parser)return this.parser.parseClose(r)||(this.parser=void 0),!0;switch(r){case this.tag:return this.model=this.map["a:hlinkClick"].model,!1;default:return!0}}}},{"../base-xform":32,"./ext-lst-xform":63,"./hlink-click-xform":65}],61:[function(s,T,S){const m=s("../base-xform"),a=s("../simple/integer-xform");T.exports=class extends m{constructor(o){super(),this.tag=o.tag,this.map={"xdr:col":new a({tag:"xdr:col",zero:!0}),"xdr:colOff":new a({tag:"xdr:colOff",zero:!0}),"xdr:row":new a({tag:"xdr:row",zero:!0}),"xdr:rowOff":new a({tag:"xdr:rowOff",zero:!0})}}render(o,r){o.openNode(this.tag),this.map["xdr:col"].render(o,r.nativeCol),this.map["xdr:colOff"].render(o,r.nativeColOff),this.map["xdr:row"].render(o,r.nativeRow),this.map["xdr:rowOff"].render(o,r.nativeRowOff),o.closeNode()}parseOpen(o){if(this.parser)return this.parser.parseOpen(o),!0;switch(o.name){case this.tag:this.reset();break;default:this.parser=this.map[o.name],this.parser&&this.parser.parseOpen(o)}return!0}parseText(o){this.parser&&this.parser.parseText(o)}parseClose(o){if(this.parser)return this.parser.parseClose(o)||(this.parser=void 0),!0;switch(o){case this.tag:return this.model={nativeCol:this.map["xdr:col"].model,nativeColOff:this.map["xdr:colOff"].model,nativeRow:this.map["xdr:row"].model,nativeRowOff:this.map["xdr:rowOff"].model},!1;default:return!0}}}},{"../base-xform":32,"../simple/integer-xform":118}],62:[function(s,T,S){const m=s("../../../utils/col-cache"),a=s("../../../utils/xml-stream"),o=s("../base-xform"),r=s("./two-cell-anchor-xform"),t=s("./one-cell-anchor-xform");class e extends o{constructor(){super(),this.map={"xdr:twoCellAnchor":new r,"xdr:oneCellAnchor":new t}}prepare(n){n.anchors.forEach((i,f)=>{i.anchorType=function(c){return(typeof c.range=="string"?m.decode(c.range):c.range).br?"xdr:twoCellAnchor":"xdr:oneCellAnchor"}(i),this.map[i.anchorType].prepare(i,{index:f})})}get tag(){return"xdr:wsDr"}render(n,i){n.openXml(a.StdDocAttributes),n.openNode(this.tag,e.DRAWING_ATTRIBUTES),i.anchors.forEach(f=>{this.map[f.anchorType].render(n,f)}),n.closeNode()}parseOpen(n){if(this.parser)return this.parser.parseOpen(n),!0;switch(n.name){case this.tag:this.reset(),this.model={anchors:[]};break;default:this.parser=this.map[n.name],this.parser&&this.parser.parseOpen(n)}return!0}parseText(n){this.parser&&this.parser.parseText(n)}parseClose(n){if(this.parser)return this.parser.parseClose(n)||(this.model.anchors.push(this.parser.model),this.parser=void 0),!0;switch(n){case this.tag:return!1;default:return!0}}reconcile(n,i){n.anchors.forEach(f=>{f.br?this.map["xdr:twoCellAnchor"].reconcile(f,i):this.map["xdr:oneCellAnchor"].reconcile(f,i)})}}e.DRAWING_ATTRIBUTES={"xmlns:xdr":"http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing","xmlns:a":"http://schemas.openxmlformats.org/drawingml/2006/main"},T.exports=e},{"../../../utils/col-cache":19,"../../../utils/xml-stream":28,"../base-xform":32,"./one-cell-anchor-xform":67,"./two-cell-anchor-xform":70}],63:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"a:extLst"}render(a){a.openNode(this.tag),a.openNode("a:ext",{uri:"{FF2B5EF4-FFF2-40B4-BE49-F238E27FC236}"}),a.leafNode("a16:creationId",{"xmlns:a16":"http://schemas.microsoft.com/office/drawing/2014/main",id:"{00000000-0008-0000-0000-000002000000}"}),a.closeNode(),a.closeNode()}parseOpen(a){switch(a.name){case this.tag:default:return!0}}parseText(){}parseClose(a){switch(a){case this.tag:return!1;default:return!0}}}},{"../base-xform":32}],64:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{constructor(a){super(),this.tag=a.tag,this.map={}}render(a,o){a.openNode(this.tag);const r=Math.floor(9525*o.width),t=Math.floor(9525*o.height);a.addAttribute("cx",r),a.addAttribute("cy",t),a.closeNode()}parseOpen(a){return a.name===this.tag&&(this.model={width:parseInt(a.attributes.cx||"0",10)/9525,height:parseInt(a.attributes.cy||"0",10)/9525},!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],65:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"a:hlinkClick"}render(a,o){o.hyperlinks&&o.hyperlinks.rId&&a.leafNode(this.tag,{"xmlns:r":"http://schemas.openxmlformats.org/officeDocument/2006/relationships","r:id":o.hyperlinks.rId,tooltip:o.hyperlinks.tooltip})}parseOpen(a){switch(a.name){case this.tag:return this.model={hyperlinks:{rId:a.attributes["r:id"],tooltip:a.attributes.tooltip}},!0;default:return!0}}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],66:[function(s,T,S){const m=s("../base-xform"),a=s("./c-nv-pr-xform"),o=s("./c-nv-pic-pr-xform");T.exports=class extends m{constructor(){super(),this.map={"xdr:cNvPr":new a,"xdr:cNvPicPr":new o}}get tag(){return"xdr:nvPicPr"}render(r,t){r.openNode(this.tag),this.map["xdr:cNvPr"].render(r,t),this.map["xdr:cNvPicPr"].render(r,t),r.closeNode()}parseOpen(r){if(this.parser)return this.parser.parseOpen(r),!0;switch(r.name){case this.tag:this.reset();break;default:this.parser=this.map[r.name],this.parser&&this.parser.parseOpen(r)}return!0}parseText(){}parseClose(r){if(this.parser)return this.parser.parseClose(r)||(this.parser=void 0),!0;switch(r){case this.tag:return this.model=this.map["xdr:cNvPr"].model,!1;default:return!0}}}},{"../base-xform":32,"./c-nv-pic-pr-xform":59,"./c-nv-pr-xform":60}],67:[function(s,T,S){const m=s("./base-cell-anchor-xform"),a=s("../static-xform"),o=s("./cell-position-xform"),r=s("./ext-xform"),t=s("./pic-xform");T.exports=class extends m{constructor(){super(),this.map={"xdr:from":new o({tag:"xdr:from"}),"xdr:ext":new r({tag:"xdr:ext"}),"xdr:pic":new t,"xdr:clientData":new a({tag:"xdr:clientData"})}}get tag(){return"xdr:oneCellAnchor"}prepare(e,l){this.map["xdr:pic"].prepare(e.picture,l)}render(e,l){e.openNode(this.tag,{editAs:l.range.editAs||"oneCell"}),this.map["xdr:from"].render(e,l.range.tl),this.map["xdr:ext"].render(e,l.range.ext),this.map["xdr:pic"].render(e,l.picture),this.map["xdr:clientData"].render(e,{}),e.closeNode()}parseClose(e){if(this.parser)return this.parser.parseClose(e)||(this.parser=void 0),!0;switch(e){case this.tag:return this.model.range.tl=this.map["xdr:from"].model,this.model.range.ext=this.map["xdr:ext"].model,this.model.picture=this.map["xdr:pic"].model,!1;default:return!0}}reconcile(e,l){e.medium=this.reconcilePicture(e.picture,l)}}},{"../static-xform":120,"./base-cell-anchor-xform":56,"./cell-position-xform":61,"./ext-xform":64,"./pic-xform":68}],68:[function(s,T,S){const m=s("../base-xform"),a=s("../static-xform"),o=s("./blip-fill-xform"),r=s("./nv-pic-pr-xform"),t=s("./sp-pr");T.exports=class extends m{constructor(){super(),this.map={"xdr:nvPicPr":new r,"xdr:blipFill":new o,"xdr:spPr":new a(t)}}get tag(){return"xdr:pic"}prepare(e,l){e.index=l.index+1}render(e,l){e.openNode(this.tag),this.map["xdr:nvPicPr"].render(e,l),this.map["xdr:blipFill"].render(e,l),this.map["xdr:spPr"].render(e,l),e.closeNode()}parseOpen(e){if(this.parser)return this.parser.parseOpen(e),!0;switch(e.name){case this.tag:this.reset();break;default:this.parser=this.map[e.name],this.parser&&this.parser.parseOpen(e)}return!0}parseText(){}parseClose(e){if(this.parser)return this.parser.parseClose(e)||(this.mergeModel(this.parser.model),this.parser=void 0),!0;switch(e){case this.tag:return!1;default:return!0}}}},{"../base-xform":32,"../static-xform":120,"./blip-fill-xform":57,"./nv-pic-pr-xform":66,"./sp-pr":69}],69:[function(s,T,S){T.exports={tag:"xdr:spPr",c:[{tag:"a:xfrm",c:[{tag:"a:off",$:{x:"0",y:"0"}},{tag:"a:ext",$:{cx:"0",cy:"0"}}]},{tag:"a:prstGeom",$:{prst:"rect"},c:[{tag:"a:avLst"}]}]}},{}],70:[function(s,T,S){const m=s("./base-cell-anchor-xform"),a=s("../static-xform"),o=s("./cell-position-xform"),r=s("./pic-xform");T.exports=class extends m{constructor(){super(),this.map={"xdr:from":new o({tag:"xdr:from"}),"xdr:to":new o({tag:"xdr:to"}),"xdr:pic":new r,"xdr:clientData":new a({tag:"xdr:clientData"})}}get tag(){return"xdr:twoCellAnchor"}prepare(t,e){this.map["xdr:pic"].prepare(t.picture,e)}render(t,e){t.openNode(this.tag,{editAs:e.range.editAs||"oneCell"}),this.map["xdr:from"].render(t,e.range.tl),this.map["xdr:to"].render(t,e.range.br),this.map["xdr:pic"].render(t,e.picture),this.map["xdr:clientData"].render(t,{}),t.closeNode()}parseClose(t){if(this.parser)return this.parser.parseClose(t)||(this.parser=void 0),!0;switch(t){case this.tag:return this.model.range.tl=this.map["xdr:from"].model,this.model.range.br=this.map["xdr:to"].model,this.model.picture=this.map["xdr:pic"].model,!1;default:return!0}}reconcile(t,e){t.medium=this.reconcilePicture(t.picture,e)}}},{"../static-xform":120,"./base-cell-anchor-xform":56,"./cell-position-xform":61,"./pic-xform":68}],71:[function(s,T,S){const m=s("./base-xform");T.exports=class extends m{constructor(a){super(),this.tag=a.tag,this.always=!!a.always,this.count=a.count,this.empty=a.empty,this.$count=a.$count||"count",this.$=a.$,this.childXform=a.childXform,this.maxItems=a.maxItems}prepare(a,o){const{childXform:r}=this;a&&a.forEach((t,e)=>{o.index=e,r.prepare(t,o)})}render(a,o){if(this.always||o&&o.length){a.openNode(this.tag,this.$),this.count&&a.addAttribute(this.$count,o&&o.length||0);const{childXform:r}=this;(o||[]).forEach((t,e)=>{r.render(a,t,e)}),a.closeNode()}else this.empty&&a.leafNode(this.tag)}parseOpen(a){if(this.parser)return this.parser.parseOpen(a),!0;switch(a.name){case this.tag:return this.model=[],!0;default:return!!this.childXform.parseOpen(a)&&(this.parser=this.childXform,!0)}}parseText(a){this.parser&&this.parser.parseText(a)}parseClose(a){if(this.parser){if(!this.parser.parseClose(a)&&(this.model.push(this.parser.model),this.parser=void 0,this.maxItems&&this.model.length>this.maxItems))throw new Error(`Max ${this.childXform.tag} count (${this.maxItems}) exceeded`);return!0}return!1}reconcile(a,o){if(a){const{childXform:r}=this;a.forEach(t=>{r.reconcile(t,o)})}}}},{"./base-xform":32}],72:[function(s,T,S){const m=s("../../../utils/col-cache"),a=s("../base-xform");T.exports=class extends a{get tag(){return"autoFilter"}render(o,r){if(r)if(typeof r=="string")o.leafNode("autoFilter",{ref:r});else{const t=function(n){return typeof n=="string"?n:m.getAddress(n.row,n.column).address},e=t(r.from),l=t(r.to);e&&l&&o.leafNode("autoFilter",{ref:`${e}:${l}`})}}parseOpen(o){o.name==="autoFilter"&&(this.model=o.attributes.ref)}}},{"../../../utils/col-cache":19,"../base-xform":32}],73:[function(s,T,S){const m=s("../../../utils/utils"),a=s("../base-xform"),o=s("../../../doc/range"),r=s("../../../doc/enums"),t=s("../strings/rich-text-xform");function e(l){if(l==null)return r.ValueType.Null;if(l instanceof String||typeof l=="string")return r.ValueType.String;if(typeof l=="number")return r.ValueType.Number;if(typeof l=="boolean")return r.ValueType.Boolean;if(l instanceof Date)return r.ValueType.Date;if(l.text&&l.hyperlink)return r.ValueType.Hyperlink;if(l.formula)return r.ValueType.Formula;if(l.error)return r.ValueType.Error;throw new Error("I could not understand type of value")}T.exports=class extends a{constructor(){super(),this.richTextXForm=new t}get tag(){return"c"}prepare(l,n){const i=n.styles.addStyleModel(l.style||{},function(f){switch(f.type){case r.ValueType.Formula:return e(f.result);default:return f.type}}(l));switch(i&&(l.styleId=i),l.comment&&n.comments.push({...l.comment,ref:l.address}),l.type){case r.ValueType.String:case r.ValueType.RichText:n.sharedStrings&&(l.ssId=n.sharedStrings.add(l.value));break;case r.ValueType.Date:n.date1904&&(l.date1904=!0);break;case r.ValueType.Hyperlink:n.sharedStrings&&l.text!==void 0&&l.text!==null&&(l.ssId=n.sharedStrings.add(l.text)),n.hyperlinks.push({address:l.address,target:l.hyperlink,tooltip:l.tooltip});break;case r.ValueType.Merge:n.merges.add(l);break;case r.ValueType.Formula:if(n.date1904&&(l.date1904=!0),l.shareType==="shared"&&(l.si=n.siFormulae++),l.formula)n.formulae[l.address]=l;else if(l.sharedFormula){const f=n.formulae[l.sharedFormula];if(!f)throw new Error("Shared Formula master must exist above and or left of clone for cell "+l.address);f.si===void 0?(f.shareType="shared",f.si=n.siFormulae++,f.range=new o(f.address,l.address)):f.range&&f.range.expandToAddress(l.address),l.si=f.si}}}renderFormula(l,n){let i=null;switch(n.shareType){case"shared":i={t:"shared",ref:n.ref||n.range.range,si:n.si};break;case"array":i={t:"array",ref:n.ref};break;default:n.si!==void 0&&(i={t:"shared",si:n.si})}switch(e(n.result)){case r.ValueType.Null:l.leafNode("f",i,n.formula);break;case r.ValueType.String:l.addAttribute("t","str"),l.leafNode("f",i,n.formula),l.leafNode("v",null,n.result);break;case r.ValueType.Number:l.leafNode("f",i,n.formula),l.leafNode("v",null,n.result);break;case r.ValueType.Boolean:l.addAttribute("t","b"),l.leafNode("f",i,n.formula),l.leafNode("v",null,n.result?1:0);break;case r.ValueType.Error:l.addAttribute("t","e"),l.leafNode("f",i,n.formula),l.leafNode("v",null,n.result.error);break;case r.ValueType.Date:l.leafNode("f",i,n.formula),l.leafNode("v",null,m.dateToExcel(n.result,n.date1904));break;default:throw new Error("I could not understand type of value")}}render(l,n){if(n.type!==r.ValueType.Null||n.styleId){switch(l.openNode("c"),l.addAttribute("r",n.address),n.styleId&&l.addAttribute("s",n.styleId),n.type){case r.ValueType.Null:break;case r.ValueType.Number:l.leafNode("v",null,n.value);break;case r.ValueType.Boolean:l.addAttribute("t","b"),l.leafNode("v",null,n.value?"1":"0");break;case r.ValueType.Error:l.addAttribute("t","e"),l.leafNode("v",null,n.value.error);break;case r.ValueType.String:case r.ValueType.RichText:n.ssId!==void 0?(l.addAttribute("t","s"),l.leafNode("v",null,n.ssId)):n.value&&n.value.richText?(l.addAttribute("t","inlineStr"),l.openNode("is"),n.value.richText.forEach(i=>{this.richTextXForm.render(l,i)}),l.closeNode("is")):(l.addAttribute("t","str"),l.leafNode("v",null,n.value));break;case r.ValueType.Date:l.leafNode("v",null,m.dateToExcel(n.value,n.date1904));break;case r.ValueType.Hyperlink:n.ssId!==void 0?(l.addAttribute("t","s"),l.leafNode("v",null,n.ssId)):(l.addAttribute("t","str"),l.leafNode("v",null,n.text));break;case r.ValueType.Formula:this.renderFormula(l,n);break;case r.ValueType.Merge:}l.closeNode()}}parseOpen(l){if(this.parser)return this.parser.parseOpen(l),!0;switch(l.name){case"c":return this.model={address:l.attributes.r},this.t=l.attributes.t,l.attributes.s&&(this.model.styleId=parseInt(l.attributes.s,10)),!0;case"f":return this.currentNode="f",this.model.si=l.attributes.si,this.model.shareType=l.attributes.t,this.model.ref=l.attributes.ref,!0;case"v":return this.currentNode="v",!0;case"t":return this.currentNode="t",!0;case"r":return this.parser=this.richTextXForm,this.parser.parseOpen(l),!0;default:return!1}}parseText(l){if(this.parser)this.parser.parseText(l);else switch(this.currentNode){case"f":this.model.formula=this.model.formula?this.model.formula+l:l;break;case"v":case"t":this.model.value&&this.model.value.richText?this.model.value.richText.text=this.model.value.richText.text?this.model.value.richText.text+l:l:this.model.value=this.model.value?this.model.value+l:l}}parseClose(l){switch(l){case"c":{const{model:n}=this;if(n.formula||n.shareType)n.type=r.ValueType.Formula,n.value&&(this.t==="str"?n.result=m.xmlDecode(n.value):this.t==="b"?n.result=parseInt(n.value,10)!==0:this.t==="e"?n.result={error:n.value}:n.result=parseFloat(n.value),n.value=void 0);else if(n.value!==void 0)switch(this.t){case"s":n.type=r.ValueType.String,n.value=parseInt(n.value,10);break;case"str":n.type=r.ValueType.String,n.value=m.xmlDecode(n.value);break;case"inlineStr":n.type=r.ValueType.String;break;case"b":n.type=r.ValueType.Boolean,n.value=parseInt(n.value,10)!==0;break;case"e":n.type=r.ValueType.Error,n.value={error:n.value};break;default:n.type=r.ValueType.Number,n.value=parseFloat(n.value)}else n.styleId?n.type=r.ValueType.Null:n.type=r.ValueType.Merge;return!1}case"f":case"v":case"is":return this.currentNode=void 0,!0;case"t":return this.parser?(this.parser.parseClose(l),!0):(this.currentNode=void 0,!0);case"r":return this.model.value=this.model.value||{},this.model.value.richText=this.model.value.richText||[],this.model.value.richText.push(this.parser.model),this.parser=void 0,this.currentNode=void 0,!0;default:return!!this.parser&&(this.parser.parseClose(l),!0)}}reconcile(l,n){const i=l.styleId&&n.styles&&n.styles.getStyleModel(l.styleId);switch(i&&(l.style=i),l.styleId!==void 0&&(l.styleId=void 0),l.type){case r.ValueType.String:typeof l.value=="number"&&n.sharedStrings&&(l.value=n.sharedStrings.getString(l.value)),l.value.richText&&(l.type=r.ValueType.RichText);break;case r.ValueType.Number:i&&m.isDateFmt(i.numFmt)&&(l.type=r.ValueType.Date,l.value=m.excelToDate(l.value,n.date1904));break;case r.ValueType.Formula:l.result!==void 0&&i&&m.isDateFmt(i.numFmt)&&(l.result=m.excelToDate(l.result,n.date1904)),l.shareType==="shared"&&(l.ref?n.formulae[l.si]=l.address:(l.sharedFormula=n.formulae[l.si],delete l.shareType),delete l.si)}const f=n.hyperlinkMap[l.address];f&&(l.type===r.ValueType.Formula?(l.text=l.result,l.result=void 0):(l.text=l.value,l.value=void 0),l.type=r.ValueType.Hyperlink,l.hyperlink=f);const c=n.commentsMap&&n.commentsMap[l.address];c&&(l.comment=c)}}},{"../../../doc/enums":7,"../../../doc/range":10,"../../../utils/utils":27,"../base-xform":32,"../strings/rich-text-xform":122}],74:[function(s,T,S){const m=s("../../base-xform");T.exports=class extends m{get tag(){return"x14:cfIcon"}render(a,o){a.leafNode(this.tag,{iconSet:o.iconSet,iconId:o.iconId})}parseOpen(a){let{attributes:o}=a;this.model={iconSet:o.iconSet,iconId:m.toIntValue(o.iconId)}}parseClose(a){return a!==this.tag}}},{"../../base-xform":32}],75:[function(s,T,S){const{v4:m}=s("uuid"),a=s("../../base-xform"),o=s("../../composite-xform"),r=s("./databar-ext-xform"),t=s("./icon-set-ext-xform"),e={"3Triangles":!0,"3Stars":!0,"5Boxes":!0};class l extends o{constructor(){super(),this.map={"x14:dataBar":this.databarXform=new r,"x14:iconSet":this.iconSetXform=new t}}get tag(){return"x14:cfRule"}static isExt(i){return i.type==="dataBar"?r.isExt(i):!(i.type!=="iconSet"||!i.custom&&!e[i.iconSet])}prepare(i){l.isExt(i)&&(i.x14Id=`{${m()}}`.toUpperCase())}render(i,f){if(l.isExt(f))switch(f.type){case"dataBar":this.renderDataBar(i,f);break;case"iconSet":this.renderIconSet(i,f)}}renderDataBar(i,f){i.openNode(this.tag,{type:"dataBar",id:f.x14Id}),this.databarXform.render(i,f),i.closeNode()}renderIconSet(i,f){i.openNode(this.tag,{type:"iconSet",priority:f.priority,id:f.x14Id||`{${m()}}`}),this.iconSetXform.render(i,f),i.closeNode()}createNewModel(i){let{attributes:f}=i;return{type:f.type,x14Id:f.id,priority:a.toIntValue(f.priority)}}onParserClose(i,f){Object.assign(this.model,f.model)}}T.exports=l},{"../../base-xform":32,"../../composite-xform":48,"./databar-ext-xform":79,"./icon-set-ext-xform":81,uuid:528}],76:[function(s,T,S){const m=s("../../composite-xform"),a=s("./f-ext-xform");T.exports=class extends m{constructor(){super(),this.map={"xm:f":this.fExtXform=new a}}get tag(){return"x14:cfvo"}render(o,r){o.openNode(this.tag,{type:r.type}),r.value!==void 0&&this.fExtXform.render(o,r.value),o.closeNode()}createNewModel(o){return{type:o.attributes.type}}onParserClose(o,r){switch(o){case"xm:f":this.model.value=r.model?parseFloat(r.model):0}}}},{"../../composite-xform":48,"./f-ext-xform":80}],77:[function(s,T,S){const m=s("../../composite-xform"),a=s("./sqref-ext-xform"),o=s("./cf-rule-ext-xform");T.exports=class extends m{constructor(){super(),this.map={"xm:sqref":this.sqRef=new a,"x14:cfRule":this.cfRule=new o}}get tag(){return"x14:conditionalFormatting"}prepare(r,t){r.rules.forEach(e=>{this.cfRule.prepare(e,t)})}render(r,t){t.rules.some(o.isExt)&&(r.openNode(this.tag,{"xmlns:xm":"http://schemas.microsoft.com/office/excel/2006/main"}),t.rules.filter(o.isExt).forEach(e=>this.cfRule.render(r,e)),this.sqRef.render(r,t.ref),r.closeNode())}createNewModel(){return{rules:[]}}onParserClose(r,t){switch(r){case"xm:sqref":this.model.ref=t.model;break;case"x14:cfRule":this.model.rules.push(t.model)}}}},{"../../composite-xform":48,"./cf-rule-ext-xform":75,"./sqref-ext-xform":82}],78:[function(s,T,S){const m=s("../../composite-xform"),a=s("./cf-rule-ext-xform"),o=s("./conditional-formatting-ext-xform");T.exports=class extends m{constructor(){super(),this.map={"x14:conditionalFormatting":this.cfXform=new o}}get tag(){return"x14:conditionalFormattings"}hasContent(r){return r.hasExtContent===void 0&&(r.hasExtContent=r.some(t=>t.rules.some(a.isExt))),r.hasExtContent}prepare(r,t){r.forEach(e=>{this.cfXform.prepare(e,t)})}render(r,t){this.hasContent(t)&&(r.openNode(this.tag),t.forEach(e=>this.cfXform.render(r,e)),r.closeNode())}createNewModel(){return[]}onParserClose(r,t){this.model.push(t.model)}}},{"../../composite-xform":48,"./cf-rule-ext-xform":75,"./conditional-formatting-ext-xform":77}],79:[function(s,T,S){const m=s("../../base-xform"),a=s("../../composite-xform"),o=s("../../style/color-xform"),r=s("./cfvo-ext-xform");T.exports=class extends a{constructor(){super(),this.map={"x14:cfvo":this.cfvoXform=new r,"x14:borderColor":this.borderColorXform=new o("x14:borderColor"),"x14:negativeBorderColor":this.negativeBorderColorXform=new o("x14:negativeBorderColor"),"x14:negativeFillColor":this.negativeFillColorXform=new o("x14:negativeFillColor"),"x14:axisColor":this.axisColorXform=new o("x14:axisColor")}}static isExt(t){return!t.gradient}get tag(){return"x14:dataBar"}render(t,e){t.openNode(this.tag,{minLength:m.toIntAttribute(e.minLength,0,!0),maxLength:m.toIntAttribute(e.maxLength,100,!0),border:m.toBoolAttribute(e.border,!1),gradient:m.toBoolAttribute(e.gradient,!0),negativeBarColorSameAsPositive:m.toBoolAttribute(e.negativeBarColorSameAsPositive,!0),negativeBarBorderColorSameAsPositive:m.toBoolAttribute(e.negativeBarBorderColorSameAsPositive,!0),axisPosition:m.toAttribute(e.axisPosition,"auto"),direction:m.toAttribute(e.direction,"leftToRight")}),e.cfvo.forEach(l=>{this.cfvoXform.render(t,l)}),this.borderColorXform.render(t,e.borderColor),this.negativeBorderColorXform.render(t,e.negativeBorderColor),this.negativeFillColorXform.render(t,e.negativeFillColor),this.axisColorXform.render(t,e.axisColor),t.closeNode()}createNewModel(t){let{attributes:e}=t;return{cfvo:[],minLength:m.toIntValue(e.minLength,0),maxLength:m.toIntValue(e.maxLength,100),border:m.toBoolValue(e.border,!1),gradient:m.toBoolValue(e.gradient,!0),negativeBarColorSameAsPositive:m.toBoolValue(e.negativeBarColorSameAsPositive,!0),negativeBarBorderColorSameAsPositive:m.toBoolValue(e.negativeBarBorderColorSameAsPositive,!0),axisPosition:m.toStringValue(e.axisPosition,"auto"),direction:m.toStringValue(e.direction,"leftToRight")}}onParserClose(t,e){const[,l]=t.split(":");switch(l){case"cfvo":this.model.cfvo.push(e.model);break;default:this.model[l]=e.model}}}},{"../../base-xform":32,"../../composite-xform":48,"../../style/color-xform":128,"./cfvo-ext-xform":76}],80:[function(s,T,S){const m=s("../../base-xform");T.exports=class extends m{get tag(){return"xm:f"}render(a,o){a.leafNode(this.tag,null,o)}parseOpen(){this.model=""}parseText(a){this.model+=a}parseClose(a){return a!==this.tag}}},{"../../base-xform":32}],81:[function(s,T,S){const m=s("../../base-xform"),a=s("../../composite-xform"),o=s("./cfvo-ext-xform"),r=s("./cf-icon-ext-xform");T.exports=class extends a{constructor(){super(),this.map={"x14:cfvo":this.cfvoXform=new o,"x14:cfIcon":this.cfIconXform=new r}}get tag(){return"x14:iconSet"}render(t,e){t.openNode(this.tag,{iconSet:m.toStringAttribute(e.iconSet),reverse:m.toBoolAttribute(e.reverse,!1),showValue:m.toBoolAttribute(e.showValue,!0),custom:m.toBoolAttribute(e.icons,!1)}),e.cfvo.forEach(l=>{this.cfvoXform.render(t,l)}),e.icons&&e.icons.forEach((l,n)=>{l.iconId=n,this.cfIconXform.render(t,l)}),t.closeNode()}createNewModel(t){let{attributes:e}=t;return{cfvo:[],iconSet:m.toStringValue(e.iconSet,"3TrafficLights"),reverse:m.toBoolValue(e.reverse,!1),showValue:m.toBoolValue(e.showValue,!0)}}onParserClose(t,e){const[,l]=t.split(":");switch(l){case"cfvo":this.model.cfvo.push(e.model);break;case"cfIcon":this.model.icons||(this.model.icons=[]),this.model.icons.push(e.model);break;default:this.model[l]=e.model}}}},{"../../base-xform":32,"../../composite-xform":48,"./cf-icon-ext-xform":74,"./cfvo-ext-xform":76}],82:[function(s,T,S){const m=s("../../base-xform");T.exports=class extends m{get tag(){return"xm:sqref"}render(a,o){a.leafNode(this.tag,null,o)}parseOpen(){this.model=""}parseText(a){this.model+=a}parseClose(a){return a!==this.tag}}},{"../../base-xform":32}],83:[function(s,T,S){const m=s("../../base-xform"),a=s("../../composite-xform"),o=s("../../../../doc/range"),r=s("./databar-xform"),t=s("./ext-lst-ref-xform"),e=s("./formula-xform"),l=s("./color-scale-xform"),n=s("./icon-set-xform"),i={"3Triangles":!0,"3Stars":!0,"5Boxes":!0},f=u=>{const{type:d,operator:h}=u;switch(d){case"containsText":case"containsBlanks":case"notContainsBlanks":case"containsErrors":case"notContainsErrors":return{type:"containsText",operator:d};default:return{type:d,operator:h}}};class c extends a{constructor(){super(),this.map={dataBar:this.databarXform=new r,extLst:this.extLstRefXform=new t,formula:this.formulaXform=new e,colorScale:this.colorScaleXform=new l,iconSet:this.iconSetXform=new n}}get tag(){return"cfRule"}static isPrimitive(d){return d.type!=="iconSet"||!d.custom&&!i[d.iconSet]}render(d,h){switch(h.type){case"expression":this.renderExpression(d,h);break;case"cellIs":this.renderCellIs(d,h);break;case"top10":this.renderTop10(d,h);break;case"aboveAverage":this.renderAboveAverage(d,h);break;case"dataBar":this.renderDataBar(d,h);break;case"colorScale":this.renderColorScale(d,h);break;case"iconSet":this.renderIconSet(d,h);break;case"containsText":this.renderText(d,h);break;case"timePeriod":this.renderTimePeriod(d,h)}}renderExpression(d,h){d.openNode(this.tag,{type:"expression",dxfId:h.dxfId,priority:h.priority}),this.formulaXform.render(d,h.formulae[0]),d.closeNode()}renderCellIs(d,h){d.openNode(this.tag,{type:"cellIs",dxfId:h.dxfId,priority:h.priority,operator:h.operator}),h.formulae.forEach(w=>{this.formulaXform.render(d,w)}),d.closeNode()}renderTop10(d,h){d.leafNode(this.tag,{type:"top10",dxfId:h.dxfId,priority:h.priority,percent:m.toBoolAttribute(h.percent,!1),bottom:m.toBoolAttribute(h.bottom,!1),rank:m.toIntValue(h.rank,10,!0)})}renderAboveAverage(d,h){d.leafNode(this.tag,{type:"aboveAverage",dxfId:h.dxfId,priority:h.priority,aboveAverage:m.toBoolAttribute(h.aboveAverage,!0)})}renderDataBar(d,h){d.openNode(this.tag,{type:"dataBar",priority:h.priority}),this.databarXform.render(d,h),this.extLstRefXform.render(d,h),d.closeNode()}renderColorScale(d,h){d.openNode(this.tag,{type:"colorScale",priority:h.priority}),this.colorScaleXform.render(d,h),d.closeNode()}renderIconSet(d,h){c.isPrimitive(h)&&(d.openNode(this.tag,{type:"iconSet",priority:h.priority}),this.iconSetXform.render(d,h),d.closeNode())}renderText(d,h){d.openNode(this.tag,{type:h.operator,dxfId:h.dxfId,priority:h.priority,operator:m.toStringAttribute(h.operator,"containsText")});const w=(_=>{if(_.formulae&&_.formulae[0])return _.formulae[0];const A=new o(_.ref),{tl:N}=A;switch(_.operator){case"containsText":return`NOT(ISERROR(SEARCH("${_.text}",${N})))`;case"containsBlanks":return`LEN(TRIM(${N}))=0`;case"notContainsBlanks":return`LEN(TRIM(${N}))>0`;case"containsErrors":return`ISERROR(${N})`;case"notContainsErrors":return`NOT(ISERROR(${N}))`;default:return}})(h);w&&this.formulaXform.render(d,w),d.closeNode()}renderTimePeriod(d,h){d.openNode(this.tag,{type:"timePeriod",dxfId:h.dxfId,priority:h.priority,timePeriod:h.timePeriod});const w=(_=>{if(_.formulae&&_.formulae[0])return _.formulae[0];const A=new o(_.ref),{tl:N}=A;switch(_.timePeriod){case"thisWeek":return`AND(TODAY()-ROUNDDOWN(${N},0)<=WEEKDAY(TODAY())-1,ROUNDDOWN(${N},0)-TODAY()<=7-WEEKDAY(TODAY()))`;case"lastWeek":return`AND(TODAY()-ROUNDDOWN(${N},0)>=(WEEKDAY(TODAY())),TODAY()-ROUNDDOWN(${N},0)<(WEEKDAY(TODAY())+7))`;case"nextWeek":return`AND(ROUNDDOWN(${N},0)-TODAY()>(7-WEEKDAY(TODAY())),ROUNDDOWN(${N},0)-TODAY()<(15-WEEKDAY(TODAY())))`;case"yesterday":return`FLOOR(${N},1)=TODAY()-1`;case"today":return`FLOOR(${N},1)=TODAY()`;case"tomorrow":return`FLOOR(${N},1)=TODAY()+1`;case"last7Days":return`AND(TODAY()-FLOOR(${N},1)<=6,FLOOR(${N},1)<=TODAY())`;case"lastMonth":return`AND(MONTH(${N})=MONTH(EDATE(TODAY(),0-1)),YEAR(${N})=YEAR(EDATE(TODAY(),0-1)))`;case"thisMonth":return`AND(MONTH(${N})=MONTH(TODAY()),YEAR(${N})=YEAR(TODAY()))`;case"nextMonth":return`AND(MONTH(${N})=MONTH(EDATE(TODAY(),0+1)),YEAR(${N})=YEAR(EDATE(TODAY(),0+1)))`;default:return}})(h);w&&this.formulaXform.render(d,w),d.closeNode()}createNewModel(d){let{attributes:h}=d;return{...f(h),dxfId:m.toIntValue(h.dxfId),priority:m.toIntValue(h.priority),timePeriod:h.timePeriod,percent:m.toBoolValue(h.percent),bottom:m.toBoolValue(h.bottom),rank:m.toIntValue(h.rank),aboveAverage:m.toBoolValue(h.aboveAverage)}}onParserClose(d,h){switch(d){case"dataBar":case"extLst":case"colorScale":case"iconSet":Object.assign(this.model,h.model);break;case"formula":this.model.formulae=this.model.formulae||[],this.model.formulae.push(h.model)}}}T.exports=c},{"../../../../doc/range":10,"../../base-xform":32,"../../composite-xform":48,"./color-scale-xform":85,"./databar-xform":88,"./ext-lst-ref-xform":89,"./formula-xform":90,"./icon-set-xform":91}],84:[function(s,T,S){const m=s("../../base-xform");T.exports=class extends m{get tag(){return"cfvo"}render(a,o){a.leafNode(this.tag,{type:o.type,val:o.value})}parseOpen(a){this.model={type:a.attributes.type,value:m.toFloatValue(a.attributes.val)}}parseClose(a){return a!==this.tag}}},{"../../base-xform":32}],85:[function(s,T,S){const m=s("../../composite-xform"),a=s("../../style/color-xform"),o=s("./cfvo-xform");T.exports=class extends m{constructor(){super(),this.map={cfvo:this.cfvoXform=new o,color:this.colorXform=new a}}get tag(){return"colorScale"}render(r,t){r.openNode(this.tag),t.cfvo.forEach(e=>{this.cfvoXform.render(r,e)}),t.color.forEach(e=>{this.colorXform.render(r,e)}),r.closeNode()}createNewModel(r){return{cfvo:[],color:[]}}onParserClose(r,t){this.model[r].push(t.model)}}},{"../../composite-xform":48,"../../style/color-xform":128,"./cfvo-xform":84}],86:[function(s,T,S){const m=s("../../composite-xform"),a=s("./cf-rule-xform");T.exports=class extends m{constructor(){super(),this.map={cfRule:new a}}get tag(){return"conditionalFormatting"}render(o,r){r.rules.some(a.isPrimitive)&&(o.openNode(this.tag,{sqref:r.ref}),r.rules.forEach(t=>{a.isPrimitive(t)&&(t.ref=r.ref,this.map.cfRule.render(o,t))}),o.closeNode())}createNewModel(o){let{attributes:r}=o;return{ref:r.sqref,rules:[]}}onParserClose(o,r){this.model.rules.push(r.model)}}},{"../../composite-xform":48,"./cf-rule-xform":83}],87:[function(s,T,S){const m=s("../../base-xform"),a=s("./conditional-formatting-xform");T.exports=class extends m{constructor(){super(),this.cfXform=new a}get tag(){return"conditionalFormatting"}reset(){this.model=[]}prepare(o,r){let t=o.reduce((e,l)=>Math.max(e,...l.rules.map(n=>n.priority||0)),1);o.forEach(e=>{e.rules.forEach(l=>{l.priority||(l.priority=t++),l.style&&(l.dxfId=r.styles.addDxfStyle(l.style))})})}render(o,r){r.forEach(t=>{this.cfXform.render(o,t)})}parseOpen(o){if(this.parser)return this.parser.parseOpen(o),!0;switch(o.name){case"conditionalFormatting":return this.parser=this.cfXform,this.parser.parseOpen(o),!0;default:return!1}}parseText(o){this.parser&&this.parser.parseText(o)}parseClose(o){return!!this.parser&&(!!this.parser.parseClose(o)||(this.model.push(this.parser.model),this.parser=void 0,!1))}reconcile(o,r){o.forEach(t=>{t.rules.forEach(e=>{e.dxfId!==void 0&&(e.style=r.styles.getDxfStyle(e.dxfId),delete e.dxfId)})})}}},{"../../base-xform":32,"./conditional-formatting-xform":86}],88:[function(s,T,S){const m=s("../../composite-xform"),a=s("../../style/color-xform"),o=s("./cfvo-xform");T.exports=class extends m{constructor(){super(),this.map={cfvo:this.cfvoXform=new o,color:this.colorXform=new a}}get tag(){return"dataBar"}render(r,t){r.openNode(this.tag),t.cfvo.forEach(e=>{this.cfvoXform.render(r,e)}),this.colorXform.render(r,t.color),r.closeNode()}createNewModel(){return{cfvo:[]}}onParserClose(r,t){switch(r){case"cfvo":this.model.cfvo.push(t.model);break;case"color":this.model.color=t.model}}}},{"../../composite-xform":48,"../../style/color-xform":128,"./cfvo-xform":84}],89:[function(s,T,S){const m=s("../../base-xform"),a=s("../../composite-xform");class o extends m{get tag(){return"x14:id"}render(e,l){e.leafNode(this.tag,null,l)}parseOpen(){this.model=""}parseText(e){this.model+=e}parseClose(e){return e!==this.tag}}class r extends a{constructor(){super(),this.map={"x14:id":this.idXform=new o}}get tag(){return"ext"}render(e,l){e.openNode(this.tag,{uri:"{B025F937-C7B1-47D3-B67F-A62EFF666E3E}","xmlns:x14":"http://schemas.microsoft.com/office/spreadsheetml/2009/9/main"}),this.idXform.render(e,l.x14Id),e.closeNode()}createNewModel(){return{}}onParserClose(e,l){this.model.x14Id=l.model}}T.exports=class extends a{constructor(){super(),this.map={ext:new r}}get tag(){return"extLst"}render(t,e){t.openNode(this.tag),this.map.ext.render(t,e),t.closeNode()}createNewModel(){return{}}onParserClose(t,e){Object.assign(this.model,e.model)}}},{"../../base-xform":32,"../../composite-xform":48}],90:[function(s,T,S){const m=s("../../base-xform");T.exports=class extends m{get tag(){return"formula"}render(a,o){a.leafNode(this.tag,null,o)}parseOpen(){this.model=""}parseText(a){this.model+=a}parseClose(a){return a!==this.tag}}},{"../../base-xform":32}],91:[function(s,T,S){const m=s("../../base-xform"),a=s("../../composite-xform"),o=s("./cfvo-xform");T.exports=class extends a{constructor(){super(),this.map={cfvo:this.cfvoXform=new o}}get tag(){return"iconSet"}render(r,t){r.openNode(this.tag,{iconSet:m.toStringAttribute(t.iconSet,"3TrafficLights"),reverse:m.toBoolAttribute(t.reverse,!1),showValue:m.toBoolAttribute(t.showValue,!0)}),t.cfvo.forEach(e=>{this.cfvoXform.render(r,e)}),r.closeNode()}createNewModel(r){let{attributes:t}=r;return{iconSet:m.toStringValue(t.iconSet,"3TrafficLights"),reverse:m.toBoolValue(t.reverse),showValue:m.toBoolValue(t.showValue),cfvo:[]}}onParserClose(r,t){this.model[r].push(t.model)}}},{"../../base-xform":32,"../../composite-xform":48,"./cfvo-xform":84}],92:[function(s,T,S){const m=s("../../../utils/utils"),a=s("../base-xform");T.exports=class extends a{get tag(){return"col"}prepare(o,r){const t=r.styles.addStyleModel(o.style||{});t&&(o.styleId=t)}render(o,r){o.openNode("col"),o.addAttribute("min",r.min),o.addAttribute("max",r.max),r.width&&o.addAttribute("width",r.width),r.styleId&&o.addAttribute("style",r.styleId),r.hidden&&o.addAttribute("hidden","1"),r.bestFit&&o.addAttribute("bestFit","1"),r.outlineLevel&&o.addAttribute("outlineLevel",r.outlineLevel),r.collapsed&&o.addAttribute("collapsed","1"),o.addAttribute("customWidth","1"),o.closeNode()}parseOpen(o){if(o.name==="col"){const r=this.model={min:parseInt(o.attributes.min||"0",10),max:parseInt(o.attributes.max||"0",10),width:o.attributes.width===void 0?void 0:parseFloat(o.attributes.width||"0")};return o.attributes.style&&(r.styleId=parseInt(o.attributes.style,10)),m.parseBoolean(o.attributes.hidden)&&(r.hidden=!0),m.parseBoolean(o.attributes.bestFit)&&(r.bestFit=!0),o.attributes.outlineLevel&&(r.outlineLevel=parseInt(o.attributes.outlineLevel,10)),m.parseBoolean(o.attributes.collapsed)&&(r.collapsed=!0),!0}return!1}parseText(){}parseClose(){return!1}reconcile(o,r){o.styleId&&(o.style=r.styles.getStyleModel(o.styleId))}}},{"../../../utils/utils":27,"../base-xform":32}],93:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../../../utils/utils"),o=s("../../../utils/col-cache"),r=s("../base-xform"),t=s("../../../doc/range");function e(n,i,f,c){const u=i[f];u!==void 0?n[f]=u:c!==void 0&&(n[f]=c)}function l(n,i,f,c){const u=i[f];u!==void 0&&(n[f]=a.parseBoolean(u))}T.exports=class extends r{get tag(){return"dataValidations"}render(n,i){const f=function(c){const u=m.map(c,(w,_)=>({address:_,dataValidation:w,marked:!1})).sort((w,_)=>m.strcmp(w.address,_.address)),d=m.keyBy(u,"address"),h=(w,_,A)=>{for(let N=0;N<_;N++){const L=o.encodeAddress(w.row+N,A);if(!c[L]||!m.isEqual(c[w.address],c[L]))return!1}return!0};return u.map(w=>{if(!w.marked){const _=o.decodeEx(w.address);if(_.dimensions)return d[_.dimensions].marked=!0,{...w.dataValidation,sqref:w.address};let A=1,N=o.encodeAddress(_.row+A,_.col);for(;c[N]&&m.isEqual(w.dataValidation,c[N]);)A++,N=o.encodeAddress(_.row+A,_.col);let L=1;for(;h(_,A,_.col+L);)L++;for(let I=0;I<A;I++)for(let P=0;P<L;P++)N=o.encodeAddress(_.row+I,_.col+P),d[N].marked=!0;if(A>1||L>1){const I=_.row+(A-1),P=_.col+(L-1);return{...w.dataValidation,sqref:`${w.address}:${o.encodeAddress(I,P)}`}}return{...w.dataValidation,sqref:w.address}}return null}).filter(Boolean)}(i);f.length&&(n.openNode("dataValidations",{count:f.length}),f.forEach(c=>{n.openNode("dataValidation"),c.type!=="any"&&(n.addAttribute("type",c.type),c.operator&&c.type!=="list"&&c.operator!=="between"&&n.addAttribute("operator",c.operator),c.allowBlank&&n.addAttribute("allowBlank","1")),c.showInputMessage&&n.addAttribute("showInputMessage","1"),c.promptTitle&&n.addAttribute("promptTitle",c.promptTitle),c.prompt&&n.addAttribute("prompt",c.prompt),c.showErrorMessage&&n.addAttribute("showErrorMessage","1"),c.errorStyle&&n.addAttribute("errorStyle",c.errorStyle),c.errorTitle&&n.addAttribute("errorTitle",c.errorTitle),c.error&&n.addAttribute("error",c.error),n.addAttribute("sqref",c.sqref),(c.formulae||[]).forEach((u,d)=>{n.openNode("formula"+(d+1)),c.type==="date"?n.writeText(a.dateToExcel(new Date(u))):n.writeText(u),n.closeNode()}),n.closeNode()}),n.closeNode())}parseOpen(n){switch(n.name){case"dataValidations":return this.model={},!0;case"dataValidation":{this._address=n.attributes.sqref;const i={type:n.attributes.type||"any",formulae:[]};switch(n.attributes.type&&l(i,n.attributes,"allowBlank"),l(i,n.attributes,"showInputMessage"),l(i,n.attributes,"showErrorMessage"),i.type){case"any":case"list":case"custom":break;default:e(i,n.attributes,"operator","between")}return e(i,n.attributes,"promptTitle"),e(i,n.attributes,"prompt"),e(i,n.attributes,"errorStyle"),e(i,n.attributes,"errorTitle"),e(i,n.attributes,"error"),this._dataValidation=i,!0}case"formula1":case"formula2":return this._formula=[],!0;default:return!1}}parseText(n){this._formula&&this._formula.push(n)}parseClose(n){switch(n){case"dataValidations":return!1;case"dataValidation":return this._dataValidation.formulae&&this._dataValidation.formulae.length||(delete this._dataValidation.formulae,delete this._dataValidation.operator),(this._address.split(/\s+/g)||[]).forEach(i=>{i.includes(":")?new t(i).forEachAddress(f=>{this.model[f]=this._dataValidation}):this.model[i]=this._dataValidation}),!0;case"formula1":case"formula2":{let i=this._formula.join("");switch(this._dataValidation.type){case"whole":case"textLength":i=parseInt(i,10);break;case"decimal":i=parseFloat(i);break;case"date":i=a.excelToDate(parseFloat(i))}return this._dataValidation.formulae.push(i),this._formula=void 0,!0}default:return!0}}}},{"../../../doc/range":10,"../../../utils/col-cache":19,"../../../utils/under-dash":26,"../../../utils/utils":27,"../base-xform":32}],94:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"dimension"}render(a,o){o&&a.leafNode("dimension",{ref:o})}parseOpen(a){return a.name==="dimension"&&(this.model=a.attributes.ref,!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],95:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"drawing"}render(a,o){o&&a.leafNode(this.tag,{"r:id":o.rId})}parseOpen(a){switch(a.name){case this.tag:return this.model={rId:a.attributes["r:id"]},!0;default:return!1}}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],96:[function(s,T,S){const m=s("../composite-xform"),a=s("./cf-ext/conditional-formattings-ext-xform");class o extends m{constructor(){super(),this.map={"x14:conditionalFormattings":this.conditionalFormattings=new a}}get tag(){return"ext"}hasContent(t){return this.conditionalFormattings.hasContent(t.conditionalFormattings)}prepare(t,e){this.conditionalFormattings.prepare(t.conditionalFormattings,e)}render(t,e){t.openNode("ext",{uri:"{78C0D931-6437-407d-A8EE-F0AAD7539E65}","xmlns:x14":"http://schemas.microsoft.com/office/spreadsheetml/2009/9/main"}),this.conditionalFormattings.render(t,e.conditionalFormattings),t.closeNode()}createNewModel(){return{}}onParserClose(t,e){this.model[t]=e.model}}T.exports=class extends m{constructor(){super(),this.map={ext:this.ext=new o}}get tag(){return"extLst"}prepare(r,t){this.ext.prepare(r,t)}hasContent(r){return this.ext.hasContent(r)}render(r,t){this.hasContent(t)&&(r.openNode("extLst"),this.ext.render(r,t),r.closeNode())}createNewModel(){return{}}onParserClose(r,t){Object.assign(this.model,t.model)}}},{"../composite-xform":48,"./cf-ext/conditional-formattings-ext-xform":78}],97:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"headerFooter"}render(a,o){if(o){a.addRollback();let r=!1;a.openNode("headerFooter"),o.differentFirst&&(a.addAttribute("differentFirst","1"),r=!0),o.differentOddEven&&(a.addAttribute("differentOddEven","1"),r=!0),o.oddHeader&&typeof o.oddHeader=="string"&&(a.leafNode("oddHeader",null,o.oddHeader),r=!0),o.oddFooter&&typeof o.oddFooter=="string"&&(a.leafNode("oddFooter",null,o.oddFooter),r=!0),o.evenHeader&&typeof o.evenHeader=="string"&&(a.leafNode("evenHeader",null,o.evenHeader),r=!0),o.evenFooter&&typeof o.evenFooter=="string"&&(a.leafNode("evenFooter",null,o.evenFooter),r=!0),o.firstHeader&&typeof o.firstHeader=="string"&&(a.leafNode("firstHeader",null,o.firstHeader),r=!0),o.firstFooter&&typeof o.firstFooter=="string"&&(a.leafNode("firstFooter",null,o.firstFooter),r=!0),r?(a.closeNode(),a.commit()):a.rollback()}}parseOpen(a){switch(a.name){case"headerFooter":return this.model={},a.attributes.differentFirst&&(this.model.differentFirst=parseInt(a.attributes.differentFirst,0)===1),a.attributes.differentOddEven&&(this.model.differentOddEven=parseInt(a.attributes.differentOddEven,0)===1),!0;case"oddHeader":return this.currentNode="oddHeader",!0;case"oddFooter":return this.currentNode="oddFooter",!0;case"evenHeader":return this.currentNode="evenHeader",!0;case"evenFooter":return this.currentNode="evenFooter",!0;case"firstHeader":return this.currentNode="firstHeader",!0;case"firstFooter":return this.currentNode="firstFooter",!0;default:return!1}}parseText(a){switch(this.currentNode){case"oddHeader":this.model.oddHeader=a;break;case"oddFooter":this.model.oddFooter=a;break;case"evenHeader":this.model.evenHeader=a;break;case"evenFooter":this.model.evenFooter=a;break;case"firstHeader":this.model.firstHeader=a;break;case"firstFooter":this.model.firstFooter=a}}parseClose(){switch(this.currentNode){case"oddHeader":case"oddFooter":case"evenHeader":case"evenFooter":case"firstHeader":case"firstFooter":return this.currentNode=void 0,!0;default:return!1}}}},{"../base-xform":32}],98:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"hyperlink"}render(a,o){this.isInternalLink(o)?a.leafNode("hyperlink",{ref:o.address,"r:id":o.rId,tooltip:o.tooltip,location:o.target}):a.leafNode("hyperlink",{ref:o.address,"r:id":o.rId,tooltip:o.tooltip})}parseOpen(a){return a.name==="hyperlink"&&(this.model={address:a.attributes.ref,rId:a.attributes["r:id"],tooltip:a.attributes.tooltip},a.attributes.location&&(this.model.target=a.attributes.location),!0)}parseText(){}parseClose(){return!1}isInternalLink(a){return a.target&&/^[^!]+![a-zA-Z]+[\d]+$/.test(a.target)}}},{"../base-xform":32}],99:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"mergeCell"}render(a,o){a.leafNode("mergeCell",{ref:o})}parseOpen(a){return a.name==="mergeCell"&&(this.model=a.attributes.ref,!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],100:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../../../doc/range"),o=s("../../../utils/col-cache"),r=s("../../../doc/enums");T.exports=class{constructor(){this.merges={}}add(t){if(this.merges[t.master])this.merges[t.master].expandToAddress(t.address);else{const e=`${t.master}:${t.address}`;this.merges[t.master]=new a(e)}}get mergeCells(){return m.map(this.merges,t=>t.range)}reconcile(t,e){m.each(t,l=>{const n=o.decode(l);for(let i=n.top;i<=n.bottom;i++){const f=e[i-1];for(let c=n.left;c<=n.right;c++){const u=f.cells[c-1];u?u.type===r.ValueType.Merge&&(u.master=n.tl):f.cells[c]={type:r.ValueType.Null,address:o.encodeAddress(i,c)}}}})}getMasterAddress(t){const e=this.hash[t];return e&&e.tl}}},{"../../../doc/enums":7,"../../../doc/range":10,"../../../utils/col-cache":19,"../../../utils/under-dash":26}],101:[function(s,T,S){const m=s("../base-xform"),a=o=>o!==void 0;T.exports=class extends m{get tag(){return"outlinePr"}render(o,r){return!(!r||!a(r.summaryBelow)&&!a(r.summaryRight))&&(o.leafNode(this.tag,{summaryBelow:a(r.summaryBelow)?Number(r.summaryBelow):void 0,summaryRight:a(r.summaryRight)?Number(r.summaryRight):void 0}),!0)}parseOpen(o){return o.name===this.tag&&(this.model={summaryBelow:a(o.attributes.summaryBelow)?!!Number(o.attributes.summaryBelow):void 0,summaryRight:a(o.attributes.summaryRight)?!!Number(o.attributes.summaryRight):void 0},!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],102:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"brk"}render(a,o){a.leafNode("brk",o)}parseOpen(a){return a.name==="brk"&&(this.model=a.attributes.ref,!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],103:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../base-xform");T.exports=class extends a{get tag(){return"pageMargins"}render(o,r){if(r){const t={left:r.left,right:r.right,top:r.top,bottom:r.bottom,header:r.header,footer:r.footer};m.some(t,e=>e!==void 0)&&o.leafNode(this.tag,t)}}parseOpen(o){switch(o.name){case this.tag:return this.model={left:parseFloat(o.attributes.left||.7),right:parseFloat(o.attributes.right||.7),top:parseFloat(o.attributes.top||.75),bottom:parseFloat(o.attributes.bottom||.75),header:parseFloat(o.attributes.header||.3),footer:parseFloat(o.attributes.footer||.3)},!0;default:return!1}}parseText(){}parseClose(){return!1}}},{"../../../utils/under-dash":26,"../base-xform":32}],104:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"pageSetUpPr"}render(a,o){return!(!o||!o.fitToPage)&&(a.leafNode(this.tag,{fitToPage:o.fitToPage?"1":void 0}),!0)}parseOpen(a){return a.name===this.tag&&(this.model={fitToPage:a.attributes.fitToPage==="1"},!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],105:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../base-xform");function o(l){return l?"1":void 0}function r(l){switch(l){case"overThenDown":return l;default:return}}function t(l){switch(l){case"atEnd":case"asDisplyed":return l;default:return}}function e(l){switch(l){case"dash":case"blank":case"NA":return l;default:return}}T.exports=class extends a{get tag(){return"pageSetup"}render(l,n){if(n){const i={paperSize:n.paperSize,orientation:n.orientation,horizontalDpi:n.horizontalDpi,verticalDpi:n.verticalDpi,pageOrder:r(n.pageOrder),blackAndWhite:o(n.blackAndWhite),draft:o(n.draft),cellComments:t(n.cellComments),errors:e(n.errors),scale:n.scale,fitToWidth:n.fitToWidth,fitToHeight:n.fitToHeight,firstPageNumber:n.firstPageNumber,useFirstPageNumber:o(n.firstPageNumber),usePrinterDefaults:o(n.usePrinterDefaults),copies:n.copies};m.some(i,f=>f!==void 0)&&l.leafNode(this.tag,i)}}parseOpen(l){switch(l.name){case this.tag:return this.model={paperSize:(n=l.attributes.paperSize,n!==void 0?parseInt(n,10):void 0),orientation:l.attributes.orientation||"portrait",horizontalDpi:parseInt(l.attributes.horizontalDpi||"4294967295",10),verticalDpi:parseInt(l.attributes.verticalDpi||"4294967295",10),pageOrder:l.attributes.pageOrder||"downThenOver",blackAndWhite:l.attributes.blackAndWhite==="1",draft:l.attributes.draft==="1",cellComments:l.attributes.cellComments||"None",errors:l.attributes.errors||"displayed",scale:parseInt(l.attributes.scale||"100",10),fitToWidth:parseInt(l.attributes.fitToWidth||"1",10),fitToHeight:parseInt(l.attributes.fitToHeight||"1",10),firstPageNumber:parseInt(l.attributes.firstPageNumber||"1",10),useFirstPageNumber:l.attributes.useFirstPageNumber==="1",usePrinterDefaults:l.attributes.usePrinterDefaults==="1",copies:parseInt(l.attributes.copies||"1",10)},!0;default:return!1}var n}parseText(){}parseClose(){return!1}}},{"../../../utils/under-dash":26,"../base-xform":32}],106:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"picture"}render(a,o){o&&a.leafNode(this.tag,{"r:id":o.rId})}parseOpen(a){switch(a.name){case this.tag:return this.model={rId:a.attributes["r:id"]},!0;default:return!1}}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],107:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../base-xform");function o(r){return r?"1":void 0}T.exports=class extends a{get tag(){return"printOptions"}render(r,t){if(t){const e={headings:o(t.showRowColHeaders),gridLines:o(t.showGridLines),horizontalCentered:o(t.horizontalCentered),verticalCentered:o(t.verticalCentered)};m.some(e,l=>l!==void 0)&&r.leafNode(this.tag,e)}}parseOpen(r){switch(r.name){case this.tag:return this.model={showRowColHeaders:r.attributes.headings==="1",showGridLines:r.attributes.gridLines==="1",horizontalCentered:r.attributes.horizontalCentered==="1",verticalCentered:r.attributes.verticalCentered==="1"},!0;default:return!1}}parseText(){}parseClose(){return!1}}},{"../../../utils/under-dash":26,"../base-xform":32}],108:[function(s,T,S){const m=s("./page-breaks-xform"),a=s("../list-xform");T.exports=class extends a{constructor(){super({tag:"rowBreaks",count:!0,childXform:new m})}render(o,r){if(r&&r.length){o.openNode(this.tag,this.$),this.count&&(o.addAttribute(this.$count,r.length),o.addAttribute("manualBreakCount",r.length));const{childXform:t}=this;r.forEach(e=>{t.render(o,e)}),o.closeNode()}else this.empty&&o.leafNode(this.tag)}}},{"../list-xform":71,"./page-breaks-xform":102}],109:[function(s,T,S){const m=s("../base-xform"),a=s("../../../utils/utils"),o=s("./cell-xform");T.exports=class extends m{constructor(r){super(),this.maxItems=r&&r.maxItems,this.map={c:new o}}get tag(){return"row"}prepare(r,t){const e=t.styles.addStyleModel(r.style);e&&(r.styleId=e);const l=this.map.c;r.cells.forEach(n=>{l.prepare(n,t)})}render(r,t,e){r.openNode("row"),r.addAttribute("r",t.number),t.height&&(r.addAttribute("ht",t.height),r.addAttribute("customHeight","1")),t.hidden&&r.addAttribute("hidden","1"),t.min>0&&t.max>0&&t.min<=t.max&&r.addAttribute("spans",`${t.min}:${t.max}`),t.styleId&&(r.addAttribute("s",t.styleId),r.addAttribute("customFormat","1")),r.addAttribute("x14ac:dyDescent","0.25"),t.outlineLevel&&r.addAttribute("outlineLevel",t.outlineLevel),t.collapsed&&r.addAttribute("collapsed","1");const l=this.map.c;t.cells.forEach(n=>{l.render(r,n,e)}),r.closeNode()}parseOpen(r){if(this.parser)return this.parser.parseOpen(r),!0;if(r.name==="row"){this.numRowsSeen+=1;const t=r.attributes.spans?r.attributes.spans.split(":").map(l=>parseInt(l,10)):[void 0,void 0],e=this.model={number:parseInt(r.attributes.r,10),min:t[0],max:t[1],cells:[]};return r.attributes.s&&(e.styleId=parseInt(r.attributes.s,10)),a.parseBoolean(r.attributes.hidden)&&(e.hidden=!0),a.parseBoolean(r.attributes.bestFit)&&(e.bestFit=!0),r.attributes.ht&&(e.height=parseFloat(r.attributes.ht)),r.attributes.outlineLevel&&(e.outlineLevel=parseInt(r.attributes.outlineLevel,10)),a.parseBoolean(r.attributes.collapsed)&&(e.collapsed=!0),!0}return this.parser=this.map[r.name],!!this.parser&&(this.parser.parseOpen(r),!0)}parseText(r){this.parser&&this.parser.parseText(r)}parseClose(r){if(this.parser){if(!this.parser.parseClose(r)){if(this.model.cells.push(this.parser.model),this.maxItems&&this.model.cells.length>this.maxItems)throw new Error(`Max column count (${this.maxItems}) exceeded`);this.parser=void 0}return!0}return!1}reconcile(r,t){r.style=r.styleId?t.styles.getStyleModel(r.styleId):{},r.styleId!==void 0&&(r.styleId=void 0);const e=this.map.c;r.cells.forEach(l=>{e.reconcile(l,t)})}}},{"../../../utils/utils":27,"../base-xform":32,"./cell-xform":73}],110:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../base-xform");T.exports=class extends a{get tag(){return"sheetFormatPr"}render(o,r){if(r){const t={defaultRowHeight:r.defaultRowHeight,outlineLevelRow:r.outlineLevelRow,outlineLevelCol:r.outlineLevelCol,"x14ac:dyDescent":r.dyDescent};r.defaultColWidth&&(t.defaultColWidth=r.defaultColWidth),r.defaultRowHeight&&r.defaultRowHeight===15||(t.customHeight="1"),m.some(t,e=>e!==void 0)&&o.leafNode("sheetFormatPr",t)}}parseOpen(o){return o.name==="sheetFormatPr"&&(this.model={defaultRowHeight:parseFloat(o.attributes.defaultRowHeight||"0"),dyDescent:parseFloat(o.attributes["x14ac:dyDescent"]||"0"),outlineLevelRow:parseInt(o.attributes.outlineLevelRow||"0",10),outlineLevelCol:parseInt(o.attributes.outlineLevelCol||"0",10)},o.attributes.defaultColWidth&&(this.model.defaultColWidth=parseFloat(o.attributes.defaultColWidth)),!0)}parseText(){}parseClose(){return!1}}},{"../../../utils/under-dash":26,"../base-xform":32}],111:[function(s,T,S){const m=s("../base-xform"),a=s("../style/color-xform"),o=s("./page-setup-properties-xform"),r=s("./outline-properties-xform");T.exports=class extends m{constructor(){super(),this.map={tabColor:new a("tabColor"),pageSetUpPr:new o,outlinePr:new r}}get tag(){return"sheetPr"}render(t,e){if(e){t.addRollback(),t.openNode("sheetPr");let l=!1;l=this.map.tabColor.render(t,e.tabColor)||l,l=this.map.pageSetUpPr.render(t,e.pageSetup)||l,l=this.map.outlinePr.render(t,e.outlineProperties)||l,l?(t.closeNode(),t.commit()):t.rollback()}}parseOpen(t){return this.parser?(this.parser.parseOpen(t),!0):t.name===this.tag?(this.reset(),!0):!!this.map[t.name]&&(this.parser=this.map[t.name],this.parser.parseOpen(t),!0)}parseText(t){return!!this.parser&&(this.parser.parseText(t),!0)}parseClose(t){return this.parser?(this.parser.parseClose(t)||(this.parser=void 0),!0):(this.map.tabColor.model||this.map.pageSetUpPr.model||this.map.outlinePr.model?(this.model={},this.map.tabColor.model&&(this.model.tabColor=this.map.tabColor.model),this.map.pageSetUpPr.model&&(this.model.pageSetup=this.map.pageSetUpPr.model),this.map.outlinePr.model&&(this.model.outlineProperties=this.map.outlinePr.model)):this.model=null,!1)}}},{"../base-xform":32,"../style/color-xform":128,"./outline-properties-xform":101,"./page-setup-properties-xform":104}],112:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../base-xform");function o(t,e){return t?e:void 0}function r(t,e){return t===e||void 0}T.exports=class extends a{get tag(){return"sheetProtection"}render(t,e){if(e){const l={sheet:o(e.sheet,"1"),selectLockedCells:e.selectLockedCells===!1?"1":void 0,selectUnlockedCells:e.selectUnlockedCells===!1?"1":void 0,formatCells:o(e.formatCells,"0"),formatColumns:o(e.formatColumns,"0"),formatRows:o(e.formatRows,"0"),insertColumns:o(e.insertColumns,"0"),insertRows:o(e.insertRows,"0"),insertHyperlinks:o(e.insertHyperlinks,"0"),deleteColumns:o(e.deleteColumns,"0"),deleteRows:o(e.deleteRows,"0"),sort:o(e.sort,"0"),autoFilter:o(e.autoFilter,"0"),pivotTables:o(e.pivotTables,"0")};e.sheet&&(l.algorithmName=e.algorithmName,l.hashValue=e.hashValue,l.saltValue=e.saltValue,l.spinCount=e.spinCount,l.objects=o(e.objects===!1,"1"),l.scenarios=o(e.scenarios===!1,"1")),m.some(l,n=>n!==void 0)&&t.leafNode(this.tag,l)}}parseOpen(t){switch(t.name){case this.tag:return this.model={sheet:r(t.attributes.sheet,"1"),objects:t.attributes.objects!=="1"&&void 0,scenarios:t.attributes.scenarios!=="1"&&void 0,selectLockedCells:t.attributes.selectLockedCells!=="1"&&void 0,selectUnlockedCells:t.attributes.selectUnlockedCells!=="1"&&void 0,formatCells:r(t.attributes.formatCells,"0"),formatColumns:r(t.attributes.formatColumns,"0"),formatRows:r(t.attributes.formatRows,"0"),insertColumns:r(t.attributes.insertColumns,"0"),insertRows:r(t.attributes.insertRows,"0"),insertHyperlinks:r(t.attributes.insertHyperlinks,"0"),deleteColumns:r(t.attributes.deleteColumns,"0"),deleteRows:r(t.attributes.deleteRows,"0"),sort:r(t.attributes.sort,"0"),autoFilter:r(t.attributes.autoFilter,"0"),pivotTables:r(t.attributes.pivotTables,"0")},t.attributes.algorithmName&&(this.model.algorithmName=t.attributes.algorithmName,this.model.hashValue=t.attributes.hashValue,this.model.saltValue=t.attributes.saltValue,this.model.spinCount=parseInt(t.attributes.spinCount,10)),!0;default:return!1}}parseText(){}parseClose(){return!1}}},{"../../../utils/under-dash":26,"../base-xform":32}],113:[function(s,T,S){const m=s("../../../utils/col-cache"),a=s("../base-xform"),o={frozen:"frozen",frozenSplit:"frozen",split:"split"};T.exports=class extends a{get tag(){return"sheetView"}prepare(r){switch(r.state){case"frozen":case"split":break;default:r.state="normal"}}render(r,t){r.openNode("sheetView",{workbookViewId:t.workbookViewId||0});const e=function(c,u,d){d&&r.addAttribute(c,u)};let l,n,i,f;switch(e("rightToLeft","1",t.rightToLeft===!0),e("tabSelected","1",t.tabSelected),e("showRuler","0",t.showRuler===!1),e("showRowColHeaders","0",t.showRowColHeaders===!1),e("showGridLines","0",t.showGridLines===!1),e("zoomScale",t.zoomScale,t.zoomScale),e("zoomScaleNormal",t.zoomScaleNormal,t.zoomScaleNormal),e("view",t.style,t.style),t.state){case"frozen":n=t.xSplit||0,i=t.ySplit||0,l=t.topLeftCell||m.getAddress(i+1,n+1).address,f=(t.xSplit&&t.ySplit?"bottomRight":t.xSplit&&"topRight")||"bottomLeft",r.leafNode("pane",{xSplit:t.xSplit||void 0,ySplit:t.ySplit||void 0,topLeftCell:l,activePane:f,state:"frozen"}),r.leafNode("selection",{pane:f,activeCell:t.activeCell,sqref:t.activeCell});break;case"split":t.activePane==="topLeft"&&(t.activePane=void 0),r.leafNode("pane",{xSplit:t.xSplit||void 0,ySplit:t.ySplit||void 0,topLeftCell:t.topLeftCell,activePane:t.activePane}),r.leafNode("selection",{pane:t.activePane,activeCell:t.activeCell,sqref:t.activeCell});break;case"normal":t.activeCell&&r.leafNode("selection",{activeCell:t.activeCell,sqref:t.activeCell})}r.closeNode()}parseOpen(r){switch(r.name){case"sheetView":return this.sheetView={workbookViewId:parseInt(r.attributes.workbookViewId,10),rightToLeft:r.attributes.rightToLeft==="1",tabSelected:r.attributes.tabSelected==="1",showRuler:r.attributes.showRuler!=="0",showRowColHeaders:r.attributes.showRowColHeaders!=="0",showGridLines:r.attributes.showGridLines!=="0",zoomScale:parseInt(r.attributes.zoomScale||"100",10),zoomScaleNormal:parseInt(r.attributes.zoomScaleNormal||"100",10),style:r.attributes.view},this.pane=void 0,this.selections={},!0;case"pane":return this.pane={xSplit:parseInt(r.attributes.xSplit||"0",10),ySplit:parseInt(r.attributes.ySplit||"0",10),topLeftCell:r.attributes.topLeftCell,activePane:r.attributes.activePane||"topLeft",state:r.attributes.state},!0;case"selection":{const t=r.attributes.pane||"topLeft";return this.selections[t]={pane:t,activeCell:r.attributes.activeCell},!0}default:return!1}}parseText(){}parseClose(r){let t,e;switch(r){case"sheetView":return this.sheetView&&this.pane?(t=this.model={workbookViewId:this.sheetView.workbookViewId,rightToLeft:this.sheetView.rightToLeft,state:o[this.pane.state]||"split",xSplit:this.pane.xSplit,ySplit:this.pane.ySplit,topLeftCell:this.pane.topLeftCell,showRuler:this.sheetView.showRuler,showRowColHeaders:this.sheetView.showRowColHeaders,showGridLines:this.sheetView.showGridLines,zoomScale:this.sheetView.zoomScale,zoomScaleNormal:this.sheetView.zoomScaleNormal},this.model.state==="split"&&(t.activePane=this.pane.activePane),e=this.selections[this.pane.activePane],e&&e.activeCell&&(t.activeCell=e.activeCell),this.sheetView.style&&(t.style=this.sheetView.style)):(t=this.model={workbookViewId:this.sheetView.workbookViewId,rightToLeft:this.sheetView.rightToLeft,state:"normal",showRuler:this.sheetView.showRuler,showRowColHeaders:this.sheetView.showRowColHeaders,showGridLines:this.sheetView.showGridLines,zoomScale:this.sheetView.zoomScale,zoomScaleNormal:this.sheetView.zoomScaleNormal},e=this.selections.topLeft,e&&e.activeCell&&(t.activeCell=e.activeCell),this.sheetView.style&&(t.style=this.sheetView.style)),!1;default:return!0}}reconcile(){}}},{"../../../utils/col-cache":19,"../base-xform":32}],114:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"tablePart"}render(a,o){o&&a.leafNode(this.tag,{"r:id":o.rId})}parseOpen(a){switch(a.name){case this.tag:return this.model={rId:a.attributes["r:id"]},!0;default:return!1}}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],115:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../../../utils/col-cache"),o=s("../../../utils/xml-stream"),r=s("../../rel-type"),t=s("./merges"),e=s("../base-xform"),l=s("../list-xform"),n=s("./row-xform"),i=s("./col-xform"),f=s("./dimension-xform"),c=s("./hyperlink-xform"),u=s("./merge-cell-xform"),d=s("./data-validations-xform"),h=s("./sheet-properties-xform"),w=s("./sheet-format-properties-xform"),_=s("./sheet-view-xform"),A=s("./sheet-protection-xform"),N=s("./page-margins-xform"),L=s("./page-setup-xform"),I=s("./print-options-xform"),P=s("./auto-filter-xform"),B=s("./picture-xform"),U=s("./drawing-xform"),D=s("./table-part-xform"),x=s("./row-breaks-xform"),M=s("./header-footer-xform"),v=s("./cf/conditional-formattings-xform"),p=s("./ext-lst-xform"),b=(y,k)=>{if(!k||!k.length)return y;if(!y||!y.length)return k;const R={},O={};return y.forEach(z=>{R[z.ref]=z,z.rules.forEach($=>{const{x14Id:W}=$;W&&(O[W]=$)})}),k.forEach(z=>{z.rules.forEach($=>{const W=O[$.x14Id];W?((j,H)=>{Object.keys(H).forEach(E=>{const C=j[E],F=H[E];C===void 0&&F!==void 0&&(j[E]=F)})})(W,$):R[z.ref]?R[z.ref].rules.push($):y.push({ref:z.ref,rules:[$]})})}),y};class g extends e{constructor(k){super();const{maxRows:R,maxCols:O,ignoreNodes:z}=k||{};this.ignoreNodes=z||[],this.map={sheetPr:new h,dimension:new f,sheetViews:new l({tag:"sheetViews",count:!1,childXform:new _}),sheetFormatPr:new w,cols:new l({tag:"cols",count:!1,childXform:new i}),sheetData:new l({tag:"sheetData",count:!1,empty:!0,childXform:new n({maxItems:O}),maxItems:R}),autoFilter:new P,mergeCells:new l({tag:"mergeCells",count:!0,childXform:new u}),rowBreaks:new x,hyperlinks:new l({tag:"hyperlinks",count:!1,childXform:new c}),pageMargins:new N,dataValidations:new d,pageSetup:new L,headerFooter:new M,printOptions:new I,picture:new B,drawing:new U,sheetProtection:new A,tableParts:new l({tag:"tableParts",count:!0,childXform:new D}),conditionalFormatting:new v,extLst:new p}}prepare(k,R){R.merges=new t,k.hyperlinks=R.hyperlinks=[],k.comments=R.comments=[],R.formulae={},R.siFormulae=0,this.map.cols.prepare(k.cols,R),this.map.sheetData.prepare(k.rows,R),this.map.conditionalFormatting.prepare(k.conditionalFormattings,R),k.mergeCells=R.merges.mergeCells;const O=k.rels=[];function z(j){return"rId"+(j.length+1)}if(k.hyperlinks.forEach(j=>{const H=z(O);j.rId=H,O.push({Id:H,Type:r.Hyperlink,Target:j.target,TargetMode:"External"})}),k.comments.length>0){const j={Id:z(O),Type:r.Comments,Target:`../comments${k.id}.xml`};O.push(j);const H={Id:z(O),Type:r.VmlDrawing,Target:`../drawings/vmlDrawing${k.id}.vml`};O.push(H),k.comments.forEach(E=>{E.refAddress=a.decodeAddress(E.ref)}),R.commentRefs.push({commentName:"comments"+k.id,vmlDrawing:"vmlDrawing"+k.id})}const $=[];let W;k.media.forEach(j=>{if(j.type==="background"){const H=z(O);W=R.media[j.imageId],O.push({Id:H,Type:r.Image,Target:`../media/${W.name}.${W.extension}`}),k.background={rId:H},k.image=R.media[j.imageId]}else if(j.type==="image"){let{drawing:H}=k;W=R.media[j.imageId],H||(H=k.drawing={rId:z(O),name:"drawing"+ ++R.drawingsCount,anchors:[],rels:[]},R.drawings.push(H),O.push({Id:H.rId,Type:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing",Target:`../drawings/${H.name}.xml`}));let E=this.preImageId===j.imageId?$[j.imageId]:$[H.rels.length];E||(E=z(H.rels),$[H.rels.length]=E,H.rels.push({Id:E,Type:"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image",Target:`../media/${W.name}.${W.extension}`}));const C={picture:{rId:E},range:j.range};if(j.hyperlinks&&j.hyperlinks.hyperlink){const F=z(H.rels);$[H.rels.length]=F,C.picture.hyperlinks={tooltip:j.hyperlinks.tooltip,rId:F},H.rels.push({Id:F,Type:r.Hyperlink,Target:j.hyperlinks.hyperlink,TargetMode:"External"})}this.preImageId=j.imageId,H.anchors.push(C)}}),k.tables.forEach(j=>{const H=z(O);j.rId=H,O.push({Id:H,Type:r.Table,Target:"../tables/"+j.target}),j.columns.forEach(E=>{const{style:C}=E;C&&(E.dxfId=R.styles.addDxfStyle(C))})}),this.map.extLst.prepare(k,R)}render(k,R){k.openXml(o.StdDocAttributes),k.openNode("worksheet",g.WORKSHEET_ATTRIBUTES);const O=R.properties?{defaultRowHeight:R.properties.defaultRowHeight,dyDescent:R.properties.dyDescent,outlineLevelCol:R.properties.outlineLevelCol,outlineLevelRow:R.properties.outlineLevelRow}:void 0;R.properties&&R.properties.defaultColWidth&&(O.defaultColWidth=R.properties.defaultColWidth);const z={outlineProperties:R.properties&&R.properties.outlineProperties,tabColor:R.properties&&R.properties.tabColor,pageSetup:R.pageSetup&&R.pageSetup.fitToPage?{fitToPage:R.pageSetup.fitToPage}:void 0},$=R.pageSetup&&R.pageSetup.margins,W={showRowColHeaders:R.pageSetup&&R.pageSetup.showRowColHeaders,showGridLines:R.pageSetup&&R.pageSetup.showGridLines,horizontalCentered:R.pageSetup&&R.pageSetup.horizontalCentered,verticalCentered:R.pageSetup&&R.pageSetup.verticalCentered},j=R.sheetProtection;this.map.sheetPr.render(k,z),this.map.dimension.render(k,R.dimensions),this.map.sheetViews.render(k,R.views),this.map.sheetFormatPr.render(k,O),this.map.cols.render(k,R.cols),this.map.sheetData.render(k,R.rows),this.map.sheetProtection.render(k,j),this.map.autoFilter.render(k,R.autoFilter),this.map.mergeCells.render(k,R.mergeCells),this.map.conditionalFormatting.render(k,R.conditionalFormattings),this.map.dataValidations.render(k,R.dataValidations),this.map.hyperlinks.render(k,R.hyperlinks),this.map.printOptions.render(k,W),this.map.pageMargins.render(k,$),this.map.pageSetup.render(k,R.pageSetup),this.map.headerFooter.render(k,R.headerFooter),this.map.rowBreaks.render(k,R.rowBreaks),this.map.drawing.render(k,R.drawing),this.map.picture.render(k,R.background),this.map.tableParts.render(k,R.tables),this.map.extLst.render(k,R),R.rels&&R.rels.forEach(H=>{H.Type===r.VmlDrawing&&k.leafNode("legacyDrawing",{"r:id":H.Id})}),k.closeNode()}parseOpen(k){return this.parser?(this.parser.parseOpen(k),!0):k.name==="worksheet"?(m.each(this.map,R=>{R.reset()}),!0):(this.map[k.name]&&!this.ignoreNodes.includes(k.name)&&(this.parser=this.map[k.name],this.parser.parseOpen(k)),!0)}parseText(k){this.parser&&this.parser.parseText(k)}parseClose(k){if(this.parser)return this.parser.parseClose(k)||(this.parser=void 0),!0;switch(k){case"worksheet":{const R=this.map.sheetFormatPr.model||{};this.map.sheetPr.model&&this.map.sheetPr.model.tabColor&&(R.tabColor=this.map.sheetPr.model.tabColor),this.map.sheetPr.model&&this.map.sheetPr.model.outlineProperties&&(R.outlineProperties=this.map.sheetPr.model.outlineProperties);const O={fitToPage:this.map.sheetPr.model&&this.map.sheetPr.model.pageSetup&&this.map.sheetPr.model.pageSetup.fitToPage||!1,margins:this.map.pageMargins.model},z=Object.assign(O,this.map.pageSetup.model,this.map.printOptions.model),$=b(this.map.conditionalFormatting.model,this.map.extLst.model&&this.map.extLst.model["x14:conditionalFormattings"]);return this.model={dimensions:this.map.dimension.model,cols:this.map.cols.model,rows:this.map.sheetData.model,mergeCells:this.map.mergeCells.model,hyperlinks:this.map.hyperlinks.model,dataValidations:this.map.dataValidations.model,properties:R,views:this.map.sheetViews.model,pageSetup:z,headerFooter:this.map.headerFooter.model,background:this.map.picture.model,drawing:this.map.drawing.model,tables:this.map.tableParts.model,conditionalFormattings:$},this.map.autoFilter.model&&(this.model.autoFilter=this.map.autoFilter.model),this.map.sheetProtection.model&&(this.model.sheetProtection=this.map.sheetProtection.model),!1}default:return!0}}reconcile(k,R){const O=(k.relationships||[]).reduce(($,W)=>{if($[W.Id]=W,W.Type===r.Comments&&(k.comments=R.comments[W.Target].comments),W.Type===r.VmlDrawing&&k.comments&&k.comments.length){const j=R.vmlDrawings[W.Target].comments;k.comments.forEach((H,E)=>{H.note=Object.assign({},H.note,j[E])})}return $},{});if(R.commentsMap=(k.comments||[]).reduce(($,W)=>(W.ref&&($[W.ref]=W),$),{}),R.hyperlinkMap=(k.hyperlinks||[]).reduce(($,W)=>(W.rId&&($[W.address]=O[W.rId].Target),$),{}),R.formulae={},k.rows=k.rows&&k.rows.filter(Boolean)||[],k.rows.forEach($=>{$.cells=$.cells&&$.cells.filter(Boolean)||[]}),this.map.cols.reconcile(k.cols,R),this.map.sheetData.reconcile(k.rows,R),this.map.conditionalFormatting.reconcile(k.conditionalFormattings,R),k.media=[],k.drawing){const $=O[k.drawing.rId].Target.match(/\/drawings\/([a-zA-Z0-9]+)[.][a-zA-Z]{3,4}$/);if($){const W=$[1];R.drawings[W].anchors.forEach(j=>{if(j.medium){const H={type:"image",imageId:j.medium.index,range:j.range,hyperlinks:j.picture.hyperlinks};k.media.push(H)}})}}const z=k.background&&O[k.background.rId];if(z){const $=z.Target.split("/media/")[1],W=R.mediaIndex&&R.mediaIndex[$];W!==void 0&&k.media.push({type:"background",imageId:W})}k.tables=(k.tables||[]).map($=>{const W=O[$.rId];return R.tables[W.Target]}),delete k.relationships,delete k.hyperlinks,delete k.comments}}g.WORKSHEET_ATTRIBUTES={xmlns:"http://schemas.openxmlformats.org/spreadsheetml/2006/main","xmlns:r":"http://schemas.openxmlformats.org/officeDocument/2006/relationships","xmlns:mc":"http://schemas.openxmlformats.org/markup-compatibility/2006","mc:Ignorable":"x14ac","xmlns:x14ac":"http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac"},T.exports=g},{"../../../utils/col-cache":19,"../../../utils/under-dash":26,"../../../utils/xml-stream":28,"../../rel-type":31,"../base-xform":32,"../list-xform":71,"./auto-filter-xform":72,"./cf/conditional-formattings-xform":87,"./col-xform":92,"./data-validations-xform":93,"./dimension-xform":94,"./drawing-xform":95,"./ext-lst-xform":96,"./header-footer-xform":97,"./hyperlink-xform":98,"./merge-cell-xform":99,"./merges":100,"./page-margins-xform":103,"./page-setup-xform":105,"./picture-xform":106,"./print-options-xform":107,"./row-breaks-xform":108,"./row-xform":109,"./sheet-format-properties-xform":110,"./sheet-properties-xform":111,"./sheet-protection-xform":112,"./sheet-view-xform":113,"./table-part-xform":114}],116:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{constructor(a){super(),this.tag=a.tag,this.attr=a.attr}render(a,o){o&&(a.openNode(this.tag),a.closeNode())}parseOpen(a){a.name===this.tag&&(this.model=!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],117:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{constructor(a){super(),this.tag=a.tag,this.attr=a.attr,this.attrs=a.attrs,this._format=a.format||function(o){try{return Number.isNaN(o.getTime())?"":o.toISOString()}catch{return""}},this._parse=a.parse||function(o){return new Date(o)}}render(a,o){o&&(a.openNode(this.tag),this.attrs&&a.addAttributes(this.attrs),this.attr?a.addAttribute(this.attr,this._format(o)):a.writeText(this._format(o)),a.closeNode())}parseOpen(a){a.name===this.tag&&(this.attr?this.model=this._parse(a.attributes[this.attr]):this.text=[])}parseText(a){this.attr||this.text.push(a)}parseClose(){return this.attr||(this.model=this._parse(this.text.join(""))),!1}}},{"../base-xform":32}],118:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{constructor(a){super(),this.tag=a.tag,this.attr=a.attr,this.attrs=a.attrs,this.zero=a.zero}render(a,o){(o||this.zero)&&(a.openNode(this.tag),this.attrs&&a.addAttributes(this.attrs),this.attr?a.addAttribute(this.attr,o):a.writeText(o),a.closeNode())}parseOpen(a){return a.name===this.tag&&(this.attr?this.model=parseInt(a.attributes[this.attr],10):this.text=[],!0)}parseText(a){this.attr||this.text.push(a)}parseClose(){return this.attr||(this.model=parseInt(this.text.join("")||0,10)),!1}}},{"../base-xform":32}],119:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{constructor(a){super(),this.tag=a.tag,this.attr=a.attr,this.attrs=a.attrs}render(a,o){o!==void 0&&(a.openNode(this.tag),this.attrs&&a.addAttributes(this.attrs),this.attr?a.addAttribute(this.attr,o):a.writeText(o),a.closeNode())}parseOpen(a){a.name===this.tag&&(this.attr?this.model=a.attributes[this.attr]:this.text=[])}parseText(a){this.attr||this.text.push(a)}parseClose(){return this.attr||(this.model=this.text.join("")),!1}}},{"../base-xform":32}],120:[function(s,T,S){const m=s("./base-xform"),a=s("../../utils/xml-stream");T.exports=class extends m{constructor(o){super(),this._model=o}render(o){if(!this._xml){const r=new a;(function t(e,l){e.openNode(l.tag,l.$),l.c&&l.c.forEach(n=>{t(e,n)}),l.t&&e.writeText(l.t),e.closeNode()})(r,this._model),this._xml=r.xml}o.writeXml(this._xml)}parseOpen(){return!0}parseText(){}parseClose(o){switch(o){case this._model.tag:return!1;default:return!0}}}},{"../../utils/xml-stream":28,"./base-xform":32}],121:[function(s,T,S){const m=s("./text-xform"),a=s("./rich-text-xform"),o=s("../base-xform");T.exports=class extends o{constructor(){super(),this.map={r:new a,t:new m}}get tag(){return"rPh"}render(r,t){if(r.openNode(this.tag,{sb:t.sb||0,eb:t.eb||0}),t&&t.hasOwnProperty("richText")&&t.richText){const{r:e}=this.map;t.richText.forEach(l=>{e.render(r,l)})}else t&&this.map.t.render(r,t.text);r.closeNode()}parseOpen(r){const{name:t}=r;return this.parser?(this.parser.parseOpen(r),!0):t===this.tag?(this.model={sb:parseInt(r.attributes.sb,10),eb:parseInt(r.attributes.eb,10)},!0):(this.parser=this.map[t],!!this.parser&&(this.parser.parseOpen(r),!0))}parseText(r){this.parser&&this.parser.parseText(r)}parseClose(r){if(this.parser){if(!this.parser.parseClose(r)){switch(r){case"r":{let t=this.model.richText;t||(t=this.model.richText=[]),t.push(this.parser.model);break}case"t":this.model.text=this.parser.model}this.parser=void 0}return!0}switch(r){case this.tag:return!1;default:return!0}}}},{"../base-xform":32,"./rich-text-xform":122,"./text-xform":125}],122:[function(s,T,S){const m=s("./text-xform"),a=s("../style/font-xform"),o=s("../base-xform");class r extends o{constructor(e){super(),this.model=e}get tag(){return"r"}get textXform(){return this._textXform||(this._textXform=new m)}get fontXform(){return this._fontXform||(this._fontXform=new a(r.FONT_OPTIONS))}render(e,l){l=l||this.model,e.openNode("r"),l.font&&this.fontXform.render(e,l.font),this.textXform.render(e,l.text),e.closeNode()}parseOpen(e){if(this.parser)return this.parser.parseOpen(e),!0;switch(e.name){case"r":return this.model={},!0;case"t":return this.parser=this.textXform,this.parser.parseOpen(e),!0;case"rPr":return this.parser=this.fontXform,this.parser.parseOpen(e),!0;default:return!1}}parseText(e){this.parser&&this.parser.parseText(e)}parseClose(e){switch(e){case"r":return!1;case"t":return this.model.text=this.parser.model,this.parser=void 0,!0;case"rPr":return this.model.font=this.parser.model,this.parser=void 0,!0;default:return this.parser&&this.parser.parseClose(e),!0}}}r.FONT_OPTIONS={tagName:"rPr",fontNameTag:"rFont"},T.exports=r},{"../base-xform":32,"../style/font-xform":131,"./text-xform":125}],123:[function(s,T,S){const m=s("./text-xform"),a=s("./rich-text-xform"),o=s("./phonetic-text-xform"),r=s("../base-xform");T.exports=class extends r{constructor(t){super(),this.model=t,this.map={r:new a,t:new m,rPh:new o}}get tag(){return"si"}render(t,e){t.openNode(this.tag),e&&e.hasOwnProperty("richText")&&e.richText?e.richText.length?e.richText.forEach(l=>{this.map.r.render(t,l)}):this.map.t.render(t,""):e!=null&&this.map.t.render(t,e),t.closeNode()}parseOpen(t){const{name:e}=t;return this.parser?(this.parser.parseOpen(t),!0):e===this.tag?(this.model={},!0):(this.parser=this.map[e],!!this.parser&&(this.parser.parseOpen(t),!0))}parseText(t){this.parser&&this.parser.parseText(t)}parseClose(t){if(this.parser){if(!this.parser.parseClose(t)){switch(t){case"r":{let e=this.model.richText;e||(e=this.model.richText=[]),e.push(this.parser.model);break}case"t":this.model=this.parser.model}this.parser=void 0}return!0}switch(t){case this.tag:return!1;default:return!0}}}},{"../base-xform":32,"./phonetic-text-xform":121,"./rich-text-xform":122,"./text-xform":125}],124:[function(s,T,S){const m=s("../../../utils/xml-stream"),a=s("../base-xform"),o=s("./shared-string-xform");T.exports=class extends a{constructor(r){super(),this.model=r||{values:[],count:0},this.hash=Object.create(null),this.rich=Object.create(null)}get sharedStringXform(){return this._sharedStringXform||(this._sharedStringXform=new o)}get values(){return this.model.values}get uniqueCount(){return this.model.values.length}get count(){return this.model.count}getString(r){return this.model.values[r]}add(r){return r.richText?this.addRichText(r):this.addText(r)}addText(r){let t=this.hash[r];return t===void 0&&(t=this.hash[r]=this.model.values.length,this.model.values.push(r)),this.model.count++,t}addRichText(r){const t=this.sharedStringXform.toXml(r);let e=this.rich[t];return e===void 0&&(e=this.rich[t]=this.model.values.length,this.model.values.push(r)),this.model.count++,e}render(r,t){t=t||this._values,r.openXml(m.StdDocAttributes),r.openNode("sst",{xmlns:"http://schemas.openxmlformats.org/spreadsheetml/2006/main",count:t.count,uniqueCount:t.values.length});const e=this.sharedStringXform;t.values.forEach(l=>{e.render(r,l)}),r.closeNode()}parseOpen(r){if(this.parser)return this.parser.parseOpen(r),!0;switch(r.name){case"sst":return!0;case"si":return this.parser=this.sharedStringXform,this.parser.parseOpen(r),!0;default:throw new Error("Unexpected xml node in parseOpen: "+JSON.stringify(r))}}parseText(r){this.parser&&this.parser.parseText(r)}parseClose(r){if(this.parser)return this.parser.parseClose(r)||(this.model.values.push(this.parser.model),this.model.count++,this.parser=void 0),!0;switch(r){case"sst":return!1;default:throw new Error("Unexpected xml node in parseClose: "+r)}}}},{"../../../utils/xml-stream":28,"../base-xform":32,"./shared-string-xform":123}],125:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"t"}render(a,o){a.openNode("t"),/^\s|\n|\s$/.test(o)&&a.addAttribute("xml:space","preserve"),a.writeText(o),a.closeNode()}get model(){return this._text.join("").replace(/_x([0-9A-F]{4})_/g,(a,o)=>String.fromCharCode(parseInt(o,16)))}parseOpen(a){switch(a.name){case"t":return this._text=[],!0;default:return!1}}parseText(a){this._text.push(a)}parseClose(){return!1}}},{"../base-xform":32}],126:[function(s,T,S){const m=s("../../../doc/enums"),a=s("../../../utils/utils"),o=s("../base-xform"),r={horizontalValues:["left","center","right","fill","centerContinuous","distributed","justify"].reduce((e,l)=>(e[l]=!0,e),{}),horizontal(e){return this.horizontalValues[e]?e:void 0},verticalValues:["top","middle","bottom","distributed","justify"].reduce((e,l)=>(e[l]=!0,e),{}),vertical(e){return e==="middle"?"center":this.verticalValues[e]?e:void 0},wrapText:e=>!!e||void 0,shrinkToFit:e=>!!e||void 0,textRotation(e){switch(e){case"vertical":return e;default:return(e=a.validInt(e))>=-90&&e<=90?e:void 0}},indent:e=>(e=a.validInt(e),Math.max(0,e)),readingOrder(e){switch(e){case"ltr":return m.ReadingOrder.LeftToRight;case"rtl":return m.ReadingOrder.RightToLeft;default:return}}},t={toXml(e){if(e=r.textRotation(e)){if(e==="vertical")return 255;const l=Math.round(e);if(l>=0&&l<=90)return l;if(l<0&&l>=-90)return 90-l}},toModel(e){const l=a.validInt(e);if(l!==void 0){if(l===255)return"vertical";if(l>=0&&l<=90)return l;if(l>90&&l<=180)return 90-l}}};T.exports=class extends o{get tag(){return"alignment"}render(e,l){e.addRollback(),e.openNode("alignment");let n=!1;function i(f,c){c&&(e.addAttribute(f,c),n=!0)}i("horizontal",r.horizontal(l.horizontal)),i("vertical",r.vertical(l.vertical)),i("wrapText",!!r.wrapText(l.wrapText)&&"1"),i("shrinkToFit",!!r.shrinkToFit(l.shrinkToFit)&&"1"),i("indent",r.indent(l.indent)),i("textRotation",t.toXml(l.textRotation)),i("readingOrder",r.readingOrder(l.readingOrder)),e.closeNode(),n?e.commit():e.rollback()}parseOpen(e){const l={};let n=!1;function i(f,c,u){f&&(l[c]=u,n=!0)}i(e.attributes.horizontal,"horizontal",e.attributes.horizontal),i(e.attributes.vertical,"vertical",e.attributes.vertical==="center"?"middle":e.attributes.vertical),i(e.attributes.wrapText,"wrapText",a.parseBoolean(e.attributes.wrapText)),i(e.attributes.shrinkToFit,"shrinkToFit",a.parseBoolean(e.attributes.shrinkToFit)),i(e.attributes.indent,"indent",parseInt(e.attributes.indent,10)),i(e.attributes.textRotation,"textRotation",t.toModel(e.attributes.textRotation)),i(e.attributes.readingOrder,"readingOrder",e.attributes.readingOrder==="2"?"rtl":"ltr"),this.model=n?l:null}parseText(){}parseClose(){return!1}}},{"../../../doc/enums":7,"../../../utils/utils":27,"../base-xform":32}],127:[function(s,T,S){const m=s("../base-xform"),a=s("../../../utils/utils"),o=s("./color-xform");class r extends m{constructor(e){super(),this.name=e,this.map={color:new o}}get tag(){return this.name}render(e,l,n){const i=l&&l.color||n||this.defaultColor;e.openNode(this.name),l&&l.style&&(e.addAttribute("style",l.style),i&&this.map.color.render(e,i)),e.closeNode()}parseOpen(e){if(this.parser)return this.parser.parseOpen(e),!0;switch(e.name){case this.name:{const{style:l}=e.attributes;return this.model=l?{style:l}:void 0,!0}case"color":return this.parser=this.map.color,this.parser.parseOpen(e),!0;default:return!1}}parseText(e){this.parser&&this.parser.parseText(e)}parseClose(e){return this.parser?(this.parser.parseClose(e)||(this.parser=void 0),!0):(e===this.name&&this.map.color.model&&(this.model||(this.model={}),this.model.color=this.map.color.model),!1)}validStyle(e){return r.validStyleValues[e]}}r.validStyleValues=["thin","dashed","dotted","dashDot","hair","dashDotDot","slantDashDot","mediumDashed","mediumDashDotDot","mediumDashDot","medium","double","thick"].reduce((t,e)=>(t[e]=!0,t),{}),T.exports=class extends m{constructor(){super(),this.map={top:new r("top"),left:new r("left"),bottom:new r("bottom"),right:new r("right"),diagonal:new r("diagonal")}}render(t,e){const{color:l}=e;function n(i,f){i&&!i.color&&e.color&&(i={...i,color:e.color}),f.render(t,i,l)}t.openNode("border"),e.diagonal&&e.diagonal.style&&(e.diagonal.up&&t.addAttribute("diagonalUp","1"),e.diagonal.down&&t.addAttribute("diagonalDown","1")),n(e.left,this.map.left),n(e.right,this.map.right),n(e.top,this.map.top),n(e.bottom,this.map.bottom),n(e.diagonal,this.map.diagonal),t.closeNode()}parseOpen(t){if(this.parser)return this.parser.parseOpen(t),!0;switch(t.name){case"border":return this.reset(),this.diagonalUp=a.parseBoolean(t.attributes.diagonalUp),this.diagonalDown=a.parseBoolean(t.attributes.diagonalDown),!0;default:return this.parser=this.map[t.name],!!this.parser&&(this.parser.parseOpen(t),!0)}}parseText(t){this.parser&&this.parser.parseText(t)}parseClose(t){if(this.parser)return this.parser.parseClose(t)||(this.parser=void 0),!0;if(t==="border"){const e=this.model={},l=function(n,i,f){i&&(f&&Object.assign(i,f),e[n]=i)};l("left",this.map.left.model),l("right",this.map.right.model),l("top",this.map.top.model),l("bottom",this.map.bottom.model),l("diagonal",this.map.diagonal.model,{up:this.diagonalUp,down:this.diagonalDown})}return!1}}},{"../../../utils/utils":27,"../base-xform":32,"./color-xform":128}],128:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{constructor(a){super(),this.name=a||"color"}get tag(){return this.name}render(a,o){return!!o&&(a.openNode(this.name),o.argb?a.addAttribute("rgb",o.argb):o.theme!==void 0?(a.addAttribute("theme",o.theme),o.tint!==void 0&&a.addAttribute("tint",o.tint)):o.indexed!==void 0?a.addAttribute("indexed",o.indexed):a.addAttribute("auto","1"),a.closeNode(),!0)}parseOpen(a){return a.name===this.name&&(a.attributes.rgb?this.model={argb:a.attributes.rgb}:a.attributes.theme?(this.model={theme:parseInt(a.attributes.theme,10)},a.attributes.tint&&(this.model.tint=parseFloat(a.attributes.tint))):a.attributes.indexed?this.model={indexed:parseInt(a.attributes.indexed,10)}:this.model=void 0,!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],129:[function(s,T,S){const m=s("../base-xform"),a=s("./alignment-xform"),o=s("./border-xform"),r=s("./fill-xform"),t=s("./font-xform"),e=s("./numfmt-xform"),l=s("./protection-xform");T.exports=class extends m{constructor(){super(),this.map={alignment:new a,border:new o,fill:new r,font:new t,numFmt:new e,protection:new l}}get tag(){return"dxf"}render(n,i){if(n.openNode(this.tag),i.font&&this.map.font.render(n,i.font),i.numFmt&&i.numFmtId){const f={id:i.numFmtId,formatCode:i.numFmt};this.map.numFmt.render(n,f)}i.fill&&this.map.fill.render(n,i.fill),i.alignment&&this.map.alignment.render(n,i.alignment),i.border&&this.map.border.render(n,i.border),i.protection&&this.map.protection.render(n,i.protection),n.closeNode()}parseOpen(n){if(this.parser)return this.parser.parseOpen(n),!0;switch(n.name){case this.tag:return this.reset(),!0;default:return this.parser=this.map[n.name],this.parser&&this.parser.parseOpen(n),!0}}parseText(n){this.parser&&this.parser.parseText(n)}parseClose(n){return this.parser?(this.parser.parseClose(n)||(this.parser=void 0),!0):n!==this.tag||(this.model={alignment:this.map.alignment.model,border:this.map.border.model,fill:this.map.fill.model,font:this.map.font.model,numFmt:this.map.numFmt.model,protection:this.map.protection.model},!1)}}},{"../base-xform":32,"./alignment-xform":126,"./border-xform":127,"./fill-xform":130,"./font-xform":131,"./numfmt-xform":132,"./protection-xform":133}],130:[function(s,T,S){const m=s("../base-xform"),a=s("./color-xform");class o extends m{constructor(){super(),this.map={color:new a}}get tag(){return"stop"}render(n,i){n.openNode("stop"),n.addAttribute("position",i.position),this.map.color.render(n,i.color),n.closeNode()}parseOpen(n){if(this.parser)return this.parser.parseOpen(n),!0;switch(n.name){case"stop":return this.model={position:parseFloat(n.attributes.position)},!0;case"color":return this.parser=this.map.color,this.parser.parseOpen(n),!0;default:return!1}}parseText(){}parseClose(n){return!!this.parser&&(this.parser.parseClose(n)||(this.model.color=this.parser.model,this.parser=void 0),!0)}}class r extends m{constructor(){super(),this.map={fgColor:new a("fgColor"),bgColor:new a("bgColor")}}get name(){return"pattern"}get tag(){return"patternFill"}render(n,i){n.openNode("patternFill"),n.addAttribute("patternType",i.pattern),i.fgColor&&this.map.fgColor.render(n,i.fgColor),i.bgColor&&this.map.bgColor.render(n,i.bgColor),n.closeNode()}parseOpen(n){if(this.parser)return this.parser.parseOpen(n),!0;switch(n.name){case"patternFill":return this.model={type:"pattern",pattern:n.attributes.patternType},!0;default:return this.parser=this.map[n.name],!!this.parser&&(this.parser.parseOpen(n),!0)}}parseText(n){this.parser&&this.parser.parseText(n)}parseClose(n){return!!this.parser&&(this.parser.parseClose(n)||(this.parser.model&&(this.model[n]=this.parser.model),this.parser=void 0),!0)}}class t extends m{constructor(){super(),this.map={stop:new o}}get name(){return"gradient"}get tag(){return"gradientFill"}render(n,i){switch(n.openNode("gradientFill"),i.gradient){case"angle":n.addAttribute("degree",i.degree);break;case"path":n.addAttribute("type","path"),i.center.left&&(n.addAttribute("left",i.center.left),i.center.right===void 0&&n.addAttribute("right",i.center.left)),i.center.right&&n.addAttribute("right",i.center.right),i.center.top&&(n.addAttribute("top",i.center.top),i.center.bottom===void 0&&n.addAttribute("bottom",i.center.top)),i.center.bottom&&n.addAttribute("bottom",i.center.bottom)}const f=this.map.stop;i.stops.forEach(c=>{f.render(n,c)}),n.closeNode()}parseOpen(n){if(this.parser)return this.parser.parseOpen(n),!0;switch(n.name){case"gradientFill":{const i=this.model={stops:[]};return n.attributes.degree?(i.gradient="angle",i.degree=parseInt(n.attributes.degree,10)):n.attributes.type==="path"&&(i.gradient="path",i.center={left:n.attributes.left?parseFloat(n.attributes.left):0,top:n.attributes.top?parseFloat(n.attributes.top):0},n.attributes.right!==n.attributes.left&&(i.center.right=n.attributes.right?parseFloat(n.attributes.right):0),n.attributes.bottom!==n.attributes.top&&(i.center.bottom=n.attributes.bottom?parseFloat(n.attributes.bottom):0)),!0}case"stop":return this.parser=this.map.stop,this.parser.parseOpen(n),!0;default:return!1}}parseText(n){this.parser&&this.parser.parseText(n)}parseClose(n){return!!this.parser&&(this.parser.parseClose(n)||(this.model.stops.push(this.parser.model),this.parser=void 0),!0)}}class e extends m{constructor(){super(),this.map={patternFill:new r,gradientFill:new t}}get tag(){return"fill"}render(n,i){switch(n.addRollback(),n.openNode("fill"),i.type){case"pattern":this.map.patternFill.render(n,i);break;case"gradient":this.map.gradientFill.render(n,i);break;default:return void n.rollback()}n.closeNode(),n.commit()}parseOpen(n){if(this.parser)return this.parser.parseOpen(n),!0;switch(n.name){case"fill":return this.model={},!0;default:return this.parser=this.map[n.name],!!this.parser&&(this.parser.parseOpen(n),!0)}}parseText(n){this.parser&&this.parser.parseText(n)}parseClose(n){return!!this.parser&&(this.parser.parseClose(n)||(this.model=this.parser.model,this.model.type=this.parser.name,this.parser=void 0),!0)}validStyle(n){return e.validPatternValues[n]}}e.validPatternValues=["none","solid","darkVertical","darkGray","mediumGray","lightGray","gray125","gray0625","darkHorizontal","darkVertical","darkDown","darkUp","darkGrid","darkTrellis","lightHorizontal","lightVertical","lightDown","lightUp","lightGrid","lightTrellis","lightGrid"].reduce((l,n)=>(l[n]=!0,l),{}),e.StopXform=o,e.PatternFillXform=r,e.GradientFillXform=t,T.exports=e},{"../base-xform":32,"./color-xform":128}],131:[function(s,T,S){const m=s("./color-xform"),a=s("../simple/boolean-xform"),o=s("../simple/integer-xform"),r=s("../simple/string-xform"),t=s("./underline-xform"),e=s("../../../utils/under-dash"),l=s("../base-xform");class n extends l{constructor(f){super(),this.options=f||n.OPTIONS,this.map={b:{prop:"bold",xform:new a({tag:"b",attr:"val"})},i:{prop:"italic",xform:new a({tag:"i",attr:"val"})},u:{prop:"underline",xform:new t},charset:{prop:"charset",xform:new o({tag:"charset",attr:"val"})},color:{prop:"color",xform:new m},condense:{prop:"condense",xform:new a({tag:"condense",attr:"val"})},extend:{prop:"extend",xform:new a({tag:"extend",attr:"val"})},family:{prop:"family",xform:new o({tag:"family",attr:"val"})},outline:{prop:"outline",xform:new a({tag:"outline",attr:"val"})},vertAlign:{prop:"vertAlign",xform:new r({tag:"vertAlign",attr:"val"})},scheme:{prop:"scheme",xform:new r({tag:"scheme",attr:"val"})},shadow:{prop:"shadow",xform:new a({tag:"shadow",attr:"val"})},strike:{prop:"strike",xform:new a({tag:"strike",attr:"val"})},sz:{prop:"size",xform:new o({tag:"sz",attr:"val"})}},this.map[this.options.fontNameTag]={prop:"name",xform:new r({tag:this.options.fontNameTag,attr:"val"})}}get tag(){return this.options.tagName}render(f,c){const{map:u}=this;f.openNode(this.options.tagName),e.each(this.map,(d,h)=>{u[h].xform.render(f,c[d.prop])}),f.closeNode()}parseOpen(f){if(this.parser)return this.parser.parseOpen(f),!0;if(this.map[f.name])return this.parser=this.map[f.name].xform,this.parser.parseOpen(f);switch(f.name){case this.options.tagName:return this.model={},!0;default:return!1}}parseText(f){this.parser&&this.parser.parseText(f)}parseClose(f){if(this.parser&&!this.parser.parseClose(f)){const c=this.map[f];return this.parser.model&&(this.model[c.prop]=this.parser.model),this.parser=void 0,!0}switch(f){case this.options.tagName:return!1;default:return!0}}}n.OPTIONS={tagName:"font",fontNameTag:"name"},T.exports=n},{"../../../utils/under-dash":26,"../base-xform":32,"../simple/boolean-xform":116,"../simple/integer-xform":118,"../simple/string-xform":119,"./color-xform":128,"./underline-xform":136}],132:[function(s,T,S){const m=s("../../../utils/under-dash"),a=s("../../defaultnumformats"),o=s("../base-xform"),r=function(){const e={};return m.each(a,(l,n)=>{l.f&&(e[l.f]=parseInt(n,10))}),e}();class t extends o{constructor(l,n){super(),this.id=l,this.formatCode=n}get tag(){return"numFmt"}render(l,n){l.leafNode("numFmt",{numFmtId:n.id,formatCode:n.formatCode})}parseOpen(l){switch(l.name){case"numFmt":return this.model={id:parseInt(l.attributes.numFmtId,10),formatCode:l.attributes.formatCode.replace(/[\\](.)/g,"$1")},!0;default:return!1}}parseText(){}parseClose(){return!1}}t.getDefaultFmtId=function(e){return r[e]},t.getDefaultFmtCode=function(e){return a[e]&&a[e].f},T.exports=t},{"../../../utils/under-dash":26,"../../defaultnumformats":30,"../base-xform":32}],133:[function(s,T,S){const m=s("../base-xform"),a={boolean:(o,r)=>o===void 0?r:o};T.exports=class extends m{get tag(){return"protection"}render(o,r){o.addRollback(),o.openNode("protection");let t=!1;function e(l,n){n!==void 0&&(o.addAttribute(l,n),t=!0)}e("locked",a.boolean(r.locked,!0)?void 0:"0"),e("hidden",a.boolean(r.hidden,!1)?"1":void 0),o.closeNode(),t?o.commit():o.rollback()}parseOpen(o){const r={locked:o.attributes.locked!=="0",hidden:o.attributes.hidden==="1"},t=!r.locked||r.hidden;this.model=t?r:null}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],134:[function(s,T,S){const m=s("../base-xform"),a=s("./alignment-xform"),o=s("./protection-xform");T.exports=class extends m{constructor(r){super(),this.xfId=!(!r||!r.xfId),this.map={alignment:new a,protection:new o}}get tag(){return"xf"}render(r,t){r.openNode("xf",{numFmtId:t.numFmtId||0,fontId:t.fontId||0,fillId:t.fillId||0,borderId:t.borderId||0}),this.xfId&&r.addAttribute("xfId",t.xfId||0),t.numFmtId&&r.addAttribute("applyNumberFormat","1"),t.fontId&&r.addAttribute("applyFont","1"),t.fillId&&r.addAttribute("applyFill","1"),t.borderId&&r.addAttribute("applyBorder","1"),t.alignment&&r.addAttribute("applyAlignment","1"),t.protection&&r.addAttribute("applyProtection","1"),t.alignment&&this.map.alignment.render(r,t.alignment),t.protection&&this.map.protection.render(r,t.protection),r.closeNode()}parseOpen(r){if(this.parser)return this.parser.parseOpen(r),!0;switch(r.name){case"xf":return this.model={numFmtId:parseInt(r.attributes.numFmtId,10),fontId:parseInt(r.attributes.fontId,10),fillId:parseInt(r.attributes.fillId,10),borderId:parseInt(r.attributes.borderId,10)},this.xfId&&(this.model.xfId=parseInt(r.attributes.xfId,10)),!0;case"alignment":return this.parser=this.map.alignment,this.parser.parseOpen(r),!0;case"protection":return this.parser=this.map.protection,this.parser.parseOpen(r),!0;default:return!1}}parseText(r){this.parser&&this.parser.parseText(r)}parseClose(r){return this.parser?(this.parser.parseClose(r)||(this.map.protection===this.parser?this.model.protection=this.parser.model:this.model.alignment=this.parser.model,this.parser=void 0),!0):r!=="xf"}}},{"../base-xform":32,"./alignment-xform":126,"./protection-xform":133}],135:[function(s,T,S){const m=s("../../../doc/enums"),a=s("../../../utils/xml-stream"),o=s("../base-xform"),r=s("../static-xform"),t=s("../list-xform"),e=s("./font-xform"),l=s("./fill-xform"),n=s("./border-xform"),i=s("./numfmt-xform"),f=s("./style-xform"),c=s("./dxf-xform");class u extends o{constructor(h){super(),this.map={numFmts:new t({tag:"numFmts",count:!0,childXform:new i}),fonts:new t({tag:"fonts",count:!0,childXform:new e,$:{"x14ac:knownFonts":1}}),fills:new t({tag:"fills",count:!0,childXform:new l}),borders:new t({tag:"borders",count:!0,childXform:new n}),cellStyleXfs:new t({tag:"cellStyleXfs",count:!0,childXform:new f}),cellXfs:new t({tag:"cellXfs",count:!0,childXform:new f({xfId:!0})}),dxfs:new t({tag:"dxfs",always:!0,count:!0,childXform:new c}),numFmt:new i,font:new e,fill:new l,border:new n,style:new f({xfId:!0}),cellStyles:u.STATIC_XFORMS.cellStyles,tableStyles:u.STATIC_XFORMS.tableStyles,extLst:u.STATIC_XFORMS.extLst},h&&this.init()}initIndex(){this.index={style:{},numFmt:{},numFmtNextId:164,font:{},border:{},fill:{}}}init(){this.model={styles:[],numFmts:[],fonts:[],borders:[],fills:[],dxfs:[]},this.initIndex(),this._addBorder({}),this._addStyle({numFmtId:0,fontId:0,fillId:0,borderId:0,xfId:0}),this._addFill({type:"pattern",pattern:"none"}),this._addFill({type:"pattern",pattern:"gray125"}),this.weakMap=new WeakMap}render(h,w){w=w||this.model,h.openXml(a.StdDocAttributes),h.openNode("styleSheet",u.STYLESHEET_ATTRIBUTES),this.index?(w.numFmts&&w.numFmts.length&&(h.openNode("numFmts",{count:w.numFmts.length}),w.numFmts.forEach(_=>{h.writeXml(_)}),h.closeNode()),w.fonts.length||this._addFont({size:11,color:{theme:1},name:"Calibri",family:2,scheme:"minor"}),h.openNode("fonts",{count:w.fonts.length,"x14ac:knownFonts":1}),w.fonts.forEach(_=>{h.writeXml(_)}),h.closeNode(),h.openNode("fills",{count:w.fills.length}),w.fills.forEach(_=>{h.writeXml(_)}),h.closeNode(),h.openNode("borders",{count:w.borders.length}),w.borders.forEach(_=>{h.writeXml(_)}),h.closeNode(),this.map.cellStyleXfs.render(h,[{numFmtId:0,fontId:0,fillId:0,borderId:0,xfId:0}]),h.openNode("cellXfs",{count:w.styles.length}),w.styles.forEach(_=>{h.writeXml(_)}),h.closeNode()):(this.map.numFmts.render(h,w.numFmts),this.map.fonts.render(h,w.fonts),this.map.fills.render(h,w.fills),this.map.borders.render(h,w.borders),this.map.cellStyleXfs.render(h,[{numFmtId:0,fontId:0,fillId:0,borderId:0,xfId:0}]),this.map.cellXfs.render(h,w.styles)),u.STATIC_XFORMS.cellStyles.render(h),this.map.dxfs.render(h,w.dxfs),u.STATIC_XFORMS.tableStyles.render(h),u.STATIC_XFORMS.extLst.render(h),h.closeNode()}parseOpen(h){if(this.parser)return this.parser.parseOpen(h),!0;switch(h.name){case"styleSheet":return this.initIndex(),!0;default:return this.parser=this.map[h.name],this.parser&&this.parser.parseOpen(h),!0}}parseText(h){this.parser&&this.parser.parseText(h)}parseClose(h){if(this.parser)return this.parser.parseClose(h)||(this.parser=void 0),!0;switch(h){case"styleSheet":{this.model={};const w=(_,A)=>{A.model&&A.model.length&&(this.model[_]=A.model)};if(w("numFmts",this.map.numFmts),w("fonts",this.map.fonts),w("fills",this.map.fills),w("borders",this.map.borders),w("styles",this.map.cellXfs),w("dxfs",this.map.dxfs),this.index={model:[],numFmt:[]},this.model.numFmts){const _=this.index.numFmt;this.model.numFmts.forEach(A=>{_[A.id]=A.formatCode})}return!1}default:return!0}}addStyleModel(h,w){if(!h)return 0;if(this.model.fonts.length||this._addFont({size:11,color:{theme:1},name:"Calibri",family:2,scheme:"minor"}),this.weakMap&&this.weakMap.has(h))return this.weakMap.get(h);const _={};if(w=w||m.ValueType.Number,h.numFmt)_.numFmtId=this._addNumFmtStr(h.numFmt);else switch(w){case m.ValueType.Number:_.numFmtId=this._addNumFmtStr("General");break;case m.ValueType.Date:_.numFmtId=this._addNumFmtStr("mm-dd-yy")}h.font&&(_.fontId=this._addFont(h.font)),h.border&&(_.borderId=this._addBorder(h.border)),h.fill&&(_.fillId=this._addFill(h.fill)),h.alignment&&(_.alignment=h.alignment),h.protection&&(_.protection=h.protection);const A=this._addStyle(_);return this.weakMap&&this.weakMap.set(h,A),A}getStyleModel(h){const w=this.model.styles[h];if(!w)return null;let _=this.index.model[h];if(_)return _;if(_=this.index.model[h]={},w.numFmtId){const N=this.index.numFmt[w.numFmtId]||i.getDefaultFmtCode(w.numFmtId);N&&(_.numFmt=N)}function A(N,L,I){if(I||I===0){const P=L[I];P&&(_[N]=P)}}return A("font",this.model.fonts,w.fontId),A("border",this.model.borders,w.borderId),A("fill",this.model.fills,w.fillId),w.alignment&&(_.alignment=w.alignment),w.protection&&(_.protection=w.protection),_}addDxfStyle(h){return h.numFmt&&(h.numFmtId=this._addNumFmtStr(h.numFmt)),this.model.dxfs.push(h),this.model.dxfs.length-1}getDxfStyle(h){return this.model.dxfs[h]}_addStyle(h){const w=this.map.style.toXml(h);let _=this.index.style[w];return _===void 0&&(_=this.index.style[w]=this.model.styles.length,this.model.styles.push(w)),_}_addNumFmtStr(h){let w=i.getDefaultFmtId(h);if(w!==void 0||(w=this.index.numFmt[h],w!==void 0))return w;w=this.index.numFmt[h]=164+this.model.numFmts.length;const _=this.map.numFmt.toXml({id:w,formatCode:h});return this.model.numFmts.push(_),w}_addFont(h){const w=this.map.font.toXml(h);let _=this.index.font[w];return _===void 0&&(_=this.index.font[w]=this.model.fonts.length,this.model.fonts.push(w)),_}_addBorder(h){const w=this.map.border.toXml(h);let _=this.index.border[w];return _===void 0&&(_=this.index.border[w]=this.model.borders.length,this.model.borders.push(w)),_}_addFill(h){const w=this.map.fill.toXml(h);let _=this.index.fill[w];return _===void 0&&(_=this.index.fill[w]=this.model.fills.length,this.model.fills.push(w)),_}}u.STYLESHEET_ATTRIBUTES={xmlns:"http://schemas.openxmlformats.org/spreadsheetml/2006/main","xmlns:mc":"http://schemas.openxmlformats.org/markup-compatibility/2006","mc:Ignorable":"x14ac x16r2","xmlns:x14ac":"http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac","xmlns:x16r2":"http://schemas.microsoft.com/office/spreadsheetml/2015/02/main"},u.STATIC_XFORMS={cellStyles:new r({tag:"cellStyles",$:{count:1},c:[{tag:"cellStyle",$:{name:"Normal",xfId:0,builtinId:0}}]}),dxfs:new r({tag:"dxfs",$:{count:0}}),tableStyles:new r({tag:"tableStyles",$:{count:0,defaultTableStyle:"TableStyleMedium2",defaultPivotStyle:"PivotStyleLight16"}}),extLst:new r({tag:"extLst",c:[{tag:"ext",$:{uri:"{EB79DEF2-80B8-43e5-95BD-54CBDDF9020C}","xmlns:x14":"http://schemas.microsoft.com/office/spreadsheetml/2009/9/main"},c:[{tag:"x14:slicerStyles",$:{defaultSlicerStyle:"SlicerStyleLight1"}}]},{tag:"ext",$:{uri:"{9260A510-F301-46a8-8635-F512D64BE5F5}","xmlns:x15":"http://schemas.microsoft.com/office/spreadsheetml/2010/11/main"},c:[{tag:"x15:timelineStyles",$:{defaultTimelineStyle:"TimeSlicerStyleLight1"}}]}]})},u.Mock=class extends u{constructor(){super(),this.model={styles:[{numFmtId:0,fontId:0,fillId:0,borderId:0,xfId:0}],numFmts:[],fonts:[{size:11,color:{theme:1},name:"Calibri",family:2,scheme:"minor"}],borders:[{}],fills:[{type:"pattern",pattern:"none"},{type:"pattern",pattern:"gray125"}]}}parseStream(d){return d.autodrain(),Promise.resolve()}addStyleModel(d,h){switch(h){case m.ValueType.Date:return this.dateStyleId;default:return 0}}get dateStyleId(){if(!this._dateStyleId){const d={numFmtId:i.getDefaultFmtId("mm-dd-yy")};this._dateStyleId=this.model.styles.length,this.model.styles.push(d)}return this._dateStyleId}getStyleModel(){return{}}},T.exports=u},{"../../../doc/enums":7,"../../../utils/xml-stream":28,"../base-xform":32,"../list-xform":71,"../static-xform":120,"./border-xform":127,"./dxf-xform":129,"./fill-xform":130,"./font-xform":131,"./numfmt-xform":132,"./style-xform":134}],136:[function(s,T,S){const m=s("../base-xform");class a extends m{constructor(r){super(),this.model=r}get tag(){return"u"}render(r,t){if((t=t||this.model)===!0)r.leafNode("u");else{const e=a.Attributes[t];e&&r.leafNode("u",e)}}parseOpen(r){r.name==="u"&&(this.model=r.attributes.val||!0)}parseText(){}parseClose(){return!1}}a.Attributes={single:{},double:{val:"double"},singleAccounting:{val:"singleAccounting"},doubleAccounting:{val:"doubleAccounting"}},T.exports=a},{"../base-xform":32}],137:[function(s,T,S){const m=s("../base-xform"),a=s("./filter-column-xform");T.exports=class extends m{constructor(){super(),this.map={filterColumn:new a}}get tag(){return"autoFilter"}prepare(o){o.columns.forEach((r,t)=>{this.map.filterColumn.prepare(r,{index:t})})}render(o,r){return o.openNode(this.tag,{ref:r.autoFilterRef}),r.columns.forEach(t=>{this.map.filterColumn.render(o,t)}),o.closeNode(),!0}parseOpen(o){if(this.parser)return this.parser.parseOpen(o),!0;switch(o.name){case this.tag:return this.model={autoFilterRef:o.attributes.ref,columns:[]},!0;default:if(this.parser=this.map[o.name],this.parser)return this.parseOpen(o),!0;throw new Error("Unexpected xml node in parseOpen: "+JSON.stringify(o))}}parseText(o){this.parser&&this.parser.parseText(o)}parseClose(o){if(this.parser)return this.parser.parseClose(o)||(this.model.columns.push(this.parser.model),this.parser=void 0),!0;switch(o){case this.tag:return!1;default:throw new Error("Unexpected xml node in parseClose: "+o)}}}},{"../base-xform":32,"./filter-column-xform":139}],138:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"customFilter"}render(a,o){a.leafNode(this.tag,{val:o.val,operator:o.operator})}parseOpen(a){return a.name===this.tag&&(this.model={val:a.attributes.val,operator:a.attributes.operator},!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],139:[function(s,T,S){const m=s("../base-xform"),a=s("../list-xform"),o=s("./custom-filter-xform"),r=s("./filter-xform");T.exports=class extends m{constructor(){super(),this.map={customFilters:new a({tag:"customFilters",count:!1,empty:!0,childXform:new o}),filters:new a({tag:"filters",count:!1,empty:!0,childXform:new r})}}get tag(){return"filterColumn"}prepare(t,e){t.colId=e.index.toString()}render(t,e){return e.customFilters?(t.openNode(this.tag,{colId:e.colId,hiddenButton:e.filterButton?"0":"1"}),this.map.customFilters.render(t,e.customFilters),t.closeNode(),!0):(t.leafNode(this.tag,{colId:e.colId,hiddenButton:e.filterButton?"0":"1"}),!0)}parseOpen(t){if(this.parser)return this.parser.parseOpen(t),!0;const{attributes:e}=t;switch(t.name){case this.tag:return this.model={filterButton:e.hiddenButton==="0"},!0;default:if(this.parser=this.map[t.name],this.parser)return this.parseOpen(t),!0;throw new Error("Unexpected xml node in parseOpen: "+JSON.stringify(t))}}parseText(){}parseClose(t){if(this.parser)return this.parser.parseClose(t)||(this.parser=void 0),!0;switch(t){case this.tag:return this.model.customFilters=this.map.customFilters.model,!1;default:return!0}}}},{"../base-xform":32,"../list-xform":71,"./custom-filter-xform":138,"./filter-xform":140}],140:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"filter"}render(a,o){a.leafNode(this.tag,{val:o.val})}parseOpen(a){return a.name===this.tag&&(this.model={val:a.attributes.val},!0)}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],141:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"tableColumn"}prepare(a,o){a.id=o.index+1}render(a,o){return a.leafNode(this.tag,{id:o.id.toString(),name:o.name,totalsRowLabel:o.totalsRowLabel,totalsRowFunction:o.totalsRowFunction,dxfId:o.dxfId}),!0}parseOpen(a){if(a.name===this.tag){const{attributes:o}=a;return this.model={name:o.name,totalsRowLabel:o.totalsRowLabel,totalsRowFunction:o.totalsRowFunction,dxfId:o.dxfId},!0}return!1}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],142:[function(s,T,S){const m=s("../base-xform");T.exports=class extends m{get tag(){return"tableStyleInfo"}render(a,o){return a.leafNode(this.tag,{name:o.theme?o.theme:void 0,showFirstColumn:o.showFirstColumn?"1":"0",showLastColumn:o.showLastColumn?"1":"0",showRowStripes:o.showRowStripes?"1":"0",showColumnStripes:o.showColumnStripes?"1":"0"}),!0}parseOpen(a){if(a.name===this.tag){const{attributes:o}=a;return this.model={theme:o.name?o.name:null,showFirstColumn:o.showFirstColumn==="1",showLastColumn:o.showLastColumn==="1",showRowStripes:o.showRowStripes==="1",showColumnStripes:o.showColumnStripes==="1"},!0}return!1}parseText(){}parseClose(){return!1}}},{"../base-xform":32}],143:[function(s,T,S){const m=s("../../../utils/xml-stream"),a=s("../base-xform"),o=s("../list-xform"),r=s("./auto-filter-xform"),t=s("./table-column-xform"),e=s("./table-style-info-xform");class l extends a{constructor(){super(),this.map={autoFilter:new r,tableColumns:new o({tag:"tableColumns",count:!0,empty:!0,childXform:new t}),tableStyleInfo:new e}}prepare(i,f){this.map.autoFilter.prepare(i),this.map.tableColumns.prepare(i.columns,f)}get tag(){return"table"}render(i,f){i.openXml(m.StdDocAttributes),i.openNode(this.tag,{...l.TABLE_ATTRIBUTES,id:f.id,name:f.name,displayName:f.displayName||f.name,ref:f.tableRef,totalsRowCount:f.totalsRow?"1":void 0,totalsRowShown:f.totalsRow?void 0:"1",headerRowCount:f.headerRow?"1":"0"}),this.map.autoFilter.render(i,f),this.map.tableColumns.render(i,f.columns),this.map.tableStyleInfo.render(i,f.style),i.closeNode()}parseOpen(i){if(this.parser)return this.parser.parseOpen(i),!0;const{name:f,attributes:c}=i;switch(f){case this.tag:this.reset(),this.model={name:c.name,displayName:c.displayName||c.name,tableRef:c.ref,totalsRow:c.totalsRowCount==="1",headerRow:c.headerRowCount==="1"};break;default:this.parser=this.map[i.name],this.parser&&this.parser.parseOpen(i)}return!0}parseText(i){this.parser&&this.parser.parseText(i)}parseClose(i){if(this.parser)return this.parser.parseClose(i)||(this.parser=void 0),!0;switch(i){case this.tag:return this.model.columns=this.map.tableColumns.model,this.map.autoFilter.model&&(this.model.autoFilterRef=this.map.autoFilter.model.autoFilterRef,this.map.autoFilter.model.columns.forEach((f,c)=>{this.model.columns[c].filterButton=f.filterButton})),this.model.style=this.map.tableStyleInfo.model,!1;default:return!0}}reconcile(i,f){i.columns.forEach(c=>{c.dxfId!==void 0&&(c.style=f.styles.getDxfStyle(c.dxfId))})}}l.TABLE_ATTRIBUTES={xmlns:"http://schemas.openxmlformats.org/spreadsheetml/2006/main","xmlns:mc":"http://schemas.openxmlformats.org/markup-compatibility/2006","mc:Ignorable":"xr xr3","xmlns:xr":"http://schemas.microsoft.com/office/spreadsheetml/2014/revision","xmlns:xr3":"http://schemas.microsoft.com/office/spreadsheetml/2016/revision3"},T.exports=l},{"../../../utils/xml-stream":28,"../base-xform":32,"../list-xform":71,"./auto-filter-xform":137,"./table-column-xform":141,"./table-style-info-xform":142}],144:[function(s,T,S){(function(m,a){(function(){const o=s("fs"),r=s("jszip"),{PassThrough:t}=s("readable-stream"),e=s("../utils/zip-stream"),l=s("../utils/stream-buf"),n=s("../utils/utils"),i=s("../utils/xml-stream"),{bufferToString:f}=s("../utils/browser-buffer-decode"),c=s("./xform/style/styles-xform"),u=s("./xform/core/core-xform"),d=s("./xform/strings/shared-strings-xform"),h=s("./xform/core/relationships-xform"),w=s("./xform/core/content-types-xform"),_=s("./xform/core/app-xform"),A=s("./xform/book/workbook-xform"),N=s("./xform/sheet/worksheet-xform"),L=s("./xform/drawing/drawing-xform"),I=s("./xform/table/table-xform"),P=s("./xform/comment/comments-xform"),B=s("./xform/comment/vml-notes-xform"),U=s("./xml/theme1");class D{constructor(M){this.workbook=M}async readFile(M,v){if(!await n.fs.exists(M))throw new Error("File not found: "+M);const p=o.createReadStream(M);try{const b=await this.read(p,v);return p.close(),b}catch(b){throw p.close(),b}}parseRels(M){return new h().parseStream(M)}parseWorkbook(M){return new A().parseStream(M)}parseSharedStrings(M){return new d().parseStream(M)}reconcile(M,v){const p=new A,b=new N(v),g=new L,y=new I;p.reconcile(M);const k={media:M.media,mediaIndex:M.mediaIndex};Object.keys(M.drawings).forEach(z=>{const $=M.drawings[z],W=M.drawingRels[z];W&&(k.rels=W.reduce((j,H)=>(j[H.Id]=H,j),{}),($.anchors||[]).forEach(j=>{const H=j.picture&&j.picture.hyperlinks;H&&k.rels[H.rId]&&(H.hyperlink=k.rels[H.rId].Target,delete H.rId)}),g.reconcile($,k))});const R={styles:M.styles};Object.values(M.tables).forEach(z=>{y.reconcile(z,R)});const O={styles:M.styles,sharedStrings:M.sharedStrings,media:M.media,mediaIndex:M.mediaIndex,date1904:M.properties&&M.properties.date1904,drawings:M.drawings,comments:M.comments,tables:M.tables,vmlDrawings:M.vmlDrawings};M.worksheets.forEach(z=>{z.relationships=M.worksheetRels[z.sheetNo],b.reconcile(z,O)}),delete M.worksheetHash,delete M.worksheetRels,delete M.globalRels,delete M.sharedStrings,delete M.workbookRels,delete M.sheetDefs,delete M.styles,delete M.mediaIndex,delete M.drawings,delete M.drawingRels,delete M.vmlDrawings}async _processWorksheetEntry(M,v,p,b,g){const y=new N(b),k=await y.parseStream(M);k.sheetNo=p,v.worksheetHash[g]=k,v.worksheets.push(k)}async _processCommentEntry(M,v,p){const b=new P,g=await b.parseStream(M);v.comments[`../${p}.xml`]=g}async _processTableEntry(M,v,p){const b=new I,g=await b.parseStream(M);v.tables[`../tables/${p}.xml`]=g}async _processWorksheetRelsEntry(M,v,p){const b=new h,g=await b.parseStream(M);v.worksheetRels[p]=g}async _processMediaEntry(M,v,p){const b=p.lastIndexOf(".");if(b>=1){const g=p.substr(b+1),y=p.substr(0,b);await new Promise((k,R)=>{const O=new l;O.on("finish",()=>{v.mediaIndex[p]=v.media.length,v.mediaIndex[y]=v.media.length;const z={type:"image",name:y,extension:g,buffer:O.toBuffer()};v.media.push(z),k()}),M.on("error",z=>{R(z)}),M.pipe(O)})}}async _processDrawingEntry(M,v,p){const b=new L,g=await b.parseStream(M);v.drawings[p]=g}async _processDrawingRelsEntry(M,v,p){const b=new h,g=await b.parseStream(M);v.drawingRels[p]=g}async _processVmlDrawingEntry(M,v,p){const b=new B,g=await b.parseStream(M);v.vmlDrawings[`../drawings/${p}.vml`]=g}async _processThemeEntry(M,v,p){await new Promise((b,g)=>{const y=new l;M.on("error",g),y.on("error",g),y.on("finish",()=>{v.themes[p]=y.read().toString(),b()}),M.pipe(y)})}createInputStream(){throw new Error("`XLSX#createInputStream` is deprecated. You should use `XLSX#read` instead. This method will be removed in version 5.0. Please follow upgrade instruction: https://github.com/exceljs/exceljs/blob/master/UPGRADE-4.0.md")}async read(M,v){!M[Symbol.asyncIterator]&&M.pipe&&(M=M.pipe(new t));const p=[];for await(const b of M)p.push(b);return this.load(a.concat(p),v)}async load(M,v){let p;p=v&&v.base64?a.from(M.toString(),"base64"):M;const b={worksheets:[],worksheetHash:{},worksheetRels:[],themes:{},media:[],mediaIndex:{},drawings:{},drawingRels:{},comments:{},tables:{},vmlDrawings:{}},g=await r.loadAsync(p);for(const y of Object.values(g.files))if(!y.dir){let k,R=y.name;if(R[0]==="/"&&(R=R.substr(1)),R.match(/xl\/media\//)||R.match(/xl\/theme\/([a-zA-Z0-9]+)[.]xml/))k=new t,k.write(await y.async("nodebuffer"));else{let O;k=new t({writableObjectMode:!0,readableObjectMode:!0}),O=m.browser?f(await y.async("nodebuffer")):await y.async("string");const z=16384;for(let $=0;$<O.length;$+=z)k.write(O.substring($,$+z))}switch(k.end(),R){case"_rels/.rels":b.globalRels=await this.parseRels(k);break;case"xl/workbook.xml":{const O=await this.parseWorkbook(k);b.sheets=O.sheets,b.definedNames=O.definedNames,b.views=O.views,b.properties=O.properties,b.calcProperties=O.calcProperties;break}case"xl/_rels/workbook.xml.rels":b.workbookRels=await this.parseRels(k);break;case"xl/sharedStrings.xml":b.sharedStrings=new d,await b.sharedStrings.parseStream(k);break;case"xl/styles.xml":b.styles=new c,await b.styles.parseStream(k);break;case"docProps/app.xml":{const O=new _,z=await O.parseStream(k);b.company=z.company,b.manager=z.manager;break}case"docProps/core.xml":{const O=new u,z=await O.parseStream(k);Object.assign(b,z);break}default:{let O=R.match(/xl\/worksheets\/sheet(\d+)[.]xml/);if(O){await this._processWorksheetEntry(k,b,O[1],v,R);break}if(O=R.match(/xl\/worksheets\/_rels\/sheet(\d+)[.]xml.rels/),O){await this._processWorksheetRelsEntry(k,b,O[1]);break}if(O=R.match(/xl\/theme\/([a-zA-Z0-9]+)[.]xml/),O){await this._processThemeEntry(k,b,O[1]);break}if(O=R.match(/xl\/media\/([a-zA-Z0-9]+[.][a-zA-Z0-9]{3,4})$/),O){await this._processMediaEntry(k,b,O[1]);break}if(O=R.match(/xl\/drawings\/([a-zA-Z0-9]+)[.]xml/),O){await this._processDrawingEntry(k,b,O[1]);break}if(O=R.match(/xl\/(comments\d+)[.]xml/),O){await this._processCommentEntry(k,b,O[1]);break}if(O=R.match(/xl\/tables\/(table\d+)[.]xml/),O){await this._processTableEntry(k,b,O[1]);break}if(O=R.match(/xl\/drawings\/_rels\/([a-zA-Z0-9]+)[.]xml[.]rels/),O){await this._processDrawingRelsEntry(k,b,O[1]);break}if(O=R.match(/xl\/drawings\/(vmlDrawing\d+)[.]vml/),O){await this._processVmlDrawingEntry(k,b,O[1]);break}}}}return this.reconcile(b,v),this.workbook.model=b,this.workbook}async addMedia(M,v){await Promise.all(v.media.map(async p=>{if(p.type==="image"){const b=`xl/media/${p.name}.${p.extension}`;if(p.filename){const g=await function(y,k){return new Promise((R,O)=>{o.readFile(y,k,(z,$)=>{z?O(z):R($)})})}(p.filename);return M.append(g,{name:b})}if(p.buffer)return M.append(p.buffer,{name:b});if(p.base64){const g=p.base64,y=g.substring(g.indexOf(",")+1);return M.append(y,{name:b,base64:!0})}}throw new Error("Unsupported media")}))}addDrawings(M,v){const p=new L,b=new h;v.worksheets.forEach(g=>{const{drawing:y}=g;if(y){p.prepare(y,{});let k=p.toXml(y);M.append(k,{name:`xl/drawings/${y.name}.xml`}),k=b.toXml(y.rels),M.append(k,{name:`xl/drawings/_rels/${y.name}.xml.rels`})}})}addTables(M,v){const p=new I;v.worksheets.forEach(b=>{const{tables:g}=b;g.forEach(y=>{p.prepare(y,{});const k=p.toXml(y);M.append(k,{name:"xl/tables/"+y.target})})})}async addContentTypes(M,v){const p=new w().toXml(v);M.append(p,{name:"[Content_Types].xml"})}async addApp(M,v){const p=new _().toXml(v);M.append(p,{name:"docProps/app.xml"})}async addCore(M,v){const p=new u;M.append(p.toXml(v),{name:"docProps/core.xml"})}async addThemes(M,v){const p=v.themes||{theme1:U};Object.keys(p).forEach(b=>{const g=p[b],y=`xl/theme/${b}.xml`;M.append(g,{name:y})})}async addOfficeRels(M){const v=new h().toXml([{Id:"rId1",Type:D.RelType.OfficeDocument,Target:"xl/workbook.xml"},{Id:"rId2",Type:D.RelType.CoreProperties,Target:"docProps/core.xml"},{Id:"rId3",Type:D.RelType.ExtenderProperties,Target:"docProps/app.xml"}]);M.append(v,{name:"_rels/.rels"})}async addWorkbookRels(M,v){let p=1;const b=[{Id:"rId"+p++,Type:D.RelType.Styles,Target:"styles.xml"},{Id:"rId"+p++,Type:D.RelType.Theme,Target:"theme/theme1.xml"}];v.sharedStrings.count&&b.push({Id:"rId"+p++,Type:D.RelType.SharedStrings,Target:"sharedStrings.xml"}),v.worksheets.forEach(y=>{y.rId="rId"+p++,b.push({Id:y.rId,Type:D.RelType.Worksheet,Target:`worksheets/sheet${y.id}.xml`})});const g=new h().toXml(b);M.append(g,{name:"xl/_rels/workbook.xml.rels"})}async addSharedStrings(M,v){v.sharedStrings&&v.sharedStrings.count&&M.append(v.sharedStrings.xml,{name:"xl/sharedStrings.xml"})}async addStyles(M,v){const{xml:p}=v.styles;p&&M.append(p,{name:"xl/styles.xml"})}async addWorkbook(M,v){const p=new A;M.append(p.toXml(v),{name:"xl/workbook.xml"})}async addWorksheets(M,v){const p=new N,b=new h,g=new P,y=new B;v.worksheets.forEach(k=>{let R=new i;p.render(R,k),M.append(R.xml,{name:`xl/worksheets/sheet${k.id}.xml`}),k.rels&&k.rels.length&&(R=new i,b.render(R,k.rels),M.append(R.xml,{name:`xl/worksheets/_rels/sheet${k.id}.xml.rels`})),k.comments.length>0&&(R=new i,g.render(R,k),M.append(R.xml,{name:`xl/comments${k.id}.xml`}),R=new i,y.render(R,k),M.append(R.xml,{name:`xl/drawings/vmlDrawing${k.id}.vml`}))})}_finalize(M){return new Promise((v,p)=>{M.on("finish",()=>{v(this)}),M.on("error",p),M.finalize()})}prepareModel(M,v){M.creator=M.creator||"ExcelJS",M.lastModifiedBy=M.lastModifiedBy||"ExcelJS",M.created=M.created||new Date,M.modified=M.modified||new Date,M.useSharedStrings=v.useSharedStrings===void 0||v.useSharedStrings,M.useStyles=v.useStyles===void 0||v.useStyles,M.sharedStrings=new d,M.styles=M.useStyles?new c(!0):new c.Mock;const p=new A,b=new N;p.prepare(M);const g={sharedStrings:M.sharedStrings,styles:M.styles,date1904:M.properties.date1904,drawingsCount:0,media:M.media};g.drawings=M.drawings=[],g.commentRefs=M.commentRefs=[];let y=0;M.tables=[],M.worksheets.forEach(k=>{k.tables.forEach(R=>{y++,R.target=`table${y}.xml`,R.id=y,M.tables.push(R)}),b.prepare(k,g)})}async write(M,v){v=v||{};const{model:p}=this.workbook,b=new e.ZipWriter(v.zip);return b.pipe(M),this.prepareModel(p,v),await this.addContentTypes(b,p),await this.addOfficeRels(b,p),await this.addWorkbookRels(b,p),await this.addWorksheets(b,p),await this.addSharedStrings(b,p),await this.addDrawings(b,p),await this.addTables(b,p),await Promise.all([this.addThemes(b,p),this.addStyles(b,p)]),await this.addMedia(b,p),await Promise.all([this.addApp(b,p),this.addCore(b,p)]),await this.addWorkbook(b,p),this._finalize(b)}writeFile(M,v){const p=o.createWriteStream(M);return new Promise((b,g)=>{p.on("finish",()=>{b()}),p.on("error",y=>{g(y)}),this.write(p,v).then(()=>{p.end()}).catch(y=>{g(y)})})}async writeBuffer(M){const v=new l;return await this.write(v,M),v.read()}}D.RelType=s("./rel-type"),T.exports=D}).call(this)}).call(this,s("_process"),s("buffer").Buffer)},{"../utils/browser-buffer-decode":16,"../utils/stream-buf":24,"../utils/utils":27,"../utils/xml-stream":28,"../utils/zip-stream":29,"./rel-type":31,"./xform/book/workbook-xform":38,"./xform/comment/comments-xform":40,"./xform/comment/vml-notes-xform":45,"./xform/core/app-xform":51,"./xform/core/content-types-xform":52,"./xform/core/core-xform":53,"./xform/core/relationships-xform":55,"./xform/drawing/drawing-xform":62,"./xform/sheet/worksheet-xform":115,"./xform/strings/shared-strings-xform":124,"./xform/style/styles-xform":135,"./xform/table/table-xform":143,"./xml/theme1":145,_process:467,buffer:220,fs:216,jszip:441,"readable-stream":491}],145:[function(s,T,S){T.exports=`<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<a:theme xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" name="Office Theme"> <a:themeElements> <a:clrScheme name="Office"> <a:dk1> <a:sysClr val="windowText" lastClr="000000"/> </a:dk1> <a:lt1> <a:sysClr val="window" lastClr="FFFFFF"/> </a:lt1> <a:dk2> <a:srgbClr val="1F497D"/> </a:dk2> <a:lt2> <a:srgbClr val="EEECE1"/> </a:lt2> <a:accent1> <a:srgbClr val="4F81BD"/> </a:accent1> <a:accent2> <a:srgbClr val="C0504D"/> </a:accent2> <a:accent3> <a:srgbClr val="9BBB59"/> </a:accent3> <a:accent4> <a:srgbClr val="8064A2"/> </a:accent4> <a:accent5> <a:srgbClr val="4BACC6"/> </a:accent5> <a:accent6> <a:srgbClr val="F79646"/> </a:accent6> <a:hlink> <a:srgbClr val="0000FF"/> </a:hlink> <a:folHlink> <a:srgbClr val="800080"/> </a:folHlink> </a:clrScheme> <a:fontScheme name="Office"> <a:majorFont> <a:latin typeface="Cambria"/> <a:ea typeface=""/> <a:cs typeface=""/> <a:font script="Jpan" typeface="ＭＳ Ｐゴシック"/> <a:font script="Hang" typeface="맑은 고딕"/> <a:font script="Hans" typeface="宋体"/> <a:font script="Hant" typeface="新細明體"/> <a:font script="Arab" typeface="Times New Roman"/> <a:font script="Hebr" typeface="Times New Roman"/> <a:font script="Thai" typeface="Tahoma"/> <a:font script="Ethi" typeface="Nyala"/> <a:font script="Beng" typeface="Vrinda"/> <a:font script="Gujr" typeface="Shruti"/> <a:font script="Khmr" typeface="MoolBoran"/> <a:font script="Knda" typeface="Tunga"/> <a:font script="Guru" typeface="Raavi"/> <a:font script="Cans" typeface="Euphemia"/> <a:font script="Cher" typeface="Plantagenet Cherokee"/> <a:font script="Yiii" typeface="Microsoft Yi Baiti"/> <a:font script="Tibt" typeface="Microsoft Himalaya"/> <a:font script="Thaa" typeface="MV Boli"/> <a:font script="Deva" typeface="Mangal"/> <a:font script="Telu" typeface="Gautami"/> <a:font script="Taml" typeface="Latha"/> <a:font script="Syrc" typeface="Estrangelo Edessa"/> <a:font script="Orya" typeface="Kalinga"/> <a:font script="Mlym" typeface="Kartika"/> <a:font script="Laoo" typeface="DokChampa"/> <a:font script="Sinh" typeface="Iskoola Pota"/> <a:font script="Mong" typeface="Mongolian Baiti"/> <a:font script="Viet" typeface="Times New Roman"/> <a:font script="Uigh" typeface="Microsoft Uighur"/> <a:font script="Geor" typeface="Sylfaen"/> </a:majorFont> <a:minorFont> <a:latin typeface="Calibri"/> <a:ea typeface=""/> <a:cs typeface=""/> <a:font script="Jpan" typeface="ＭＳ Ｐゴシック"/> <a:font script="Hang" typeface="맑은 고딕"/> <a:font script="Hans" typeface="宋体"/> <a:font script="Hant" typeface="新細明體"/> <a:font script="Arab" typeface="Arial"/> <a:font script="Hebr" typeface="Arial"/> <a:font script="Thai" typeface="Tahoma"/> <a:font script="Ethi" typeface="Nyala"/> <a:font script="Beng" typeface="Vrinda"/> <a:font script="Gujr" typeface="Shruti"/> <a:font script="Khmr" typeface="DaunPenh"/> <a:font script="Knda" typeface="Tunga"/> <a:font script="Guru" typeface="Raavi"/> <a:font script="Cans" typeface="Euphemia"/> <a:font script="Cher" typeface="Plantagenet Cherokee"/> <a:font script="Yiii" typeface="Microsoft Yi Baiti"/> <a:font script="Tibt" typeface="Microsoft Himalaya"/> <a:font script="Thaa" typeface="MV Boli"/> <a:font script="Deva" typeface="Mangal"/> <a:font script="Telu" typeface="Gautami"/> <a:font script="Taml" typeface="Latha"/> <a:font script="Syrc" typeface="Estrangelo Edessa"/> <a:font script="Orya" typeface="Kalinga"/> <a:font script="Mlym" typeface="Kartika"/> <a:font script="Laoo" typeface="DokChampa"/> <a:font script="Sinh" typeface="Iskoola Pota"/> <a:font script="Mong" typeface="Mongolian Baiti"/> <a:font script="Viet" typeface="Arial"/> <a:font script="Uigh" typeface="Microsoft Uighur"/> <a:font script="Geor" typeface="Sylfaen"/> </a:minorFont> </a:fontScheme> <a:fmtScheme name="Office"> <a:fillStyleLst> <a:solidFill> <a:schemeClr val="phClr"/> </a:solidFill> <a:gradFill rotWithShape="1"> <a:gsLst> <a:gs pos="0"> <a:schemeClr val="phClr"> <a:tint val="50000"/> <a:satMod val="300000"/> </a:schemeClr> </a:gs> <a:gs pos="35000"> <a:schemeClr val="phClr"> <a:tint val="37000"/> <a:satMod val="300000"/> </a:schemeClr> </a:gs> <a:gs pos="100000"> <a:schemeClr val="phClr"> <a:tint val="15000"/> <a:satMod val="350000"/> </a:schemeClr> </a:gs> </a:gsLst> <a:lin ang="16200000" scaled="1"/> </a:gradFill> <a:gradFill rotWithShape="1"> <a:gsLst> <a:gs pos="0"> <a:schemeClr val="phClr"> <a:tint val="100000"/> <a:shade val="100000"/> <a:satMod val="130000"/> </a:schemeClr> </a:gs> <a:gs pos="100000"> <a:schemeClr val="phClr"> <a:tint val="50000"/> <a:shade val="100000"/> <a:satMod val="350000"/> </a:schemeClr> </a:gs> </a:gsLst> <a:lin ang="16200000" scaled="0"/> </a:gradFill> </a:fillStyleLst> <a:lnStyleLst> <a:ln w="9525" cap="flat" cmpd="sng" algn="ctr"> <a:solidFill> <a:schemeClr val="phClr"> <a:shade val="95000"/> <a:satMod val="105000"/> </a:schemeClr> </a:solidFill> <a:prstDash val="solid"/> </a:ln> <a:ln w="25400" cap="flat" cmpd="sng" algn="ctr"> <a:solidFill> <a:schemeClr val="phClr"/> </a:solidFill> <a:prstDash val="solid"/> </a:ln> <a:ln w="38100" cap="flat" cmpd="sng" algn="ctr"> <a:solidFill> <a:schemeClr val="phClr"/> </a:solidFill> <a:prstDash val="solid"/> </a:ln> </a:lnStyleLst> <a:effectStyleLst> <a:effectStyle> <a:effectLst> <a:outerShdw blurRad="40000" dist="20000" dir="5400000" rotWithShape="0"> <a:srgbClr val="000000"> <a:alpha val="38000"/> </a:srgbClr> </a:outerShdw> </a:effectLst> </a:effectStyle> <a:effectStyle> <a:effectLst> <a:outerShdw blurRad="40000" dist="23000" dir="5400000" rotWithShape="0"> <a:srgbClr val="000000"> <a:alpha val="35000"/> </a:srgbClr> </a:outerShdw> </a:effectLst> </a:effectStyle> <a:effectStyle> <a:effectLst> <a:outerShdw blurRad="40000" dist="23000" dir="5400000" rotWithShape="0"> <a:srgbClr val="000000"> <a:alpha val="35000"/> </a:srgbClr> </a:outerShdw> </a:effectLst> <a:scene3d> <a:camera prst="orthographicFront"> <a:rot lat="0" lon="0" rev="0"/> </a:camera> <a:lightRig rig="threePt" dir="t"> <a:rot lat="0" lon="0" rev="1200000"/> </a:lightRig> </a:scene3d> <a:sp3d> <a:bevelT w="63500" h="25400"/> </a:sp3d> </a:effectStyle> </a:effectStyleLst> <a:bgFillStyleLst> <a:solidFill> <a:schemeClr val="phClr"/> </a:solidFill> <a:gradFill rotWithShape="1"> <a:gsLst> <a:gs pos="0"> <a:schemeClr val="phClr"> <a:tint val="40000"/> <a:satMod val="350000"/> </a:schemeClr> </a:gs> <a:gs pos="40000"> <a:schemeClr val="phClr"> <a:tint val="45000"/> <a:shade val="99000"/> <a:satMod val="350000"/> </a:schemeClr> </a:gs> <a:gs pos="100000"> <a:schemeClr val="phClr"> <a:shade val="20000"/> <a:satMod val="255000"/> </a:schemeClr> </a:gs> </a:gsLst> <a:path path="circle"> <a:fillToRect l="50000" t="-80000" r="50000" b="180000"/> </a:path> </a:gradFill> <a:gradFill rotWithShape="1"> <a:gsLst> <a:gs pos="0"> <a:schemeClr val="phClr"> <a:tint val="80000"/> <a:satMod val="300000"/> </a:schemeClr> </a:gs> <a:gs pos="100000"> <a:schemeClr val="phClr"> <a:shade val="30000"/> <a:satMod val="200000"/> </a:schemeClr> </a:gs> </a:gsLst> <a:path path="circle"> <a:fillToRect l="50000" t="50000" r="50000" b="50000"/> </a:path> </a:gradFill> </a:bgFillStyleLst> </a:fmtScheme> </a:themeElements> <a:objectDefaults> <a:spDef> <a:spPr/> <a:bodyPr/> <a:lstStyle/> <a:style> <a:lnRef idx="1"> <a:schemeClr val="accent1"/> </a:lnRef> <a:fillRef idx="3"> <a:schemeClr val="accent1"/> </a:fillRef> <a:effectRef idx="2"> <a:schemeClr val="accent1"/> </a:effectRef> <a:fontRef idx="minor"> <a:schemeClr val="lt1"/> </a:fontRef> </a:style> </a:spDef> <a:lnDef> <a:spPr/> <a:bodyPr/> <a:lstStyle/> <a:style> <a:lnRef idx="2"> <a:schemeClr val="accent1"/> </a:lnRef> <a:fillRef idx="0"> <a:schemeClr val="accent1"/> </a:fillRef> <a:effectRef idx="1"> <a:schemeClr val="accent1"/> </a:effectRef> <a:fontRef idx="minor"> <a:schemeClr val="tx1"/> </a:fontRef> </a:style> </a:lnDef> </a:objectDefaults> <a:extraClrSchemeLst/> </a:theme>`},{}],146:[function(s,T,S){(function(m){(function(){Object.defineProperty(S,"__esModule",{value:!0}),S.CsvFormatterStream=void 0;const a=s("stream"),o=s("./formatter");class r extends a.Transform{constructor(e){super({writableObjectMode:e.objectMode}),this.hasWrittenBOM=!1,this.formatterOptions=e,this.rowFormatter=new o.RowFormatter(e),this.hasWrittenBOM=!e.writeBOM}transform(e){return this.rowFormatter.rowTransform=e,this}_transform(e,l,n){let i=!1;try{this.hasWrittenBOM||(this.push(this.formatterOptions.BOM),this.hasWrittenBOM=!0),this.rowFormatter.format(e,(f,c)=>f?(i=!0,n(f)):(c&&c.forEach(u=>{this.push(m.from(u,"utf8"))}),i=!0,n()))}catch(f){if(i)throw f;n(f)}}_flush(e){this.rowFormatter.finish((l,n)=>l?e(l):(n&&n.forEach(i=>{this.push(m.from(i,"utf8"))}),e()))}}S.CsvFormatterStream=r}).call(this)}).call(this,s("buffer").Buffer)},{"./formatter":150,buffer:220,stream:505}],147:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.FormatterOptions=void 0,S.FormatterOptions=class{constructor(){let m=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};var a;this.objectMode=!0,this.delimiter=",",this.rowDelimiter=`
`,this.quote='"',this.escape=this.quote,this.quoteColumns=!1,this.quoteHeaders=this.quoteColumns,this.headers=null,this.includeEndRowDelimiter=!1,this.writeBOM=!1,this.BOM="\uFEFF",this.alwaysWriteHeaders=!1,Object.assign(this,m||{}),m?.quoteHeaders===void 0&&(this.quoteHeaders=this.quoteColumns),m?.quote===!0?this.quote='"':m?.quote===!1&&(this.quote=""),typeof m?.escape!="string"&&(this.escape=this.quote),this.shouldWriteHeaders=!!this.headers&&((a=m.writeHeaders)===null||a===void 0||a),this.headers=Array.isArray(this.headers)?this.headers:null,this.escapedQuote=`${this.escape}${this.quote}`}}},{}],148:[function(s,T,S){var m=function(t){return t&&t.__esModule?t:{default:t}};Object.defineProperty(S,"__esModule",{value:!0}),S.FieldFormatter=void 0;const a=m(s("lodash.isboolean")),o=m(s("lodash.isnil")),r=m(s("lodash.escaperegexp"));S.FieldFormatter=class{constructor(t){this._headers=null,this.formatterOptions=t,t.headers!==null&&(this.headers=t.headers),this.REPLACE_REGEXP=new RegExp(t.quote,"g");const e=`[${t.delimiter}${r.default(t.rowDelimiter)}|\r|
]`;this.ESCAPE_REGEXP=new RegExp(e)}set headers(t){this._headers=t}shouldQuote(t,e){const l=e?this.formatterOptions.quoteHeaders:this.formatterOptions.quoteColumns;return a.default(l)?l:Array.isArray(l)?l[t]:this._headers!==null&&l[this._headers[t]]}format(t,e,l){const n=(""+(o.default(t)?"":t)).replace(/\0/g,""),{formatterOptions:i}=this;return i.quote!==""&&n.indexOf(i.quote)!==-1?this.quoteField(n.replace(this.REPLACE_REGEXP,i.escapedQuote)):n.search(this.ESCAPE_REGEXP)!==-1||this.shouldQuote(e,l)?this.quoteField(n):n}quoteField(t){const{quote:e}=this.formatterOptions;return`${e}${t}${e}`}}},{"lodash.escaperegexp":442,"lodash.isboolean":444,"lodash.isnil":447}],149:[function(s,T,S){var m=function(l){return l&&l.__esModule?l:{default:l}};Object.defineProperty(S,"__esModule",{value:!0}),S.RowFormatter=void 0;const a=m(s("lodash.isfunction")),o=m(s("lodash.isequal")),r=s("./FieldFormatter"),t=s("../types");class e{constructor(n){this.rowCount=0,this.formatterOptions=n,this.fieldFormatter=new r.FieldFormatter(n),this.headers=n.headers,this.shouldWriteHeaders=n.shouldWriteHeaders,this.hasWrittenHeaders=!1,this.headers!==null&&(this.fieldFormatter.headers=this.headers),n.transform&&(this.rowTransform=n.transform)}static isRowHashArray(n){return!!Array.isArray(n)&&Array.isArray(n[0])&&n[0].length===2}static isRowArray(n){return Array.isArray(n)&&!this.isRowHashArray(n)}static gatherHeaders(n){return e.isRowHashArray(n)?n.map(i=>i[0]):Array.isArray(n)?n:Object.keys(n)}static createTransform(n){return t.isSyncTransform(n)?(i,f)=>{let c=null;try{c=n(i)}catch(u){return f(u)}return f(null,c)}:(i,f)=>{n(i,f)}}set rowTransform(n){if(!a.default(n))throw new TypeError("The transform should be a function");this._rowTransform=e.createTransform(n)}format(n,i){this.callTransformer(n,(f,c)=>{if(f)return i(f);if(!n)return i(null);const u=[];if(c){const{shouldFormatColumns:d,headers:h}=this.checkHeaders(c);if(this.shouldWriteHeaders&&h&&!this.hasWrittenHeaders&&(u.push(this.formatColumns(h,!0)),this.hasWrittenHeaders=!0),d){const w=this.gatherColumns(c);u.push(this.formatColumns(w,!1))}}return i(null,u)})}finish(n){const i=[];if(this.formatterOptions.alwaysWriteHeaders&&this.rowCount===0){if(!this.headers)return n(new Error("`alwaysWriteHeaders` option is set to true but `headers` option not provided."));i.push(this.formatColumns(this.headers,!0))}return this.formatterOptions.includeEndRowDelimiter&&i.push(this.formatterOptions.rowDelimiter),n(null,i)}checkHeaders(n){if(this.headers)return{shouldFormatColumns:!0,headers:this.headers};const i=e.gatherHeaders(n);return this.headers=i,this.fieldFormatter.headers=i,this.shouldWriteHeaders?{shouldFormatColumns:!o.default(i,n),headers:i}:{shouldFormatColumns:!0,headers:null}}gatherColumns(n){if(this.headers===null)throw new Error("Headers is currently null");return Array.isArray(n)?e.isRowHashArray(n)?this.headers.map((i,f)=>{const c=n[f];return c?c[1]:""}):e.isRowArray(n)&&!this.shouldWriteHeaders?n:this.headers.map((i,f)=>n[f]):this.headers.map(i=>n[i])}callTransformer(n,i){return this._rowTransform?this._rowTransform(n,i):i(null,n)}formatColumns(n,i){const f=n.map((u,d)=>this.fieldFormatter.format(u,d,i)).join(this.formatterOptions.delimiter),{rowCount:c}=this;return this.rowCount+=1,c?[this.formatterOptions.rowDelimiter,f].join(""):f}}S.RowFormatter=e},{"../types":152,"./FieldFormatter":148,"lodash.isequal":445,"lodash.isfunction":446}],150:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.FieldFormatter=S.RowFormatter=void 0;var m=s("./RowFormatter");Object.defineProperty(S,"RowFormatter",{enumerable:!0,get:function(){return m.RowFormatter}});var a=s("./FieldFormatter");Object.defineProperty(S,"FieldFormatter",{enumerable:!0,get:function(){return a.FieldFormatter}})},{"./FieldFormatter":148,"./RowFormatter":149}],151:[function(s,T,S){(function(m){(function(){var a=Object.create?function(d,h,w,_){_===void 0&&(_=w),Object.defineProperty(d,_,{enumerable:!0,get:function(){return h[w]}})}:function(d,h,w,_){_===void 0&&(_=w),d[_]=h[w]},o=Object.create?function(d,h){Object.defineProperty(d,"default",{enumerable:!0,value:h})}:function(d,h){d.default=h},r=function(d){if(d&&d.__esModule)return d;var h={};if(d!=null)for(var w in d)w!=="default"&&Object.prototype.hasOwnProperty.call(d,w)&&a(h,d,w);return o(h,d),h},t=function(d,h){for(var w in d)w==="default"||Object.prototype.hasOwnProperty.call(h,w)||a(h,d,w)};Object.defineProperty(S,"__esModule",{value:!0}),S.writeToPath=S.writeToString=S.writeToBuffer=S.writeToStream=S.write=S.format=S.FormatterOptions=S.CsvFormatterStream=void 0;const e=s("util"),l=s("stream"),n=r(s("fs")),i=s("./FormatterOptions"),f=s("./CsvFormatterStream");t(s("./types"),S);var c=s("./CsvFormatterStream");Object.defineProperty(S,"CsvFormatterStream",{enumerable:!0,get:function(){return c.CsvFormatterStream}});var u=s("./FormatterOptions");Object.defineProperty(S,"FormatterOptions",{enumerable:!0,get:function(){return u.FormatterOptions}}),S.format=d=>new f.CsvFormatterStream(new i.FormatterOptions(d)),S.write=(d,h)=>{const w=S.format(h),_=e.promisify((A,N)=>{w.write(A,void 0,N)});return d.reduce((A,N)=>A.then(()=>_(N)),Promise.resolve()).then(()=>w.end()).catch(A=>{w.emit("error",A)}),w},S.writeToStream=(d,h,w)=>S.write(h,w).pipe(d),S.writeToBuffer=function(d){let h=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};const w=[],_=new l.Writable({write(A,N,L){w.push(A),L()}});return new Promise((A,N)=>{_.on("error",N).on("finish",()=>A(m.concat(w))),S.write(d,h).pipe(_)})},S.writeToString=(d,h)=>S.writeToBuffer(d,h).then(w=>w.toString()),S.writeToPath=(d,h,w)=>{const _=n.createWriteStream(d,{encoding:"utf8"});return S.write(h,w).pipe(_)}}).call(this)}).call(this,s("buffer").Buffer)},{"./CsvFormatterStream":146,"./FormatterOptions":147,"./types":152,buffer:220,fs:216,stream:505,util:527}],152:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.isSyncTransform=void 0,S.isSyncTransform=m=>m.length===1},{}],153:[function(s,T,S){(function(m){(function(){Object.defineProperty(S,"__esModule",{value:!0}),S.CsvParserStream=void 0;const a=s("string_decoder"),o=s("stream"),r=s("./transforms"),t=s("./parser");class e extends o.Transform{constructor(n){super({objectMode:n.objectMode}),this.lines="",this.rowCount=0,this.parsedRowCount=0,this.parsedLineCount=0,this.endEmitted=!1,this.headersEmitted=!1,this.parserOptions=n,this.parser=new t.Parser(n),this.headerTransformer=new r.HeaderTransformer(n),this.decoder=new a.StringDecoder(n.encoding),this.rowTransformerValidator=new r.RowTransformerValidator}get hasHitRowLimit(){return this.parserOptions.limitRows&&this.rowCount>=this.parserOptions.maxRows}get shouldEmitRows(){return this.parsedRowCount>this.parserOptions.skipRows}get shouldSkipLine(){return this.parsedLineCount<=this.parserOptions.skipLines}transform(n){return this.rowTransformerValidator.rowTransform=n,this}validate(n){return this.rowTransformerValidator.rowValidator=n,this}emit(n){if(n==="end")return this.endEmitted||(this.endEmitted=!0,super.emit("end",this.rowCount)),!1;for(var i=arguments.length,f=new Array(i>1?i-1:0),c=1;c<i;c++)f[c-1]=arguments[c];return super.emit(n,...f)}_transform(n,i,f){if(this.hasHitRowLimit)return f();const c=e.wrapDoneCallback(f);try{const{lines:u}=this,d=u+this.decoder.write(n),h=this.parse(d,!0);return this.processRows(h,c)}catch(u){return c(u)}}_flush(n){const i=e.wrapDoneCallback(n);if(this.hasHitRowLimit)return i();try{const f=this.lines+this.decoder.end(),c=this.parse(f,!1);return this.processRows(c,i)}catch(f){return i(f)}}parse(n,i){if(!n)return[];const{line:f,rows:c}=this.parser.parse(n,i);return this.lines=f,c}processRows(n,i){const f=n.length,c=u=>{const d=_=>_?i(_):u%100!=0?c(u+1):void m(()=>c(u+1));if(this.checkAndEmitHeaders(),u>=f||this.hasHitRowLimit)return i();if(this.parsedLineCount+=1,this.shouldSkipLine)return d();const h=n[u];this.rowCount+=1,this.parsedRowCount+=1;const w=this.rowCount;return this.transformRow(h,(_,A)=>{if(_)return this.rowCount-=1,d(_);if(!A)return d(new Error("expected transform result"));if(A.isValid){if(A.row)return this.pushRow(A.row,d)}else this.emit("data-invalid",A.row,w,A.reason);return d()})};c(0)}transformRow(n,i){try{this.headerTransformer.transform(n,(f,c)=>f?i(f):c?c.isValid?c.row?this.shouldEmitRows?this.rowTransformerValidator.transformAndValidate(c.row,i):this.skipRow(i):(this.rowCount-=1,this.parsedRowCount-=1,i(null,{row:null,isValid:!0})):this.shouldEmitRows?i(null,{isValid:!1,row:n}):this.skipRow(i):i(new Error("Expected result from header transform")))}catch(f){i(f)}}checkAndEmitHeaders(){!this.headersEmitted&&this.headerTransformer.headers&&(this.headersEmitted=!0,this.emit("headers",this.headerTransformer.headers))}skipRow(n){return this.rowCount-=1,n(null,{row:null,isValid:!0})}pushRow(n,i){try{this.parserOptions.objectMode?this.push(n):this.push(JSON.stringify(n)),i()}catch(f){i(f)}}static wrapDoneCallback(n){let i=!1;return function(f){if(f){if(i)throw f;return i=!0,void n(f)}for(var c=arguments.length,u=new Array(c>1?c-1:0),d=1;d<c;d++)u[d-1]=arguments[d];n(...u)}}}S.CsvParserStream=e}).call(this)}).call(this,s("timers").setImmediate)},{"./parser":165,"./transforms":168,stream:505,string_decoder:218,timers:523}],154:[function(s,T,S){var m=function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(S,"__esModule",{value:!0}),S.ParserOptions=void 0;const a=m(s("lodash.escaperegexp")),o=m(s("lodash.isnil"));S.ParserOptions=class{constructor(r){var t;if(this.objectMode=!0,this.delimiter=",",this.ignoreEmpty=!1,this.quote='"',this.escape=null,this.escapeChar=this.quote,this.comment=null,this.supportsComments=!1,this.ltrim=!1,this.rtrim=!1,this.trim=!1,this.headers=null,this.renameHeaders=!1,this.strictColumnHandling=!1,this.discardUnmappedColumns=!1,this.carriageReturn="\r",this.encoding="utf8",this.limitRows=!1,this.maxRows=0,this.skipLines=0,this.skipRows=0,Object.assign(this,r||{}),this.delimiter.length>1)throw new Error("delimiter option must be one character long");this.escapedDelimiter=a.default(this.delimiter),this.escapeChar=(t=this.escape)!==null&&t!==void 0?t:this.quote,this.supportsComments=!o.default(this.comment),this.NEXT_TOKEN_REGEXP=new RegExp(`([^\\s]|\\r\\n|\\n|\\r|${this.escapedDelimiter})`),this.maxRows>0&&(this.limitRows=!0)}}},{"lodash.escaperegexp":442,"lodash.isnil":447}],155:[function(s,T,S){var m=Object.create?function(c,u,d,h){h===void 0&&(h=d),Object.defineProperty(c,h,{enumerable:!0,get:function(){return u[d]}})}:function(c,u,d,h){h===void 0&&(h=d),c[h]=u[d]},a=Object.create?function(c,u){Object.defineProperty(c,"default",{enumerable:!0,value:u})}:function(c,u){c.default=u},o=function(c){if(c&&c.__esModule)return c;var u={};if(c!=null)for(var d in c)d!=="default"&&Object.prototype.hasOwnProperty.call(c,d)&&m(u,c,d);return a(u,c),u},r=function(c,u){for(var d in c)d==="default"||Object.prototype.hasOwnProperty.call(u,d)||m(u,c,d)};Object.defineProperty(S,"__esModule",{value:!0}),S.parseString=S.parseFile=S.parseStream=S.parse=S.ParserOptions=S.CsvParserStream=void 0;const t=o(s("fs")),e=s("stream"),l=s("./ParserOptions"),n=s("./CsvParserStream");r(s("./types"),S);var i=s("./CsvParserStream");Object.defineProperty(S,"CsvParserStream",{enumerable:!0,get:function(){return i.CsvParserStream}});var f=s("./ParserOptions");Object.defineProperty(S,"ParserOptions",{enumerable:!0,get:function(){return f.ParserOptions}}),S.parse=c=>new n.CsvParserStream(new l.ParserOptions(c)),S.parseStream=(c,u)=>c.pipe(new n.CsvParserStream(new l.ParserOptions(u))),S.parseFile=function(c){let u=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};return t.createReadStream(c).pipe(new n.CsvParserStream(new l.ParserOptions(u)))},S.parseString=(c,u)=>{const d=new e.Readable;return d.push(c),d.push(null),d.pipe(new n.CsvParserStream(new l.ParserOptions(u)))}},{"./CsvParserStream":153,"./ParserOptions":154,"./types":169,fs:216,stream:505}],156:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.Parser=void 0;const m=s("./Scanner"),a=s("./RowParser"),o=s("./Token");class r{constructor(e){this.parserOptions=e,this.rowParser=new a.RowParser(this.parserOptions)}static removeBOM(e){return e&&e.charCodeAt(0)===65279?e.slice(1):e}parse(e,l){const n=new m.Scanner({line:r.removeBOM(e),parserOptions:this.parserOptions,hasMoreData:l});return this.parserOptions.supportsComments?this.parseWithComments(n):this.parseWithoutComments(n)}parseWithoutComments(e){const l=[];let n=!0;for(;n;)n=this.parseRow(e,l);return{line:e.line,rows:l}}parseWithComments(e){const{parserOptions:l}=this,n=[];for(let i=e.nextCharacterToken;i!==null;i=e.nextCharacterToken)if(o.Token.isTokenComment(i,l)){if(e.advancePastLine()===null)return{line:e.lineFromCursor,rows:n};if(!e.hasMoreCharacters)return{line:e.lineFromCursor,rows:n};e.truncateToCursor()}else if(!this.parseRow(e,n))break;return{line:e.line,rows:n}}parseRow(e,l){if(!e.nextNonSpaceToken)return!1;const n=this.rowParser.parse(e);return n!==null&&(this.parserOptions.ignoreEmpty&&a.RowParser.isEmptyRow(n)||l.push(n),!0)}}S.Parser=r},{"./RowParser":157,"./Scanner":158,"./Token":159}],157:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.RowParser=void 0;const m=s("./column"),a=s("./Token");S.RowParser=class{constructor(o){this.parserOptions=o,this.columnParser=new m.ColumnParser(o)}static isEmptyRow(o){return o.join("").replace(/\s+/g,"")===""}parse(o){const{parserOptions:r}=this,{hasMoreData:t}=o,e=o,l=[];let n=this.getStartToken(e,l);for(;n;){if(a.Token.isTokenRowDelimiter(n))return e.advancePastToken(n),!e.hasMoreCharacters&&a.Token.isTokenCarriageReturn(n,r)&&t?null:(e.truncateToCursor(),l);if(!this.shouldSkipColumnParse(e,n,l)){const i=this.columnParser.parse(e);if(i===null)return null;l.push(i)}n=e.nextNonSpaceToken}return t?null:(e.truncateToCursor(),l)}getStartToken(o,r){const t=o.nextNonSpaceToken;return t!==null&&a.Token.isTokenDelimiter(t,this.parserOptions)?(r.push(""),o.nextNonSpaceToken):t}shouldSkipColumnParse(o,r,t){const{parserOptions:e}=this;if(a.Token.isTokenDelimiter(r,e)){o.advancePastToken(r);const l=o.nextCharacterToken;if(!o.hasMoreCharacters||l!==null&&a.Token.isTokenRowDelimiter(l)||l!==null&&a.Token.isTokenDelimiter(l,e))return t.push(""),!0}return!1}}},{"./Token":159,"./column":164}],158:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.Scanner=void 0;const m=s("./Token"),a=/((?:\r\n)|\n|\r)/;S.Scanner=class{constructor(o){this.cursor=0,this.line=o.line,this.lineLength=this.line.length,this.parserOptions=o.parserOptions,this.hasMoreData=o.hasMoreData,this.cursor=o.cursor||0}get hasMoreCharacters(){return this.lineLength>this.cursor}get nextNonSpaceToken(){const{lineFromCursor:o}=this,r=this.parserOptions.NEXT_TOKEN_REGEXP;if(o.search(r)===-1)return null;const t=r.exec(o);if(t==null)return null;const e=t[1],l=this.cursor+(t.index||0);return new m.Token({token:e,startCursor:l,endCursor:l+e.length-1})}get nextCharacterToken(){const{cursor:o,lineLength:r}=this;return r<=o?null:new m.Token({token:this.line[o],startCursor:o,endCursor:o})}get lineFromCursor(){return this.line.substr(this.cursor)}advancePastLine(){const o=a.exec(this.lineFromCursor);return o?(this.cursor+=(o.index||0)+o[0].length,this):this.hasMoreData?null:(this.cursor=this.lineLength,this)}advanceTo(o){return this.cursor=o,this}advanceToToken(o){return this.cursor=o.startCursor,this}advancePastToken(o){return this.cursor=o.endCursor+1,this}truncateToCursor(){return this.line=this.lineFromCursor,this.lineLength=this.line.length,this.cursor=0,this}}},{"./Token":159}],159:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.Token=void 0,S.Token=class{constructor(m){this.token=m.token,this.startCursor=m.startCursor,this.endCursor=m.endCursor}static isTokenRowDelimiter(m){const a=m.token;return a==="\r"||a===`
`||a===`\r
`}static isTokenCarriageReturn(m,a){return m.token===a.carriageReturn}static isTokenComment(m,a){return a.supportsComments&&!!m&&m.token===a.comment}static isTokenEscapeCharacter(m,a){return m.token===a.escapeChar}static isTokenQuote(m,a){return m.token===a.quote}static isTokenDelimiter(m,a){return m.token===a.delimiter}}},{}],160:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.ColumnFormatter=void 0,S.ColumnFormatter=class{constructor(m){m.trim?this.format=a=>a.trim():m.ltrim?this.format=a=>a.trimLeft():m.rtrim?this.format=a=>a.trimRight():this.format=a=>a}}},{}],161:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.ColumnParser=void 0;const m=s("./NonQuotedColumnParser"),a=s("./QuotedColumnParser"),o=s("../Token");S.ColumnParser=class{constructor(r){this.parserOptions=r,this.quotedColumnParser=new a.QuotedColumnParser(r),this.nonQuotedColumnParser=new m.NonQuotedColumnParser(r)}parse(r){const{nextNonSpaceToken:t}=r;return t!==null&&o.Token.isTokenQuote(t,this.parserOptions)?(r.advanceToToken(t),this.quotedColumnParser.parse(r)):this.nonQuotedColumnParser.parse(r)}}},{"../Token":159,"./NonQuotedColumnParser":162,"./QuotedColumnParser":163}],162:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.NonQuotedColumnParser=void 0;const m=s("./ColumnFormatter"),a=s("../Token");S.NonQuotedColumnParser=class{constructor(o){this.parserOptions=o,this.columnFormatter=new m.ColumnFormatter(o)}parse(o){if(!o.hasMoreCharacters)return null;const{parserOptions:r}=this,t=[];let e=o.nextCharacterToken;for(;e&&!a.Token.isTokenDelimiter(e,r)&&!a.Token.isTokenRowDelimiter(e);e=o.nextCharacterToken)t.push(e.token),o.advancePastToken(e);return this.columnFormatter.format(t.join(""))}}},{"../Token":159,"./ColumnFormatter":160}],163:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.QuotedColumnParser=void 0;const m=s("./ColumnFormatter"),a=s("../Token");S.QuotedColumnParser=class{constructor(o){this.parserOptions=o,this.columnFormatter=new m.ColumnFormatter(o)}parse(o){if(!o.hasMoreCharacters)return null;const r=o.cursor,{foundClosingQuote:t,col:e}=this.gatherDataBetweenQuotes(o);if(!t){if(o.advanceTo(r),!o.hasMoreData)throw new Error(`Parse Error: missing closing: '${this.parserOptions.quote||""}' in line: at '${o.lineFromCursor.replace(/[\r\n]/g,"\\n'")}'`);return null}return this.checkForMalformedColumn(o),e}gatherDataBetweenQuotes(o){const{parserOptions:r}=this;let t=!1,e=!1;const l=[];let n=o.nextCharacterToken;for(;!e&&n!==null;n=o.nextCharacterToken){const i=a.Token.isTokenQuote(n,r);if(!t&&i)t=!0;else if(t)if(a.Token.isTokenEscapeCharacter(n,r)){o.advancePastToken(n);const f=o.nextCharacterToken;f!==null&&(a.Token.isTokenQuote(f,r)||a.Token.isTokenEscapeCharacter(f,r))?(l.push(f.token),n=f):i?e=!0:l.push(n.token)}else i?e=!0:l.push(n.token);o.advancePastToken(n)}return{col:this.columnFormatter.format(l.join("")),foundClosingQuote:e}}checkForMalformedColumn(o){const{parserOptions:r}=this,{nextNonSpaceToken:t}=o;if(t){const e=a.Token.isTokenDelimiter(t,r),l=a.Token.isTokenRowDelimiter(t);if(!e&&!l){const n=o.lineFromCursor.substr(0,10).replace(/[\r\n]/g,"\\n'");throw new Error(`Parse Error: expected: '${r.escapedDelimiter}' OR new line got: '${t.token}'. at '${n}`)}o.advanceToToken(t)}else o.hasMoreData||o.advancePastLine()}}},{"../Token":159,"./ColumnFormatter":160}],164:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.ColumnFormatter=S.QuotedColumnParser=S.NonQuotedColumnParser=S.ColumnParser=void 0;var m=s("./ColumnParser");Object.defineProperty(S,"ColumnParser",{enumerable:!0,get:function(){return m.ColumnParser}});var a=s("./NonQuotedColumnParser");Object.defineProperty(S,"NonQuotedColumnParser",{enumerable:!0,get:function(){return a.NonQuotedColumnParser}});var o=s("./QuotedColumnParser");Object.defineProperty(S,"QuotedColumnParser",{enumerable:!0,get:function(){return o.QuotedColumnParser}});var r=s("./ColumnFormatter");Object.defineProperty(S,"ColumnFormatter",{enumerable:!0,get:function(){return r.ColumnFormatter}})},{"./ColumnFormatter":160,"./ColumnParser":161,"./NonQuotedColumnParser":162,"./QuotedColumnParser":163}],165:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.QuotedColumnParser=S.NonQuotedColumnParser=S.ColumnParser=S.Token=S.Scanner=S.RowParser=S.Parser=void 0;var m=s("./Parser");Object.defineProperty(S,"Parser",{enumerable:!0,get:function(){return m.Parser}});var a=s("./RowParser");Object.defineProperty(S,"RowParser",{enumerable:!0,get:function(){return a.RowParser}});var o=s("./Scanner");Object.defineProperty(S,"Scanner",{enumerable:!0,get:function(){return o.Scanner}});var r=s("./Token");Object.defineProperty(S,"Token",{enumerable:!0,get:function(){return r.Token}});var t=s("./column");Object.defineProperty(S,"ColumnParser",{enumerable:!0,get:function(){return t.ColumnParser}}),Object.defineProperty(S,"NonQuotedColumnParser",{enumerable:!0,get:function(){return t.NonQuotedColumnParser}}),Object.defineProperty(S,"QuotedColumnParser",{enumerable:!0,get:function(){return t.QuotedColumnParser}})},{"./Parser":156,"./RowParser":157,"./Scanner":158,"./Token":159,"./column":164}],166:[function(s,T,S){var m=function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(S,"__esModule",{value:!0}),S.HeaderTransformer=void 0;const a=m(s("lodash.isundefined")),o=m(s("lodash.isfunction")),r=m(s("lodash.uniq")),t=m(s("lodash.groupby"));S.HeaderTransformer=class{constructor(e){this.headers=null,this.receivedHeaders=!1,this.shouldUseFirstRow=!1,this.processedFirstRow=!1,this.headersLength=0,this.parserOptions=e,e.headers===!0?this.shouldUseFirstRow=!0:Array.isArray(e.headers)?this.setHeaders(e.headers):o.default(e.headers)&&(this.headersTransform=e.headers)}transform(e,l){return this.shouldMapRow(e)?l(null,this.processRow(e)):l(null,{row:null,isValid:!0})}shouldMapRow(e){const{parserOptions:l}=this;if(!this.headersTransform&&l.renameHeaders&&!this.processedFirstRow){if(!this.receivedHeaders)throw new Error("Error renaming headers: new headers must be provided in an array");return this.processedFirstRow=!0,!1}if(!this.receivedHeaders&&Array.isArray(e)){if(this.headersTransform)this.setHeaders(this.headersTransform(e));else{if(!this.shouldUseFirstRow)return!0;this.setHeaders(e)}return!1}return!0}processRow(e){if(!this.headers)return{row:e,isValid:!0};const{parserOptions:l}=this;if(!l.discardUnmappedColumns&&e.length>this.headersLength){if(!l.strictColumnHandling)throw new Error(`Unexpected Error: column header mismatch expected: ${this.headersLength} columns got: ${e.length}`);return{row:e,isValid:!1,reason:`Column header mismatch expected: ${this.headersLength} columns got: ${e.length}`}}return l.strictColumnHandling&&e.length<this.headersLength?{row:e,isValid:!1,reason:`Column header mismatch expected: ${this.headersLength} columns got: ${e.length}`}:{row:this.mapHeaders(e),isValid:!0}}mapHeaders(e){const l={},{headers:n,headersLength:i}=this;for(let f=0;f<i;f+=1){const c=n[f];if(!a.default(c)){const u=e[f];a.default(u)?l[c]="":l[c]=u}}return l}setHeaders(e){var l;const n=e.filter(i=>!!i);if(r.default(n).length!==n.length){const i=t.default(n),f=Object.keys(i).filter(c=>i[c].length>1);throw new Error("Duplicate headers found "+JSON.stringify(f))}this.headers=e,this.receivedHeaders=!0,this.headersLength=((l=this.headers)===null||l===void 0?void 0:l.length)||0}}},{"lodash.groupby":443,"lodash.isfunction":446,"lodash.isundefined":448,"lodash.uniq":449}],167:[function(s,T,S){var m=function(t){return t&&t.__esModule?t:{default:t}};Object.defineProperty(S,"__esModule",{value:!0}),S.RowTransformerValidator=void 0;const a=m(s("lodash.isfunction")),o=s("../types");class r{constructor(){this._rowTransform=null,this._rowValidator=null}static createTransform(e){return o.isSyncTransform(e)?(l,n)=>{let i=null;try{i=e(l)}catch(f){return n(f)}return n(null,i)}:e}static createValidator(e){return o.isSyncValidate(e)?(l,n)=>{n(null,{row:l,isValid:e(l)})}:(l,n)=>{e(l,(i,f,c)=>i?n(i):n(null,f?{row:l,isValid:f,reason:c}:{row:l,isValid:!1,reason:c}))}}set rowTransform(e){if(!a.default(e))throw new TypeError("The transform should be a function");this._rowTransform=r.createTransform(e)}set rowValidator(e){if(!a.default(e))throw new TypeError("The validate should be a function");this._rowValidator=r.createValidator(e)}transformAndValidate(e,l){return this.callTransformer(e,(n,i)=>n?l(n):i?this.callValidator(i,(f,c)=>f?l(f):c&&!c.isValid?l(null,{row:i,isValid:!1,reason:c.reason}):l(null,{row:i,isValid:!0})):l(null,{row:null,isValid:!0}))}callTransformer(e,l){return this._rowTransform?this._rowTransform(e,l):l(null,e)}callValidator(e,l){return this._rowValidator?this._rowValidator(e,l):l(null,{row:e,isValid:!0})}}S.RowTransformerValidator=r},{"../types":169,"lodash.isfunction":446}],168:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.HeaderTransformer=S.RowTransformerValidator=void 0;var m=s("./RowTransformerValidator");Object.defineProperty(S,"RowTransformerValidator",{enumerable:!0,get:function(){return m.RowTransformerValidator}});var a=s("./HeaderTransformer");Object.defineProperty(S,"HeaderTransformer",{enumerable:!0,get:function(){return a.HeaderTransformer}})},{"./HeaderTransformer":166,"./RowTransformerValidator":167}],169:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.isSyncValidate=S.isSyncTransform=void 0,S.isSyncTransform=m=>m.length===1,S.isSyncValidate=m=>m.length===1},{}],170:[function(s,T,S){const m=S;m.bignum=s("bn.js"),m.define=s("./asn1/api").define,m.base=s("./asn1/base"),m.constants=s("./asn1/constants"),m.decoders=s("./asn1/decoders"),m.encoders=s("./asn1/encoders")},{"./asn1/api":171,"./asn1/base":173,"./asn1/constants":177,"./asn1/decoders":179,"./asn1/encoders":182,"bn.js":184}],171:[function(s,T,S){const m=s("./encoders"),a=s("./decoders"),o=s("inherits");function r(t,e){this.name=t,this.body=e,this.decoders={},this.encoders={}}S.define=function(t,e){return new r(t,e)},r.prototype._createNamed=function(t){const e=this.name;function l(n){this._initNamed(n,e)}return o(l,t),l.prototype._initNamed=function(n,i){t.call(this,n,i)},new l(this)},r.prototype._getDecoder=function(t){return t=t||"der",this.decoders.hasOwnProperty(t)||(this.decoders[t]=this._createNamed(a[t])),this.decoders[t]},r.prototype.decode=function(t,e,l){return this._getDecoder(e).decode(t,l)},r.prototype._getEncoder=function(t){return t=t||"der",this.encoders.hasOwnProperty(t)||(this.encoders[t]=this._createNamed(m[t])),this.encoders[t]},r.prototype.encode=function(t,e,l){return this._getEncoder(e).encode(t,l)}},{"./decoders":179,"./encoders":182,inherits:440}],172:[function(s,T,S){const m=s("inherits"),a=s("../base/reporter").Reporter,o=s("safer-buffer").Buffer;function r(e,l){a.call(this,l),o.isBuffer(e)?(this.base=e,this.offset=0,this.length=e.length):this.error("Input not Buffer")}function t(e,l){if(Array.isArray(e))this.length=0,this.value=e.map(function(n){return t.isEncoderBuffer(n)||(n=new t(n,l)),this.length+=n.length,n},this);else if(typeof e=="number"){if(!(0<=e&&e<=255))return l.error("non-byte EncoderBuffer value");this.value=e,this.length=1}else if(typeof e=="string")this.value=e,this.length=o.byteLength(e);else{if(!o.isBuffer(e))return l.error("Unsupported type: "+typeof e);this.value=e,this.length=e.length}}m(r,a),S.DecoderBuffer=r,r.isDecoderBuffer=function(e){return e instanceof r?!0:typeof e=="object"&&o.isBuffer(e.base)&&e.constructor.name==="DecoderBuffer"&&typeof e.offset=="number"&&typeof e.length=="number"&&typeof e.save=="function"&&typeof e.restore=="function"&&typeof e.isEmpty=="function"&&typeof e.readUInt8=="function"&&typeof e.skip=="function"&&typeof e.raw=="function"},r.prototype.save=function(){return{offset:this.offset,reporter:a.prototype.save.call(this)}},r.prototype.restore=function(e){const l=new r(this.base);return l.offset=e.offset,l.length=this.offset,this.offset=e.offset,a.prototype.restore.call(this,e.reporter),l},r.prototype.isEmpty=function(){return this.offset===this.length},r.prototype.readUInt8=function(e){return this.offset+1<=this.length?this.base.readUInt8(this.offset++,!0):this.error(e||"DecoderBuffer overrun")},r.prototype.skip=function(e,l){if(!(this.offset+e<=this.length))return this.error(l||"DecoderBuffer overrun");const n=new r(this.base);return n._reporterState=this._reporterState,n.offset=this.offset,n.length=this.offset+e,this.offset+=e,n},r.prototype.raw=function(e){return this.base.slice(e?e.offset:this.offset,this.length)},S.EncoderBuffer=t,t.isEncoderBuffer=function(e){return e instanceof t?!0:typeof e=="object"&&e.constructor.name==="EncoderBuffer"&&typeof e.length=="number"&&typeof e.join=="function"},t.prototype.join=function(e,l){return e||(e=o.alloc(this.length)),l||(l=0),this.length===0||(Array.isArray(this.value)?this.value.forEach(function(n){n.join(e,l),l+=n.length}):(typeof this.value=="number"?e[l]=this.value:typeof this.value=="string"?e.write(this.value,l):o.isBuffer(this.value)&&this.value.copy(e,l),l+=this.length)),e}},{"../base/reporter":175,inherits:440,"safer-buffer":495}],173:[function(s,T,S){const m=S;m.Reporter=s("./reporter").Reporter,m.DecoderBuffer=s("./buffer").DecoderBuffer,m.EncoderBuffer=s("./buffer").EncoderBuffer,m.Node=s("./node")},{"./buffer":172,"./node":174,"./reporter":175}],174:[function(s,T,S){const m=s("../base/reporter").Reporter,a=s("../base/buffer").EncoderBuffer,o=s("../base/buffer").DecoderBuffer,r=s("minimalistic-assert"),t=["seq","seqof","set","setof","objid","bool","gentime","utctime","null_","enum","int","objDesc","bitstr","bmpstr","charstr","genstr","graphstr","ia5str","iso646str","numstr","octstr","printstr","t61str","unistr","utf8str","videostr"],e=["key","obj","use","optional","explicit","implicit","def","choice","any","contains"].concat(t);function l(i,f,c){const u={};this._baseState=u,u.name=c,u.enc=i,u.parent=f||null,u.children=null,u.tag=null,u.args=null,u.reverseArgs=null,u.choice=null,u.optional=!1,u.any=!1,u.obj=!1,u.use=null,u.useDecoder=null,u.key=null,u.default=null,u.explicit=null,u.implicit=null,u.contains=null,u.parent||(u.children=[],this._wrap())}T.exports=l;const n=["enc","parent","children","tag","args","reverseArgs","choice","optional","any","obj","use","alteredUse","key","default","explicit","implicit","contains"];l.prototype.clone=function(){const i=this._baseState,f={};n.forEach(function(u){f[u]=i[u]});const c=new this.constructor(f.parent);return c._baseState=f,c},l.prototype._wrap=function(){const i=this._baseState;e.forEach(function(f){this[f]=function(){const c=new this.constructor(this);return i.children.push(c),c[f].apply(c,arguments)}},this)},l.prototype._init=function(i){const f=this._baseState;r(f.parent===null),i.call(this),f.children=f.children.filter(function(c){return c._baseState.parent===this},this),r.equal(f.children.length,1,"Root node can have only one child")},l.prototype._useArgs=function(i){const f=this._baseState,c=i.filter(function(u){return u instanceof this.constructor},this);i=i.filter(function(u){return!(u instanceof this.constructor)},this),c.length!==0&&(r(f.children===null),f.children=c,c.forEach(function(u){u._baseState.parent=this},this)),i.length!==0&&(r(f.args===null),f.args=i,f.reverseArgs=i.map(function(u){if(typeof u!="object"||u.constructor!==Object)return u;const d={};return Object.keys(u).forEach(function(h){h==(0|h)&&(h|=0);const w=u[h];d[w]=h}),d}))},["_peekTag","_decodeTag","_use","_decodeStr","_decodeObjid","_decodeTime","_decodeNull","_decodeInt","_decodeBool","_decodeList","_encodeComposite","_encodeStr","_encodeObjid","_encodeTime","_encodeNull","_encodeInt","_encodeBool"].forEach(function(i){l.prototype[i]=function(){const f=this._baseState;throw new Error(i+" not implemented for encoding: "+f.enc)}}),t.forEach(function(i){l.prototype[i]=function(){const f=this._baseState,c=Array.prototype.slice.call(arguments);return r(f.tag===null),f.tag=i,this._useArgs(c),this}}),l.prototype.use=function(i){r(i);const f=this._baseState;return r(f.use===null),f.use=i,this},l.prototype.optional=function(){return this._baseState.optional=!0,this},l.prototype.def=function(i){const f=this._baseState;return r(f.default===null),f.default=i,f.optional=!0,this},l.prototype.explicit=function(i){const f=this._baseState;return r(f.explicit===null&&f.implicit===null),f.explicit=i,this},l.prototype.implicit=function(i){const f=this._baseState;return r(f.explicit===null&&f.implicit===null),f.implicit=i,this},l.prototype.obj=function(){const i=this._baseState,f=Array.prototype.slice.call(arguments);return i.obj=!0,f.length!==0&&this._useArgs(f),this},l.prototype.key=function(i){const f=this._baseState;return r(f.key===null),f.key=i,this},l.prototype.any=function(){return this._baseState.any=!0,this},l.prototype.choice=function(i){const f=this._baseState;return r(f.choice===null),f.choice=i,this._useArgs(Object.keys(i).map(function(c){return i[c]})),this},l.prototype.contains=function(i){const f=this._baseState;return r(f.use===null),f.contains=i,this},l.prototype._decode=function(i,f){const c=this._baseState;if(c.parent===null)return i.wrapResult(c.children[0]._decode(i,f));let u,d=c.default,h=!0,w=null;if(c.key!==null&&(w=i.enterKey(c.key)),c.optional){let _=null;if(c.explicit!==null?_=c.explicit:c.implicit!==null?_=c.implicit:c.tag!==null&&(_=c.tag),_!==null||c.any){if(h=this._peekTag(i,_,c.any),i.isError(h))return h}else{const A=i.save();try{c.choice===null?this._decodeGeneric(c.tag,i,f):this._decodeChoice(i,f),h=!0}catch{h=!1}i.restore(A)}}if(c.obj&&h&&(u=i.enterObject()),h){if(c.explicit!==null){const A=this._decodeTag(i,c.explicit);if(i.isError(A))return A;i=A}const _=i.offset;if(c.use===null&&c.choice===null){let A;c.any&&(A=i.save());const N=this._decodeTag(i,c.implicit!==null?c.implicit:c.tag,c.any);if(i.isError(N))return N;c.any?d=i.raw(A):i=N}if(f&&f.track&&c.tag!==null&&f.track(i.path(),_,i.length,"tagged"),f&&f.track&&c.tag!==null&&f.track(i.path(),i.offset,i.length,"content"),c.any||(d=c.choice===null?this._decodeGeneric(c.tag,i,f):this._decodeChoice(i,f)),i.isError(d))return d;if(c.any||c.choice!==null||c.children===null||c.children.forEach(function(A){A._decode(i,f)}),c.contains&&(c.tag==="octstr"||c.tag==="bitstr")){const A=new o(d);d=this._getUse(c.contains,i._reporterState.obj)._decode(A,f)}}return c.obj&&h&&(d=i.leaveObject(u)),c.key===null||d===null&&h!==!0?w!==null&&i.exitKey(w):i.leaveKey(w,c.key,d),d},l.prototype._decodeGeneric=function(i,f,c){const u=this._baseState;return i==="seq"||i==="set"?null:i==="seqof"||i==="setof"?this._decodeList(f,i,u.args[0],c):/str$/.test(i)?this._decodeStr(f,i,c):i==="objid"&&u.args?this._decodeObjid(f,u.args[0],u.args[1],c):i==="objid"?this._decodeObjid(f,null,null,c):i==="gentime"||i==="utctime"?this._decodeTime(f,i,c):i==="null_"?this._decodeNull(f,c):i==="bool"?this._decodeBool(f,c):i==="objDesc"?this._decodeStr(f,i,c):i==="int"||i==="enum"?this._decodeInt(f,u.args&&u.args[0],c):u.use!==null?this._getUse(u.use,f._reporterState.obj)._decode(f,c):f.error("unknown tag: "+i)},l.prototype._getUse=function(i,f){const c=this._baseState;return c.useDecoder=this._use(i,f),r(c.useDecoder._baseState.parent===null),c.useDecoder=c.useDecoder._baseState.children[0],c.implicit!==c.useDecoder._baseState.implicit&&(c.useDecoder=c.useDecoder.clone(),c.useDecoder._baseState.implicit=c.implicit),c.useDecoder},l.prototype._decodeChoice=function(i,f){const c=this._baseState;let u=null,d=!1;return Object.keys(c.choice).some(function(h){const w=i.save(),_=c.choice[h];try{const A=_._decode(i,f);if(i.isError(A))return!1;u={type:h,value:A},d=!0}catch{return i.restore(w),!1}return!0},this),d?u:i.error("Choice not matched")},l.prototype._createEncoderBuffer=function(i){return new a(i,this.reporter)},l.prototype._encode=function(i,f,c){const u=this._baseState;if(u.default!==null&&u.default===i)return;const d=this._encodeValue(i,f,c);return d===void 0||this._skipDefault(d,f,c)?void 0:d},l.prototype._encodeValue=function(i,f,c){const u=this._baseState;if(u.parent===null)return u.children[0]._encode(i,f||new m);let d=null;if(this.reporter=f,u.optional&&i===void 0){if(u.default===null)return;i=u.default}let h=null,w=!1;if(u.any)d=this._createEncoderBuffer(i);else if(u.choice)d=this._encodeChoice(i,f);else if(u.contains)h=this._getUse(u.contains,c)._encode(i,f),w=!0;else if(u.children)h=u.children.map(function(_){if(_._baseState.tag==="null_")return _._encode(null,f,i);if(_._baseState.key===null)return f.error("Child should have a key");const A=f.enterKey(_._baseState.key);if(typeof i!="object")return f.error("Child expected, but input is not object");const N=_._encode(i[_._baseState.key],f,i);return f.leaveKey(A),N},this).filter(function(_){return _}),h=this._createEncoderBuffer(h);else if(u.tag==="seqof"||u.tag==="setof"){if(!u.args||u.args.length!==1)return f.error("Too many args for : "+u.tag);if(!Array.isArray(i))return f.error("seqof/setof, but data is not Array");const _=this.clone();_._baseState.implicit=null,h=this._createEncoderBuffer(i.map(function(A){const N=this._baseState;return this._getUse(N.args[0],i)._encode(A,f)},_))}else u.use!==null?d=this._getUse(u.use,c)._encode(i,f):(h=this._encodePrimitive(u.tag,i),w=!0);if(!u.any&&u.choice===null){const _=u.implicit!==null?u.implicit:u.tag,A=u.implicit===null?"universal":"context";_===null?u.use===null&&f.error("Tag could be omitted only for .use()"):u.use===null&&(d=this._encodeComposite(_,w,A,h))}return u.explicit!==null&&(d=this._encodeComposite(u.explicit,!1,"context",d)),d},l.prototype._encodeChoice=function(i,f){const c=this._baseState,u=c.choice[i.type];return u||r(!1,i.type+" not found in "+JSON.stringify(Object.keys(c.choice))),u._encode(i.value,f)},l.prototype._encodePrimitive=function(i,f){const c=this._baseState;if(/str$/.test(i))return this._encodeStr(f,i);if(i==="objid"&&c.args)return this._encodeObjid(f,c.reverseArgs[0],c.args[1]);if(i==="objid")return this._encodeObjid(f,null,null);if(i==="gentime"||i==="utctime")return this._encodeTime(f,i);if(i==="null_")return this._encodeNull();if(i==="int"||i==="enum")return this._encodeInt(f,c.args&&c.reverseArgs[0]);if(i==="bool")return this._encodeBool(f);if(i==="objDesc")return this._encodeStr(f,i);throw new Error("Unsupported tag: "+i)},l.prototype._isNumstr=function(i){return/^[0-9 ]*$/.test(i)},l.prototype._isPrintstr=function(i){return/^[A-Za-z0-9 '()+,-./:=?]*$/.test(i)}},{"../base/buffer":172,"../base/reporter":175,"minimalistic-assert":453}],175:[function(s,T,S){const m=s("inherits");function a(r){this._reporterState={obj:null,path:[],options:r||{},errors:[]}}function o(r,t){this.path=r,this.rethrow(t)}S.Reporter=a,a.prototype.isError=function(r){return r instanceof o},a.prototype.save=function(){const r=this._reporterState;return{obj:r.obj,pathLen:r.path.length}},a.prototype.restore=function(r){const t=this._reporterState;t.obj=r.obj,t.path=t.path.slice(0,r.pathLen)},a.prototype.enterKey=function(r){return this._reporterState.path.push(r)},a.prototype.exitKey=function(r){const t=this._reporterState;t.path=t.path.slice(0,r-1)},a.prototype.leaveKey=function(r,t,e){const l=this._reporterState;this.exitKey(r),l.obj!==null&&(l.obj[t]=e)},a.prototype.path=function(){return this._reporterState.path.join("/")},a.prototype.enterObject=function(){const r=this._reporterState,t=r.obj;return r.obj={},t},a.prototype.leaveObject=function(r){const t=this._reporterState,e=t.obj;return t.obj=r,e},a.prototype.error=function(r){let t;const e=this._reporterState,l=r instanceof o;if(t=l?r:new o(e.path.map(function(n){return"["+JSON.stringify(n)+"]"}).join(""),r.message||r,r.stack),!e.options.partial)throw t;return l||e.errors.push(t),t},a.prototype.wrapResult=function(r){const t=this._reporterState;return t.options.partial?{result:this.isError(r)?null:r,errors:t.errors}:r},m(o,Error),o.prototype.rethrow=function(r){if(this.message=r+" at: "+(this.path||"(shallow)"),Error.captureStackTrace&&Error.captureStackTrace(this,o),!this.stack)try{throw new Error(this.message)}catch(t){this.stack=t.stack}return this}},{inherits:440}],176:[function(s,T,S){function m(a){const o={};return Object.keys(a).forEach(function(r){(0|r)==r&&(r|=0);const t=a[r];o[t]=r}),o}S.tagClass={0:"universal",1:"application",2:"context",3:"private"},S.tagClassByName=m(S.tagClass),S.tag={0:"end",1:"bool",2:"int",3:"bitstr",4:"octstr",5:"null_",6:"objid",7:"objDesc",8:"external",9:"real",10:"enum",11:"embed",12:"utf8str",13:"relativeOid",16:"seq",17:"set",18:"numstr",19:"printstr",20:"t61str",21:"videostr",22:"ia5str",23:"utctime",24:"gentime",25:"graphstr",26:"iso646str",27:"genstr",28:"unistr",29:"charstr",30:"bmpstr"},S.tagByName=m(S.tag)},{}],177:[function(s,T,S){const m=S;m._reverse=function(a){const o={};return Object.keys(a).forEach(function(r){(0|r)==r&&(r|=0);const t=a[r];o[t]=r}),o},m.der=s("./der")},{"./der":176}],178:[function(s,T,S){const m=s("inherits"),a=s("bn.js"),o=s("../base/buffer").DecoderBuffer,r=s("../base/node"),t=s("../constants/der");function e(f){this.enc="der",this.name=f.name,this.entity=f,this.tree=new l,this.tree._init(f.body)}function l(f){r.call(this,"der",f)}function n(f,c){let u=f.readUInt8(c);if(f.isError(u))return u;const d=t.tagClass[u>>6],h=(32&u)==0;if((31&u)==31){let w=u;for(u=0;(128&w)==128;){if(w=f.readUInt8(c),f.isError(w))return w;u<<=7,u|=127&w}}else u&=31;return{cls:d,primitive:h,tag:u,tagStr:t.tag[u]}}function i(f,c,u){let d=f.readUInt8(u);if(f.isError(d))return d;if(!c&&d===128)return null;if(!(128&d))return d;const h=127&d;if(h>4)return f.error("length octect is too long");d=0;for(let w=0;w<h;w++){d<<=8;const _=f.readUInt8(u);if(f.isError(_))return _;d|=_}return d}T.exports=e,e.prototype.decode=function(f,c){return o.isDecoderBuffer(f)||(f=new o(f,c)),this.tree._decode(f,c)},m(l,r),l.prototype._peekTag=function(f,c,u){if(f.isEmpty())return!1;const d=f.save(),h=n(f,'Failed to peek tag: "'+c+'"');return f.isError(h)?h:(f.restore(d),h.tag===c||h.tagStr===c||h.tagStr+"of"===c||u)},l.prototype._decodeTag=function(f,c,u){const d=n(f,'Failed to decode tag of "'+c+'"');if(f.isError(d))return d;let h=i(f,d.primitive,'Failed to get length of "'+c+'"');if(f.isError(h))return h;if(!u&&d.tag!==c&&d.tagStr!==c&&d.tagStr+"of"!==c)return f.error('Failed to match tag: "'+c+'"');if(d.primitive||h!==null)return f.skip(h,'Failed to match body of: "'+c+'"');const w=f.save(),_=this._skipUntilEnd(f,'Failed to skip indefinite length body: "'+this.tag+'"');return f.isError(_)?_:(h=f.offset-w.offset,f.restore(w),f.skip(h,'Failed to match body of: "'+c+'"'))},l.prototype._skipUntilEnd=function(f,c){for(;;){const u=n(f,c);if(f.isError(u))return u;const d=i(f,u.primitive,c);if(f.isError(d))return d;let h;if(h=u.primitive||d!==null?f.skip(d):this._skipUntilEnd(f,c),f.isError(h))return h;if(u.tagStr==="end")break}},l.prototype._decodeList=function(f,c,u,d){const h=[];for(;!f.isEmpty();){const w=this._peekTag(f,"end");if(f.isError(w))return w;const _=u.decode(f,"der",d);if(f.isError(_)&&w)break;h.push(_)}return h},l.prototype._decodeStr=function(f,c){if(c==="bitstr"){const u=f.readUInt8();return f.isError(u)?u:{unused:u,data:f.raw()}}if(c==="bmpstr"){const u=f.raw();if(u.length%2==1)return f.error("Decoding of string type: bmpstr length mismatch");let d="";for(let h=0;h<u.length/2;h++)d+=String.fromCharCode(u.readUInt16BE(2*h));return d}if(c==="numstr"){const u=f.raw().toString("ascii");return this._isNumstr(u)?u:f.error("Decoding of string type: numstr unsupported characters")}if(c==="octstr"||c==="objDesc")return f.raw();if(c==="printstr"){const u=f.raw().toString("ascii");return this._isPrintstr(u)?u:f.error("Decoding of string type: printstr unsupported characters")}return/str$/.test(c)?f.raw().toString():f.error("Decoding of string type: "+c+" unsupported")},l.prototype._decodeObjid=function(f,c,u){let d;const h=[];let w=0,_=0;for(;!f.isEmpty();)_=f.readUInt8(),w<<=7,w|=127&_,!(128&_)&&(h.push(w),w=0);128&_&&h.push(w);const A=h[0]/40|0,N=h[0]%40;if(d=u?h:[A,N].concat(h.slice(1)),c){let L=c[d.join(" ")];L===void 0&&(L=c[d.join(".")]),L!==void 0&&(d=L)}return d},l.prototype._decodeTime=function(f,c){const u=f.raw().toString();let d,h,w,_,A,N;if(c==="gentime")d=0|u.slice(0,4),h=0|u.slice(4,6),w=0|u.slice(6,8),_=0|u.slice(8,10),A=0|u.slice(10,12),N=0|u.slice(12,14);else{if(c!=="utctime")return f.error("Decoding "+c+" time is not supported yet");d=0|u.slice(0,2),h=0|u.slice(2,4),w=0|u.slice(4,6),_=0|u.slice(6,8),A=0|u.slice(8,10),N=0|u.slice(10,12),d=d<70?2e3+d:1900+d}return Date.UTC(d,h-1,w,_,A,N,0)},l.prototype._decodeNull=function(){return null},l.prototype._decodeBool=function(f){const c=f.readUInt8();return f.isError(c)?c:c!==0},l.prototype._decodeInt=function(f,c){const u=f.raw();let d=new a(u);return c&&(d=c[d.toString(10)]||d),d},l.prototype._use=function(f,c){return typeof f=="function"&&(f=f(c)),f._getDecoder("der").tree}},{"../base/buffer":172,"../base/node":174,"../constants/der":176,"bn.js":184,inherits:440}],179:[function(s,T,S){const m=S;m.der=s("./der"),m.pem=s("./pem")},{"./der":178,"./pem":180}],180:[function(s,T,S){const m=s("inherits"),a=s("safer-buffer").Buffer,o=s("./der");function r(t){o.call(this,t),this.enc="pem"}m(r,o),T.exports=r,r.prototype.decode=function(t,e){const l=t.toString().split(/[\r\n]+/g),n=e.label.toUpperCase(),i=/^-----(BEGIN|END) ([^-]+)-----$/;let f=-1,c=-1;for(let h=0;h<l.length;h++){const w=l[h].match(i);if(w!==null&&w[2]===n){if(f!==-1){if(w[1]!=="END")break;c=h;break}if(w[1]!=="BEGIN")break;f=h}}if(f===-1||c===-1)throw new Error("PEM section not found for: "+n);const u=l.slice(f+1,c).join("");u.replace(/[^a-z0-9+/=]+/gi,"");const d=a.from(u,"base64");return o.prototype.decode.call(this,d,e)}},{"./der":178,inherits:440,"safer-buffer":495}],181:[function(s,T,S){const m=s("inherits"),a=s("safer-buffer").Buffer,o=s("../base/node"),r=s("../constants/der");function t(n){this.enc="der",this.name=n.name,this.entity=n,this.tree=new e,this.tree._init(n.body)}function e(n){o.call(this,"der",n)}function l(n){return n<10?"0"+n:n}T.exports=t,t.prototype.encode=function(n,i){return this.tree._encode(n,i).join()},m(e,o),e.prototype._encodeComposite=function(n,i,f,c){const u=function(w,_,A,N){let L;if(w==="seqof"?w="seq":w==="setof"&&(w="set"),r.tagByName.hasOwnProperty(w))L=r.tagByName[w];else{if(typeof w!="number"||(0|w)!==w)return N.error("Unknown tag: "+w);L=w}return L>=31?N.error("Multi-octet tag encoding unsupported"):(_||(L|=32),L|=r.tagClassByName[A||"universal"]<<6,L)}(n,i,f,this.reporter);if(c.length<128){const w=a.alloc(2);return w[0]=u,w[1]=c.length,this._createEncoderBuffer([w,c])}let d=1;for(let w=c.length;w>=256;w>>=8)d++;const h=a.alloc(2+d);h[0]=u,h[1]=128|d;for(let w=1+d,_=c.length;_>0;w--,_>>=8)h[w]=255&_;return this._createEncoderBuffer([h,c])},e.prototype._encodeStr=function(n,i){if(i==="bitstr")return this._createEncoderBuffer([0|n.unused,n.data]);if(i==="bmpstr"){const f=a.alloc(2*n.length);for(let c=0;c<n.length;c++)f.writeUInt16BE(n.charCodeAt(c),2*c);return this._createEncoderBuffer(f)}return i==="numstr"?this._isNumstr(n)?this._createEncoderBuffer(n):this.reporter.error("Encoding of string type: numstr supports only digits and space"):i==="printstr"?this._isPrintstr(n)?this._createEncoderBuffer(n):this.reporter.error("Encoding of string type: printstr supports only latin upper and lower case letters, digits, space, apostrophe, left and rigth parenthesis, plus sign, comma, hyphen, dot, slash, colon, equal sign, question mark"):/str$/.test(i)||i==="objDesc"?this._createEncoderBuffer(n):this.reporter.error("Encoding of string type: "+i+" unsupported")},e.prototype._encodeObjid=function(n,i,f){if(typeof n=="string"){if(!i)return this.reporter.error("string objid given, but no values map found");if(!i.hasOwnProperty(n))return this.reporter.error("objid not found in values map");n=i[n].split(/[\s.]+/g);for(let h=0;h<n.length;h++)n[h]|=0}else if(Array.isArray(n)){n=n.slice();for(let h=0;h<n.length;h++)n[h]|=0}if(!Array.isArray(n))return this.reporter.error("objid() should be either array or string, got: "+JSON.stringify(n));if(!f){if(n[1]>=40)return this.reporter.error("Second objid identifier OOB");n.splice(0,2,40*n[0]+n[1])}let c=0;for(let h=0;h<n.length;h++){let w=n[h];for(c++;w>=128;w>>=7)c++}const u=a.alloc(c);let d=u.length-1;for(let h=n.length-1;h>=0;h--){let w=n[h];for(u[d--]=127&w;(w>>=7)>0;)u[d--]=128|127&w}return this._createEncoderBuffer(u)},e.prototype._encodeTime=function(n,i){let f;const c=new Date(n);return i==="gentime"?f=[l(c.getUTCFullYear()),l(c.getUTCMonth()+1),l(c.getUTCDate()),l(c.getUTCHours()),l(c.getUTCMinutes()),l(c.getUTCSeconds()),"Z"].join(""):i==="utctime"?f=[l(c.getUTCFullYear()%100),l(c.getUTCMonth()+1),l(c.getUTCDate()),l(c.getUTCHours()),l(c.getUTCMinutes()),l(c.getUTCSeconds()),"Z"].join(""):this.reporter.error("Encoding "+i+" time is not supported yet"),this._encodeStr(f,"octstr")},e.prototype._encodeNull=function(){return this._createEncoderBuffer("")},e.prototype._encodeInt=function(n,i){if(typeof n=="string"){if(!i)return this.reporter.error("String int or enum given, but no values map");if(!i.hasOwnProperty(n))return this.reporter.error("Values map doesn't contain: "+JSON.stringify(n));n=i[n]}if(typeof n!="number"&&!a.isBuffer(n)){const u=n.toArray();!n.sign&&128&u[0]&&u.unshift(0),n=a.from(u)}if(a.isBuffer(n)){let u=n.length;n.length===0&&u++;const d=a.alloc(u);return n.copy(d),n.length===0&&(d[0]=0),this._createEncoderBuffer(d)}if(n<128)return this._createEncoderBuffer(n);if(n<256)return this._createEncoderBuffer([0,n]);let f=1;for(let u=n;u>=256;u>>=8)f++;const c=new Array(f);for(let u=c.length-1;u>=0;u--)c[u]=255&n,n>>=8;return 128&c[0]&&c.unshift(0),this._createEncoderBuffer(a.from(c))},e.prototype._encodeBool=function(n){return this._createEncoderBuffer(n?255:0)},e.prototype._use=function(n,i){return typeof n=="function"&&(n=n(i)),n._getEncoder("der").tree},e.prototype._skipDefault=function(n,i,f){const c=this._baseState;let u;if(c.default===null)return!1;const d=n.join();if(c.defaultBuffer===void 0&&(c.defaultBuffer=this._encodeValue(c.default,i,f).join()),d.length!==c.defaultBuffer.length)return!1;for(u=0;u<d.length;u++)if(d[u]!==c.defaultBuffer[u])return!1;return!0}},{"../base/node":174,"../constants/der":176,inherits:440,"safer-buffer":495}],182:[function(s,T,S){const m=S;m.der=s("./der"),m.pem=s("./pem")},{"./der":181,"./pem":183}],183:[function(s,T,S){const m=s("inherits"),a=s("./der");function o(r){a.call(this,r),this.enc="pem"}m(o,a),T.exports=o,o.prototype.encode=function(r,t){const e=a.prototype.encode.call(this,r).toString("base64"),l=["-----BEGIN "+t.label+"-----"];for(let n=0;n<e.length;n+=64)l.push(e.slice(n,n+64));return l.push("-----END "+t.label+"-----"),l.join(`
`)}},{"./der":181,inherits:440}],184:[function(s,T,S){(function(m,a){function o(x,M){if(!x)throw new Error(M||"Assertion failed")}function r(x,M){x.super_=M;var v=function(){};v.prototype=M.prototype,x.prototype=new v,x.prototype.constructor=x}function t(x,M,v){if(t.isBN(x))return x;this.negative=0,this.words=null,this.length=0,this.red=null,x!==null&&(M!=="le"&&M!=="be"||(v=M,M=10),this._init(x||0,M||10,v||"be"))}var e;typeof m=="object"?m.exports=t:(void 0).BN=t,t.BN=t,t.wordSize=26;try{e=typeof window<"u"&&window.Buffer!==void 0?window.Buffer:s("buffer").Buffer}catch{}function l(x,M){var v=x.charCodeAt(M);return v>=65&&v<=70?v-55:v>=97&&v<=102?v-87:v-48&15}function n(x,M,v){var p=l(x,v);return v-1>=M&&(p|=l(x,v-1)<<4),p}function i(x,M,v,p){for(var b=0,g=Math.min(x.length,v),y=M;y<g;y++){var k=x.charCodeAt(y)-48;b*=p,b+=k>=49?k-49+10:k>=17?k-17+10:k}return b}t.isBN=function(x){return x instanceof t||x!==null&&typeof x=="object"&&x.constructor.wordSize===t.wordSize&&Array.isArray(x.words)},t.max=function(x,M){return x.cmp(M)>0?x:M},t.min=function(x,M){return x.cmp(M)<0?x:M},t.prototype._init=function(x,M,v){if(typeof x=="number")return this._initNumber(x,M,v);if(typeof x=="object")return this._initArray(x,M,v);M==="hex"&&(M=16),o(M===(0|M)&&M>=2&&M<=36);var p=0;(x=x.toString().replace(/\s+/g,""))[0]==="-"&&(p++,this.negative=1),p<x.length&&(M===16?this._parseHex(x,p,v):(this._parseBase(x,M,p),v==="le"&&this._initArray(this.toArray(),M,v)))},t.prototype._initNumber=function(x,M,v){x<0&&(this.negative=1,x=-x),x<67108864?(this.words=[67108863&x],this.length=1):x<4503599627370496?(this.words=[67108863&x,x/67108864&67108863],this.length=2):(o(x<9007199254740992),this.words=[67108863&x,x/67108864&67108863,1],this.length=3),v==="le"&&this._initArray(this.toArray(),M,v)},t.prototype._initArray=function(x,M,v){if(o(typeof x.length=="number"),x.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(x.length/3),this.words=new Array(this.length);for(var p=0;p<this.length;p++)this.words[p]=0;var b,g,y=0;if(v==="be")for(p=x.length-1,b=0;p>=0;p-=3)g=x[p]|x[p-1]<<8|x[p-2]<<16,this.words[b]|=g<<y&67108863,this.words[b+1]=g>>>26-y&67108863,(y+=24)>=26&&(y-=26,b++);else if(v==="le")for(p=0,b=0;p<x.length;p+=3)g=x[p]|x[p+1]<<8|x[p+2]<<16,this.words[b]|=g<<y&67108863,this.words[b+1]=g>>>26-y&67108863,(y+=24)>=26&&(y-=26,b++);return this.strip()},t.prototype._parseHex=function(x,M,v){this.length=Math.ceil((x.length-M)/6),this.words=new Array(this.length);for(var p=0;p<this.length;p++)this.words[p]=0;var b,g=0,y=0;if(v==="be")for(p=x.length-1;p>=M;p-=2)b=n(x,M,p)<<g,this.words[y]|=67108863&b,g>=18?(g-=18,y+=1,this.words[y]|=b>>>26):g+=8;else for(p=(x.length-M)%2==0?M+1:M;p<x.length;p+=2)b=n(x,M,p)<<g,this.words[y]|=67108863&b,g>=18?(g-=18,y+=1,this.words[y]|=b>>>26):g+=8;this.strip()},t.prototype._parseBase=function(x,M,v){this.words=[0],this.length=1;for(var p=0,b=1;b<=67108863;b*=M)p++;p--,b=b/M|0;for(var g=x.length-v,y=g%p,k=Math.min(g,g-y)+v,R=0,O=v;O<k;O+=p)R=i(x,O,O+p,M),this.imuln(b),this.words[0]+R<67108864?this.words[0]+=R:this._iaddn(R);if(y!==0){var z=1;for(R=i(x,O,x.length,M),O=0;O<y;O++)z*=M;this.imuln(z),this.words[0]+R<67108864?this.words[0]+=R:this._iaddn(R)}this.strip()},t.prototype.copy=function(x){x.words=new Array(this.length);for(var M=0;M<this.length;M++)x.words[M]=this.words[M];x.length=this.length,x.negative=this.negative,x.red=this.red},t.prototype.clone=function(){var x=new t(null);return this.copy(x),x},t.prototype._expand=function(x){for(;this.length<x;)this.words[this.length++]=0;return this},t.prototype.strip=function(){for(;this.length>1&&this.words[this.length-1]===0;)this.length--;return this._normSign()},t.prototype._normSign=function(){return this.length===1&&this.words[0]===0&&(this.negative=0),this},t.prototype.inspect=function(){return(this.red?"<BN-R: ":"<BN: ")+this.toString(16)+">"};var f=["","0","00","000","0000","00000","000000","0000000","00000000","000000000","0000000000","00000000000","000000000000","0000000000000","00000000000000","000000000000000","0000000000000000","00000000000000000","000000000000000000","0000000000000000000","00000000000000000000","000000000000000000000","0000000000000000000000","00000000000000000000000","000000000000000000000000","0000000000000000000000000"],c=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],u=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function d(x,M,v){v.negative=M.negative^x.negative;var p=x.length+M.length|0;v.length=p,p=p-1|0;var b=0|x.words[0],g=0|M.words[0],y=b*g,k=67108863&y,R=y/67108864|0;v.words[0]=k;for(var O=1;O<p;O++){for(var z=R>>>26,$=67108863&R,W=Math.min(O,M.length-1),j=Math.max(0,O-x.length+1);j<=W;j++){var H=O-j|0;z+=(y=(b=0|x.words[H])*(g=0|M.words[j])+$)/67108864|0,$=67108863&y}v.words[O]=0|$,R=0|z}return R!==0?v.words[O]=0|R:v.length--,v.strip()}t.prototype.toString=function(x,M){var v;if(M=0|M||1,(x=x||10)===16||x==="hex"){v="";for(var p=0,b=0,g=0;g<this.length;g++){var y=this.words[g],k=(16777215&(y<<p|b)).toString(16);v=(b=y>>>24-p&16777215)!==0||g!==this.length-1?f[6-k.length]+k+v:k+v,(p+=2)>=26&&(p-=26,g--)}for(b!==0&&(v=b.toString(16)+v);v.length%M!=0;)v="0"+v;return this.negative!==0&&(v="-"+v),v}if(x===(0|x)&&x>=2&&x<=36){var R=c[x],O=u[x];v="";var z=this.clone();for(z.negative=0;!z.isZero();){var $=z.modn(O).toString(x);v=(z=z.idivn(O)).isZero()?$+v:f[R-$.length]+$+v}for(this.isZero()&&(v="0"+v);v.length%M!=0;)v="0"+v;return this.negative!==0&&(v="-"+v),v}o(!1,"Base should be between 2 and 36")},t.prototype.toNumber=function(){var x=this.words[0];return this.length===2?x+=67108864*this.words[1]:this.length===3&&this.words[2]===1?x+=4503599627370496+67108864*this.words[1]:this.length>2&&o(!1,"Number can only safely store up to 53 bits"),this.negative!==0?-x:x},t.prototype.toJSON=function(){return this.toString(16)},t.prototype.toBuffer=function(x,M){return o(e!==void 0),this.toArrayLike(e,x,M)},t.prototype.toArray=function(x,M){return this.toArrayLike(Array,x,M)},t.prototype.toArrayLike=function(x,M,v){var p=this.byteLength(),b=v||Math.max(1,p);o(p<=b,"byte array longer than desired length"),o(b>0,"Requested array length <= 0"),this.strip();var g,y,k=M==="le",R=new x(b),O=this.clone();if(k){for(y=0;!O.isZero();y++)g=O.andln(255),O.iushrn(8),R[y]=g;for(;y<b;y++)R[y]=0}else{for(y=0;y<b-p;y++)R[y]=0;for(y=0;!O.isZero();y++)g=O.andln(255),O.iushrn(8),R[b-y-1]=g}return R},Math.clz32?t.prototype._countBits=function(x){return 32-Math.clz32(x)}:t.prototype._countBits=function(x){var M=x,v=0;return M>=4096&&(v+=13,M>>>=13),M>=64&&(v+=7,M>>>=7),M>=8&&(v+=4,M>>>=4),M>=2&&(v+=2,M>>>=2),v+M},t.prototype._zeroBits=function(x){if(x===0)return 26;var M=x,v=0;return!(8191&M)&&(v+=13,M>>>=13),!(127&M)&&(v+=7,M>>>=7),!(15&M)&&(v+=4,M>>>=4),!(3&M)&&(v+=2,M>>>=2),!(1&M)&&v++,v},t.prototype.bitLength=function(){var x=this.words[this.length-1],M=this._countBits(x);return 26*(this.length-1)+M},t.prototype.zeroBits=function(){if(this.isZero())return 0;for(var x=0,M=0;M<this.length;M++){var v=this._zeroBits(this.words[M]);if(x+=v,v!==26)break}return x},t.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},t.prototype.toTwos=function(x){return this.negative!==0?this.abs().inotn(x).iaddn(1):this.clone()},t.prototype.fromTwos=function(x){return this.testn(x-1)?this.notn(x).iaddn(1).ineg():this.clone()},t.prototype.isNeg=function(){return this.negative!==0},t.prototype.neg=function(){return this.clone().ineg()},t.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},t.prototype.iuor=function(x){for(;this.length<x.length;)this.words[this.length++]=0;for(var M=0;M<x.length;M++)this.words[M]=this.words[M]|x.words[M];return this.strip()},t.prototype.ior=function(x){return o((this.negative|x.negative)==0),this.iuor(x)},t.prototype.or=function(x){return this.length>x.length?this.clone().ior(x):x.clone().ior(this)},t.prototype.uor=function(x){return this.length>x.length?this.clone().iuor(x):x.clone().iuor(this)},t.prototype.iuand=function(x){var M;M=this.length>x.length?x:this;for(var v=0;v<M.length;v++)this.words[v]=this.words[v]&x.words[v];return this.length=M.length,this.strip()},t.prototype.iand=function(x){return o((this.negative|x.negative)==0),this.iuand(x)},t.prototype.and=function(x){return this.length>x.length?this.clone().iand(x):x.clone().iand(this)},t.prototype.uand=function(x){return this.length>x.length?this.clone().iuand(x):x.clone().iuand(this)},t.prototype.iuxor=function(x){var M,v;this.length>x.length?(M=this,v=x):(M=x,v=this);for(var p=0;p<v.length;p++)this.words[p]=M.words[p]^v.words[p];if(this!==M)for(;p<M.length;p++)this.words[p]=M.words[p];return this.length=M.length,this.strip()},t.prototype.ixor=function(x){return o((this.negative|x.negative)==0),this.iuxor(x)},t.prototype.xor=function(x){return this.length>x.length?this.clone().ixor(x):x.clone().ixor(this)},t.prototype.uxor=function(x){return this.length>x.length?this.clone().iuxor(x):x.clone().iuxor(this)},t.prototype.inotn=function(x){o(typeof x=="number"&&x>=0);var M=0|Math.ceil(x/26),v=x%26;this._expand(M),v>0&&M--;for(var p=0;p<M;p++)this.words[p]=67108863&~this.words[p];return v>0&&(this.words[p]=~this.words[p]&67108863>>26-v),this.strip()},t.prototype.notn=function(x){return this.clone().inotn(x)},t.prototype.setn=function(x,M){o(typeof x=="number"&&x>=0);var v=x/26|0,p=x%26;return this._expand(v+1),this.words[v]=M?this.words[v]|1<<p:this.words[v]&~(1<<p),this.strip()},t.prototype.iadd=function(x){var M,v,p;if(this.negative!==0&&x.negative===0)return this.negative=0,M=this.isub(x),this.negative^=1,this._normSign();if(this.negative===0&&x.negative!==0)return x.negative=0,M=this.isub(x),x.negative=1,M._normSign();this.length>x.length?(v=this,p=x):(v=x,p=this);for(var b=0,g=0;g<p.length;g++)M=(0|v.words[g])+(0|p.words[g])+b,this.words[g]=67108863&M,b=M>>>26;for(;b!==0&&g<v.length;g++)M=(0|v.words[g])+b,this.words[g]=67108863&M,b=M>>>26;if(this.length=v.length,b!==0)this.words[this.length]=b,this.length++;else if(v!==this)for(;g<v.length;g++)this.words[g]=v.words[g];return this},t.prototype.add=function(x){var M;return x.negative!==0&&this.negative===0?(x.negative=0,M=this.sub(x),x.negative^=1,M):x.negative===0&&this.negative!==0?(this.negative=0,M=x.sub(this),this.negative=1,M):this.length>x.length?this.clone().iadd(x):x.clone().iadd(this)},t.prototype.isub=function(x){if(x.negative!==0){x.negative=0;var M=this.iadd(x);return x.negative=1,M._normSign()}if(this.negative!==0)return this.negative=0,this.iadd(x),this.negative=1,this._normSign();var v,p,b=this.cmp(x);if(b===0)return this.negative=0,this.length=1,this.words[0]=0,this;b>0?(v=this,p=x):(v=x,p=this);for(var g=0,y=0;y<p.length;y++)g=(M=(0|v.words[y])-(0|p.words[y])+g)>>26,this.words[y]=67108863&M;for(;g!==0&&y<v.length;y++)g=(M=(0|v.words[y])+g)>>26,this.words[y]=67108863&M;if(g===0&&y<v.length&&v!==this)for(;y<v.length;y++)this.words[y]=v.words[y];return this.length=Math.max(this.length,y),v!==this&&(this.negative=1),this.strip()},t.prototype.sub=function(x){return this.clone().isub(x)};var h=function(x,M,v){var p,b,g,y=x.words,k=M.words,R=v.words,O=0,z=0|y[0],$=8191&z,W=z>>>13,j=0|y[1],H=8191&j,E=j>>>13,C=0|y[2],F=8191&C,V=C>>>13,Z=0|y[3],q=8191&Z,K=Z>>>13,et=0|y[4],tt=8191&et,X=et>>>13,J=0|y[5],G=8191&J,nt=J>>>13,rt=0|y[6],st=8191&rt,ot=rt>>>13,lt=0|y[7],ct=8191&lt,wt=lt>>>13,vt=0|y[8],mt=8191&vt,Rt=vt>>>13,Et=0|y[9],At=8191&Et,jt=Et>>>13,_t=0|k[0],dt=8191&_t,xt=_t>>>13,Tt=0|k[1],St=8191&Tt,Kt=Tt>>>13,re=0|k[2],It=8191&re,Qt=re>>>13,Xt=0|k[3],Ut=8191&Xt,ue=Xt>>>13,te=0|k[4],Dt=8191&te,Gt=te>>>13,ae=0|k[5],Ft=8191&ae,ee=ae>>>13,oe=0|k[6],Ht=8191&oe,Q=oe>>>13,it=0|k[7],ut=8191&it,bt=it>>>13,Nt=0|k[8],yt=8191&Nt,Lt=Nt>>>13,Pt=0|k[9],Ot=8191&Pt,$t=Pt>>>13;v.negative=x.negative^M.negative,v.length=19;var zt=(O+(p=Math.imul($,dt))|0)+((8191&(b=(b=Math.imul($,xt))+Math.imul(W,dt)|0))<<13)|0;O=((g=Math.imul(W,xt))+(b>>>13)|0)+(zt>>>26)|0,zt&=67108863,p=Math.imul(H,dt),b=(b=Math.imul(H,xt))+Math.imul(E,dt)|0,g=Math.imul(E,xt);var qt=(O+(p=p+Math.imul($,St)|0)|0)+((8191&(b=(b=b+Math.imul($,Kt)|0)+Math.imul(W,St)|0))<<13)|0;O=((g=g+Math.imul(W,Kt)|0)+(b>>>13)|0)+(qt>>>26)|0,qt&=67108863,p=Math.imul(F,dt),b=(b=Math.imul(F,xt))+Math.imul(V,dt)|0,g=Math.imul(V,xt),p=p+Math.imul(H,St)|0,b=(b=b+Math.imul(H,Kt)|0)+Math.imul(E,St)|0,g=g+Math.imul(E,Kt)|0;var he=(O+(p=p+Math.imul($,It)|0)|0)+((8191&(b=(b=b+Math.imul($,Qt)|0)+Math.imul(W,It)|0))<<13)|0;O=((g=g+Math.imul(W,Qt)|0)+(b>>>13)|0)+(he>>>26)|0,he&=67108863,p=Math.imul(q,dt),b=(b=Math.imul(q,xt))+Math.imul(K,dt)|0,g=Math.imul(K,xt),p=p+Math.imul(F,St)|0,b=(b=b+Math.imul(F,Kt)|0)+Math.imul(V,St)|0,g=g+Math.imul(V,Kt)|0,p=p+Math.imul(H,It)|0,b=(b=b+Math.imul(H,Qt)|0)+Math.imul(E,It)|0,g=g+Math.imul(E,Qt)|0;var fe=(O+(p=p+Math.imul($,Ut)|0)|0)+((8191&(b=(b=b+Math.imul($,ue)|0)+Math.imul(W,Ut)|0))<<13)|0;O=((g=g+Math.imul(W,ue)|0)+(b>>>13)|0)+(fe>>>26)|0,fe&=67108863,p=Math.imul(tt,dt),b=(b=Math.imul(tt,xt))+Math.imul(X,dt)|0,g=Math.imul(X,xt),p=p+Math.imul(q,St)|0,b=(b=b+Math.imul(q,Kt)|0)+Math.imul(K,St)|0,g=g+Math.imul(K,Kt)|0,p=p+Math.imul(F,It)|0,b=(b=b+Math.imul(F,Qt)|0)+Math.imul(V,It)|0,g=g+Math.imul(V,Qt)|0,p=p+Math.imul(H,Ut)|0,b=(b=b+Math.imul(H,ue)|0)+Math.imul(E,Ut)|0,g=g+Math.imul(E,ue)|0;var de=(O+(p=p+Math.imul($,Dt)|0)|0)+((8191&(b=(b=b+Math.imul($,Gt)|0)+Math.imul(W,Dt)|0))<<13)|0;O=((g=g+Math.imul(W,Gt)|0)+(b>>>13)|0)+(de>>>26)|0,de&=67108863,p=Math.imul(G,dt),b=(b=Math.imul(G,xt))+Math.imul(nt,dt)|0,g=Math.imul(nt,xt),p=p+Math.imul(tt,St)|0,b=(b=b+Math.imul(tt,Kt)|0)+Math.imul(X,St)|0,g=g+Math.imul(X,Kt)|0,p=p+Math.imul(q,It)|0,b=(b=b+Math.imul(q,Qt)|0)+Math.imul(K,It)|0,g=g+Math.imul(K,Qt)|0,p=p+Math.imul(F,Ut)|0,b=(b=b+Math.imul(F,ue)|0)+Math.imul(V,Ut)|0,g=g+Math.imul(V,ue)|0,p=p+Math.imul(H,Dt)|0,b=(b=b+Math.imul(H,Gt)|0)+Math.imul(E,Dt)|0,g=g+Math.imul(E,Gt)|0;var pe=(O+(p=p+Math.imul($,Ft)|0)|0)+((8191&(b=(b=b+Math.imul($,ee)|0)+Math.imul(W,Ft)|0))<<13)|0;O=((g=g+Math.imul(W,ee)|0)+(b>>>13)|0)+(pe>>>26)|0,pe&=67108863,p=Math.imul(st,dt),b=(b=Math.imul(st,xt))+Math.imul(ot,dt)|0,g=Math.imul(ot,xt),p=p+Math.imul(G,St)|0,b=(b=b+Math.imul(G,Kt)|0)+Math.imul(nt,St)|0,g=g+Math.imul(nt,Kt)|0,p=p+Math.imul(tt,It)|0,b=(b=b+Math.imul(tt,Qt)|0)+Math.imul(X,It)|0,g=g+Math.imul(X,Qt)|0,p=p+Math.imul(q,Ut)|0,b=(b=b+Math.imul(q,ue)|0)+Math.imul(K,Ut)|0,g=g+Math.imul(K,ue)|0,p=p+Math.imul(F,Dt)|0,b=(b=b+Math.imul(F,Gt)|0)+Math.imul(V,Dt)|0,g=g+Math.imul(V,Gt)|0,p=p+Math.imul(H,Ft)|0,b=(b=b+Math.imul(H,ee)|0)+Math.imul(E,Ft)|0,g=g+Math.imul(E,ee)|0;var ge=(O+(p=p+Math.imul($,Ht)|0)|0)+((8191&(b=(b=b+Math.imul($,Q)|0)+Math.imul(W,Ht)|0))<<13)|0;O=((g=g+Math.imul(W,Q)|0)+(b>>>13)|0)+(ge>>>26)|0,ge&=67108863,p=Math.imul(ct,dt),b=(b=Math.imul(ct,xt))+Math.imul(wt,dt)|0,g=Math.imul(wt,xt),p=p+Math.imul(st,St)|0,b=(b=b+Math.imul(st,Kt)|0)+Math.imul(ot,St)|0,g=g+Math.imul(ot,Kt)|0,p=p+Math.imul(G,It)|0,b=(b=b+Math.imul(G,Qt)|0)+Math.imul(nt,It)|0,g=g+Math.imul(nt,Qt)|0,p=p+Math.imul(tt,Ut)|0,b=(b=b+Math.imul(tt,ue)|0)+Math.imul(X,Ut)|0,g=g+Math.imul(X,ue)|0,p=p+Math.imul(q,Dt)|0,b=(b=b+Math.imul(q,Gt)|0)+Math.imul(K,Dt)|0,g=g+Math.imul(K,Gt)|0,p=p+Math.imul(F,Ft)|0,b=(b=b+Math.imul(F,ee)|0)+Math.imul(V,Ft)|0,g=g+Math.imul(V,ee)|0,p=p+Math.imul(H,Ht)|0,b=(b=b+Math.imul(H,Q)|0)+Math.imul(E,Ht)|0,g=g+Math.imul(E,Q)|0;var Y=(O+(p=p+Math.imul($,ut)|0)|0)+((8191&(b=(b=b+Math.imul($,bt)|0)+Math.imul(W,ut)|0))<<13)|0;O=((g=g+Math.imul(W,bt)|0)+(b>>>13)|0)+(Y>>>26)|0,Y&=67108863,p=Math.imul(mt,dt),b=(b=Math.imul(mt,xt))+Math.imul(Rt,dt)|0,g=Math.imul(Rt,xt),p=p+Math.imul(ct,St)|0,b=(b=b+Math.imul(ct,Kt)|0)+Math.imul(wt,St)|0,g=g+Math.imul(wt,Kt)|0,p=p+Math.imul(st,It)|0,b=(b=b+Math.imul(st,Qt)|0)+Math.imul(ot,It)|0,g=g+Math.imul(ot,Qt)|0,p=p+Math.imul(G,Ut)|0,b=(b=b+Math.imul(G,ue)|0)+Math.imul(nt,Ut)|0,g=g+Math.imul(nt,ue)|0,p=p+Math.imul(tt,Dt)|0,b=(b=b+Math.imul(tt,Gt)|0)+Math.imul(X,Dt)|0,g=g+Math.imul(X,Gt)|0,p=p+Math.imul(q,Ft)|0,b=(b=b+Math.imul(q,ee)|0)+Math.imul(K,Ft)|0,g=g+Math.imul(K,ee)|0,p=p+Math.imul(F,Ht)|0,b=(b=b+Math.imul(F,Q)|0)+Math.imul(V,Ht)|0,g=g+Math.imul(V,Q)|0,p=p+Math.imul(H,ut)|0,b=(b=b+Math.imul(H,bt)|0)+Math.imul(E,ut)|0,g=g+Math.imul(E,bt)|0;var at=(O+(p=p+Math.imul($,yt)|0)|0)+((8191&(b=(b=b+Math.imul($,Lt)|0)+Math.imul(W,yt)|0))<<13)|0;O=((g=g+Math.imul(W,Lt)|0)+(b>>>13)|0)+(at>>>26)|0,at&=67108863,p=Math.imul(At,dt),b=(b=Math.imul(At,xt))+Math.imul(jt,dt)|0,g=Math.imul(jt,xt),p=p+Math.imul(mt,St)|0,b=(b=b+Math.imul(mt,Kt)|0)+Math.imul(Rt,St)|0,g=g+Math.imul(Rt,Kt)|0,p=p+Math.imul(ct,It)|0,b=(b=b+Math.imul(ct,Qt)|0)+Math.imul(wt,It)|0,g=g+Math.imul(wt,Qt)|0,p=p+Math.imul(st,Ut)|0,b=(b=b+Math.imul(st,ue)|0)+Math.imul(ot,Ut)|0,g=g+Math.imul(ot,ue)|0,p=p+Math.imul(G,Dt)|0,b=(b=b+Math.imul(G,Gt)|0)+Math.imul(nt,Dt)|0,g=g+Math.imul(nt,Gt)|0,p=p+Math.imul(tt,Ft)|0,b=(b=b+Math.imul(tt,ee)|0)+Math.imul(X,Ft)|0,g=g+Math.imul(X,ee)|0,p=p+Math.imul(q,Ht)|0,b=(b=b+Math.imul(q,Q)|0)+Math.imul(K,Ht)|0,g=g+Math.imul(K,Q)|0,p=p+Math.imul(F,ut)|0,b=(b=b+Math.imul(F,bt)|0)+Math.imul(V,ut)|0,g=g+Math.imul(V,bt)|0,p=p+Math.imul(H,yt)|0,b=(b=b+Math.imul(H,Lt)|0)+Math.imul(E,yt)|0,g=g+Math.imul(E,Lt)|0;var ft=(O+(p=p+Math.imul($,Ot)|0)|0)+((8191&(b=(b=b+Math.imul($,$t)|0)+Math.imul(W,Ot)|0))<<13)|0;O=((g=g+Math.imul(W,$t)|0)+(b>>>13)|0)+(ft>>>26)|0,ft&=67108863,p=Math.imul(At,St),b=(b=Math.imul(At,Kt))+Math.imul(jt,St)|0,g=Math.imul(jt,Kt),p=p+Math.imul(mt,It)|0,b=(b=b+Math.imul(mt,Qt)|0)+Math.imul(Rt,It)|0,g=g+Math.imul(Rt,Qt)|0,p=p+Math.imul(ct,Ut)|0,b=(b=b+Math.imul(ct,ue)|0)+Math.imul(wt,Ut)|0,g=g+Math.imul(wt,ue)|0,p=p+Math.imul(st,Dt)|0,b=(b=b+Math.imul(st,Gt)|0)+Math.imul(ot,Dt)|0,g=g+Math.imul(ot,Gt)|0,p=p+Math.imul(G,Ft)|0,b=(b=b+Math.imul(G,ee)|0)+Math.imul(nt,Ft)|0,g=g+Math.imul(nt,ee)|0,p=p+Math.imul(tt,Ht)|0,b=(b=b+Math.imul(tt,Q)|0)+Math.imul(X,Ht)|0,g=g+Math.imul(X,Q)|0,p=p+Math.imul(q,ut)|0,b=(b=b+Math.imul(q,bt)|0)+Math.imul(K,ut)|0,g=g+Math.imul(K,bt)|0,p=p+Math.imul(F,yt)|0,b=(b=b+Math.imul(F,Lt)|0)+Math.imul(V,yt)|0,g=g+Math.imul(V,Lt)|0;var ht=(O+(p=p+Math.imul(H,Ot)|0)|0)+((8191&(b=(b=b+Math.imul(H,$t)|0)+Math.imul(E,Ot)|0))<<13)|0;O=((g=g+Math.imul(E,$t)|0)+(b>>>13)|0)+(ht>>>26)|0,ht&=67108863,p=Math.imul(At,It),b=(b=Math.imul(At,Qt))+Math.imul(jt,It)|0,g=Math.imul(jt,Qt),p=p+Math.imul(mt,Ut)|0,b=(b=b+Math.imul(mt,ue)|0)+Math.imul(Rt,Ut)|0,g=g+Math.imul(Rt,ue)|0,p=p+Math.imul(ct,Dt)|0,b=(b=b+Math.imul(ct,Gt)|0)+Math.imul(wt,Dt)|0,g=g+Math.imul(wt,Gt)|0,p=p+Math.imul(st,Ft)|0,b=(b=b+Math.imul(st,ee)|0)+Math.imul(ot,Ft)|0,g=g+Math.imul(ot,ee)|0,p=p+Math.imul(G,Ht)|0,b=(b=b+Math.imul(G,Q)|0)+Math.imul(nt,Ht)|0,g=g+Math.imul(nt,Q)|0,p=p+Math.imul(tt,ut)|0,b=(b=b+Math.imul(tt,bt)|0)+Math.imul(X,ut)|0,g=g+Math.imul(X,bt)|0,p=p+Math.imul(q,yt)|0,b=(b=b+Math.imul(q,Lt)|0)+Math.imul(K,yt)|0,g=g+Math.imul(K,Lt)|0;var kt=(O+(p=p+Math.imul(F,Ot)|0)|0)+((8191&(b=(b=b+Math.imul(F,$t)|0)+Math.imul(V,Ot)|0))<<13)|0;O=((g=g+Math.imul(V,$t)|0)+(b>>>13)|0)+(kt>>>26)|0,kt&=67108863,p=Math.imul(At,Ut),b=(b=Math.imul(At,ue))+Math.imul(jt,Ut)|0,g=Math.imul(jt,ue),p=p+Math.imul(mt,Dt)|0,b=(b=b+Math.imul(mt,Gt)|0)+Math.imul(Rt,Dt)|0,g=g+Math.imul(Rt,Gt)|0,p=p+Math.imul(ct,Ft)|0,b=(b=b+Math.imul(ct,ee)|0)+Math.imul(wt,Ft)|0,g=g+Math.imul(wt,ee)|0,p=p+Math.imul(st,Ht)|0,b=(b=b+Math.imul(st,Q)|0)+Math.imul(ot,Ht)|0,g=g+Math.imul(ot,Q)|0,p=p+Math.imul(G,ut)|0,b=(b=b+Math.imul(G,bt)|0)+Math.imul(nt,ut)|0,g=g+Math.imul(nt,bt)|0,p=p+Math.imul(tt,yt)|0,b=(b=b+Math.imul(tt,Lt)|0)+Math.imul(X,yt)|0,g=g+Math.imul(X,Lt)|0;var pt=(O+(p=p+Math.imul(q,Ot)|0)|0)+((8191&(b=(b=b+Math.imul(q,$t)|0)+Math.imul(K,Ot)|0))<<13)|0;O=((g=g+Math.imul(K,$t)|0)+(b>>>13)|0)+(pt>>>26)|0,pt&=67108863,p=Math.imul(At,Dt),b=(b=Math.imul(At,Gt))+Math.imul(jt,Dt)|0,g=Math.imul(jt,Gt),p=p+Math.imul(mt,Ft)|0,b=(b=b+Math.imul(mt,ee)|0)+Math.imul(Rt,Ft)|0,g=g+Math.imul(Rt,ee)|0,p=p+Math.imul(ct,Ht)|0,b=(b=b+Math.imul(ct,Q)|0)+Math.imul(wt,Ht)|0,g=g+Math.imul(wt,Q)|0,p=p+Math.imul(st,ut)|0,b=(b=b+Math.imul(st,bt)|0)+Math.imul(ot,ut)|0,g=g+Math.imul(ot,bt)|0,p=p+Math.imul(G,yt)|0,b=(b=b+Math.imul(G,Lt)|0)+Math.imul(nt,yt)|0,g=g+Math.imul(nt,Lt)|0;var gt=(O+(p=p+Math.imul(tt,Ot)|0)|0)+((8191&(b=(b=b+Math.imul(tt,$t)|0)+Math.imul(X,Ot)|0))<<13)|0;O=((g=g+Math.imul(X,$t)|0)+(b>>>13)|0)+(gt>>>26)|0,gt&=67108863,p=Math.imul(At,Ft),b=(b=Math.imul(At,ee))+Math.imul(jt,Ft)|0,g=Math.imul(jt,ee),p=p+Math.imul(mt,Ht)|0,b=(b=b+Math.imul(mt,Q)|0)+Math.imul(Rt,Ht)|0,g=g+Math.imul(Rt,Q)|0,p=p+Math.imul(ct,ut)|0,b=(b=b+Math.imul(ct,bt)|0)+Math.imul(wt,ut)|0,g=g+Math.imul(wt,bt)|0,p=p+Math.imul(st,yt)|0,b=(b=b+Math.imul(st,Lt)|0)+Math.imul(ot,yt)|0,g=g+Math.imul(ot,Lt)|0;var Zt=(O+(p=p+Math.imul(G,Ot)|0)|0)+((8191&(b=(b=b+Math.imul(G,$t)|0)+Math.imul(nt,Ot)|0))<<13)|0;O=((g=g+Math.imul(nt,$t)|0)+(b>>>13)|0)+(Zt>>>26)|0,Zt&=67108863,p=Math.imul(At,Ht),b=(b=Math.imul(At,Q))+Math.imul(jt,Ht)|0,g=Math.imul(jt,Q),p=p+Math.imul(mt,ut)|0,b=(b=b+Math.imul(mt,bt)|0)+Math.imul(Rt,ut)|0,g=g+Math.imul(Rt,bt)|0,p=p+Math.imul(ct,yt)|0,b=(b=b+Math.imul(ct,Lt)|0)+Math.imul(wt,yt)|0,g=g+Math.imul(wt,Lt)|0;var Vt=(O+(p=p+Math.imul(st,Ot)|0)|0)+((8191&(b=(b=b+Math.imul(st,$t)|0)+Math.imul(ot,Ot)|0))<<13)|0;O=((g=g+Math.imul(ot,$t)|0)+(b>>>13)|0)+(Vt>>>26)|0,Vt&=67108863,p=Math.imul(At,ut),b=(b=Math.imul(At,bt))+Math.imul(jt,ut)|0,g=Math.imul(jt,bt),p=p+Math.imul(mt,yt)|0,b=(b=b+Math.imul(mt,Lt)|0)+Math.imul(Rt,yt)|0,g=g+Math.imul(Rt,Lt)|0;var Wt=(O+(p=p+Math.imul(ct,Ot)|0)|0)+((8191&(b=(b=b+Math.imul(ct,$t)|0)+Math.imul(wt,Ot)|0))<<13)|0;O=((g=g+Math.imul(wt,$t)|0)+(b>>>13)|0)+(Wt>>>26)|0,Wt&=67108863,p=Math.imul(At,yt),b=(b=Math.imul(At,Lt))+Math.imul(jt,yt)|0,g=Math.imul(jt,Lt);var Bt=(O+(p=p+Math.imul(mt,Ot)|0)|0)+((8191&(b=(b=b+Math.imul(mt,$t)|0)+Math.imul(Rt,Ot)|0))<<13)|0;O=((g=g+Math.imul(Rt,$t)|0)+(b>>>13)|0)+(Bt>>>26)|0,Bt&=67108863;var ne=(O+(p=Math.imul(At,Ot))|0)+((8191&(b=(b=Math.imul(At,$t))+Math.imul(jt,Ot)|0))<<13)|0;return O=((g=Math.imul(jt,$t))+(b>>>13)|0)+(ne>>>26)|0,ne&=67108863,R[0]=zt,R[1]=qt,R[2]=he,R[3]=fe,R[4]=de,R[5]=pe,R[6]=ge,R[7]=Y,R[8]=at,R[9]=ft,R[10]=ht,R[11]=kt,R[12]=pt,R[13]=gt,R[14]=Zt,R[15]=Vt,R[16]=Wt,R[17]=Bt,R[18]=ne,O!==0&&(R[19]=O,v.length++),v};function w(x,M,v){return new _().mulp(x,M,v)}function _(x,M){this.x=x,this.y=M}Math.imul||(h=d),t.prototype.mulTo=function(x,M){var v=this.length+x.length;return this.length===10&&x.length===10?h(this,x,M):v<63?d(this,x,M):v<1024?function(p,b,g){g.negative=b.negative^p.negative,g.length=p.length+b.length;for(var y=0,k=0,R=0;R<g.length-1;R++){var O=k;k=0;for(var z=67108863&y,$=Math.min(R,b.length-1),W=Math.max(0,R-p.length+1);W<=$;W++){var j=R-W,H=(0|p.words[j])*(0|b.words[W]),E=67108863&H;z=67108863&(E=E+z|0),k+=(O=(O=O+(H/67108864|0)|0)+(E>>>26)|0)>>>26,O&=67108863}g.words[R]=z,y=O,O=k}return y!==0?g.words[R]=y:g.length--,g.strip()}(this,x,M):w(this,x,M)},_.prototype.makeRBT=function(x){for(var M=new Array(x),v=t.prototype._countBits(x)-1,p=0;p<x;p++)M[p]=this.revBin(p,v,x);return M},_.prototype.revBin=function(x,M,v){if(x===0||x===v-1)return x;for(var p=0,b=0;b<M;b++)p|=(1&x)<<M-b-1,x>>=1;return p},_.prototype.permute=function(x,M,v,p,b,g){for(var y=0;y<g;y++)p[y]=M[x[y]],b[y]=v[x[y]]},_.prototype.transform=function(x,M,v,p,b,g){this.permute(g,x,M,v,p,b);for(var y=1;y<b;y<<=1)for(var k=y<<1,R=Math.cos(2*Math.PI/k),O=Math.sin(2*Math.PI/k),z=0;z<b;z+=k)for(var $=R,W=O,j=0;j<y;j++){var H=v[z+j],E=p[z+j],C=v[z+j+y],F=p[z+j+y],V=$*C-W*F;F=$*F+W*C,C=V,v[z+j]=H+C,p[z+j]=E+F,v[z+j+y]=H-C,p[z+j+y]=E-F,j!==k&&(V=R*$-O*W,W=R*W+O*$,$=V)}},_.prototype.guessLen13b=function(x,M){var v=1|Math.max(M,x),p=1&v,b=0;for(v=v/2|0;v;v>>>=1)b++;return 1<<b+1+p},_.prototype.conjugate=function(x,M,v){if(!(v<=1))for(var p=0;p<v/2;p++){var b=x[p];x[p]=x[v-p-1],x[v-p-1]=b,b=M[p],M[p]=-M[v-p-1],M[v-p-1]=-b}},_.prototype.normalize13b=function(x,M){for(var v=0,p=0;p<M/2;p++){var b=8192*Math.round(x[2*p+1]/M)+Math.round(x[2*p]/M)+v;x[p]=67108863&b,v=b<67108864?0:b/67108864|0}return x},_.prototype.convert13b=function(x,M,v,p){for(var b=0,g=0;g<M;g++)b+=0|x[g],v[2*g]=8191&b,b>>>=13,v[2*g+1]=8191&b,b>>>=13;for(g=2*M;g<p;++g)v[g]=0;o(b===0),o((-8192&b)==0)},_.prototype.stub=function(x){for(var M=new Array(x),v=0;v<x;v++)M[v]=0;return M},_.prototype.mulp=function(x,M,v){var p=2*this.guessLen13b(x.length,M.length),b=this.makeRBT(p),g=this.stub(p),y=new Array(p),k=new Array(p),R=new Array(p),O=new Array(p),z=new Array(p),$=new Array(p),W=v.words;W.length=p,this.convert13b(x.words,x.length,y,p),this.convert13b(M.words,M.length,O,p),this.transform(y,g,k,R,p,b),this.transform(O,g,z,$,p,b);for(var j=0;j<p;j++){var H=k[j]*z[j]-R[j]*$[j];R[j]=k[j]*$[j]+R[j]*z[j],k[j]=H}return this.conjugate(k,R,p),this.transform(k,R,W,g,p,b),this.conjugate(W,g,p),this.normalize13b(W,p),v.negative=x.negative^M.negative,v.length=x.length+M.length,v.strip()},t.prototype.mul=function(x){var M=new t(null);return M.words=new Array(this.length+x.length),this.mulTo(x,M)},t.prototype.mulf=function(x){var M=new t(null);return M.words=new Array(this.length+x.length),w(this,x,M)},t.prototype.imul=function(x){return this.clone().mulTo(x,this)},t.prototype.imuln=function(x){o(typeof x=="number"),o(x<67108864);for(var M=0,v=0;v<this.length;v++){var p=(0|this.words[v])*x,b=(67108863&p)+(67108863&M);M>>=26,M+=p/67108864|0,M+=b>>>26,this.words[v]=67108863&b}return M!==0&&(this.words[v]=M,this.length++),this},t.prototype.muln=function(x){return this.clone().imuln(x)},t.prototype.sqr=function(){return this.mul(this)},t.prototype.isqr=function(){return this.imul(this.clone())},t.prototype.pow=function(x){var M=function(g){for(var y=new Array(g.bitLength()),k=0;k<y.length;k++){var R=k/26|0,O=k%26;y[k]=(g.words[R]&1<<O)>>>O}return y}(x);if(M.length===0)return new t(1);for(var v=this,p=0;p<M.length&&M[p]===0;p++,v=v.sqr());if(++p<M.length)for(var b=v.sqr();p<M.length;p++,b=b.sqr())M[p]!==0&&(v=v.mul(b));return v},t.prototype.iushln=function(x){o(typeof x=="number"&&x>=0);var M,v=x%26,p=(x-v)/26,b=67108863>>>26-v<<26-v;if(v!==0){var g=0;for(M=0;M<this.length;M++){var y=this.words[M]&b,k=(0|this.words[M])-y<<v;this.words[M]=k|g,g=y>>>26-v}g&&(this.words[M]=g,this.length++)}if(p!==0){for(M=this.length-1;M>=0;M--)this.words[M+p]=this.words[M];for(M=0;M<p;M++)this.words[M]=0;this.length+=p}return this.strip()},t.prototype.ishln=function(x){return o(this.negative===0),this.iushln(x)},t.prototype.iushrn=function(x,M,v){var p;o(typeof x=="number"&&x>=0),p=M?(M-M%26)/26:0;var b=x%26,g=Math.min((x-b)/26,this.length),y=67108863^67108863>>>b<<b,k=v;if(p-=g,p=Math.max(0,p),k){for(var R=0;R<g;R++)k.words[R]=this.words[R];k.length=g}if(g!==0)if(this.length>g)for(this.length-=g,R=0;R<this.length;R++)this.words[R]=this.words[R+g];else this.words[0]=0,this.length=1;var O=0;for(R=this.length-1;R>=0&&(O!==0||R>=p);R--){var z=0|this.words[R];this.words[R]=O<<26-b|z>>>b,O=z&y}return k&&O!==0&&(k.words[k.length++]=O),this.length===0&&(this.words[0]=0,this.length=1),this.strip()},t.prototype.ishrn=function(x,M,v){return o(this.negative===0),this.iushrn(x,M,v)},t.prototype.shln=function(x){return this.clone().ishln(x)},t.prototype.ushln=function(x){return this.clone().iushln(x)},t.prototype.shrn=function(x){return this.clone().ishrn(x)},t.prototype.ushrn=function(x){return this.clone().iushrn(x)},t.prototype.testn=function(x){o(typeof x=="number"&&x>=0);var M=x%26,v=(x-M)/26,p=1<<M;return!(this.length<=v)&&!!(this.words[v]&p)},t.prototype.imaskn=function(x){o(typeof x=="number"&&x>=0);var M=x%26,v=(x-M)/26;if(o(this.negative===0,"imaskn works only with positive numbers"),this.length<=v)return this;if(M!==0&&v++,this.length=Math.min(v,this.length),M!==0){var p=67108863^67108863>>>M<<M;this.words[this.length-1]&=p}return this.strip()},t.prototype.maskn=function(x){return this.clone().imaskn(x)},t.prototype.iaddn=function(x){return o(typeof x=="number"),o(x<67108864),x<0?this.isubn(-x):this.negative!==0?this.length===1&&(0|this.words[0])<x?(this.words[0]=x-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(x),this.negative=1,this):this._iaddn(x)},t.prototype._iaddn=function(x){this.words[0]+=x;for(var M=0;M<this.length&&this.words[M]>=67108864;M++)this.words[M]-=67108864,M===this.length-1?this.words[M+1]=1:this.words[M+1]++;return this.length=Math.max(this.length,M+1),this},t.prototype.isubn=function(x){if(o(typeof x=="number"),o(x<67108864),x<0)return this.iaddn(-x);if(this.negative!==0)return this.negative=0,this.iaddn(x),this.negative=1,this;if(this.words[0]-=x,this.length===1&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var M=0;M<this.length&&this.words[M]<0;M++)this.words[M]+=67108864,this.words[M+1]-=1;return this.strip()},t.prototype.addn=function(x){return this.clone().iaddn(x)},t.prototype.subn=function(x){return this.clone().isubn(x)},t.prototype.iabs=function(){return this.negative=0,this},t.prototype.abs=function(){return this.clone().iabs()},t.prototype._ishlnsubmul=function(x,M,v){var p,b,g=x.length+v;this._expand(g);var y=0;for(p=0;p<x.length;p++){b=(0|this.words[p+v])+y;var k=(0|x.words[p])*M;y=((b-=67108863&k)>>26)-(k/67108864|0),this.words[p+v]=67108863&b}for(;p<this.length-v;p++)y=(b=(0|this.words[p+v])+y)>>26,this.words[p+v]=67108863&b;if(y===0)return this.strip();for(o(y===-1),y=0,p=0;p<this.length;p++)y=(b=-(0|this.words[p])+y)>>26,this.words[p]=67108863&b;return this.negative=1,this.strip()},t.prototype._wordDiv=function(x,M){var v=(this.length,x.length),p=this.clone(),b=x,g=0|b.words[b.length-1];(v=26-this._countBits(g))!==0&&(b=b.ushln(v),p.iushln(v),g=0|b.words[b.length-1]);var y,k=p.length-b.length;if(M!=="mod"){(y=new t(null)).length=k+1,y.words=new Array(y.length);for(var R=0;R<y.length;R++)y.words[R]=0}var O=p.clone()._ishlnsubmul(b,1,k);O.negative===0&&(p=O,y&&(y.words[k]=1));for(var z=k-1;z>=0;z--){var $=67108864*(0|p.words[b.length+z])+(0|p.words[b.length+z-1]);for($=Math.min($/g|0,67108863),p._ishlnsubmul(b,$,z);p.negative!==0;)$--,p.negative=0,p._ishlnsubmul(b,1,z),p.isZero()||(p.negative^=1);y&&(y.words[z]=$)}return y&&y.strip(),p.strip(),M!=="div"&&v!==0&&p.iushrn(v),{div:y||null,mod:p}},t.prototype.divmod=function(x,M,v){return o(!x.isZero()),this.isZero()?{div:new t(0),mod:new t(0)}:this.negative!==0&&x.negative===0?(g=this.neg().divmod(x,M),M!=="mod"&&(p=g.div.neg()),M!=="div"&&(b=g.mod.neg(),v&&b.negative!==0&&b.iadd(x)),{div:p,mod:b}):this.negative===0&&x.negative!==0?(g=this.divmod(x.neg(),M),M!=="mod"&&(p=g.div.neg()),{div:p,mod:g.mod}):this.negative&x.negative?(g=this.neg().divmod(x.neg(),M),M!=="div"&&(b=g.mod.neg(),v&&b.negative!==0&&b.isub(x)),{div:g.div,mod:b}):x.length>this.length||this.cmp(x)<0?{div:new t(0),mod:this}:x.length===1?M==="div"?{div:this.divn(x.words[0]),mod:null}:M==="mod"?{div:null,mod:new t(this.modn(x.words[0]))}:{div:this.divn(x.words[0]),mod:new t(this.modn(x.words[0]))}:this._wordDiv(x,M);var p,b,g},t.prototype.div=function(x){return this.divmod(x,"div",!1).div},t.prototype.mod=function(x){return this.divmod(x,"mod",!1).mod},t.prototype.umod=function(x){return this.divmod(x,"mod",!0).mod},t.prototype.divRound=function(x){var M=this.divmod(x);if(M.mod.isZero())return M.div;var v=M.div.negative!==0?M.mod.isub(x):M.mod,p=x.ushrn(1),b=x.andln(1),g=v.cmp(p);return g<0||b===1&&g===0?M.div:M.div.negative!==0?M.div.isubn(1):M.div.iaddn(1)},t.prototype.modn=function(x){o(x<=67108863);for(var M=(1<<26)%x,v=0,p=this.length-1;p>=0;p--)v=(M*v+(0|this.words[p]))%x;return v},t.prototype.idivn=function(x){o(x<=67108863);for(var M=0,v=this.length-1;v>=0;v--){var p=(0|this.words[v])+67108864*M;this.words[v]=p/x|0,M=p%x}return this.strip()},t.prototype.divn=function(x){return this.clone().idivn(x)},t.prototype.egcd=function(x){o(x.negative===0),o(!x.isZero());var M=this,v=x.clone();M=M.negative!==0?M.umod(x):M.clone();for(var p=new t(1),b=new t(0),g=new t(0),y=new t(1),k=0;M.isEven()&&v.isEven();)M.iushrn(1),v.iushrn(1),++k;for(var R=v.clone(),O=M.clone();!M.isZero();){for(var z=0,$=1;!(M.words[0]&$)&&z<26;++z,$<<=1);if(z>0)for(M.iushrn(z);z-- >0;)(p.isOdd()||b.isOdd())&&(p.iadd(R),b.isub(O)),p.iushrn(1),b.iushrn(1);for(var W=0,j=1;!(v.words[0]&j)&&W<26;++W,j<<=1);if(W>0)for(v.iushrn(W);W-- >0;)(g.isOdd()||y.isOdd())&&(g.iadd(R),y.isub(O)),g.iushrn(1),y.iushrn(1);M.cmp(v)>=0?(M.isub(v),p.isub(g),b.isub(y)):(v.isub(M),g.isub(p),y.isub(b))}return{a:g,b:y,gcd:v.iushln(k)}},t.prototype._invmp=function(x){o(x.negative===0),o(!x.isZero());var M=this,v=x.clone();M=M.negative!==0?M.umod(x):M.clone();for(var p,b=new t(1),g=new t(0),y=v.clone();M.cmpn(1)>0&&v.cmpn(1)>0;){for(var k=0,R=1;!(M.words[0]&R)&&k<26;++k,R<<=1);if(k>0)for(M.iushrn(k);k-- >0;)b.isOdd()&&b.iadd(y),b.iushrn(1);for(var O=0,z=1;!(v.words[0]&z)&&O<26;++O,z<<=1);if(O>0)for(v.iushrn(O);O-- >0;)g.isOdd()&&g.iadd(y),g.iushrn(1);M.cmp(v)>=0?(M.isub(v),b.isub(g)):(v.isub(M),g.isub(b))}return(p=M.cmpn(1)===0?b:g).cmpn(0)<0&&p.iadd(x),p},t.prototype.gcd=function(x){if(this.isZero())return x.abs();if(x.isZero())return this.abs();var M=this.clone(),v=x.clone();M.negative=0,v.negative=0;for(var p=0;M.isEven()&&v.isEven();p++)M.iushrn(1),v.iushrn(1);for(;;){for(;M.isEven();)M.iushrn(1);for(;v.isEven();)v.iushrn(1);var b=M.cmp(v);if(b<0){var g=M;M=v,v=g}else if(b===0||v.cmpn(1)===0)break;M.isub(v)}return v.iushln(p)},t.prototype.invm=function(x){return this.egcd(x).a.umod(x)},t.prototype.isEven=function(){return(1&this.words[0])==0},t.prototype.isOdd=function(){return(1&this.words[0])==1},t.prototype.andln=function(x){return this.words[0]&x},t.prototype.bincn=function(x){o(typeof x=="number");var M=x%26,v=(x-M)/26,p=1<<M;if(this.length<=v)return this._expand(v+1),this.words[v]|=p,this;for(var b=p,g=v;b!==0&&g<this.length;g++){var y=0|this.words[g];b=(y+=b)>>>26,y&=67108863,this.words[g]=y}return b!==0&&(this.words[g]=b,this.length++),this},t.prototype.isZero=function(){return this.length===1&&this.words[0]===0},t.prototype.cmpn=function(x){var M,v=x<0;if(this.negative!==0&&!v)return-1;if(this.negative===0&&v)return 1;if(this.strip(),this.length>1)M=1;else{v&&(x=-x),o(x<=67108863,"Number is too big");var p=0|this.words[0];M=p===x?0:p<x?-1:1}return this.negative!==0?0|-M:M},t.prototype.cmp=function(x){if(this.negative!==0&&x.negative===0)return-1;if(this.negative===0&&x.negative!==0)return 1;var M=this.ucmp(x);return this.negative!==0?0|-M:M},t.prototype.ucmp=function(x){if(this.length>x.length)return 1;if(this.length<x.length)return-1;for(var M=0,v=this.length-1;v>=0;v--){var p=0|this.words[v],b=0|x.words[v];if(p!==b){p<b?M=-1:p>b&&(M=1);break}}return M},t.prototype.gtn=function(x){return this.cmpn(x)===1},t.prototype.gt=function(x){return this.cmp(x)===1},t.prototype.gten=function(x){return this.cmpn(x)>=0},t.prototype.gte=function(x){return this.cmp(x)>=0},t.prototype.ltn=function(x){return this.cmpn(x)===-1},t.prototype.lt=function(x){return this.cmp(x)===-1},t.prototype.lten=function(x){return this.cmpn(x)<=0},t.prototype.lte=function(x){return this.cmp(x)<=0},t.prototype.eqn=function(x){return this.cmpn(x)===0},t.prototype.eq=function(x){return this.cmp(x)===0},t.red=function(x){return new U(x)},t.prototype.toRed=function(x){return o(!this.red,"Already a number in reduction context"),o(this.negative===0,"red works only with positives"),x.convertTo(this)._forceRed(x)},t.prototype.fromRed=function(){return o(this.red,"fromRed works only with numbers in reduction context"),this.red.convertFrom(this)},t.prototype._forceRed=function(x){return this.red=x,this},t.prototype.forceRed=function(x){return o(!this.red,"Already a number in reduction context"),this._forceRed(x)},t.prototype.redAdd=function(x){return o(this.red,"redAdd works only with red numbers"),this.red.add(this,x)},t.prototype.redIAdd=function(x){return o(this.red,"redIAdd works only with red numbers"),this.red.iadd(this,x)},t.prototype.redSub=function(x){return o(this.red,"redSub works only with red numbers"),this.red.sub(this,x)},t.prototype.redISub=function(x){return o(this.red,"redISub works only with red numbers"),this.red.isub(this,x)},t.prototype.redShl=function(x){return o(this.red,"redShl works only with red numbers"),this.red.shl(this,x)},t.prototype.redMul=function(x){return o(this.red,"redMul works only with red numbers"),this.red._verify2(this,x),this.red.mul(this,x)},t.prototype.redIMul=function(x){return o(this.red,"redMul works only with red numbers"),this.red._verify2(this,x),this.red.imul(this,x)},t.prototype.redSqr=function(){return o(this.red,"redSqr works only with red numbers"),this.red._verify1(this),this.red.sqr(this)},t.prototype.redISqr=function(){return o(this.red,"redISqr works only with red numbers"),this.red._verify1(this),this.red.isqr(this)},t.prototype.redSqrt=function(){return o(this.red,"redSqrt works only with red numbers"),this.red._verify1(this),this.red.sqrt(this)},t.prototype.redInvm=function(){return o(this.red,"redInvm works only with red numbers"),this.red._verify1(this),this.red.invm(this)},t.prototype.redNeg=function(){return o(this.red,"redNeg works only with red numbers"),this.red._verify1(this),this.red.neg(this)},t.prototype.redPow=function(x){return o(this.red&&!x.red,"redPow(normalNum)"),this.red._verify1(this),this.red.pow(this,x)};var A={k256:null,p224:null,p192:null,p25519:null};function N(x,M){this.name=x,this.p=new t(M,16),this.n=this.p.bitLength(),this.k=new t(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function L(){N.call(this,"k256","ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f")}function I(){N.call(this,"p224","ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001")}function P(){N.call(this,"p192","ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff")}function B(){N.call(this,"25519","7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed")}function U(x){if(typeof x=="string"){var M=t._prime(x);this.m=M.p,this.prime=M}else o(x.gtn(1),"modulus must be greater than 1"),this.m=x,this.prime=null}function D(x){U.call(this,x),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new t(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}N.prototype._tmp=function(){var x=new t(null);return x.words=new Array(Math.ceil(this.n/13)),x},N.prototype.ireduce=function(x){var M,v=x;do this.split(v,this.tmp),M=(v=(v=this.imulK(v)).iadd(this.tmp)).bitLength();while(M>this.n);var p=M<this.n?-1:v.ucmp(this.p);return p===0?(v.words[0]=0,v.length=1):p>0?v.isub(this.p):v.strip!==void 0?v.strip():v._strip(),v},N.prototype.split=function(x,M){x.iushrn(this.n,0,M)},N.prototype.imulK=function(x){return x.imul(this.k)},r(L,N),L.prototype.split=function(x,M){for(var v=Math.min(x.length,9),p=0;p<v;p++)M.words[p]=x.words[p];if(M.length=v,x.length<=9)return x.words[0]=0,void(x.length=1);var b=x.words[9];for(M.words[M.length++]=4194303&b,p=10;p<x.length;p++){var g=0|x.words[p];x.words[p-10]=(4194303&g)<<4|b>>>22,b=g}b>>>=22,x.words[p-10]=b,b===0&&x.length>10?x.length-=10:x.length-=9},L.prototype.imulK=function(x){x.words[x.length]=0,x.words[x.length+1]=0,x.length+=2;for(var M=0,v=0;v<x.length;v++){var p=0|x.words[v];M+=977*p,x.words[v]=67108863&M,M=64*p+(M/67108864|0)}return x.words[x.length-1]===0&&(x.length--,x.words[x.length-1]===0&&x.length--),x},r(I,N),r(P,N),r(B,N),B.prototype.imulK=function(x){for(var M=0,v=0;v<x.length;v++){var p=19*(0|x.words[v])+M,b=67108863&p;p>>>=26,x.words[v]=b,M=p}return M!==0&&(x.words[x.length++]=M),x},t._prime=function(x){if(A[x])return A[x];var M;if(x==="k256")M=new L;else if(x==="p224")M=new I;else if(x==="p192")M=new P;else{if(x!=="p25519")throw new Error("Unknown prime "+x);M=new B}return A[x]=M,M},U.prototype._verify1=function(x){o(x.negative===0,"red works only with positives"),o(x.red,"red works only with red numbers")},U.prototype._verify2=function(x,M){o((x.negative|M.negative)==0,"red works only with positives"),o(x.red&&x.red===M.red,"red works only with red numbers")},U.prototype.imod=function(x){return this.prime?this.prime.ireduce(x)._forceRed(this):x.umod(this.m)._forceRed(this)},U.prototype.neg=function(x){return x.isZero()?x.clone():this.m.sub(x)._forceRed(this)},U.prototype.add=function(x,M){this._verify2(x,M);var v=x.add(M);return v.cmp(this.m)>=0&&v.isub(this.m),v._forceRed(this)},U.prototype.iadd=function(x,M){this._verify2(x,M);var v=x.iadd(M);return v.cmp(this.m)>=0&&v.isub(this.m),v},U.prototype.sub=function(x,M){this._verify2(x,M);var v=x.sub(M);return v.cmpn(0)<0&&v.iadd(this.m),v._forceRed(this)},U.prototype.isub=function(x,M){this._verify2(x,M);var v=x.isub(M);return v.cmpn(0)<0&&v.iadd(this.m),v},U.prototype.shl=function(x,M){return this._verify1(x),this.imod(x.ushln(M))},U.prototype.imul=function(x,M){return this._verify2(x,M),this.imod(x.imul(M))},U.prototype.mul=function(x,M){return this._verify2(x,M),this.imod(x.mul(M))},U.prototype.isqr=function(x){return this.imul(x,x.clone())},U.prototype.sqr=function(x){return this.mul(x,x)},U.prototype.sqrt=function(x){if(x.isZero())return x.clone();var M=this.m.andln(3);if(o(M%2==1),M===3){var v=this.m.add(new t(1)).iushrn(2);return this.pow(x,v)}for(var p=this.m.subn(1),b=0;!p.isZero()&&p.andln(1)===0;)b++,p.iushrn(1);o(!p.isZero());var g=new t(1).toRed(this),y=g.redNeg(),k=this.m.subn(1).iushrn(1),R=this.m.bitLength();for(R=new t(2*R*R).toRed(this);this.pow(R,k).cmp(y)!==0;)R.redIAdd(y);for(var O=this.pow(R,p),z=this.pow(x,p.addn(1).iushrn(1)),$=this.pow(x,p),W=b;$.cmp(g)!==0;){for(var j=$,H=0;j.cmp(g)!==0;H++)j=j.redSqr();o(H<W);var E=this.pow(O,new t(1).iushln(W-H-1));z=z.redMul(E),O=E.redSqr(),$=$.redMul(O),W=H}return z},U.prototype.invm=function(x){var M=x._invmp(this.m);return M.negative!==0?(M.negative=0,this.imod(M).redNeg()):this.imod(M)},U.prototype.pow=function(x,M){if(M.isZero())return new t(1).toRed(this);if(M.cmpn(1)===0)return x.clone();var v=new Array(16);v[0]=new t(1).toRed(this),v[1]=x;for(var p=2;p<v.length;p++)v[p]=this.mul(v[p-1],x);var b=v[0],g=0,y=0,k=M.bitLength()%26;for(k===0&&(k=26),p=M.length-1;p>=0;p--){for(var R=M.words[p],O=k-1;O>=0;O--){var z=R>>O&1;b!==v[0]&&(b=this.sqr(b)),z!==0||g!==0?(g<<=1,g|=z,(++y===4||p===0&&O===0)&&(b=this.mul(b,v[g]),y=0,g=0)):y=0}k=26}return b},U.prototype.convertTo=function(x){var M=x.umod(this.m);return M===x?M.clone():M},U.prototype.convertFrom=function(x){var M=x.clone();return M.red=null,M},t.mont=function(x){return new D(x)},r(D,U),D.prototype.convertTo=function(x){return this.imod(x.ushln(this.shift))},D.prototype.convertFrom=function(x){var M=this.imod(x.mul(this.rinv));return M.red=null,M},D.prototype.imul=function(x,M){if(x.isZero()||M.isZero())return x.words[0]=0,x.length=1,x;var v=x.imul(M),p=v.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),b=v.isub(p).iushrn(this.shift),g=b;return b.cmp(this.m)>=0?g=b.isub(this.m):b.cmpn(0)<0&&(g=b.iadd(this.m)),g._forceRed(this)},D.prototype.mul=function(x,M){if(x.isZero()||M.isZero())return new t(0)._forceRed(this);var v=x.mul(M),p=v.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),b=v.isub(p).iushrn(this.shift),g=b;return b.cmp(this.m)>=0?g=b.isub(this.m):b.cmpn(0)<0&&(g=b.iadd(this.m)),g._forceRed(this)},D.prototype.invm=function(x){return this.imod(x._invmp(this.m).mul(this.r2))._forceRed(this)}})(T===void 0||T)},{buffer:188}],185:[function(s,T,S){S.byteLength=function(i){var f=l(i),c=f[0],u=f[1];return 3*(c+u)/4-u},S.toByteArray=function(i){var f,c,u=l(i),d=u[0],h=u[1],w=new o(function(N,L,I){return 3*(L+I)/4-I}(0,d,h)),_=0,A=h>0?d-4:d;for(c=0;c<A;c+=4)f=a[i.charCodeAt(c)]<<18|a[i.charCodeAt(c+1)]<<12|a[i.charCodeAt(c+2)]<<6|a[i.charCodeAt(c+3)],w[_++]=f>>16&255,w[_++]=f>>8&255,w[_++]=255&f;return h===2&&(f=a[i.charCodeAt(c)]<<2|a[i.charCodeAt(c+1)]>>4,w[_++]=255&f),h===1&&(f=a[i.charCodeAt(c)]<<10|a[i.charCodeAt(c+1)]<<4|a[i.charCodeAt(c+2)]>>2,w[_++]=f>>8&255,w[_++]=255&f),w},S.fromByteArray=function(i){for(var f,c=i.length,u=c%3,d=[],h=0,w=c-u;h<w;h+=16383)d.push(n(i,h,h+16383>w?w:h+16383));return u===1?(f=i[c-1],d.push(m[f>>2]+m[f<<4&63]+"==")):u===2&&(f=(i[c-2]<<8)+i[c-1],d.push(m[f>>10]+m[f>>4&63]+m[f<<2&63]+"=")),d.join("")};for(var m=[],a=[],o=typeof Uint8Array<"u"?Uint8Array:Array,r="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t=0,e=r.length;t<e;++t)m[t]=r[t],a[r.charCodeAt(t)]=t;function l(i){var f=i.length;if(f%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var c=i.indexOf("=");return c===-1&&(c=f),[c,c===f?0:4-c%4]}function n(i,f,c){for(var u,d,h=[],w=f;w<c;w+=3)u=(i[w]<<16&16711680)+(i[w+1]<<8&65280)+(255&i[w+2]),h.push(m[(d=u)>>18&63]+m[d>>12&63]+m[d>>6&63]+m[63&d]);return h.join("")}a[45]=62,a[95]=63},{}],186:[function(s,T,S){(function(m,a){function o(v,p){if(!v)throw new Error(p||"Assertion failed")}function r(v,p){v.super_=p;var b=function(){};b.prototype=p.prototype,v.prototype=new b,v.prototype.constructor=v}function t(v,p,b){if(t.isBN(v))return v;this.negative=0,this.words=null,this.length=0,this.red=null,v!==null&&(p!=="le"&&p!=="be"||(b=p,p=10),this._init(v||0,p||10,b||"be"))}var e;typeof m=="object"?m.exports=t:(void 0).BN=t,t.BN=t,t.wordSize=26;try{e=typeof window<"u"&&window.Buffer!==void 0?window.Buffer:s("buffer").Buffer}catch{}function l(v,p){var b=v.charCodeAt(p);return b>=48&&b<=57?b-48:b>=65&&b<=70?b-55:b>=97&&b<=102?b-87:void o(!1,"Invalid character in "+v)}function n(v,p,b){var g=l(v,b);return b-1>=p&&(g|=l(v,b-1)<<4),g}function i(v,p,b,g){for(var y=0,k=0,R=Math.min(v.length,b),O=p;O<R;O++){var z=v.charCodeAt(O)-48;y*=g,k=z>=49?z-49+10:z>=17?z-17+10:z,o(z>=0&&k<g,"Invalid character"),y+=k}return y}function f(v,p){v.words=p.words,v.length=p.length,v.negative=p.negative,v.red=p.red}if(t.isBN=function(v){return v instanceof t||v!==null&&typeof v=="object"&&v.constructor.wordSize===t.wordSize&&Array.isArray(v.words)},t.max=function(v,p){return v.cmp(p)>0?v:p},t.min=function(v,p){return v.cmp(p)<0?v:p},t.prototype._init=function(v,p,b){if(typeof v=="number")return this._initNumber(v,p,b);if(typeof v=="object")return this._initArray(v,p,b);p==="hex"&&(p=16),o(p===(0|p)&&p>=2&&p<=36);var g=0;(v=v.toString().replace(/\s+/g,""))[0]==="-"&&(g++,this.negative=1),g<v.length&&(p===16?this._parseHex(v,g,b):(this._parseBase(v,p,g),b==="le"&&this._initArray(this.toArray(),p,b)))},t.prototype._initNumber=function(v,p,b){v<0&&(this.negative=1,v=-v),v<67108864?(this.words=[67108863&v],this.length=1):v<4503599627370496?(this.words=[67108863&v,v/67108864&67108863],this.length=2):(o(v<9007199254740992),this.words=[67108863&v,v/67108864&67108863,1],this.length=3),b==="le"&&this._initArray(this.toArray(),p,b)},t.prototype._initArray=function(v,p,b){if(o(typeof v.length=="number"),v.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(v.length/3),this.words=new Array(this.length);for(var g=0;g<this.length;g++)this.words[g]=0;var y,k,R=0;if(b==="be")for(g=v.length-1,y=0;g>=0;g-=3)k=v[g]|v[g-1]<<8|v[g-2]<<16,this.words[y]|=k<<R&67108863,this.words[y+1]=k>>>26-R&67108863,(R+=24)>=26&&(R-=26,y++);else if(b==="le")for(g=0,y=0;g<v.length;g+=3)k=v[g]|v[g+1]<<8|v[g+2]<<16,this.words[y]|=k<<R&67108863,this.words[y+1]=k>>>26-R&67108863,(R+=24)>=26&&(R-=26,y++);return this._strip()},t.prototype._parseHex=function(v,p,b){this.length=Math.ceil((v.length-p)/6),this.words=new Array(this.length);for(var g=0;g<this.length;g++)this.words[g]=0;var y,k=0,R=0;if(b==="be")for(g=v.length-1;g>=p;g-=2)y=n(v,p,g)<<k,this.words[R]|=67108863&y,k>=18?(k-=18,R+=1,this.words[R]|=y>>>26):k+=8;else for(g=(v.length-p)%2==0?p+1:p;g<v.length;g+=2)y=n(v,p,g)<<k,this.words[R]|=67108863&y,k>=18?(k-=18,R+=1,this.words[R]|=y>>>26):k+=8;this._strip()},t.prototype._parseBase=function(v,p,b){this.words=[0],this.length=1;for(var g=0,y=1;y<=67108863;y*=p)g++;g--,y=y/p|0;for(var k=v.length-b,R=k%g,O=Math.min(k,k-R)+b,z=0,$=b;$<O;$+=g)z=i(v,$,$+g,p),this.imuln(y),this.words[0]+z<67108864?this.words[0]+=z:this._iaddn(z);if(R!==0){var W=1;for(z=i(v,$,v.length,p),$=0;$<R;$++)W*=p;this.imuln(W),this.words[0]+z<67108864?this.words[0]+=z:this._iaddn(z)}this._strip()},t.prototype.copy=function(v){v.words=new Array(this.length);for(var p=0;p<this.length;p++)v.words[p]=this.words[p];v.length=this.length,v.negative=this.negative,v.red=this.red},t.prototype._move=function(v){f(v,this)},t.prototype.clone=function(){var v=new t(null);return this.copy(v),v},t.prototype._expand=function(v){for(;this.length<v;)this.words[this.length++]=0;return this},t.prototype._strip=function(){for(;this.length>1&&this.words[this.length-1]===0;)this.length--;return this._normSign()},t.prototype._normSign=function(){return this.length===1&&this.words[0]===0&&(this.negative=0),this},typeof Symbol<"u"&&typeof Symbol.for=="function")try{t.prototype[Symbol.for("nodejs.util.inspect.custom")]=c}catch{t.prototype.inspect=c}else t.prototype.inspect=c;function c(){return(this.red?"<BN-R: ":"<BN: ")+this.toString(16)+">"}var u=["","0","00","000","0000","00000","000000","0000000","00000000","000000000","0000000000","00000000000","000000000000","0000000000000","00000000000000","000000000000000","0000000000000000","00000000000000000","000000000000000000","0000000000000000000","00000000000000000000","000000000000000000000","0000000000000000000000","00000000000000000000000","000000000000000000000000","0000000000000000000000000"],d=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];t.prototype.toString=function(v,p){var b;if(p=0|p||1,(v=v||10)===16||v==="hex"){b="";for(var g=0,y=0,k=0;k<this.length;k++){var R=this.words[k],O=(16777215&(R<<g|y)).toString(16);y=R>>>24-g&16777215,(g+=2)>=26&&(g-=26,k--),b=y!==0||k!==this.length-1?u[6-O.length]+O+b:O+b}for(y!==0&&(b=y.toString(16)+b);b.length%p!=0;)b="0"+b;return this.negative!==0&&(b="-"+b),b}if(v===(0|v)&&v>=2&&v<=36){var z=d[v],$=h[v];b="";var W=this.clone();for(W.negative=0;!W.isZero();){var j=W.modrn($).toString(v);b=(W=W.idivn($)).isZero()?j+b:u[z-j.length]+j+b}for(this.isZero()&&(b="0"+b);b.length%p!=0;)b="0"+b;return this.negative!==0&&(b="-"+b),b}o(!1,"Base should be between 2 and 36")},t.prototype.toNumber=function(){var v=this.words[0];return this.length===2?v+=67108864*this.words[1]:this.length===3&&this.words[2]===1?v+=4503599627370496+67108864*this.words[1]:this.length>2&&o(!1,"Number can only safely store up to 53 bits"),this.negative!==0?-v:v},t.prototype.toJSON=function(){return this.toString(16,2)},e&&(t.prototype.toBuffer=function(v,p){return this.toArrayLike(e,v,p)}),t.prototype.toArray=function(v,p){return this.toArrayLike(Array,v,p)};function w(v,p,b){b.negative=p.negative^v.negative;var g=v.length+p.length|0;b.length=g,g=g-1|0;var y=0|v.words[0],k=0|p.words[0],R=y*k,O=67108863&R,z=R/67108864|0;b.words[0]=O;for(var $=1;$<g;$++){for(var W=z>>>26,j=67108863&z,H=Math.min($,p.length-1),E=Math.max(0,$-v.length+1);E<=H;E++){var C=$-E|0;W+=(R=(y=0|v.words[C])*(k=0|p.words[E])+j)/67108864|0,j=67108863&R}b.words[$]=0|j,z=0|W}return z!==0?b.words[$]=0|z:b.length--,b._strip()}t.prototype.toArrayLike=function(v,p,b){this._strip();var g=this.byteLength(),y=b||Math.max(1,g);o(g<=y,"byte array longer than desired length"),o(y>0,"Requested array length <= 0");var k=function(R,O){return R.allocUnsafe?R.allocUnsafe(O):new R(O)}(v,y);return this["_toArrayLike"+(p==="le"?"LE":"BE")](k,g),k},t.prototype._toArrayLikeLE=function(v,p){for(var b=0,g=0,y=0,k=0;y<this.length;y++){var R=this.words[y]<<k|g;v[b++]=255&R,b<v.length&&(v[b++]=R>>8&255),b<v.length&&(v[b++]=R>>16&255),k===6?(b<v.length&&(v[b++]=R>>24&255),g=0,k=0):(g=R>>>24,k+=2)}if(b<v.length)for(v[b++]=g;b<v.length;)v[b++]=0},t.prototype._toArrayLikeBE=function(v,p){for(var b=v.length-1,g=0,y=0,k=0;y<this.length;y++){var R=this.words[y]<<k|g;v[b--]=255&R,b>=0&&(v[b--]=R>>8&255),b>=0&&(v[b--]=R>>16&255),k===6?(b>=0&&(v[b--]=R>>24&255),g=0,k=0):(g=R>>>24,k+=2)}if(b>=0)for(v[b--]=g;b>=0;)v[b--]=0},Math.clz32?t.prototype._countBits=function(v){return 32-Math.clz32(v)}:t.prototype._countBits=function(v){var p=v,b=0;return p>=4096&&(b+=13,p>>>=13),p>=64&&(b+=7,p>>>=7),p>=8&&(b+=4,p>>>=4),p>=2&&(b+=2,p>>>=2),b+p},t.prototype._zeroBits=function(v){if(v===0)return 26;var p=v,b=0;return!(8191&p)&&(b+=13,p>>>=13),!(127&p)&&(b+=7,p>>>=7),!(15&p)&&(b+=4,p>>>=4),!(3&p)&&(b+=2,p>>>=2),!(1&p)&&b++,b},t.prototype.bitLength=function(){var v=this.words[this.length-1],p=this._countBits(v);return 26*(this.length-1)+p},t.prototype.zeroBits=function(){if(this.isZero())return 0;for(var v=0,p=0;p<this.length;p++){var b=this._zeroBits(this.words[p]);if(v+=b,b!==26)break}return v},t.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},t.prototype.toTwos=function(v){return this.negative!==0?this.abs().inotn(v).iaddn(1):this.clone()},t.prototype.fromTwos=function(v){return this.testn(v-1)?this.notn(v).iaddn(1).ineg():this.clone()},t.prototype.isNeg=function(){return this.negative!==0},t.prototype.neg=function(){return this.clone().ineg()},t.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},t.prototype.iuor=function(v){for(;this.length<v.length;)this.words[this.length++]=0;for(var p=0;p<v.length;p++)this.words[p]=this.words[p]|v.words[p];return this._strip()},t.prototype.ior=function(v){return o((this.negative|v.negative)==0),this.iuor(v)},t.prototype.or=function(v){return this.length>v.length?this.clone().ior(v):v.clone().ior(this)},t.prototype.uor=function(v){return this.length>v.length?this.clone().iuor(v):v.clone().iuor(this)},t.prototype.iuand=function(v){var p;p=this.length>v.length?v:this;for(var b=0;b<p.length;b++)this.words[b]=this.words[b]&v.words[b];return this.length=p.length,this._strip()},t.prototype.iand=function(v){return o((this.negative|v.negative)==0),this.iuand(v)},t.prototype.and=function(v){return this.length>v.length?this.clone().iand(v):v.clone().iand(this)},t.prototype.uand=function(v){return this.length>v.length?this.clone().iuand(v):v.clone().iuand(this)},t.prototype.iuxor=function(v){var p,b;this.length>v.length?(p=this,b=v):(p=v,b=this);for(var g=0;g<b.length;g++)this.words[g]=p.words[g]^b.words[g];if(this!==p)for(;g<p.length;g++)this.words[g]=p.words[g];return this.length=p.length,this._strip()},t.prototype.ixor=function(v){return o((this.negative|v.negative)==0),this.iuxor(v)},t.prototype.xor=function(v){return this.length>v.length?this.clone().ixor(v):v.clone().ixor(this)},t.prototype.uxor=function(v){return this.length>v.length?this.clone().iuxor(v):v.clone().iuxor(this)},t.prototype.inotn=function(v){o(typeof v=="number"&&v>=0);var p=0|Math.ceil(v/26),b=v%26;this._expand(p),b>0&&p--;for(var g=0;g<p;g++)this.words[g]=67108863&~this.words[g];return b>0&&(this.words[g]=~this.words[g]&67108863>>26-b),this._strip()},t.prototype.notn=function(v){return this.clone().inotn(v)},t.prototype.setn=function(v,p){o(typeof v=="number"&&v>=0);var b=v/26|0,g=v%26;return this._expand(b+1),this.words[b]=p?this.words[b]|1<<g:this.words[b]&~(1<<g),this._strip()},t.prototype.iadd=function(v){var p,b,g;if(this.negative!==0&&v.negative===0)return this.negative=0,p=this.isub(v),this.negative^=1,this._normSign();if(this.negative===0&&v.negative!==0)return v.negative=0,p=this.isub(v),v.negative=1,p._normSign();this.length>v.length?(b=this,g=v):(b=v,g=this);for(var y=0,k=0;k<g.length;k++)p=(0|b.words[k])+(0|g.words[k])+y,this.words[k]=67108863&p,y=p>>>26;for(;y!==0&&k<b.length;k++)p=(0|b.words[k])+y,this.words[k]=67108863&p,y=p>>>26;if(this.length=b.length,y!==0)this.words[this.length]=y,this.length++;else if(b!==this)for(;k<b.length;k++)this.words[k]=b.words[k];return this},t.prototype.add=function(v){var p;return v.negative!==0&&this.negative===0?(v.negative=0,p=this.sub(v),v.negative^=1,p):v.negative===0&&this.negative!==0?(this.negative=0,p=v.sub(this),this.negative=1,p):this.length>v.length?this.clone().iadd(v):v.clone().iadd(this)},t.prototype.isub=function(v){if(v.negative!==0){v.negative=0;var p=this.iadd(v);return v.negative=1,p._normSign()}if(this.negative!==0)return this.negative=0,this.iadd(v),this.negative=1,this._normSign();var b,g,y=this.cmp(v);if(y===0)return this.negative=0,this.length=1,this.words[0]=0,this;y>0?(b=this,g=v):(b=v,g=this);for(var k=0,R=0;R<g.length;R++)k=(p=(0|b.words[R])-(0|g.words[R])+k)>>26,this.words[R]=67108863&p;for(;k!==0&&R<b.length;R++)k=(p=(0|b.words[R])+k)>>26,this.words[R]=67108863&p;if(k===0&&R<b.length&&b!==this)for(;R<b.length;R++)this.words[R]=b.words[R];return this.length=Math.max(this.length,R),b!==this&&(this.negative=1),this._strip()},t.prototype.sub=function(v){return this.clone().isub(v)};var _=function(v,p,b){var g,y,k,R=v.words,O=p.words,z=b.words,$=0,W=0|R[0],j=8191&W,H=W>>>13,E=0|R[1],C=8191&E,F=E>>>13,V=0|R[2],Z=8191&V,q=V>>>13,K=0|R[3],et=8191&K,tt=K>>>13,X=0|R[4],J=8191&X,G=X>>>13,nt=0|R[5],rt=8191&nt,st=nt>>>13,ot=0|R[6],lt=8191&ot,ct=ot>>>13,wt=0|R[7],vt=8191&wt,mt=wt>>>13,Rt=0|R[8],Et=8191&Rt,At=Rt>>>13,jt=0|R[9],_t=8191&jt,dt=jt>>>13,xt=0|O[0],Tt=8191&xt,St=xt>>>13,Kt=0|O[1],re=8191&Kt,It=Kt>>>13,Qt=0|O[2],Xt=8191&Qt,Ut=Qt>>>13,ue=0|O[3],te=8191&ue,Dt=ue>>>13,Gt=0|O[4],ae=8191&Gt,Ft=Gt>>>13,ee=0|O[5],oe=8191&ee,Ht=ee>>>13,Q=0|O[6],it=8191&Q,ut=Q>>>13,bt=0|O[7],Nt=8191&bt,yt=bt>>>13,Lt=0|O[8],Pt=8191&Lt,Ot=Lt>>>13,$t=0|O[9],zt=8191&$t,qt=$t>>>13;b.negative=v.negative^p.negative,b.length=19;var he=($+(g=Math.imul(j,Tt))|0)+((8191&(y=(y=Math.imul(j,St))+Math.imul(H,Tt)|0))<<13)|0;$=((k=Math.imul(H,St))+(y>>>13)|0)+(he>>>26)|0,he&=67108863,g=Math.imul(C,Tt),y=(y=Math.imul(C,St))+Math.imul(F,Tt)|0,k=Math.imul(F,St);var fe=($+(g=g+Math.imul(j,re)|0)|0)+((8191&(y=(y=y+Math.imul(j,It)|0)+Math.imul(H,re)|0))<<13)|0;$=((k=k+Math.imul(H,It)|0)+(y>>>13)|0)+(fe>>>26)|0,fe&=67108863,g=Math.imul(Z,Tt),y=(y=Math.imul(Z,St))+Math.imul(q,Tt)|0,k=Math.imul(q,St),g=g+Math.imul(C,re)|0,y=(y=y+Math.imul(C,It)|0)+Math.imul(F,re)|0,k=k+Math.imul(F,It)|0;var de=($+(g=g+Math.imul(j,Xt)|0)|0)+((8191&(y=(y=y+Math.imul(j,Ut)|0)+Math.imul(H,Xt)|0))<<13)|0;$=((k=k+Math.imul(H,Ut)|0)+(y>>>13)|0)+(de>>>26)|0,de&=67108863,g=Math.imul(et,Tt),y=(y=Math.imul(et,St))+Math.imul(tt,Tt)|0,k=Math.imul(tt,St),g=g+Math.imul(Z,re)|0,y=(y=y+Math.imul(Z,It)|0)+Math.imul(q,re)|0,k=k+Math.imul(q,It)|0,g=g+Math.imul(C,Xt)|0,y=(y=y+Math.imul(C,Ut)|0)+Math.imul(F,Xt)|0,k=k+Math.imul(F,Ut)|0;var pe=($+(g=g+Math.imul(j,te)|0)|0)+((8191&(y=(y=y+Math.imul(j,Dt)|0)+Math.imul(H,te)|0))<<13)|0;$=((k=k+Math.imul(H,Dt)|0)+(y>>>13)|0)+(pe>>>26)|0,pe&=67108863,g=Math.imul(J,Tt),y=(y=Math.imul(J,St))+Math.imul(G,Tt)|0,k=Math.imul(G,St),g=g+Math.imul(et,re)|0,y=(y=y+Math.imul(et,It)|0)+Math.imul(tt,re)|0,k=k+Math.imul(tt,It)|0,g=g+Math.imul(Z,Xt)|0,y=(y=y+Math.imul(Z,Ut)|0)+Math.imul(q,Xt)|0,k=k+Math.imul(q,Ut)|0,g=g+Math.imul(C,te)|0,y=(y=y+Math.imul(C,Dt)|0)+Math.imul(F,te)|0,k=k+Math.imul(F,Dt)|0;var ge=($+(g=g+Math.imul(j,ae)|0)|0)+((8191&(y=(y=y+Math.imul(j,Ft)|0)+Math.imul(H,ae)|0))<<13)|0;$=((k=k+Math.imul(H,Ft)|0)+(y>>>13)|0)+(ge>>>26)|0,ge&=67108863,g=Math.imul(rt,Tt),y=(y=Math.imul(rt,St))+Math.imul(st,Tt)|0,k=Math.imul(st,St),g=g+Math.imul(J,re)|0,y=(y=y+Math.imul(J,It)|0)+Math.imul(G,re)|0,k=k+Math.imul(G,It)|0,g=g+Math.imul(et,Xt)|0,y=(y=y+Math.imul(et,Ut)|0)+Math.imul(tt,Xt)|0,k=k+Math.imul(tt,Ut)|0,g=g+Math.imul(Z,te)|0,y=(y=y+Math.imul(Z,Dt)|0)+Math.imul(q,te)|0,k=k+Math.imul(q,Dt)|0,g=g+Math.imul(C,ae)|0,y=(y=y+Math.imul(C,Ft)|0)+Math.imul(F,ae)|0,k=k+Math.imul(F,Ft)|0;var Y=($+(g=g+Math.imul(j,oe)|0)|0)+((8191&(y=(y=y+Math.imul(j,Ht)|0)+Math.imul(H,oe)|0))<<13)|0;$=((k=k+Math.imul(H,Ht)|0)+(y>>>13)|0)+(Y>>>26)|0,Y&=67108863,g=Math.imul(lt,Tt),y=(y=Math.imul(lt,St))+Math.imul(ct,Tt)|0,k=Math.imul(ct,St),g=g+Math.imul(rt,re)|0,y=(y=y+Math.imul(rt,It)|0)+Math.imul(st,re)|0,k=k+Math.imul(st,It)|0,g=g+Math.imul(J,Xt)|0,y=(y=y+Math.imul(J,Ut)|0)+Math.imul(G,Xt)|0,k=k+Math.imul(G,Ut)|0,g=g+Math.imul(et,te)|0,y=(y=y+Math.imul(et,Dt)|0)+Math.imul(tt,te)|0,k=k+Math.imul(tt,Dt)|0,g=g+Math.imul(Z,ae)|0,y=(y=y+Math.imul(Z,Ft)|0)+Math.imul(q,ae)|0,k=k+Math.imul(q,Ft)|0,g=g+Math.imul(C,oe)|0,y=(y=y+Math.imul(C,Ht)|0)+Math.imul(F,oe)|0,k=k+Math.imul(F,Ht)|0;var at=($+(g=g+Math.imul(j,it)|0)|0)+((8191&(y=(y=y+Math.imul(j,ut)|0)+Math.imul(H,it)|0))<<13)|0;$=((k=k+Math.imul(H,ut)|0)+(y>>>13)|0)+(at>>>26)|0,at&=67108863,g=Math.imul(vt,Tt),y=(y=Math.imul(vt,St))+Math.imul(mt,Tt)|0,k=Math.imul(mt,St),g=g+Math.imul(lt,re)|0,y=(y=y+Math.imul(lt,It)|0)+Math.imul(ct,re)|0,k=k+Math.imul(ct,It)|0,g=g+Math.imul(rt,Xt)|0,y=(y=y+Math.imul(rt,Ut)|0)+Math.imul(st,Xt)|0,k=k+Math.imul(st,Ut)|0,g=g+Math.imul(J,te)|0,y=(y=y+Math.imul(J,Dt)|0)+Math.imul(G,te)|0,k=k+Math.imul(G,Dt)|0,g=g+Math.imul(et,ae)|0,y=(y=y+Math.imul(et,Ft)|0)+Math.imul(tt,ae)|0,k=k+Math.imul(tt,Ft)|0,g=g+Math.imul(Z,oe)|0,y=(y=y+Math.imul(Z,Ht)|0)+Math.imul(q,oe)|0,k=k+Math.imul(q,Ht)|0,g=g+Math.imul(C,it)|0,y=(y=y+Math.imul(C,ut)|0)+Math.imul(F,it)|0,k=k+Math.imul(F,ut)|0;var ft=($+(g=g+Math.imul(j,Nt)|0)|0)+((8191&(y=(y=y+Math.imul(j,yt)|0)+Math.imul(H,Nt)|0))<<13)|0;$=((k=k+Math.imul(H,yt)|0)+(y>>>13)|0)+(ft>>>26)|0,ft&=67108863,g=Math.imul(Et,Tt),y=(y=Math.imul(Et,St))+Math.imul(At,Tt)|0,k=Math.imul(At,St),g=g+Math.imul(vt,re)|0,y=(y=y+Math.imul(vt,It)|0)+Math.imul(mt,re)|0,k=k+Math.imul(mt,It)|0,g=g+Math.imul(lt,Xt)|0,y=(y=y+Math.imul(lt,Ut)|0)+Math.imul(ct,Xt)|0,k=k+Math.imul(ct,Ut)|0,g=g+Math.imul(rt,te)|0,y=(y=y+Math.imul(rt,Dt)|0)+Math.imul(st,te)|0,k=k+Math.imul(st,Dt)|0,g=g+Math.imul(J,ae)|0,y=(y=y+Math.imul(J,Ft)|0)+Math.imul(G,ae)|0,k=k+Math.imul(G,Ft)|0,g=g+Math.imul(et,oe)|0,y=(y=y+Math.imul(et,Ht)|0)+Math.imul(tt,oe)|0,k=k+Math.imul(tt,Ht)|0,g=g+Math.imul(Z,it)|0,y=(y=y+Math.imul(Z,ut)|0)+Math.imul(q,it)|0,k=k+Math.imul(q,ut)|0,g=g+Math.imul(C,Nt)|0,y=(y=y+Math.imul(C,yt)|0)+Math.imul(F,Nt)|0,k=k+Math.imul(F,yt)|0;var ht=($+(g=g+Math.imul(j,Pt)|0)|0)+((8191&(y=(y=y+Math.imul(j,Ot)|0)+Math.imul(H,Pt)|0))<<13)|0;$=((k=k+Math.imul(H,Ot)|0)+(y>>>13)|0)+(ht>>>26)|0,ht&=67108863,g=Math.imul(_t,Tt),y=(y=Math.imul(_t,St))+Math.imul(dt,Tt)|0,k=Math.imul(dt,St),g=g+Math.imul(Et,re)|0,y=(y=y+Math.imul(Et,It)|0)+Math.imul(At,re)|0,k=k+Math.imul(At,It)|0,g=g+Math.imul(vt,Xt)|0,y=(y=y+Math.imul(vt,Ut)|0)+Math.imul(mt,Xt)|0,k=k+Math.imul(mt,Ut)|0,g=g+Math.imul(lt,te)|0,y=(y=y+Math.imul(lt,Dt)|0)+Math.imul(ct,te)|0,k=k+Math.imul(ct,Dt)|0,g=g+Math.imul(rt,ae)|0,y=(y=y+Math.imul(rt,Ft)|0)+Math.imul(st,ae)|0,k=k+Math.imul(st,Ft)|0,g=g+Math.imul(J,oe)|0,y=(y=y+Math.imul(J,Ht)|0)+Math.imul(G,oe)|0,k=k+Math.imul(G,Ht)|0,g=g+Math.imul(et,it)|0,y=(y=y+Math.imul(et,ut)|0)+Math.imul(tt,it)|0,k=k+Math.imul(tt,ut)|0,g=g+Math.imul(Z,Nt)|0,y=(y=y+Math.imul(Z,yt)|0)+Math.imul(q,Nt)|0,k=k+Math.imul(q,yt)|0,g=g+Math.imul(C,Pt)|0,y=(y=y+Math.imul(C,Ot)|0)+Math.imul(F,Pt)|0,k=k+Math.imul(F,Ot)|0;var kt=($+(g=g+Math.imul(j,zt)|0)|0)+((8191&(y=(y=y+Math.imul(j,qt)|0)+Math.imul(H,zt)|0))<<13)|0;$=((k=k+Math.imul(H,qt)|0)+(y>>>13)|0)+(kt>>>26)|0,kt&=67108863,g=Math.imul(_t,re),y=(y=Math.imul(_t,It))+Math.imul(dt,re)|0,k=Math.imul(dt,It),g=g+Math.imul(Et,Xt)|0,y=(y=y+Math.imul(Et,Ut)|0)+Math.imul(At,Xt)|0,k=k+Math.imul(At,Ut)|0,g=g+Math.imul(vt,te)|0,y=(y=y+Math.imul(vt,Dt)|0)+Math.imul(mt,te)|0,k=k+Math.imul(mt,Dt)|0,g=g+Math.imul(lt,ae)|0,y=(y=y+Math.imul(lt,Ft)|0)+Math.imul(ct,ae)|0,k=k+Math.imul(ct,Ft)|0,g=g+Math.imul(rt,oe)|0,y=(y=y+Math.imul(rt,Ht)|0)+Math.imul(st,oe)|0,k=k+Math.imul(st,Ht)|0,g=g+Math.imul(J,it)|0,y=(y=y+Math.imul(J,ut)|0)+Math.imul(G,it)|0,k=k+Math.imul(G,ut)|0,g=g+Math.imul(et,Nt)|0,y=(y=y+Math.imul(et,yt)|0)+Math.imul(tt,Nt)|0,k=k+Math.imul(tt,yt)|0,g=g+Math.imul(Z,Pt)|0,y=(y=y+Math.imul(Z,Ot)|0)+Math.imul(q,Pt)|0,k=k+Math.imul(q,Ot)|0;var pt=($+(g=g+Math.imul(C,zt)|0)|0)+((8191&(y=(y=y+Math.imul(C,qt)|0)+Math.imul(F,zt)|0))<<13)|0;$=((k=k+Math.imul(F,qt)|0)+(y>>>13)|0)+(pt>>>26)|0,pt&=67108863,g=Math.imul(_t,Xt),y=(y=Math.imul(_t,Ut))+Math.imul(dt,Xt)|0,k=Math.imul(dt,Ut),g=g+Math.imul(Et,te)|0,y=(y=y+Math.imul(Et,Dt)|0)+Math.imul(At,te)|0,k=k+Math.imul(At,Dt)|0,g=g+Math.imul(vt,ae)|0,y=(y=y+Math.imul(vt,Ft)|0)+Math.imul(mt,ae)|0,k=k+Math.imul(mt,Ft)|0,g=g+Math.imul(lt,oe)|0,y=(y=y+Math.imul(lt,Ht)|0)+Math.imul(ct,oe)|0,k=k+Math.imul(ct,Ht)|0,g=g+Math.imul(rt,it)|0,y=(y=y+Math.imul(rt,ut)|0)+Math.imul(st,it)|0,k=k+Math.imul(st,ut)|0,g=g+Math.imul(J,Nt)|0,y=(y=y+Math.imul(J,yt)|0)+Math.imul(G,Nt)|0,k=k+Math.imul(G,yt)|0,g=g+Math.imul(et,Pt)|0,y=(y=y+Math.imul(et,Ot)|0)+Math.imul(tt,Pt)|0,k=k+Math.imul(tt,Ot)|0;var gt=($+(g=g+Math.imul(Z,zt)|0)|0)+((8191&(y=(y=y+Math.imul(Z,qt)|0)+Math.imul(q,zt)|0))<<13)|0;$=((k=k+Math.imul(q,qt)|0)+(y>>>13)|0)+(gt>>>26)|0,gt&=67108863,g=Math.imul(_t,te),y=(y=Math.imul(_t,Dt))+Math.imul(dt,te)|0,k=Math.imul(dt,Dt),g=g+Math.imul(Et,ae)|0,y=(y=y+Math.imul(Et,Ft)|0)+Math.imul(At,ae)|0,k=k+Math.imul(At,Ft)|0,g=g+Math.imul(vt,oe)|0,y=(y=y+Math.imul(vt,Ht)|0)+Math.imul(mt,oe)|0,k=k+Math.imul(mt,Ht)|0,g=g+Math.imul(lt,it)|0,y=(y=y+Math.imul(lt,ut)|0)+Math.imul(ct,it)|0,k=k+Math.imul(ct,ut)|0,g=g+Math.imul(rt,Nt)|0,y=(y=y+Math.imul(rt,yt)|0)+Math.imul(st,Nt)|0,k=k+Math.imul(st,yt)|0,g=g+Math.imul(J,Pt)|0,y=(y=y+Math.imul(J,Ot)|0)+Math.imul(G,Pt)|0,k=k+Math.imul(G,Ot)|0;var Zt=($+(g=g+Math.imul(et,zt)|0)|0)+((8191&(y=(y=y+Math.imul(et,qt)|0)+Math.imul(tt,zt)|0))<<13)|0;$=((k=k+Math.imul(tt,qt)|0)+(y>>>13)|0)+(Zt>>>26)|0,Zt&=67108863,g=Math.imul(_t,ae),y=(y=Math.imul(_t,Ft))+Math.imul(dt,ae)|0,k=Math.imul(dt,Ft),g=g+Math.imul(Et,oe)|0,y=(y=y+Math.imul(Et,Ht)|0)+Math.imul(At,oe)|0,k=k+Math.imul(At,Ht)|0,g=g+Math.imul(vt,it)|0,y=(y=y+Math.imul(vt,ut)|0)+Math.imul(mt,it)|0,k=k+Math.imul(mt,ut)|0,g=g+Math.imul(lt,Nt)|0,y=(y=y+Math.imul(lt,yt)|0)+Math.imul(ct,Nt)|0,k=k+Math.imul(ct,yt)|0,g=g+Math.imul(rt,Pt)|0,y=(y=y+Math.imul(rt,Ot)|0)+Math.imul(st,Pt)|0,k=k+Math.imul(st,Ot)|0;var Vt=($+(g=g+Math.imul(J,zt)|0)|0)+((8191&(y=(y=y+Math.imul(J,qt)|0)+Math.imul(G,zt)|0))<<13)|0;$=((k=k+Math.imul(G,qt)|0)+(y>>>13)|0)+(Vt>>>26)|0,Vt&=67108863,g=Math.imul(_t,oe),y=(y=Math.imul(_t,Ht))+Math.imul(dt,oe)|0,k=Math.imul(dt,Ht),g=g+Math.imul(Et,it)|0,y=(y=y+Math.imul(Et,ut)|0)+Math.imul(At,it)|0,k=k+Math.imul(At,ut)|0,g=g+Math.imul(vt,Nt)|0,y=(y=y+Math.imul(vt,yt)|0)+Math.imul(mt,Nt)|0,k=k+Math.imul(mt,yt)|0,g=g+Math.imul(lt,Pt)|0,y=(y=y+Math.imul(lt,Ot)|0)+Math.imul(ct,Pt)|0,k=k+Math.imul(ct,Ot)|0;var Wt=($+(g=g+Math.imul(rt,zt)|0)|0)+((8191&(y=(y=y+Math.imul(rt,qt)|0)+Math.imul(st,zt)|0))<<13)|0;$=((k=k+Math.imul(st,qt)|0)+(y>>>13)|0)+(Wt>>>26)|0,Wt&=67108863,g=Math.imul(_t,it),y=(y=Math.imul(_t,ut))+Math.imul(dt,it)|0,k=Math.imul(dt,ut),g=g+Math.imul(Et,Nt)|0,y=(y=y+Math.imul(Et,yt)|0)+Math.imul(At,Nt)|0,k=k+Math.imul(At,yt)|0,g=g+Math.imul(vt,Pt)|0,y=(y=y+Math.imul(vt,Ot)|0)+Math.imul(mt,Pt)|0,k=k+Math.imul(mt,Ot)|0;var Bt=($+(g=g+Math.imul(lt,zt)|0)|0)+((8191&(y=(y=y+Math.imul(lt,qt)|0)+Math.imul(ct,zt)|0))<<13)|0;$=((k=k+Math.imul(ct,qt)|0)+(y>>>13)|0)+(Bt>>>26)|0,Bt&=67108863,g=Math.imul(_t,Nt),y=(y=Math.imul(_t,yt))+Math.imul(dt,Nt)|0,k=Math.imul(dt,yt),g=g+Math.imul(Et,Pt)|0,y=(y=y+Math.imul(Et,Ot)|0)+Math.imul(At,Pt)|0,k=k+Math.imul(At,Ot)|0;var ne=($+(g=g+Math.imul(vt,zt)|0)|0)+((8191&(y=(y=y+Math.imul(vt,qt)|0)+Math.imul(mt,zt)|0))<<13)|0;$=((k=k+Math.imul(mt,qt)|0)+(y>>>13)|0)+(ne>>>26)|0,ne&=67108863,g=Math.imul(_t,Pt),y=(y=Math.imul(_t,Ot))+Math.imul(dt,Pt)|0,k=Math.imul(dt,Ot);var ie=($+(g=g+Math.imul(Et,zt)|0)|0)+((8191&(y=(y=y+Math.imul(Et,qt)|0)+Math.imul(At,zt)|0))<<13)|0;$=((k=k+Math.imul(At,qt)|0)+(y>>>13)|0)+(ie>>>26)|0,ie&=67108863;var le=($+(g=Math.imul(_t,zt))|0)+((8191&(y=(y=Math.imul(_t,qt))+Math.imul(dt,zt)|0))<<13)|0;return $=((k=Math.imul(dt,qt))+(y>>>13)|0)+(le>>>26)|0,le&=67108863,z[0]=he,z[1]=fe,z[2]=de,z[3]=pe,z[4]=ge,z[5]=Y,z[6]=at,z[7]=ft,z[8]=ht,z[9]=kt,z[10]=pt,z[11]=gt,z[12]=Zt,z[13]=Vt,z[14]=Wt,z[15]=Bt,z[16]=ne,z[17]=ie,z[18]=le,$!==0&&(z[19]=$,b.length++),b};function A(v,p,b){b.negative=p.negative^v.negative,b.length=v.length+p.length;for(var g=0,y=0,k=0;k<b.length-1;k++){var R=y;y=0;for(var O=67108863&g,z=Math.min(k,p.length-1),$=Math.max(0,k-v.length+1);$<=z;$++){var W=k-$,j=(0|v.words[W])*(0|p.words[$]),H=67108863&j;O=67108863&(H=H+O|0),y+=(R=(R=R+(j/67108864|0)|0)+(H>>>26)|0)>>>26,R&=67108863}b.words[k]=O,g=R,R=y}return g!==0?b.words[k]=g:b.length--,b._strip()}function N(v,p,b){return A(v,p,b)}Math.imul||(_=w),t.prototype.mulTo=function(v,p){var b=this.length+v.length;return this.length===10&&v.length===10?_(this,v,p):b<63?w(this,v,p):b<1024?A(this,v,p):N(this,v,p)},t.prototype.mul=function(v){var p=new t(null);return p.words=new Array(this.length+v.length),this.mulTo(v,p)},t.prototype.mulf=function(v){var p=new t(null);return p.words=new Array(this.length+v.length),N(this,v,p)},t.prototype.imul=function(v){return this.clone().mulTo(v,this)},t.prototype.imuln=function(v){var p=v<0;p&&(v=-v),o(typeof v=="number"),o(v<67108864);for(var b=0,g=0;g<this.length;g++){var y=(0|this.words[g])*v,k=(67108863&y)+(67108863&b);b>>=26,b+=y/67108864|0,b+=k>>>26,this.words[g]=67108863&k}return b!==0&&(this.words[g]=b,this.length++),p?this.ineg():this},t.prototype.muln=function(v){return this.clone().imuln(v)},t.prototype.sqr=function(){return this.mul(this)},t.prototype.isqr=function(){return this.imul(this.clone())},t.prototype.pow=function(v){var p=function(k){for(var R=new Array(k.bitLength()),O=0;O<R.length;O++){var z=O/26|0,$=O%26;R[O]=k.words[z]>>>$&1}return R}(v);if(p.length===0)return new t(1);for(var b=this,g=0;g<p.length&&p[g]===0;g++,b=b.sqr());if(++g<p.length)for(var y=b.sqr();g<p.length;g++,y=y.sqr())p[g]!==0&&(b=b.mul(y));return b},t.prototype.iushln=function(v){o(typeof v=="number"&&v>=0);var p,b=v%26,g=(v-b)/26,y=67108863>>>26-b<<26-b;if(b!==0){var k=0;for(p=0;p<this.length;p++){var R=this.words[p]&y,O=(0|this.words[p])-R<<b;this.words[p]=O|k,k=R>>>26-b}k&&(this.words[p]=k,this.length++)}if(g!==0){for(p=this.length-1;p>=0;p--)this.words[p+g]=this.words[p];for(p=0;p<g;p++)this.words[p]=0;this.length+=g}return this._strip()},t.prototype.ishln=function(v){return o(this.negative===0),this.iushln(v)},t.prototype.iushrn=function(v,p,b){var g;o(typeof v=="number"&&v>=0),g=p?(p-p%26)/26:0;var y=v%26,k=Math.min((v-y)/26,this.length),R=67108863^67108863>>>y<<y,O=b;if(g-=k,g=Math.max(0,g),O){for(var z=0;z<k;z++)O.words[z]=this.words[z];O.length=k}if(k!==0)if(this.length>k)for(this.length-=k,z=0;z<this.length;z++)this.words[z]=this.words[z+k];else this.words[0]=0,this.length=1;var $=0;for(z=this.length-1;z>=0&&($!==0||z>=g);z--){var W=0|this.words[z];this.words[z]=$<<26-y|W>>>y,$=W&R}return O&&$!==0&&(O.words[O.length++]=$),this.length===0&&(this.words[0]=0,this.length=1),this._strip()},t.prototype.ishrn=function(v,p,b){return o(this.negative===0),this.iushrn(v,p,b)},t.prototype.shln=function(v){return this.clone().ishln(v)},t.prototype.ushln=function(v){return this.clone().iushln(v)},t.prototype.shrn=function(v){return this.clone().ishrn(v)},t.prototype.ushrn=function(v){return this.clone().iushrn(v)},t.prototype.testn=function(v){o(typeof v=="number"&&v>=0);var p=v%26,b=(v-p)/26,g=1<<p;return!(this.length<=b)&&!!(this.words[b]&g)},t.prototype.imaskn=function(v){o(typeof v=="number"&&v>=0);var p=v%26,b=(v-p)/26;if(o(this.negative===0,"imaskn works only with positive numbers"),this.length<=b)return this;if(p!==0&&b++,this.length=Math.min(b,this.length),p!==0){var g=67108863^67108863>>>p<<p;this.words[this.length-1]&=g}return this._strip()},t.prototype.maskn=function(v){return this.clone().imaskn(v)},t.prototype.iaddn=function(v){return o(typeof v=="number"),o(v<67108864),v<0?this.isubn(-v):this.negative!==0?this.length===1&&(0|this.words[0])<=v?(this.words[0]=v-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(v),this.negative=1,this):this._iaddn(v)},t.prototype._iaddn=function(v){this.words[0]+=v;for(var p=0;p<this.length&&this.words[p]>=67108864;p++)this.words[p]-=67108864,p===this.length-1?this.words[p+1]=1:this.words[p+1]++;return this.length=Math.max(this.length,p+1),this},t.prototype.isubn=function(v){if(o(typeof v=="number"),o(v<67108864),v<0)return this.iaddn(-v);if(this.negative!==0)return this.negative=0,this.iaddn(v),this.negative=1,this;if(this.words[0]-=v,this.length===1&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var p=0;p<this.length&&this.words[p]<0;p++)this.words[p]+=67108864,this.words[p+1]-=1;return this._strip()},t.prototype.addn=function(v){return this.clone().iaddn(v)},t.prototype.subn=function(v){return this.clone().isubn(v)},t.prototype.iabs=function(){return this.negative=0,this},t.prototype.abs=function(){return this.clone().iabs()},t.prototype._ishlnsubmul=function(v,p,b){var g,y,k=v.length+b;this._expand(k);var R=0;for(g=0;g<v.length;g++){y=(0|this.words[g+b])+R;var O=(0|v.words[g])*p;R=((y-=67108863&O)>>26)-(O/67108864|0),this.words[g+b]=67108863&y}for(;g<this.length-b;g++)R=(y=(0|this.words[g+b])+R)>>26,this.words[g+b]=67108863&y;if(R===0)return this._strip();for(o(R===-1),R=0,g=0;g<this.length;g++)R=(y=-(0|this.words[g])+R)>>26,this.words[g]=67108863&y;return this.negative=1,this._strip()},t.prototype._wordDiv=function(v,p){var b=(this.length,v.length),g=this.clone(),y=v,k=0|y.words[y.length-1];(b=26-this._countBits(k))!==0&&(y=y.ushln(b),g.iushln(b),k=0|y.words[y.length-1]);var R,O=g.length-y.length;if(p!=="mod"){(R=new t(null)).length=O+1,R.words=new Array(R.length);for(var z=0;z<R.length;z++)R.words[z]=0}var $=g.clone()._ishlnsubmul(y,1,O);$.negative===0&&(g=$,R&&(R.words[O]=1));for(var W=O-1;W>=0;W--){var j=67108864*(0|g.words[y.length+W])+(0|g.words[y.length+W-1]);for(j=Math.min(j/k|0,67108863),g._ishlnsubmul(y,j,W);g.negative!==0;)j--,g.negative=0,g._ishlnsubmul(y,1,W),g.isZero()||(g.negative^=1);R&&(R.words[W]=j)}return R&&R._strip(),g._strip(),p!=="div"&&b!==0&&g.iushrn(b),{div:R||null,mod:g}},t.prototype.divmod=function(v,p,b){return o(!v.isZero()),this.isZero()?{div:new t(0),mod:new t(0)}:this.negative!==0&&v.negative===0?(k=this.neg().divmod(v,p),p!=="mod"&&(g=k.div.neg()),p!=="div"&&(y=k.mod.neg(),b&&y.negative!==0&&y.iadd(v)),{div:g,mod:y}):this.negative===0&&v.negative!==0?(k=this.divmod(v.neg(),p),p!=="mod"&&(g=k.div.neg()),{div:g,mod:k.mod}):this.negative&v.negative?(k=this.neg().divmod(v.neg(),p),p!=="div"&&(y=k.mod.neg(),b&&y.negative!==0&&y.isub(v)),{div:k.div,mod:y}):v.length>this.length||this.cmp(v)<0?{div:new t(0),mod:this}:v.length===1?p==="div"?{div:this.divn(v.words[0]),mod:null}:p==="mod"?{div:null,mod:new t(this.modrn(v.words[0]))}:{div:this.divn(v.words[0]),mod:new t(this.modrn(v.words[0]))}:this._wordDiv(v,p);var g,y,k},t.prototype.div=function(v){return this.divmod(v,"div",!1).div},t.prototype.mod=function(v){return this.divmod(v,"mod",!1).mod},t.prototype.umod=function(v){return this.divmod(v,"mod",!0).mod},t.prototype.divRound=function(v){var p=this.divmod(v);if(p.mod.isZero())return p.div;var b=p.div.negative!==0?p.mod.isub(v):p.mod,g=v.ushrn(1),y=v.andln(1),k=b.cmp(g);return k<0||y===1&&k===0?p.div:p.div.negative!==0?p.div.isubn(1):p.div.iaddn(1)},t.prototype.modrn=function(v){var p=v<0;p&&(v=-v),o(v<=67108863);for(var b=(1<<26)%v,g=0,y=this.length-1;y>=0;y--)g=(b*g+(0|this.words[y]))%v;return p?-g:g},t.prototype.modn=function(v){return this.modrn(v)},t.prototype.idivn=function(v){var p=v<0;p&&(v=-v),o(v<=67108863);for(var b=0,g=this.length-1;g>=0;g--){var y=(0|this.words[g])+67108864*b;this.words[g]=y/v|0,b=y%v}return this._strip(),p?this.ineg():this},t.prototype.divn=function(v){return this.clone().idivn(v)},t.prototype.egcd=function(v){o(v.negative===0),o(!v.isZero());var p=this,b=v.clone();p=p.negative!==0?p.umod(v):p.clone();for(var g=new t(1),y=new t(0),k=new t(0),R=new t(1),O=0;p.isEven()&&b.isEven();)p.iushrn(1),b.iushrn(1),++O;for(var z=b.clone(),$=p.clone();!p.isZero();){for(var W=0,j=1;!(p.words[0]&j)&&W<26;++W,j<<=1);if(W>0)for(p.iushrn(W);W-- >0;)(g.isOdd()||y.isOdd())&&(g.iadd(z),y.isub($)),g.iushrn(1),y.iushrn(1);for(var H=0,E=1;!(b.words[0]&E)&&H<26;++H,E<<=1);if(H>0)for(b.iushrn(H);H-- >0;)(k.isOdd()||R.isOdd())&&(k.iadd(z),R.isub($)),k.iushrn(1),R.iushrn(1);p.cmp(b)>=0?(p.isub(b),g.isub(k),y.isub(R)):(b.isub(p),k.isub(g),R.isub(y))}return{a:k,b:R,gcd:b.iushln(O)}},t.prototype._invmp=function(v){o(v.negative===0),o(!v.isZero());var p=this,b=v.clone();p=p.negative!==0?p.umod(v):p.clone();for(var g,y=new t(1),k=new t(0),R=b.clone();p.cmpn(1)>0&&b.cmpn(1)>0;){for(var O=0,z=1;!(p.words[0]&z)&&O<26;++O,z<<=1);if(O>0)for(p.iushrn(O);O-- >0;)y.isOdd()&&y.iadd(R),y.iushrn(1);for(var $=0,W=1;!(b.words[0]&W)&&$<26;++$,W<<=1);if($>0)for(b.iushrn($);$-- >0;)k.isOdd()&&k.iadd(R),k.iushrn(1);p.cmp(b)>=0?(p.isub(b),y.isub(k)):(b.isub(p),k.isub(y))}return(g=p.cmpn(1)===0?y:k).cmpn(0)<0&&g.iadd(v),g},t.prototype.gcd=function(v){if(this.isZero())return v.abs();if(v.isZero())return this.abs();var p=this.clone(),b=v.clone();p.negative=0,b.negative=0;for(var g=0;p.isEven()&&b.isEven();g++)p.iushrn(1),b.iushrn(1);for(;;){for(;p.isEven();)p.iushrn(1);for(;b.isEven();)b.iushrn(1);var y=p.cmp(b);if(y<0){var k=p;p=b,b=k}else if(y===0||b.cmpn(1)===0)break;p.isub(b)}return b.iushln(g)},t.prototype.invm=function(v){return this.egcd(v).a.umod(v)},t.prototype.isEven=function(){return(1&this.words[0])==0},t.prototype.isOdd=function(){return(1&this.words[0])==1},t.prototype.andln=function(v){return this.words[0]&v},t.prototype.bincn=function(v){o(typeof v=="number");var p=v%26,b=(v-p)/26,g=1<<p;if(this.length<=b)return this._expand(b+1),this.words[b]|=g,this;for(var y=g,k=b;y!==0&&k<this.length;k++){var R=0|this.words[k];y=(R+=y)>>>26,R&=67108863,this.words[k]=R}return y!==0&&(this.words[k]=y,this.length++),this},t.prototype.isZero=function(){return this.length===1&&this.words[0]===0},t.prototype.cmpn=function(v){var p,b=v<0;if(this.negative!==0&&!b)return-1;if(this.negative===0&&b)return 1;if(this._strip(),this.length>1)p=1;else{b&&(v=-v),o(v<=67108863,"Number is too big");var g=0|this.words[0];p=g===v?0:g<v?-1:1}return this.negative!==0?0|-p:p},t.prototype.cmp=function(v){if(this.negative!==0&&v.negative===0)return-1;if(this.negative===0&&v.negative!==0)return 1;var p=this.ucmp(v);return this.negative!==0?0|-p:p},t.prototype.ucmp=function(v){if(this.length>v.length)return 1;if(this.length<v.length)return-1;for(var p=0,b=this.length-1;b>=0;b--){var g=0|this.words[b],y=0|v.words[b];if(g!==y){g<y?p=-1:g>y&&(p=1);break}}return p},t.prototype.gtn=function(v){return this.cmpn(v)===1},t.prototype.gt=function(v){return this.cmp(v)===1},t.prototype.gten=function(v){return this.cmpn(v)>=0},t.prototype.gte=function(v){return this.cmp(v)>=0},t.prototype.ltn=function(v){return this.cmpn(v)===-1},t.prototype.lt=function(v){return this.cmp(v)===-1},t.prototype.lten=function(v){return this.cmpn(v)<=0},t.prototype.lte=function(v){return this.cmp(v)<=0},t.prototype.eqn=function(v){return this.cmpn(v)===0},t.prototype.eq=function(v){return this.cmp(v)===0},t.red=function(v){return new x(v)},t.prototype.toRed=function(v){return o(!this.red,"Already a number in reduction context"),o(this.negative===0,"red works only with positives"),v.convertTo(this)._forceRed(v)},t.prototype.fromRed=function(){return o(this.red,"fromRed works only with numbers in reduction context"),this.red.convertFrom(this)},t.prototype._forceRed=function(v){return this.red=v,this},t.prototype.forceRed=function(v){return o(!this.red,"Already a number in reduction context"),this._forceRed(v)},t.prototype.redAdd=function(v){return o(this.red,"redAdd works only with red numbers"),this.red.add(this,v)},t.prototype.redIAdd=function(v){return o(this.red,"redIAdd works only with red numbers"),this.red.iadd(this,v)},t.prototype.redSub=function(v){return o(this.red,"redSub works only with red numbers"),this.red.sub(this,v)},t.prototype.redISub=function(v){return o(this.red,"redISub works only with red numbers"),this.red.isub(this,v)},t.prototype.redShl=function(v){return o(this.red,"redShl works only with red numbers"),this.red.shl(this,v)},t.prototype.redMul=function(v){return o(this.red,"redMul works only with red numbers"),this.red._verify2(this,v),this.red.mul(this,v)},t.prototype.redIMul=function(v){return o(this.red,"redMul works only with red numbers"),this.red._verify2(this,v),this.red.imul(this,v)},t.prototype.redSqr=function(){return o(this.red,"redSqr works only with red numbers"),this.red._verify1(this),this.red.sqr(this)},t.prototype.redISqr=function(){return o(this.red,"redISqr works only with red numbers"),this.red._verify1(this),this.red.isqr(this)},t.prototype.redSqrt=function(){return o(this.red,"redSqrt works only with red numbers"),this.red._verify1(this),this.red.sqrt(this)},t.prototype.redInvm=function(){return o(this.red,"redInvm works only with red numbers"),this.red._verify1(this),this.red.invm(this)},t.prototype.redNeg=function(){return o(this.red,"redNeg works only with red numbers"),this.red._verify1(this),this.red.neg(this)},t.prototype.redPow=function(v){return o(this.red&&!v.red,"redPow(normalNum)"),this.red._verify1(this),this.red.pow(this,v)};var L={k256:null,p224:null,p192:null,p25519:null};function I(v,p){this.name=v,this.p=new t(p,16),this.n=this.p.bitLength(),this.k=new t(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function P(){I.call(this,"k256","ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f")}function B(){I.call(this,"p224","ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001")}function U(){I.call(this,"p192","ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff")}function D(){I.call(this,"25519","7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed")}function x(v){if(typeof v=="string"){var p=t._prime(v);this.m=p.p,this.prime=p}else o(v.gtn(1),"modulus must be greater than 1"),this.m=v,this.prime=null}function M(v){x.call(this,v),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new t(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}I.prototype._tmp=function(){var v=new t(null);return v.words=new Array(Math.ceil(this.n/13)),v},I.prototype.ireduce=function(v){var p,b=v;do this.split(b,this.tmp),p=(b=(b=this.imulK(b)).iadd(this.tmp)).bitLength();while(p>this.n);var g=p<this.n?-1:b.ucmp(this.p);return g===0?(b.words[0]=0,b.length=1):g>0?b.isub(this.p):b.strip!==void 0?b.strip():b._strip(),b},I.prototype.split=function(v,p){v.iushrn(this.n,0,p)},I.prototype.imulK=function(v){return v.imul(this.k)},r(P,I),P.prototype.split=function(v,p){for(var b=Math.min(v.length,9),g=0;g<b;g++)p.words[g]=v.words[g];if(p.length=b,v.length<=9)return v.words[0]=0,void(v.length=1);var y=v.words[9];for(p.words[p.length++]=4194303&y,g=10;g<v.length;g++){var k=0|v.words[g];v.words[g-10]=(4194303&k)<<4|y>>>22,y=k}y>>>=22,v.words[g-10]=y,y===0&&v.length>10?v.length-=10:v.length-=9},P.prototype.imulK=function(v){v.words[v.length]=0,v.words[v.length+1]=0,v.length+=2;for(var p=0,b=0;b<v.length;b++){var g=0|v.words[b];p+=977*g,v.words[b]=67108863&p,p=64*g+(p/67108864|0)}return v.words[v.length-1]===0&&(v.length--,v.words[v.length-1]===0&&v.length--),v},r(B,I),r(U,I),r(D,I),D.prototype.imulK=function(v){for(var p=0,b=0;b<v.length;b++){var g=19*(0|v.words[b])+p,y=67108863&g;g>>>=26,v.words[b]=y,p=g}return p!==0&&(v.words[v.length++]=p),v},t._prime=function(v){if(L[v])return L[v];var p;if(v==="k256")p=new P;else if(v==="p224")p=new B;else if(v==="p192")p=new U;else{if(v!=="p25519")throw new Error("Unknown prime "+v);p=new D}return L[v]=p,p},x.prototype._verify1=function(v){o(v.negative===0,"red works only with positives"),o(v.red,"red works only with red numbers")},x.prototype._verify2=function(v,p){o((v.negative|p.negative)==0,"red works only with positives"),o(v.red&&v.red===p.red,"red works only with red numbers")},x.prototype.imod=function(v){return this.prime?this.prime.ireduce(v)._forceRed(this):(f(v,v.umod(this.m)._forceRed(this)),v)},x.prototype.neg=function(v){return v.isZero()?v.clone():this.m.sub(v)._forceRed(this)},x.prototype.add=function(v,p){this._verify2(v,p);var b=v.add(p);return b.cmp(this.m)>=0&&b.isub(this.m),b._forceRed(this)},x.prototype.iadd=function(v,p){this._verify2(v,p);var b=v.iadd(p);return b.cmp(this.m)>=0&&b.isub(this.m),b},x.prototype.sub=function(v,p){this._verify2(v,p);var b=v.sub(p);return b.cmpn(0)<0&&b.iadd(this.m),b._forceRed(this)},x.prototype.isub=function(v,p){this._verify2(v,p);var b=v.isub(p);return b.cmpn(0)<0&&b.iadd(this.m),b},x.prototype.shl=function(v,p){return this._verify1(v),this.imod(v.ushln(p))},x.prototype.imul=function(v,p){return this._verify2(v,p),this.imod(v.imul(p))},x.prototype.mul=function(v,p){return this._verify2(v,p),this.imod(v.mul(p))},x.prototype.isqr=function(v){return this.imul(v,v.clone())},x.prototype.sqr=function(v){return this.mul(v,v)},x.prototype.sqrt=function(v){if(v.isZero())return v.clone();var p=this.m.andln(3);if(o(p%2==1),p===3){var b=this.m.add(new t(1)).iushrn(2);return this.pow(v,b)}for(var g=this.m.subn(1),y=0;!g.isZero()&&g.andln(1)===0;)y++,g.iushrn(1);o(!g.isZero());var k=new t(1).toRed(this),R=k.redNeg(),O=this.m.subn(1).iushrn(1),z=this.m.bitLength();for(z=new t(2*z*z).toRed(this);this.pow(z,O).cmp(R)!==0;)z.redIAdd(R);for(var $=this.pow(z,g),W=this.pow(v,g.addn(1).iushrn(1)),j=this.pow(v,g),H=y;j.cmp(k)!==0;){for(var E=j,C=0;E.cmp(k)!==0;C++)E=E.redSqr();o(C<H);var F=this.pow($,new t(1).iushln(H-C-1));W=W.redMul(F),$=F.redSqr(),j=j.redMul($),H=C}return W},x.prototype.invm=function(v){var p=v._invmp(this.m);return p.negative!==0?(p.negative=0,this.imod(p).redNeg()):this.imod(p)},x.prototype.pow=function(v,p){if(p.isZero())return new t(1).toRed(this);if(p.cmpn(1)===0)return v.clone();var b=new Array(16);b[0]=new t(1).toRed(this),b[1]=v;for(var g=2;g<b.length;g++)b[g]=this.mul(b[g-1],v);var y=b[0],k=0,R=0,O=p.bitLength()%26;for(O===0&&(O=26),g=p.length-1;g>=0;g--){for(var z=p.words[g],$=O-1;$>=0;$--){var W=z>>$&1;y!==b[0]&&(y=this.sqr(y)),W!==0||k!==0?(k<<=1,k|=W,(++R===4||g===0&&$===0)&&(y=this.mul(y,b[k]),R=0,k=0)):R=0}O=26}return y},x.prototype.convertTo=function(v){var p=v.umod(this.m);return p===v?p.clone():p},x.prototype.convertFrom=function(v){var p=v.clone();return p.red=null,p},t.mont=function(v){return new M(v)},r(M,x),M.prototype.convertTo=function(v){return this.imod(v.ushln(this.shift))},M.prototype.convertFrom=function(v){var p=this.imod(v.mul(this.rinv));return p.red=null,p},M.prototype.imul=function(v,p){if(v.isZero()||p.isZero())return v.words[0]=0,v.length=1,v;var b=v.imul(p),g=b.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),y=b.isub(g).iushrn(this.shift),k=y;return y.cmp(this.m)>=0?k=y.isub(this.m):y.cmpn(0)<0&&(k=y.iadd(this.m)),k._forceRed(this)},M.prototype.mul=function(v,p){if(v.isZero()||p.isZero())return new t(0)._forceRed(this);var b=v.mul(p),g=b.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),y=b.isub(g).iushrn(this.shift),k=y;return y.cmp(this.m)>=0?k=y.isub(this.m):y.cmpn(0)<0&&(k=y.iadd(this.m)),k._forceRed(this)},M.prototype.invm=function(v){return this.imod(v._invmp(this.m).mul(this.r2))._forceRed(this)}})(T===void 0||T)},{buffer:188}],187:[function(s,T,S){var m;function a(r){this.rand=r}if(T.exports=function(r){return m||(m=new a(null)),m.generate(r)},T.exports.Rand=a,a.prototype.generate=function(r){return this._rand(r)},a.prototype._rand=function(r){if(this.rand.getBytes)return this.rand.getBytes(r);for(var t=new Uint8Array(r),e=0;e<t.length;e++)t[e]=this.rand.getByte();return t},typeof self=="object")self.crypto&&self.crypto.getRandomValues?a.prototype._rand=function(r){var t=new Uint8Array(r);return self.crypto.getRandomValues(t),t}:self.msCrypto&&self.msCrypto.getRandomValues?a.prototype._rand=function(r){var t=new Uint8Array(r);return self.msCrypto.getRandomValues(t),t}:typeof window=="object"&&(a.prototype._rand=function(){throw new Error("Not implemented yet")});else try{var o=s("crypto");if(typeof o.randomBytes!="function")throw new Error("Not supported");a.prototype._rand=function(r){return o.randomBytes(r)}}catch{}},{crypto:188}],188:[function(s,T,S){},{}],189:[function(s,T,S){var m=s("safe-buffer").Buffer;function a(n){m.isBuffer(n)||(n=m.from(n));for(var i=n.length/4|0,f=new Array(i),c=0;c<i;c++)f[c]=n.readUInt32BE(4*c);return f}function o(n){for(;0<n.length;n++)n[0]=0}function r(n,i,f,c,u){for(var d,h,w,_,A=f[0],N=f[1],L=f[2],I=f[3],P=n[0]^i[0],B=n[1]^i[1],U=n[2]^i[2],D=n[3]^i[3],x=4,M=1;M<u;M++)d=A[P>>>24]^N[B>>>16&255]^L[U>>>8&255]^I[255&D]^i[x++],h=A[B>>>24]^N[U>>>16&255]^L[D>>>8&255]^I[255&P]^i[x++],w=A[U>>>24]^N[D>>>16&255]^L[P>>>8&255]^I[255&B]^i[x++],_=A[D>>>24]^N[P>>>16&255]^L[B>>>8&255]^I[255&U]^i[x++],P=d,B=h,U=w,D=_;return d=(c[P>>>24]<<24|c[B>>>16&255]<<16|c[U>>>8&255]<<8|c[255&D])^i[x++],h=(c[B>>>24]<<24|c[U>>>16&255]<<16|c[D>>>8&255]<<8|c[255&P])^i[x++],w=(c[U>>>24]<<24|c[D>>>16&255]<<16|c[P>>>8&255]<<8|c[255&B])^i[x++],_=(c[D>>>24]<<24|c[P>>>16&255]<<16|c[B>>>8&255]<<8|c[255&U])^i[x++],[d>>>=0,h>>>=0,w>>>=0,_>>>=0]}var t=[0,1,2,4,8,16,32,64,128,27,54],e=function(){for(var n=new Array(256),i=0;i<256;i++)n[i]=i<128?i<<1:i<<1^283;for(var f=[],c=[],u=[[],[],[],[]],d=[[],[],[],[]],h=0,w=0,_=0;_<256;++_){var A=w^w<<1^w<<2^w<<3^w<<4;A=A>>>8^255&A^99,f[h]=A,c[A]=h;var N=n[h],L=n[N],I=n[L],P=257*n[A]^16843008*A;u[0][h]=P<<24|P>>>8,u[1][h]=P<<16|P>>>16,u[2][h]=P<<8|P>>>24,u[3][h]=P,P=16843009*I^65537*L^257*N^16843008*h,d[0][A]=P<<24|P>>>8,d[1][A]=P<<16|P>>>16,d[2][A]=P<<8|P>>>24,d[3][A]=P,h===0?h=w=1:(h=N^n[n[n[I^N]]],w^=n[n[w]])}return{SBOX:f,INV_SBOX:c,SUB_MIX:u,INV_SUB_MIX:d}}();function l(n){this._key=a(n),this._reset()}l.blockSize=16,l.keySize=32,l.prototype.blockSize=l.blockSize,l.prototype.keySize=l.keySize,l.prototype._reset=function(){for(var n=this._key,i=n.length,f=i+6,c=4*(f+1),u=[],d=0;d<i;d++)u[d]=n[d];for(d=i;d<c;d++){var h=u[d-1];d%i==0?(h=h<<8|h>>>24,h=e.SBOX[h>>>24]<<24|e.SBOX[h>>>16&255]<<16|e.SBOX[h>>>8&255]<<8|e.SBOX[255&h],h^=t[d/i|0]<<24):i>6&&d%i==4&&(h=e.SBOX[h>>>24]<<24|e.SBOX[h>>>16&255]<<16|e.SBOX[h>>>8&255]<<8|e.SBOX[255&h]),u[d]=u[d-i]^h}for(var w=[],_=0;_<c;_++){var A=c-_,N=u[A-(_%4?0:4)];w[_]=_<4||A<=4?N:e.INV_SUB_MIX[0][e.SBOX[N>>>24]]^e.INV_SUB_MIX[1][e.SBOX[N>>>16&255]]^e.INV_SUB_MIX[2][e.SBOX[N>>>8&255]]^e.INV_SUB_MIX[3][e.SBOX[255&N]]}this._nRounds=f,this._keySchedule=u,this._invKeySchedule=w},l.prototype.encryptBlockRaw=function(n){return r(n=a(n),this._keySchedule,e.SUB_MIX,e.SBOX,this._nRounds)},l.prototype.encryptBlock=function(n){var i=this.encryptBlockRaw(n),f=m.allocUnsafe(16);return f.writeUInt32BE(i[0],0),f.writeUInt32BE(i[1],4),f.writeUInt32BE(i[2],8),f.writeUInt32BE(i[3],12),f},l.prototype.decryptBlock=function(n){var i=(n=a(n))[1];n[1]=n[3],n[3]=i;var f=r(n,this._invKeySchedule,e.INV_SUB_MIX,e.INV_SBOX,this._nRounds),c=m.allocUnsafe(16);return c.writeUInt32BE(f[0],0),c.writeUInt32BE(f[3],4),c.writeUInt32BE(f[2],8),c.writeUInt32BE(f[1],12),c},l.prototype.scrub=function(){o(this._keySchedule),o(this._invKeySchedule),o(this._key)},T.exports.AES=l},{"safe-buffer":494}],190:[function(s,T,S){var m=s("./aes"),a=s("safe-buffer").Buffer,o=s("cipher-base"),r=s("inherits"),t=s("./ghash"),e=s("buffer-xor"),l=s("./incr32");function n(i,f,c,u){o.call(this);var d=a.alloc(4,0);this._cipher=new m.AES(f);var h=this._cipher.encryptBlock(d);this._ghash=new t(h),c=function(w,_,A){if(_.length===12)return w._finID=a.concat([_,a.from([0,0,0,1])]),a.concat([_,a.from([0,0,0,2])]);var N=new t(A),L=_.length,I=L%16;N.update(_),I&&(I=16-I,N.update(a.alloc(I,0))),N.update(a.alloc(8,0));var P=8*L,B=a.alloc(8);B.writeUIntBE(P,0,8),N.update(B),w._finID=N.state;var U=a.from(w._finID);return l(U),U}(this,c,h),this._prev=a.from(c),this._cache=a.allocUnsafe(0),this._secCache=a.allocUnsafe(0),this._decrypt=u,this._alen=0,this._len=0,this._mode=i,this._authTag=null,this._called=!1}r(n,o),n.prototype._update=function(i){if(!this._called&&this._alen){var f=16-this._alen%16;f<16&&(f=a.alloc(f,0),this._ghash.update(f))}this._called=!0;var c=this._mode.encrypt(this,i);return this._decrypt?this._ghash.update(i):this._ghash.update(c),this._len+=i.length,c},n.prototype._final=function(){if(this._decrypt&&!this._authTag)throw new Error("Unsupported state or unable to authenticate data");var i=e(this._ghash.final(8*this._alen,8*this._len),this._cipher.encryptBlock(this._finID));if(this._decrypt&&function(f,c){var u=0;f.length!==c.length&&u++;for(var d=Math.min(f.length,c.length),h=0;h<d;++h)u+=f[h]^c[h];return u}(i,this._authTag))throw new Error("Unsupported state or unable to authenticate data");this._authTag=i,this._cipher.scrub()},n.prototype.getAuthTag=function(){if(this._decrypt||!a.isBuffer(this._authTag))throw new Error("Attempting to get auth tag in unsupported state");return this._authTag},n.prototype.setAuthTag=function(i){if(!this._decrypt)throw new Error("Attempting to set auth tag in unsupported state");this._authTag=i},n.prototype.setAAD=function(i){if(this._called)throw new Error("Attempting to set AAD in unsupported state");this._ghash.update(i),this._alen+=i.length},T.exports=n},{"./aes":189,"./ghash":194,"./incr32":195,"buffer-xor":219,"cipher-base":221,inherits:440,"safe-buffer":494}],191:[function(s,T,S){var m=s("./encrypter"),a=s("./decrypter"),o=s("./modes/list.json");S.createCipher=S.Cipher=m.createCipher,S.createCipheriv=S.Cipheriv=m.createCipheriv,S.createDecipher=S.Decipher=a.createDecipher,S.createDecipheriv=S.Decipheriv=a.createDecipheriv,S.listCiphers=S.getCiphers=function(){return Object.keys(o)}},{"./decrypter":192,"./encrypter":193,"./modes/list.json":203}],192:[function(s,T,S){var m=s("./authCipher"),a=s("safe-buffer").Buffer,o=s("./modes"),r=s("./streamCipher"),t=s("cipher-base"),e=s("./aes"),l=s("evp_bytestokey");function n(c,u,d){t.call(this),this._cache=new i,this._last=void 0,this._cipher=new e.AES(u),this._prev=a.from(d),this._mode=c,this._autopadding=!0}function i(){this.cache=a.allocUnsafe(0)}function f(c,u,d){var h=o[c.toLowerCase()];if(!h)throw new TypeError("invalid suite type");if(typeof d=="string"&&(d=a.from(d)),h.mode!=="GCM"&&d.length!==h.iv)throw new TypeError("invalid iv length "+d.length);if(typeof u=="string"&&(u=a.from(u)),u.length!==h.key/8)throw new TypeError("invalid key length "+u.length);return h.type==="stream"?new r(h.module,u,d,!0):h.type==="auth"?new m(h.module,u,d,!0):new n(h.module,u,d)}s("inherits")(n,t),n.prototype._update=function(c){var u,d;this._cache.add(c);for(var h=[];u=this._cache.get(this._autopadding);)d=this._mode.decrypt(this,u),h.push(d);return a.concat(h)},n.prototype._final=function(){var c=this._cache.flush();if(this._autopadding)return function(u){var d=u[15];if(d<1||d>16)throw new Error("unable to decrypt data");for(var h=-1;++h<d;)if(u[h+(16-d)]!==d)throw new Error("unable to decrypt data");if(d!==16)return u.slice(0,16-d)}(this._mode.decrypt(this,c));if(c)throw new Error("data not multiple of block length")},n.prototype.setAutoPadding=function(c){return this._autopadding=!!c,this},i.prototype.add=function(c){this.cache=a.concat([this.cache,c])},i.prototype.get=function(c){var u;if(c){if(this.cache.length>16)return u=this.cache.slice(0,16),this.cache=this.cache.slice(16),u}else if(this.cache.length>=16)return u=this.cache.slice(0,16),this.cache=this.cache.slice(16),u;return null},i.prototype.flush=function(){if(this.cache.length)return this.cache},S.createDecipher=function(c,u){var d=o[c.toLowerCase()];if(!d)throw new TypeError("invalid suite type");var h=l(u,!1,d.key,d.iv);return f(c,h.key,h.iv)},S.createDecipheriv=f},{"./aes":189,"./authCipher":190,"./modes":202,"./streamCipher":205,"cipher-base":221,evp_bytestokey:423,inherits:440,"safe-buffer":494}],193:[function(s,T,S){var m=s("./modes"),a=s("./authCipher"),o=s("safe-buffer").Buffer,r=s("./streamCipher"),t=s("cipher-base"),e=s("./aes"),l=s("evp_bytestokey");function n(u,d,h){t.call(this),this._cache=new f,this._cipher=new e.AES(d),this._prev=o.from(h),this._mode=u,this._autopadding=!0}s("inherits")(n,t),n.prototype._update=function(u){var d,h;this._cache.add(u);for(var w=[];d=this._cache.get();)h=this._mode.encrypt(this,d),w.push(h);return o.concat(w)};var i=o.alloc(16,16);function f(){this.cache=o.allocUnsafe(0)}function c(u,d,h){var w=m[u.toLowerCase()];if(!w)throw new TypeError("invalid suite type");if(typeof d=="string"&&(d=o.from(d)),d.length!==w.key/8)throw new TypeError("invalid key length "+d.length);if(typeof h=="string"&&(h=o.from(h)),w.mode!=="GCM"&&h.length!==w.iv)throw new TypeError("invalid iv length "+h.length);return w.type==="stream"?new r(w.module,d,h):w.type==="auth"?new a(w.module,d,h):new n(w.module,d,h)}n.prototype._final=function(){var u=this._cache.flush();if(this._autopadding)return u=this._mode.encrypt(this,u),this._cipher.scrub(),u;if(!u.equals(i))throw this._cipher.scrub(),new Error("data not multiple of block length")},n.prototype.setAutoPadding=function(u){return this._autopadding=!!u,this},f.prototype.add=function(u){this.cache=o.concat([this.cache,u])},f.prototype.get=function(){if(this.cache.length>15){var u=this.cache.slice(0,16);return this.cache=this.cache.slice(16),u}return null},f.prototype.flush=function(){for(var u=16-this.cache.length,d=o.allocUnsafe(u),h=-1;++h<u;)d.writeUInt8(u,h);return o.concat([this.cache,d])},S.createCipheriv=c,S.createCipher=function(u,d){var h=m[u.toLowerCase()];if(!h)throw new TypeError("invalid suite type");var w=l(d,!1,h.key,h.iv);return c(u,w.key,w.iv)}},{"./aes":189,"./authCipher":190,"./modes":202,"./streamCipher":205,"cipher-base":221,evp_bytestokey:423,inherits:440,"safe-buffer":494}],194:[function(s,T,S){var m=s("safe-buffer").Buffer,a=m.alloc(16,0);function o(t){var e=m.allocUnsafe(16);return e.writeUInt32BE(t[0]>>>0,0),e.writeUInt32BE(t[1]>>>0,4),e.writeUInt32BE(t[2]>>>0,8),e.writeUInt32BE(t[3]>>>0,12),e}function r(t){this.h=t,this.state=m.alloc(16,0),this.cache=m.allocUnsafe(0)}r.prototype.ghash=function(t){for(var e=-1;++e<t.length;)this.state[e]^=t[e];this._multiply()},r.prototype._multiply=function(){for(var t,e,l,n=[(t=this.h).readUInt32BE(0),t.readUInt32BE(4),t.readUInt32BE(8),t.readUInt32BE(12)],i=[0,0,0,0],f=-1;++f<128;){for(this.state[~~(f/8)]&1<<7-f%8&&(i[0]^=n[0],i[1]^=n[1],i[2]^=n[2],i[3]^=n[3]),l=(1&n[3])!=0,e=3;e>0;e--)n[e]=n[e]>>>1|(1&n[e-1])<<31;n[0]=n[0]>>>1,l&&(n[0]=n[0]^225<<24)}this.state=o(i)},r.prototype.update=function(t){var e;for(this.cache=m.concat([this.cache,t]);this.cache.length>=16;)e=this.cache.slice(0,16),this.cache=this.cache.slice(16),this.ghash(e)},r.prototype.final=function(t,e){return this.cache.length&&this.ghash(m.concat([this.cache,a],16)),this.ghash(o([0,t,0,e])),this.state},T.exports=r},{"safe-buffer":494}],195:[function(s,T,S){T.exports=function(m){for(var a,o=m.length;o--;){if((a=m.readUInt8(o))!==255){a++,m.writeUInt8(a,o);break}m.writeUInt8(0,o)}}},{}],196:[function(s,T,S){var m=s("buffer-xor");S.encrypt=function(a,o){var r=m(o,a._prev);return a._prev=a._cipher.encryptBlock(r),a._prev},S.decrypt=function(a,o){var r=a._prev;a._prev=o;var t=a._cipher.decryptBlock(o);return m(t,r)}},{"buffer-xor":219}],197:[function(s,T,S){var m=s("safe-buffer").Buffer,a=s("buffer-xor");function o(r,t,e){var l=t.length,n=a(t,r._cache);return r._cache=r._cache.slice(l),r._prev=m.concat([r._prev,e?t:n]),n}S.encrypt=function(r,t,e){for(var l,n=m.allocUnsafe(0);t.length;){if(r._cache.length===0&&(r._cache=r._cipher.encryptBlock(r._prev),r._prev=m.allocUnsafe(0)),!(r._cache.length<=t.length)){n=m.concat([n,o(r,t,e)]);break}l=r._cache.length,n=m.concat([n,o(r,t.slice(0,l),e)]),t=t.slice(l)}return n}},{"buffer-xor":219,"safe-buffer":494}],198:[function(s,T,S){var m=s("safe-buffer").Buffer;function a(r,t,e){for(var l,n,i=-1,f=0;++i<8;)l=t&1<<7-i?128:0,f+=(128&(n=r._cipher.encryptBlock(r._prev)[0]^l))>>i%8,r._prev=o(r._prev,e?l:n);return f}function o(r,t){var e=r.length,l=-1,n=m.allocUnsafe(r.length);for(r=m.concat([r,m.from([t])]);++l<e;)n[l]=r[l]<<1|r[l+1]>>7;return n}S.encrypt=function(r,t,e){for(var l=t.length,n=m.allocUnsafe(l),i=-1;++i<l;)n[i]=a(r,t[i],e);return n}},{"safe-buffer":494}],199:[function(s,T,S){var m=s("safe-buffer").Buffer;function a(o,r,t){var e=o._cipher.encryptBlock(o._prev)[0]^r;return o._prev=m.concat([o._prev.slice(1),m.from([t?r:e])]),e}S.encrypt=function(o,r,t){for(var e=r.length,l=m.allocUnsafe(e),n=-1;++n<e;)l[n]=a(o,r[n],t);return l}},{"safe-buffer":494}],200:[function(s,T,S){var m=s("buffer-xor"),a=s("safe-buffer").Buffer,o=s("../incr32");function r(t){var e=t._cipher.encryptBlockRaw(t._prev);return o(t._prev),e}S.encrypt=function(t,e){var l=Math.ceil(e.length/16),n=t._cache.length;t._cache=a.concat([t._cache,a.allocUnsafe(16*l)]);for(var i=0;i<l;i++){var f=r(t),c=n+16*i;t._cache.writeUInt32BE(f[0],c+0),t._cache.writeUInt32BE(f[1],c+4),t._cache.writeUInt32BE(f[2],c+8),t._cache.writeUInt32BE(f[3],c+12)}var u=t._cache.slice(0,e.length);return t._cache=t._cache.slice(e.length),m(e,u)}},{"../incr32":195,"buffer-xor":219,"safe-buffer":494}],201:[function(s,T,S){S.encrypt=function(m,a){return m._cipher.encryptBlock(a)},S.decrypt=function(m,a){return m._cipher.decryptBlock(a)}},{}],202:[function(s,T,S){var m={ECB:s("./ecb"),CBC:s("./cbc"),CFB:s("./cfb"),CFB8:s("./cfb8"),CFB1:s("./cfb1"),OFB:s("./ofb"),CTR:s("./ctr"),GCM:s("./ctr")},a=s("./list.json");for(var o in a)a[o].module=m[a[o].mode];T.exports=a},{"./cbc":196,"./cfb":197,"./cfb1":198,"./cfb8":199,"./ctr":200,"./ecb":201,"./list.json":203,"./ofb":204}],203:[function(s,T,S){T.exports={"aes-128-ecb":{cipher:"AES",key:128,iv:0,mode:"ECB",type:"block"},"aes-192-ecb":{cipher:"AES",key:192,iv:0,mode:"ECB",type:"block"},"aes-256-ecb":{cipher:"AES",key:256,iv:0,mode:"ECB",type:"block"},"aes-128-cbc":{cipher:"AES",key:128,iv:16,mode:"CBC",type:"block"},"aes-192-cbc":{cipher:"AES",key:192,iv:16,mode:"CBC",type:"block"},"aes-256-cbc":{cipher:"AES",key:256,iv:16,mode:"CBC",type:"block"},aes128:{cipher:"AES",key:128,iv:16,mode:"CBC",type:"block"},aes192:{cipher:"AES",key:192,iv:16,mode:"CBC",type:"block"},aes256:{cipher:"AES",key:256,iv:16,mode:"CBC",type:"block"},"aes-128-cfb":{cipher:"AES",key:128,iv:16,mode:"CFB",type:"stream"},"aes-192-cfb":{cipher:"AES",key:192,iv:16,mode:"CFB",type:"stream"},"aes-256-cfb":{cipher:"AES",key:256,iv:16,mode:"CFB",type:"stream"},"aes-128-cfb8":{cipher:"AES",key:128,iv:16,mode:"CFB8",type:"stream"},"aes-192-cfb8":{cipher:"AES",key:192,iv:16,mode:"CFB8",type:"stream"},"aes-256-cfb8":{cipher:"AES",key:256,iv:16,mode:"CFB8",type:"stream"},"aes-128-cfb1":{cipher:"AES",key:128,iv:16,mode:"CFB1",type:"stream"},"aes-192-cfb1":{cipher:"AES",key:192,iv:16,mode:"CFB1",type:"stream"},"aes-256-cfb1":{cipher:"AES",key:256,iv:16,mode:"CFB1",type:"stream"},"aes-128-ofb":{cipher:"AES",key:128,iv:16,mode:"OFB",type:"stream"},"aes-192-ofb":{cipher:"AES",key:192,iv:16,mode:"OFB",type:"stream"},"aes-256-ofb":{cipher:"AES",key:256,iv:16,mode:"OFB",type:"stream"},"aes-128-ctr":{cipher:"AES",key:128,iv:16,mode:"CTR",type:"stream"},"aes-192-ctr":{cipher:"AES",key:192,iv:16,mode:"CTR",type:"stream"},"aes-256-ctr":{cipher:"AES",key:256,iv:16,mode:"CTR",type:"stream"},"aes-128-gcm":{cipher:"AES",key:128,iv:12,mode:"GCM",type:"auth"},"aes-192-gcm":{cipher:"AES",key:192,iv:12,mode:"GCM",type:"auth"},"aes-256-gcm":{cipher:"AES",key:256,iv:12,mode:"GCM",type:"auth"}}},{}],204:[function(s,T,S){(function(m){(function(){var a=s("buffer-xor");function o(r){return r._prev=r._cipher.encryptBlock(r._prev),r._prev}S.encrypt=function(r,t){for(;r._cache.length<t.length;)r._cache=m.concat([r._cache,o(r)]);var e=r._cache.slice(0,t.length);return r._cache=r._cache.slice(t.length),a(t,e)}}).call(this)}).call(this,s("buffer").Buffer)},{buffer:220,"buffer-xor":219}],205:[function(s,T,S){var m=s("./aes"),a=s("safe-buffer").Buffer,o=s("cipher-base");function r(t,e,l,n){o.call(this),this._cipher=new m.AES(e),this._prev=a.from(l),this._cache=a.allocUnsafe(0),this._secCache=a.allocUnsafe(0),this._decrypt=n,this._mode=t}s("inherits")(r,o),r.prototype._update=function(t){return this._mode.encrypt(this,t,this._decrypt)},r.prototype._final=function(){this._cipher.scrub()},T.exports=r},{"./aes":189,"cipher-base":221,inherits:440,"safe-buffer":494}],206:[function(s,T,S){var m=s("browserify-des"),a=s("browserify-aes/browser"),o=s("browserify-aes/modes"),r=s("browserify-des/modes"),t=s("evp_bytestokey");function e(n,i,f){if(n=n.toLowerCase(),o[n])return a.createCipheriv(n,i,f);if(r[n])return new m({key:i,iv:f,mode:n});throw new TypeError("invalid suite type")}function l(n,i,f){if(n=n.toLowerCase(),o[n])return a.createDecipheriv(n,i,f);if(r[n])return new m({key:i,iv:f,mode:n,decrypt:!0});throw new TypeError("invalid suite type")}S.createCipher=S.Cipher=function(n,i){var f,c;if(n=n.toLowerCase(),o[n])f=o[n].key,c=o[n].iv;else{if(!r[n])throw new TypeError("invalid suite type");f=8*r[n].key,c=r[n].iv}var u=t(i,!1,f,c);return e(n,u.key,u.iv)},S.createCipheriv=S.Cipheriv=e,S.createDecipher=S.Decipher=function(n,i){var f,c;if(n=n.toLowerCase(),o[n])f=o[n].key,c=o[n].iv;else{if(!r[n])throw new TypeError("invalid suite type");f=8*r[n].key,c=r[n].iv}var u=t(i,!1,f,c);return l(n,u.key,u.iv)},S.createDecipheriv=S.Decipheriv=l,S.listCiphers=S.getCiphers=function(){return Object.keys(r).concat(a.getCiphers())}},{"browserify-aes/browser":191,"browserify-aes/modes":202,"browserify-des":207,"browserify-des/modes":208,evp_bytestokey:423}],207:[function(s,T,S){var m=s("cipher-base"),a=s("des.js"),o=s("inherits"),r=s("safe-buffer").Buffer,t={"des-ede3-cbc":a.CBC.instantiate(a.EDE),"des-ede3":a.EDE,"des-ede-cbc":a.CBC.instantiate(a.EDE),"des-ede":a.EDE,"des-cbc":a.CBC.instantiate(a.DES),"des-ecb":a.DES};function e(l){m.call(this);var n,i=l.mode.toLowerCase(),f=t[i];n=l.decrypt?"decrypt":"encrypt";var c=l.key;r.isBuffer(c)||(c=r.from(c)),i!=="des-ede"&&i!=="des-ede-cbc"||(c=r.concat([c,c.slice(0,8)]));var u=l.iv;r.isBuffer(u)||(u=r.from(u)),this._des=f.create({key:c,iv:u,type:n})}t.des=t["des-cbc"],t.des3=t["des-ede3-cbc"],T.exports=e,o(e,m),e.prototype._update=function(l){return r.from(this._des.update(l))},e.prototype._final=function(){return r.from(this._des.final())}},{"cipher-base":221,"des.js":394,inherits:440,"safe-buffer":494}],208:[function(s,T,S){S["des-ecb"]={key:8,iv:0},S["des-cbc"]=S.des={key:8,iv:8},S["des-ede3-cbc"]=S.des3={key:24,iv:8},S["des-ede3"]={key:24,iv:0},S["des-ede-cbc"]={key:16,iv:8},S["des-ede"]={key:16,iv:0}},{}],209:[function(s,T,S){(function(m){(function(){var a=s("bn.js"),o=s("randombytes");function r(e){var l,n=e.modulus.byteLength();do l=new a(o(n));while(l.cmp(e.modulus)>=0||!l.umod(e.prime1)||!l.umod(e.prime2));return l}function t(e,l){var n=function(L){var I=r(L);return{blinder:I.toRed(a.mont(L.modulus)).redPow(new a(L.publicExponent)).fromRed(),unblinder:I.invm(L.modulus)}}(l),i=l.modulus.byteLength(),f=new a(e).mul(n.blinder).umod(l.modulus),c=f.toRed(a.mont(l.prime1)),u=f.toRed(a.mont(l.prime2)),d=l.coefficient,h=l.prime1,w=l.prime2,_=c.redPow(l.exponent1).fromRed(),A=u.redPow(l.exponent2).fromRed(),N=_.isub(A).imul(d).umod(h).imul(w);return A.iadd(N).imul(n.unblinder).umod(l.modulus).toArrayLike(m,"be",i)}t.getr=r,T.exports=t}).call(this)}).call(this,s("buffer").Buffer)},{"bn.js":186,buffer:220,randombytes:475}],210:[function(s,T,S){T.exports=s("./browser/algorithms.json")},{"./browser/algorithms.json":211}],211:[function(s,T,S){T.exports={sha224WithRSAEncryption:{sign:"rsa",hash:"sha224",id:"302d300d06096086480165030402040500041c"},"RSA-SHA224":{sign:"ecdsa/rsa",hash:"sha224",id:"302d300d06096086480165030402040500041c"},sha256WithRSAEncryption:{sign:"rsa",hash:"sha256",id:"3031300d060960864801650304020105000420"},"RSA-SHA256":{sign:"ecdsa/rsa",hash:"sha256",id:"3031300d060960864801650304020105000420"},sha384WithRSAEncryption:{sign:"rsa",hash:"sha384",id:"3041300d060960864801650304020205000430"},"RSA-SHA384":{sign:"ecdsa/rsa",hash:"sha384",id:"3041300d060960864801650304020205000430"},sha512WithRSAEncryption:{sign:"rsa",hash:"sha512",id:"3051300d060960864801650304020305000440"},"RSA-SHA512":{sign:"ecdsa/rsa",hash:"sha512",id:"3051300d060960864801650304020305000440"},"RSA-SHA1":{sign:"rsa",hash:"sha1",id:"3021300906052b0e03021a05000414"},"ecdsa-with-SHA1":{sign:"ecdsa",hash:"sha1",id:""},sha256:{sign:"ecdsa",hash:"sha256",id:""},sha224:{sign:"ecdsa",hash:"sha224",id:""},sha384:{sign:"ecdsa",hash:"sha384",id:""},sha512:{sign:"ecdsa",hash:"sha512",id:""},"DSA-SHA":{sign:"dsa",hash:"sha1",id:""},"DSA-SHA1":{sign:"dsa",hash:"sha1",id:""},DSA:{sign:"dsa",hash:"sha1",id:""},"DSA-WITH-SHA224":{sign:"dsa",hash:"sha224",id:""},"DSA-SHA224":{sign:"dsa",hash:"sha224",id:""},"DSA-WITH-SHA256":{sign:"dsa",hash:"sha256",id:""},"DSA-SHA256":{sign:"dsa",hash:"sha256",id:""},"DSA-WITH-SHA384":{sign:"dsa",hash:"sha384",id:""},"DSA-SHA384":{sign:"dsa",hash:"sha384",id:""},"DSA-WITH-SHA512":{sign:"dsa",hash:"sha512",id:""},"DSA-SHA512":{sign:"dsa",hash:"sha512",id:""},"DSA-RIPEMD160":{sign:"dsa",hash:"rmd160",id:""},ripemd160WithRSA:{sign:"rsa",hash:"rmd160",id:"3021300906052b2403020105000414"},"RSA-RIPEMD160":{sign:"rsa",hash:"rmd160",id:"3021300906052b2403020105000414"},md5WithRSAEncryption:{sign:"rsa",hash:"md5",id:"3020300c06082a864886f70d020505000410"},"RSA-MD5":{sign:"rsa",hash:"md5",id:"3020300c06082a864886f70d020505000410"}}},{}],212:[function(s,T,S){T.exports={"1.3.132.0.10":"secp256k1","1.3.132.0.33":"p224","1.2.840.10045.3.1.1":"p192","1.2.840.10045.3.1.7":"p256","1.3.132.0.34":"p384","1.3.132.0.35":"p521"}},{}],213:[function(s,T,S){var m=s("safe-buffer").Buffer,a=s("create-hash"),o=s("readable-stream"),r=s("inherits"),t=s("./sign"),e=s("./verify"),l=s("./algorithms.json");function n(u){o.Writable.call(this);var d=l[u];if(!d)throw new Error("Unknown message digest");this._hashType=d.hash,this._hash=a(d.hash),this._tag=d.id,this._signType=d.sign}function i(u){o.Writable.call(this);var d=l[u];if(!d)throw new Error("Unknown message digest");this._hash=a(d.hash),this._tag=d.id,this._signType=d.sign}function f(u){return new n(u)}function c(u){return new i(u)}Object.keys(l).forEach(function(u){l[u].id=m.from(l[u].id,"hex"),l[u.toLowerCase()]=l[u]}),r(n,o.Writable),n.prototype._write=function(u,d,h){this._hash.update(u),h()},n.prototype.update=function(u,d){return typeof u=="string"&&(u=m.from(u,d)),this._hash.update(u),this},n.prototype.sign=function(u,d){this.end();var h=this._hash.digest(),w=t(h,u,this._hashType,this._signType,this._tag);return d?w.toString(d):w},r(i,o.Writable),i.prototype._write=function(u,d,h){this._hash.update(u),h()},i.prototype.update=function(u,d){return typeof u=="string"&&(u=m.from(u,d)),this._hash.update(u),this},i.prototype.verify=function(u,d,h){typeof d=="string"&&(d=m.from(d,h)),this.end();var w=this._hash.digest();return e(d,w,u,this._signType,this._tag)},T.exports={Sign:f,Verify:c,createSign:f,createVerify:c}},{"./algorithms.json":211,"./sign":214,"./verify":215,"create-hash":386,inherits:440,"readable-stream":491,"safe-buffer":494}],214:[function(s,T,S){var m=s("safe-buffer").Buffer,a=s("create-hmac"),o=s("browserify-rsa"),r=s("elliptic").ec,t=s("bn.js"),e=s("parse-asn1"),l=s("./curves.json");function n(u,d,h,w){if((u=m.from(u.toArray())).length<d.byteLength()){var _=m.alloc(d.byteLength()-u.length);u=m.concat([_,u])}var A=h.length,N=function(P,B){P=(P=i(P,B)).mod(B);var U=m.from(P.toArray());if(U.length<B.byteLength()){var D=m.alloc(B.byteLength()-U.length);U=m.concat([D,U])}return U}(h,d),L=m.alloc(A);L.fill(1);var I=m.alloc(A);return I=a(w,I).update(L).update(m.from([0])).update(u).update(N).digest(),L=a(w,I).update(L).digest(),{k:I=a(w,I).update(L).update(m.from([1])).update(u).update(N).digest(),v:L=a(w,I).update(L).digest()}}function i(u,d){var h=new t(u),w=(u.length<<3)-d.bitLength();return w>0&&h.ishrn(w),h}function f(u,d,h){var w,_;do{for(w=m.alloc(0);8*w.length<u.bitLength();)d.v=a(h,d.k).update(d.v).digest(),w=m.concat([w,d.v]);_=i(w,u),d.k=a(h,d.k).update(d.v).update(m.from([0])).digest(),d.v=a(h,d.k).update(d.v).digest()}while(_.cmp(u)!==-1);return _}function c(u,d,h,w){return u.toRed(t.mont(h)).redPow(d).fromRed().mod(w)}T.exports=function(u,d,h,w,_){var A=e(d);if(A.curve){if(w!=="ecdsa"&&w!=="ecdsa/rsa")throw new Error("wrong private key type");return function(P,B){var U=l[B.curve.join(".")];if(!U)throw new Error("unknown curve "+B.curve.join("."));var D=new r(U).keyFromPrivate(B.privateKey).sign(P);return m.from(D.toDER())}(u,A)}if(A.type==="dsa"){if(w!=="dsa")throw new Error("wrong private key type");return function(P,B,U){for(var D,x=B.params.priv_key,M=B.params.p,v=B.params.q,p=B.params.g,b=new t(0),g=i(P,v).mod(v),y=!1,k=n(x,v,P,U);y===!1;)D=f(v,k,U),b=c(p,D,M,v),(y=D.invm(v).imul(g.add(x.mul(b))).mod(v)).cmpn(0)===0&&(y=!1,b=new t(0));return function(R,O){R=R.toArray(),O=O.toArray(),128&R[0]&&(R=[0].concat(R)),128&O[0]&&(O=[0].concat(O));var z=[48,R.length+O.length+4,2,R.length];return z=z.concat(R,[2,O.length],O),m.from(z)}(b,y)}(u,A,h)}if(w!=="rsa"&&w!=="ecdsa/rsa")throw new Error("wrong private key type");u=m.concat([_,u]);for(var N=A.modulus.byteLength(),L=[0,1];u.length+L.length+1<N;)L.push(255);L.push(0);for(var I=-1;++I<u.length;)L.push(u[I]);return o(L,A)},T.exports.getKey=n,T.exports.makeKey=f},{"./curves.json":212,"bn.js":186,"browserify-rsa":209,"create-hmac":388,elliptic:405,"parse-asn1":459,"safe-buffer":494}],215:[function(s,T,S){var m=s("safe-buffer").Buffer,a=s("bn.js"),o=s("elliptic").ec,r=s("parse-asn1"),t=s("./curves.json");function e(l,n){if(l.cmpn(0)<=0)throw new Error("invalid sig");if(l.cmp(n)>=n)throw new Error("invalid sig")}T.exports=function(l,n,i,f,c){var u=r(i);if(u.type==="ec"){if(f!=="ecdsa"&&f!=="ecdsa/rsa")throw new Error("wrong public key type");return function(L,I,P){var B=t[P.data.algorithm.curve.join(".")];if(!B)throw new Error("unknown curve "+P.data.algorithm.curve.join("."));var U=new o(B),D=P.data.subjectPrivateKey.data;return U.verify(I,L,D)}(l,n,u)}if(u.type==="dsa"){if(f!=="dsa")throw new Error("wrong public key type");return function(L,I,P){var B=P.data.p,U=P.data.q,D=P.data.g,x=P.data.pub_key,M=r.signature.decode(L,"der"),v=M.s,p=M.r;e(v,U),e(p,U);var b=a.mont(B),g=v.invm(U);return D.toRed(b).redPow(new a(I).mul(g).mod(U)).fromRed().mul(x.toRed(b).redPow(p.mul(g).mod(U)).fromRed()).mod(B).mod(U).cmp(p)===0}(l,n,u)}if(f!=="rsa"&&f!=="ecdsa/rsa")throw new Error("wrong public key type");n=m.concat([c,n]);for(var d=u.modulus.byteLength(),h=[1],w=0;n.length+h.length+2<d;)h.push(255),w++;h.push(0);for(var _=-1;++_<n.length;)h.push(n[_]);h=m.from(h);var A=a.mont(u.modulus);l=(l=new a(l).toRed(A)).redPow(new a(u.publicExponent)),l=m.from(l.fromRed().toArray());var N=w<8?1:0;for(d=Math.min(l.length,h.length),l.length!==h.length&&(N=1),_=-1;++_<d;)N|=l[_]^h[_];return N===0}},{"./curves.json":212,"bn.js":186,elliptic:405,"parse-asn1":459,"safe-buffer":494}],216:[function(s,T,S){},{}],217:[function(s,T,S){var m=s("buffer"),a=m.Buffer;function o(t,e){for(var l in t)e[l]=t[l]}function r(t,e,l){return a(t,e,l)}a.from&&a.alloc&&a.allocUnsafe&&a.allocUnsafeSlow?T.exports=m:(o(m,S),S.Buffer=r),o(a,r),r.from=function(t,e,l){if(typeof t=="number")throw new TypeError("Argument must not be a number");return a(t,e,l)},r.alloc=function(t,e,l){if(typeof t!="number")throw new TypeError("Argument must be a number");var n=a(t);return e!==void 0?typeof l=="string"?n.fill(e,l):n.fill(e):n.fill(0),n},r.allocUnsafe=function(t){if(typeof t!="number")throw new TypeError("Argument must be a number");return a(t)},r.allocUnsafeSlow=function(t){if(typeof t!="number")throw new TypeError("Argument must be a number");return m.SlowBuffer(t)}},{buffer:220}],218:[function(s,T,S){var m=s("safe-buffer").Buffer,a=m.isEncoding||function(u){switch((u=""+u)&&u.toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":case"raw":return!0;default:return!1}};function o(u){var d;switch(this.encoding=function(h){var w=function(_){if(!_)return"utf8";for(var A;;)switch(_){case"utf8":case"utf-8":return"utf8";case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return"utf16le";case"latin1":case"binary":return"latin1";case"base64":case"ascii":case"hex":return _;default:if(A)return;_=(""+_).toLowerCase(),A=!0}}(h);if(typeof w!="string"&&(m.isEncoding===a||!a(h)))throw new Error("Unknown encoding: "+h);return w||h}(u),this.encoding){case"utf16le":this.text=e,this.end=l,d=4;break;case"utf8":this.fillLast=t,d=4;break;case"base64":this.text=n,this.end=i,d=3;break;default:return this.write=f,void(this.end=c)}this.lastNeed=0,this.lastTotal=0,this.lastChar=m.allocUnsafe(d)}function r(u){return u<=127?0:u>>5==6?2:u>>4==14?3:u>>3==30?4:u>>6==2?-1:-2}function t(u){var d=this.lastTotal-this.lastNeed,h=function(w,_,A){if((192&_[0])!=128)return w.lastNeed=0,"�";if(w.lastNeed>1&&_.length>1){if((192&_[1])!=128)return w.lastNeed=1,"�";if(w.lastNeed>2&&_.length>2&&(192&_[2])!=128)return w.lastNeed=2,"�"}}(this,u);return h!==void 0?h:this.lastNeed<=u.length?(u.copy(this.lastChar,d,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal)):(u.copy(this.lastChar,d,0,u.length),void(this.lastNeed-=u.length))}function e(u,d){if((u.length-d)%2==0){var h=u.toString("utf16le",d);if(h){var w=h.charCodeAt(h.length-1);if(w>=55296&&w<=56319)return this.lastNeed=2,this.lastTotal=4,this.lastChar[0]=u[u.length-2],this.lastChar[1]=u[u.length-1],h.slice(0,-1)}return h}return this.lastNeed=1,this.lastTotal=2,this.lastChar[0]=u[u.length-1],u.toString("utf16le",d,u.length-1)}function l(u){var d=u&&u.length?this.write(u):"";if(this.lastNeed){var h=this.lastTotal-this.lastNeed;return d+this.lastChar.toString("utf16le",0,h)}return d}function n(u,d){var h=(u.length-d)%3;return h===0?u.toString("base64",d):(this.lastNeed=3-h,this.lastTotal=3,h===1?this.lastChar[0]=u[u.length-1]:(this.lastChar[0]=u[u.length-2],this.lastChar[1]=u[u.length-1]),u.toString("base64",d,u.length-h))}function i(u){var d=u&&u.length?this.write(u):"";return this.lastNeed?d+this.lastChar.toString("base64",0,3-this.lastNeed):d}function f(u){return u.toString(this.encoding)}function c(u){return u&&u.length?this.write(u):""}S.StringDecoder=o,o.prototype.write=function(u){if(u.length===0)return"";var d,h;if(this.lastNeed){if((d=this.fillLast(u))===void 0)return"";h=this.lastNeed,this.lastNeed=0}else h=0;return h<u.length?d?d+this.text(u,h):this.text(u,h):d||""},o.prototype.end=function(u){var d=u&&u.length?this.write(u):"";return this.lastNeed?d+"�":d},o.prototype.text=function(u,d){var h=function(_,A,N){var L=A.length-1;if(L<N)return 0;var I=r(A[L]);return I>=0?(I>0&&(_.lastNeed=I-1),I):--L<N||I===-2?0:(I=r(A[L]))>=0?(I>0&&(_.lastNeed=I-2),I):--L<N||I===-2?0:(I=r(A[L]))>=0?(I>0&&(I===2?I=0:_.lastNeed=I-3),I):0}(this,u,d);if(!this.lastNeed)return u.toString("utf8",d);this.lastTotal=h;var w=u.length-(h-this.lastNeed);return u.copy(this.lastChar,0,w),u.toString("utf8",d,w)},o.prototype.fillLast=function(u){if(this.lastNeed<=u.length)return u.copy(this.lastChar,this.lastTotal-this.lastNeed,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal);u.copy(this.lastChar,this.lastTotal-this.lastNeed,0,u.length),this.lastNeed-=u.length}},{"safe-buffer":217}],219:[function(s,T,S){(function(m){(function(){T.exports=function(a,o){for(var r=Math.min(a.length,o.length),t=new m(r),e=0;e<r;++e)t[e]=a[e]^o[e];return t}}).call(this)}).call(this,s("buffer").Buffer)},{buffer:220}],220:[function(s,T,S){(function(m){(function(){var a=s("base64-js"),o=s("ieee754");S.Buffer=t,S.SlowBuffer=function(E){return+E!=E&&(E=0),t.alloc(+E)},S.INSPECT_MAX_BYTES=50;function r(E){if(E>2147483647)throw new RangeError('The value "'+E+'" is invalid for option "size"');var C=new Uint8Array(E);return C.__proto__=t.prototype,C}function t(E,C,F){if(typeof E=="number"){if(typeof C=="string")throw new TypeError('The "string" argument must be of type string. Received type number');return n(E)}return e(E,C,F)}function e(E,C,F){if(typeof E=="string")return function(q,K){if(typeof K=="string"&&K!==""||(K="utf8"),!t.isEncoding(K))throw new TypeError("Unknown encoding: "+K);var et=0|c(q,K),tt=r(et),X=tt.write(q,K);return X!==et&&(tt=tt.slice(0,X)),tt}(E,C);if(ArrayBuffer.isView(E))return i(E);if(E==null)throw TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof E);if(j(E,ArrayBuffer)||E&&j(E.buffer,ArrayBuffer))return function(q,K,et){if(K<0||q.byteLength<K)throw new RangeError('"offset" is outside of buffer bounds');if(q.byteLength<K+(et||0))throw new RangeError('"length" is outside of buffer bounds');var tt;return tt=K===void 0&&et===void 0?new Uint8Array(q):et===void 0?new Uint8Array(q,K):new Uint8Array(q,K,et),tt.__proto__=t.prototype,tt}(E,C,F);if(typeof E=="number")throw new TypeError('The "value" argument must not be of type number. Received type number');var V=E.valueOf&&E.valueOf();if(V!=null&&V!==E)return t.from(V,C,F);var Z=function(q){if(t.isBuffer(q)){var K=0|f(q.length),et=r(K);return et.length===0||q.copy(et,0,0,K),et}if(q.length!==void 0)return typeof q.length!="number"||H(q.length)?r(0):i(q);if(q.type==="Buffer"&&Array.isArray(q.data))return i(q.data)}(E);if(Z)return Z;if(typeof Symbol<"u"&&Symbol.toPrimitive!=null&&typeof E[Symbol.toPrimitive]=="function")return t.from(E[Symbol.toPrimitive]("string"),C,F);throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof E)}function l(E){if(typeof E!="number")throw new TypeError('"size" argument must be of type number');if(E<0)throw new RangeError('The value "'+E+'" is invalid for option "size"')}function n(E){return l(E),r(E<0?0:0|f(E))}function i(E){for(var C=E.length<0?0:0|f(E.length),F=r(C),V=0;V<C;V+=1)F[V]=255&E[V];return F}function f(E){if(E>=2147483647)throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x7fffffff bytes");return 0|E}function c(E,C){if(t.isBuffer(E))return E.length;if(ArrayBuffer.isView(E)||j(E,ArrayBuffer))return E.byteLength;if(typeof E!="string")throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof E);var F=E.length,V=arguments.length>2&&arguments[2]===!0;if(!V&&F===0)return 0;for(var Z=!1;;)switch(C){case"ascii":case"latin1":case"binary":return F;case"utf8":case"utf-8":return z(E).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*F;case"hex":return F>>>1;case"base64":return $(E).length;default:if(Z)return V?-1:z(E).length;C=(""+C).toLowerCase(),Z=!0}}function u(E,C,F){var V=!1;if((C===void 0||C<0)&&(C=0),C>this.length||((F===void 0||F>this.length)&&(F=this.length),F<=0)||(F>>>=0)<=(C>>>=0))return"";for(E||(E="utf8");;)switch(E){case"hex":return M(this,C,F);case"utf8":case"utf-8":return U(this,C,F);case"ascii":return D(this,C,F);case"latin1":case"binary":return x(this,C,F);case"base64":return B(this,C,F);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return v(this,C,F);default:if(V)throw new TypeError("Unknown encoding: "+E);E=(E+"").toLowerCase(),V=!0}}function d(E,C,F){var V=E[C];E[C]=E[F],E[F]=V}function h(E,C,F,V,Z){if(E.length===0)return-1;if(typeof F=="string"?(V=F,F=0):F>2147483647?F=2147483647:F<-2147483648&&(F=-2147483648),H(F=+F)&&(F=Z?0:E.length-1),F<0&&(F=E.length+F),F>=E.length){if(Z)return-1;F=E.length-1}else if(F<0){if(!Z)return-1;F=0}if(typeof C=="string"&&(C=t.from(C,V)),t.isBuffer(C))return C.length===0?-1:w(E,C,F,V,Z);if(typeof C=="number")return C&=255,typeof Uint8Array.prototype.indexOf=="function"?Z?Uint8Array.prototype.indexOf.call(E,C,F):Uint8Array.prototype.lastIndexOf.call(E,C,F):w(E,[C],F,V,Z);throw new TypeError("val must be string, number or Buffer")}function w(E,C,F,V,Z){var q,K=1,et=E.length,tt=C.length;if(V!==void 0&&((V=String(V).toLowerCase())==="ucs2"||V==="ucs-2"||V==="utf16le"||V==="utf-16le")){if(E.length<2||C.length<2)return-1;K=2,et/=2,tt/=2,F/=2}function X(rt,st){return K===1?rt[st]:rt.readUInt16BE(st*K)}if(Z){var J=-1;for(q=F;q<et;q++)if(X(E,q)===X(C,J===-1?0:q-J)){if(J===-1&&(J=q),q-J+1===tt)return J*K}else J!==-1&&(q-=q-J),J=-1}else for(F+tt>et&&(F=et-tt),q=F;q>=0;q--){for(var G=!0,nt=0;nt<tt;nt++)if(X(E,q+nt)!==X(C,nt)){G=!1;break}if(G)return q}return-1}function _(E,C,F,V){F=Number(F)||0;var Z=E.length-F;V?(V=Number(V))>Z&&(V=Z):V=Z;var q=C.length;V>q/2&&(V=q/2);for(var K=0;K<V;++K){var et=parseInt(C.substr(2*K,2),16);if(H(et))return K;E[F+K]=et}return K}function A(E,C,F,V){return W(z(C,E.length-F),E,F,V)}function N(E,C,F,V){return W(function(Z){for(var q=[],K=0;K<Z.length;++K)q.push(255&Z.charCodeAt(K));return q}(C),E,F,V)}function L(E,C,F,V){return N(E,C,F,V)}function I(E,C,F,V){return W($(C),E,F,V)}function P(E,C,F,V){return W(function(Z,q){for(var K,et,tt,X=[],J=0;J<Z.length&&!((q-=2)<0);++J)K=Z.charCodeAt(J),et=K>>8,tt=K%256,X.push(tt),X.push(et);return X}(C,E.length-F),E,F,V)}function B(E,C,F){return C===0&&F===E.length?a.fromByteArray(E):a.fromByteArray(E.slice(C,F))}function U(E,C,F){F=Math.min(E.length,F);for(var V=[],Z=C;Z<F;){var q,K,et,tt,X=E[Z],J=null,G=X>239?4:X>223?3:X>191?2:1;if(Z+G<=F)switch(G){case 1:X<128&&(J=X);break;case 2:(192&(q=E[Z+1]))==128&&(tt=(31&X)<<6|63&q)>127&&(J=tt);break;case 3:q=E[Z+1],K=E[Z+2],(192&q)==128&&(192&K)==128&&(tt=(15&X)<<12|(63&q)<<6|63&K)>2047&&(tt<55296||tt>57343)&&(J=tt);break;case 4:q=E[Z+1],K=E[Z+2],et=E[Z+3],(192&q)==128&&(192&K)==128&&(192&et)==128&&(tt=(15&X)<<18|(63&q)<<12|(63&K)<<6|63&et)>65535&&tt<1114112&&(J=tt)}J===null?(J=65533,G=1):J>65535&&(J-=65536,V.push(J>>>10&1023|55296),J=56320|1023&J),V.push(J),Z+=G}return function(nt){var rt=nt.length;if(rt<=4096)return String.fromCharCode.apply(String,nt);for(var st="",ot=0;ot<rt;)st+=String.fromCharCode.apply(String,nt.slice(ot,ot+=4096));return st}(V)}S.kMaxLength=2147483647,t.TYPED_ARRAY_SUPPORT=function(){try{var E=new Uint8Array(1);return E.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},E.foo()===42}catch{return!1}}(),t.TYPED_ARRAY_SUPPORT||typeof console>"u"||typeof console.error!="function"||console.error("This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support."),Object.defineProperty(t.prototype,"parent",{enumerable:!0,get:function(){if(t.isBuffer(this))return this.buffer}}),Object.defineProperty(t.prototype,"offset",{enumerable:!0,get:function(){if(t.isBuffer(this))return this.byteOffset}}),typeof Symbol<"u"&&Symbol.species!=null&&t[Symbol.species]===t&&Object.defineProperty(t,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),t.poolSize=8192,t.from=function(E,C,F){return e(E,C,F)},t.prototype.__proto__=Uint8Array.prototype,t.__proto__=Uint8Array,t.alloc=function(E,C,F){return function(V,Z,q){return l(V),V<=0?r(V):Z!==void 0?typeof q=="string"?r(V).fill(Z,q):r(V).fill(Z):r(V)}(E,C,F)},t.allocUnsafe=function(E){return n(E)},t.allocUnsafeSlow=function(E){return n(E)},t.isBuffer=function(E){return E!=null&&E._isBuffer===!0&&E!==t.prototype},t.compare=function(E,C){if(j(E,Uint8Array)&&(E=t.from(E,E.offset,E.byteLength)),j(C,Uint8Array)&&(C=t.from(C,C.offset,C.byteLength)),!t.isBuffer(E)||!t.isBuffer(C))throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');if(E===C)return 0;for(var F=E.length,V=C.length,Z=0,q=Math.min(F,V);Z<q;++Z)if(E[Z]!==C[Z]){F=E[Z],V=C[Z];break}return F<V?-1:V<F?1:0},t.isEncoding=function(E){switch(String(E).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},t.concat=function(E,C){if(!Array.isArray(E))throw new TypeError('"list" argument must be an Array of Buffers');if(E.length===0)return t.alloc(0);var F;if(C===void 0)for(C=0,F=0;F<E.length;++F)C+=E[F].length;var V=t.allocUnsafe(C),Z=0;for(F=0;F<E.length;++F){var q=E[F];if(j(q,Uint8Array)&&(q=t.from(q)),!t.isBuffer(q))throw new TypeError('"list" argument must be an Array of Buffers');q.copy(V,Z),Z+=q.length}return V},t.byteLength=c,t.prototype._isBuffer=!0,t.prototype.swap16=function(){var E=this.length;if(E%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var C=0;C<E;C+=2)d(this,C,C+1);return this},t.prototype.swap32=function(){var E=this.length;if(E%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var C=0;C<E;C+=4)d(this,C,C+3),d(this,C+1,C+2);return this},t.prototype.swap64=function(){var E=this.length;if(E%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var C=0;C<E;C+=8)d(this,C,C+7),d(this,C+1,C+6),d(this,C+2,C+5),d(this,C+3,C+4);return this},t.prototype.toString=function(){var E=this.length;return E===0?"":arguments.length===0?U(this,0,E):u.apply(this,arguments)},t.prototype.toLocaleString=t.prototype.toString,t.prototype.equals=function(E){if(!t.isBuffer(E))throw new TypeError("Argument must be a Buffer");return this===E||t.compare(this,E)===0},t.prototype.inspect=function(){var E="",C=S.INSPECT_MAX_BYTES;return E=this.toString("hex",0,C).replace(/(.{2})/g,"$1 ").trim(),this.length>C&&(E+=" ... "),"<Buffer "+E+">"},t.prototype.compare=function(E,C,F,V,Z){if(j(E,Uint8Array)&&(E=t.from(E,E.offset,E.byteLength)),!t.isBuffer(E))throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type '+typeof E);if(C===void 0&&(C=0),F===void 0&&(F=E?E.length:0),V===void 0&&(V=0),Z===void 0&&(Z=this.length),C<0||F>E.length||V<0||Z>this.length)throw new RangeError("out of range index");if(V>=Z&&C>=F)return 0;if(V>=Z)return-1;if(C>=F)return 1;if(this===E)return 0;for(var q=(Z>>>=0)-(V>>>=0),K=(F>>>=0)-(C>>>=0),et=Math.min(q,K),tt=this.slice(V,Z),X=E.slice(C,F),J=0;J<et;++J)if(tt[J]!==X[J]){q=tt[J],K=X[J];break}return q<K?-1:K<q?1:0},t.prototype.includes=function(E,C,F){return this.indexOf(E,C,F)!==-1},t.prototype.indexOf=function(E,C,F){return h(this,E,C,F,!0)},t.prototype.lastIndexOf=function(E,C,F){return h(this,E,C,F,!1)},t.prototype.write=function(E,C,F,V){if(C===void 0)V="utf8",F=this.length,C=0;else if(F===void 0&&typeof C=="string")V=C,F=this.length,C=0;else{if(!isFinite(C))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");C>>>=0,isFinite(F)?(F>>>=0,V===void 0&&(V="utf8")):(V=F,F=void 0)}var Z=this.length-C;if((F===void 0||F>Z)&&(F=Z),E.length>0&&(F<0||C<0)||C>this.length)throw new RangeError("Attempt to write outside buffer bounds");V||(V="utf8");for(var q=!1;;)switch(V){case"hex":return _(this,E,C,F);case"utf8":case"utf-8":return A(this,E,C,F);case"ascii":return N(this,E,C,F);case"latin1":case"binary":return L(this,E,C,F);case"base64":return I(this,E,C,F);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return P(this,E,C,F);default:if(q)throw new TypeError("Unknown encoding: "+V);V=(""+V).toLowerCase(),q=!0}},t.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};function D(E,C,F){var V="";F=Math.min(E.length,F);for(var Z=C;Z<F;++Z)V+=String.fromCharCode(127&E[Z]);return V}function x(E,C,F){var V="";F=Math.min(E.length,F);for(var Z=C;Z<F;++Z)V+=String.fromCharCode(E[Z]);return V}function M(E,C,F){var V=E.length;(!C||C<0)&&(C=0),(!F||F<0||F>V)&&(F=V);for(var Z="",q=C;q<F;++q)Z+=O(E[q]);return Z}function v(E,C,F){for(var V=E.slice(C,F),Z="",q=0;q<V.length;q+=2)Z+=String.fromCharCode(V[q]+256*V[q+1]);return Z}function p(E,C,F){if(E%1!=0||E<0)throw new RangeError("offset is not uint");if(E+C>F)throw new RangeError("Trying to access beyond buffer length")}function b(E,C,F,V,Z,q){if(!t.isBuffer(E))throw new TypeError('"buffer" argument must be a Buffer instance');if(C>Z||C<q)throw new RangeError('"value" argument is out of bounds');if(F+V>E.length)throw new RangeError("Index out of range")}function g(E,C,F,V,Z,q){if(F+V>E.length)throw new RangeError("Index out of range");if(F<0)throw new RangeError("Index out of range")}function y(E,C,F,V,Z){return C=+C,F>>>=0,Z||g(E,0,F,4),o.write(E,C,F,V,23,4),F+4}function k(E,C,F,V,Z){return C=+C,F>>>=0,Z||g(E,0,F,8),o.write(E,C,F,V,52,8),F+8}t.prototype.slice=function(E,C){var F=this.length;(E=~~E)<0?(E+=F)<0&&(E=0):E>F&&(E=F),(C=C===void 0?F:~~C)<0?(C+=F)<0&&(C=0):C>F&&(C=F),C<E&&(C=E);var V=this.subarray(E,C);return V.__proto__=t.prototype,V},t.prototype.readUIntLE=function(E,C,F){E>>>=0,C>>>=0,F||p(E,C,this.length);for(var V=this[E],Z=1,q=0;++q<C&&(Z*=256);)V+=this[E+q]*Z;return V},t.prototype.readUIntBE=function(E,C,F){E>>>=0,C>>>=0,F||p(E,C,this.length);for(var V=this[E+--C],Z=1;C>0&&(Z*=256);)V+=this[E+--C]*Z;return V},t.prototype.readUInt8=function(E,C){return E>>>=0,C||p(E,1,this.length),this[E]},t.prototype.readUInt16LE=function(E,C){return E>>>=0,C||p(E,2,this.length),this[E]|this[E+1]<<8},t.prototype.readUInt16BE=function(E,C){return E>>>=0,C||p(E,2,this.length),this[E]<<8|this[E+1]},t.prototype.readUInt32LE=function(E,C){return E>>>=0,C||p(E,4,this.length),(this[E]|this[E+1]<<8|this[E+2]<<16)+16777216*this[E+3]},t.prototype.readUInt32BE=function(E,C){return E>>>=0,C||p(E,4,this.length),16777216*this[E]+(this[E+1]<<16|this[E+2]<<8|this[E+3])},t.prototype.readIntLE=function(E,C,F){E>>>=0,C>>>=0,F||p(E,C,this.length);for(var V=this[E],Z=1,q=0;++q<C&&(Z*=256);)V+=this[E+q]*Z;return V>=(Z*=128)&&(V-=Math.pow(2,8*C)),V},t.prototype.readIntBE=function(E,C,F){E>>>=0,C>>>=0,F||p(E,C,this.length);for(var V=C,Z=1,q=this[E+--V];V>0&&(Z*=256);)q+=this[E+--V]*Z;return q>=(Z*=128)&&(q-=Math.pow(2,8*C)),q},t.prototype.readInt8=function(E,C){return E>>>=0,C||p(E,1,this.length),128&this[E]?-1*(255-this[E]+1):this[E]},t.prototype.readInt16LE=function(E,C){E>>>=0,C||p(E,2,this.length);var F=this[E]|this[E+1]<<8;return 32768&F?4294901760|F:F},t.prototype.readInt16BE=function(E,C){E>>>=0,C||p(E,2,this.length);var F=this[E+1]|this[E]<<8;return 32768&F?4294901760|F:F},t.prototype.readInt32LE=function(E,C){return E>>>=0,C||p(E,4,this.length),this[E]|this[E+1]<<8|this[E+2]<<16|this[E+3]<<24},t.prototype.readInt32BE=function(E,C){return E>>>=0,C||p(E,4,this.length),this[E]<<24|this[E+1]<<16|this[E+2]<<8|this[E+3]},t.prototype.readFloatLE=function(E,C){return E>>>=0,C||p(E,4,this.length),o.read(this,E,!0,23,4)},t.prototype.readFloatBE=function(E,C){return E>>>=0,C||p(E,4,this.length),o.read(this,E,!1,23,4)},t.prototype.readDoubleLE=function(E,C){return E>>>=0,C||p(E,8,this.length),o.read(this,E,!0,52,8)},t.prototype.readDoubleBE=function(E,C){return E>>>=0,C||p(E,8,this.length),o.read(this,E,!1,52,8)},t.prototype.writeUIntLE=function(E,C,F,V){E=+E,C>>>=0,F>>>=0,V||b(this,E,C,F,Math.pow(2,8*F)-1,0);var Z=1,q=0;for(this[C]=255&E;++q<F&&(Z*=256);)this[C+q]=E/Z&255;return C+F},t.prototype.writeUIntBE=function(E,C,F,V){E=+E,C>>>=0,F>>>=0,V||b(this,E,C,F,Math.pow(2,8*F)-1,0);var Z=F-1,q=1;for(this[C+Z]=255&E;--Z>=0&&(q*=256);)this[C+Z]=E/q&255;return C+F},t.prototype.writeUInt8=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,1,255,0),this[C]=255&E,C+1},t.prototype.writeUInt16LE=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,2,65535,0),this[C]=255&E,this[C+1]=E>>>8,C+2},t.prototype.writeUInt16BE=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,2,65535,0),this[C]=E>>>8,this[C+1]=255&E,C+2},t.prototype.writeUInt32LE=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,4,4294967295,0),this[C+3]=E>>>24,this[C+2]=E>>>16,this[C+1]=E>>>8,this[C]=255&E,C+4},t.prototype.writeUInt32BE=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,4,4294967295,0),this[C]=E>>>24,this[C+1]=E>>>16,this[C+2]=E>>>8,this[C+3]=255&E,C+4},t.prototype.writeIntLE=function(E,C,F,V){if(E=+E,C>>>=0,!V){var Z=Math.pow(2,8*F-1);b(this,E,C,F,Z-1,-Z)}var q=0,K=1,et=0;for(this[C]=255&E;++q<F&&(K*=256);)E<0&&et===0&&this[C+q-1]!==0&&(et=1),this[C+q]=(E/K>>0)-et&255;return C+F},t.prototype.writeIntBE=function(E,C,F,V){if(E=+E,C>>>=0,!V){var Z=Math.pow(2,8*F-1);b(this,E,C,F,Z-1,-Z)}var q=F-1,K=1,et=0;for(this[C+q]=255&E;--q>=0&&(K*=256);)E<0&&et===0&&this[C+q+1]!==0&&(et=1),this[C+q]=(E/K>>0)-et&255;return C+F},t.prototype.writeInt8=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,1,127,-128),E<0&&(E=255+E+1),this[C]=255&E,C+1},t.prototype.writeInt16LE=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,2,32767,-32768),this[C]=255&E,this[C+1]=E>>>8,C+2},t.prototype.writeInt16BE=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,2,32767,-32768),this[C]=E>>>8,this[C+1]=255&E,C+2},t.prototype.writeInt32LE=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,4,2147483647,-2147483648),this[C]=255&E,this[C+1]=E>>>8,this[C+2]=E>>>16,this[C+3]=E>>>24,C+4},t.prototype.writeInt32BE=function(E,C,F){return E=+E,C>>>=0,F||b(this,E,C,4,2147483647,-2147483648),E<0&&(E=4294967295+E+1),this[C]=E>>>24,this[C+1]=E>>>16,this[C+2]=E>>>8,this[C+3]=255&E,C+4},t.prototype.writeFloatLE=function(E,C,F){return y(this,E,C,!0,F)},t.prototype.writeFloatBE=function(E,C,F){return y(this,E,C,!1,F)},t.prototype.writeDoubleLE=function(E,C,F){return k(this,E,C,!0,F)},t.prototype.writeDoubleBE=function(E,C,F){return k(this,E,C,!1,F)},t.prototype.copy=function(E,C,F,V){if(!t.isBuffer(E))throw new TypeError("argument should be a Buffer");if(F||(F=0),V||V===0||(V=this.length),C>=E.length&&(C=E.length),C||(C=0),V>0&&V<F&&(V=F),V===F||E.length===0||this.length===0)return 0;if(C<0)throw new RangeError("targetStart out of bounds");if(F<0||F>=this.length)throw new RangeError("Index out of range");if(V<0)throw new RangeError("sourceEnd out of bounds");V>this.length&&(V=this.length),E.length-C<V-F&&(V=E.length-C+F);var Z=V-F;if(this===E&&typeof Uint8Array.prototype.copyWithin=="function")this.copyWithin(C,F,V);else if(this===E&&F<C&&C<V)for(var q=Z-1;q>=0;--q)E[q+C]=this[q+F];else Uint8Array.prototype.set.call(E,this.subarray(F,V),C);return Z},t.prototype.fill=function(E,C,F,V){if(typeof E=="string"){if(typeof C=="string"?(V=C,C=0,F=this.length):typeof F=="string"&&(V=F,F=this.length),V!==void 0&&typeof V!="string")throw new TypeError("encoding must be a string");if(typeof V=="string"&&!t.isEncoding(V))throw new TypeError("Unknown encoding: "+V);if(E.length===1){var Z=E.charCodeAt(0);(V==="utf8"&&Z<128||V==="latin1")&&(E=Z)}}else typeof E=="number"&&(E&=255);if(C<0||this.length<C||this.length<F)throw new RangeError("Out of range index");if(F<=C)return this;var q;if(C>>>=0,F=F===void 0?this.length:F>>>0,E||(E=0),typeof E=="number")for(q=C;q<F;++q)this[q]=E;else{var K=t.isBuffer(E)?E:t.from(E,V),et=K.length;if(et===0)throw new TypeError('The value "'+E+'" is invalid for argument "value"');for(q=0;q<F-C;++q)this[q+C]=K[q%et]}return this};var R=/[^+/0-9A-Za-z-_]/g;function O(E){return E<16?"0"+E.toString(16):E.toString(16)}function z(E,C){var F;C=C||1/0;for(var V=E.length,Z=null,q=[],K=0;K<V;++K){if((F=E.charCodeAt(K))>55295&&F<57344){if(!Z){if(F>56319){(C-=3)>-1&&q.push(239,191,189);continue}if(K+1===V){(C-=3)>-1&&q.push(239,191,189);continue}Z=F;continue}if(F<56320){(C-=3)>-1&&q.push(239,191,189),Z=F;continue}F=65536+(Z-55296<<10|F-56320)}else Z&&(C-=3)>-1&&q.push(239,191,189);if(Z=null,F<128){if((C-=1)<0)break;q.push(F)}else if(F<2048){if((C-=2)<0)break;q.push(F>>6|192,63&F|128)}else if(F<65536){if((C-=3)<0)break;q.push(F>>12|224,F>>6&63|128,63&F|128)}else{if(!(F<1114112))throw new Error("Invalid code point");if((C-=4)<0)break;q.push(F>>18|240,F>>12&63|128,F>>6&63|128,63&F|128)}}return q}function $(E){return a.toByteArray(function(C){if((C=(C=C.split("=")[0]).trim().replace(R,"")).length<2)return"";for(;C.length%4!=0;)C+="=";return C}(E))}function W(E,C,F,V){for(var Z=0;Z<V&&!(Z+F>=C.length||Z>=E.length);++Z)C[Z+F]=E[Z];return Z}function j(E,C){return E instanceof C||E!=null&&E.constructor!=null&&E.constructor.name!=null&&E.constructor.name===C.name}function H(E){return E!=E}}).call(this)}).call(this,s("buffer").Buffer)},{"base64-js":185,buffer:220,ieee754:439}],221:[function(s,T,S){var m=s("safe-buffer").Buffer,a=s("stream").Transform,o=s("string_decoder").StringDecoder;function r(t){a.call(this),this.hashMode=typeof t=="string",this.hashMode?this[t]=this._finalOrDigest:this.final=this._finalOrDigest,this._final&&(this.__final=this._final,this._final=null),this._decoder=null,this._encoding=null}s("inherits")(r,a),r.prototype.update=function(t,e,l){typeof t=="string"&&(t=m.from(t,e));var n=this._update(t);return this.hashMode?this:(l&&(n=this._toString(n,l)),n)},r.prototype.setAutoPadding=function(){},r.prototype.getAuthTag=function(){throw new Error("trying to get auth tag in unsupported state")},r.prototype.setAuthTag=function(){throw new Error("trying to set auth tag in unsupported state")},r.prototype.setAAD=function(){throw new Error("trying to set aad in unsupported state")},r.prototype._transform=function(t,e,l){var n;try{this.hashMode?this._update(t):this.push(this._update(t))}catch(i){n=i}finally{l(n)}},r.prototype._flush=function(t){var e;try{this.push(this.__final())}catch(l){e=l}t(e)},r.prototype._finalOrDigest=function(t){var e=this.__final()||m.alloc(0);return t&&(e=this._toString(e,t,!0)),e},r.prototype._toString=function(t,e,l){if(this._decoder||(this._decoder=new o(e),this._encoding=e),this._encoding!==e)throw new Error("can't switch encodings");var n=this._decoder.write(t);return l&&(n+=this._decoder.end()),n},T.exports=r},{inherits:440,"safe-buffer":494,stream:505,string_decoder:218}],222:[function(s,T,S){var m=s("../internals/is-callable"),a=s("../internals/try-to-string"),o=TypeError;T.exports=function(r){if(m(r))return r;throw new o(a(r)+" is not a function")}},{"../internals/is-callable":285,"../internals/try-to-string":349}],223:[function(s,T,S){var m=s("../internals/is-constructor"),a=s("../internals/try-to-string"),o=TypeError;T.exports=function(r){if(m(r))return r;throw new o(a(r)+" is not a constructor")}},{"../internals/is-constructor":286,"../internals/try-to-string":349}],224:[function(s,T,S){var m=s("../internals/is-callable"),a=String,o=TypeError;T.exports=function(r){if(typeof r=="object"||m(r))return r;throw new o("Can't set "+a(r)+" as a prototype")}},{"../internals/is-callable":285}],225:[function(s,T,S){var m=s("../internals/well-known-symbol"),a=s("../internals/object-create"),o=s("../internals/object-define-property").f,r=m("unscopables"),t=Array.prototype;t[r]===void 0&&o(t,r,{configurable:!0,value:a(null)}),T.exports=function(e){t[r][e]=!0}},{"../internals/object-create":306,"../internals/object-define-property":308,"../internals/well-known-symbol":357}],226:[function(s,T,S){var m=s("../internals/object-is-prototype-of"),a=TypeError;T.exports=function(o,r){if(m(r,o))return o;throw new a("Incorrect invocation")}},{"../internals/object-is-prototype-of":314}],227:[function(s,T,S){var m=s("../internals/is-object"),a=String,o=TypeError;T.exports=function(r){if(m(r))return r;throw new o(a(r)+" is not an object")}},{"../internals/is-object":289}],228:[function(s,T,S){var m=s("../internals/to-indexed-object"),a=s("../internals/to-absolute-index"),o=s("../internals/length-of-array-like"),r=function(t){return function(e,l,n){var i,f=m(e),c=o(f),u=a(n,c);if(t&&l!=l){for(;c>u;)if((i=f[u++])!=i)return!0}else for(;c>u;u++)if((t||u in f)&&f[u]===l)return t||u||0;return!t&&-1}};T.exports={includes:r(!0),indexOf:r(!1)}},{"../internals/length-of-array-like":299,"../internals/to-absolute-index":340,"../internals/to-indexed-object":341}],229:[function(s,T,S){var m=s("../internals/function-bind-context"),a=s("../internals/function-uncurry-this"),o=s("../internals/indexed-object"),r=s("../internals/to-object"),t=s("../internals/length-of-array-like"),e=s("../internals/array-species-create"),l=a([].push),n=function(i){var f=i===1,c=i===2,u=i===3,d=i===4,h=i===6,w=i===7,_=i===5||h;return function(A,N,L,I){for(var P,B,U=r(A),D=o(U),x=m(N,L),M=t(D),v=0,p=I||e,b=f?p(A,M):c||w?p(A,0):void 0;M>v;v++)if((_||v in D)&&(B=x(P=D[v],v,U),i))if(f)b[v]=B;else if(B)switch(i){case 3:return!0;case 5:return P;case 6:return v;case 2:l(b,P)}else switch(i){case 4:return!1;case 7:l(b,P)}return h?-1:u||d?d:b}};T.exports={forEach:n(0),map:n(1),filter:n(2),some:n(3),every:n(4),find:n(5),findIndex:n(6),filterReject:n(7)}},{"../internals/array-species-create":233,"../internals/function-bind-context":262,"../internals/function-uncurry-this":268,"../internals/indexed-object":280,"../internals/length-of-array-like":299,"../internals/to-object":344}],230:[function(s,T,S){var m=s("../internals/to-absolute-index"),a=s("../internals/length-of-array-like"),o=s("../internals/create-property"),r=Array,t=Math.max;T.exports=function(e,l,n){for(var i=a(e),f=m(l,i),c=m(n===void 0?i:n,i),u=r(t(c-f,0)),d=0;f<c;f++,d++)o(u,d,e[f]);return u.length=d,u}},{"../internals/create-property":243,"../internals/length-of-array-like":299,"../internals/to-absolute-index":340}],231:[function(s,T,S){var m=s("../internals/function-uncurry-this");T.exports=m([].slice)},{"../internals/function-uncurry-this":268}],232:[function(s,T,S){var m=s("../internals/is-array"),a=s("../internals/is-constructor"),o=s("../internals/is-object"),r=s("../internals/well-known-symbol")("species"),t=Array;T.exports=function(e){var l;return m(e)&&(l=e.constructor,(a(l)&&(l===t||m(l.prototype))||o(l)&&(l=l[r])===null)&&(l=void 0)),l===void 0?t:l}},{"../internals/is-array":284,"../internals/is-constructor":286,"../internals/is-object":289,"../internals/well-known-symbol":357}],233:[function(s,T,S){var m=s("../internals/array-species-constructor");T.exports=function(a,o){return new(m(a))(o===0?0:o)}},{"../internals/array-species-constructor":232}],234:[function(s,T,S){var m=s("../internals/well-known-symbol")("iterator"),a=!1;try{var o=0,r={next:function(){return{done:!!o++}},return:function(){a=!0}};r[m]=function(){return this},Array.from(r,function(){throw 2})}catch{}T.exports=function(t,e){try{if(!e&&!a)return!1}catch{return!1}var l=!1;try{var n={};n[m]=function(){return{next:function(){return{done:l=!0}}}},t(n)}catch{}return l}},{"../internals/well-known-symbol":357}],235:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=m({}.toString),o=m("".slice);T.exports=function(r){return o(a(r),8,-1)}},{"../internals/function-uncurry-this":268}],236:[function(s,T,S){var m=s("../internals/to-string-tag-support"),a=s("../internals/is-callable"),o=s("../internals/classof-raw"),r=s("../internals/well-known-symbol")("toStringTag"),t=Object,e=o(function(){return arguments}())==="Arguments";T.exports=m?o:function(l){var n,i,f;return l===void 0?"Undefined":l===null?"Null":typeof(i=function(c,u){try{return c[u]}catch{}}(n=t(l),r))=="string"?i:e?o(n):(f=o(n))==="Object"&&a(n.callee)?"Arguments":f}},{"../internals/classof-raw":235,"../internals/is-callable":285,"../internals/to-string-tag-support":347,"../internals/well-known-symbol":357}],237:[function(s,T,S){var m=s("../internals/has-own-property"),a=s("../internals/own-keys"),o=s("../internals/object-get-own-property-descriptor"),r=s("../internals/object-define-property");T.exports=function(t,e,l){for(var n=a(e),i=r.f,f=o.f,c=0;c<n.length;c++){var u=n[c];m(t,u)||l&&m(l,u)||i(t,u,f(e,u))}}},{"../internals/has-own-property":275,"../internals/object-define-property":308,"../internals/object-get-own-property-descriptor":309,"../internals/own-keys":321}],238:[function(s,T,S){var m=s("../internals/well-known-symbol")("match");T.exports=function(a){var o=/./;try{"/./"[a](o)}catch{try{return o[m]=!1,"/./"[a](o)}catch{}}return!1}},{"../internals/well-known-symbol":357}],239:[function(s,T,S){var m=s("../internals/fails");T.exports=!m(function(){function a(){}return a.prototype.constructor=null,Object.getPrototypeOf(new a)!==a.prototype})},{"../internals/fails":260}],240:[function(s,T,S){T.exports=function(m,a){return{value:m,done:a}}},{}],241:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/object-define-property"),o=s("../internals/create-property-descriptor");T.exports=m?function(r,t,e){return a.f(r,t,o(1,e))}:function(r,t,e){return r[t]=e,r}},{"../internals/create-property-descriptor":242,"../internals/descriptors":247,"../internals/object-define-property":308}],242:[function(s,T,S){T.exports=function(m,a){return{enumerable:!(1&m),configurable:!(2&m),writable:!(4&m),value:a}}},{}],243:[function(s,T,S){var m=s("../internals/to-property-key"),a=s("../internals/object-define-property"),o=s("../internals/create-property-descriptor");T.exports=function(r,t,e){var l=m(t);l in r?a.f(r,l,o(0,e)):r[l]=e}},{"../internals/create-property-descriptor":242,"../internals/object-define-property":308,"../internals/to-property-key":346}],244:[function(s,T,S){var m=s("../internals/make-built-in"),a=s("../internals/object-define-property");T.exports=function(o,r,t){return t.get&&m(t.get,r,{getter:!0}),t.set&&m(t.set,r,{setter:!0}),a.f(o,r,t)}},{"../internals/make-built-in":300,"../internals/object-define-property":308}],245:[function(s,T,S){var m=s("../internals/is-callable"),a=s("../internals/object-define-property"),o=s("../internals/make-built-in"),r=s("../internals/define-global-property");T.exports=function(t,e,l,n){n||(n={});var i=n.enumerable,f=n.name!==void 0?n.name:e;if(m(l)&&o(l,f,n),n.global)i?t[e]=l:r(e,l);else{try{n.unsafe?t[e]&&(i=!0):delete t[e]}catch{}i?t[e]=l:a.f(t,e,{value:l,enumerable:!1,configurable:!n.nonConfigurable,writable:!n.nonWritable})}return t}},{"../internals/define-global-property":246,"../internals/is-callable":285,"../internals/make-built-in":300,"../internals/object-define-property":308}],246:[function(s,T,S){var m=s("../internals/global"),a=Object.defineProperty;T.exports=function(o,r){try{a(m,o,{value:r,configurable:!0,writable:!0})}catch{m[o]=r}return r}},{"../internals/global":274}],247:[function(s,T,S){var m=s("../internals/fails");T.exports=!m(function(){return Object.defineProperty({},1,{get:function(){return 7}})[1]!==7})},{"../internals/fails":260}],248:[function(s,T,S){var m=typeof document=="object"&&document.all,a=m===void 0&&m!==void 0;T.exports={all:m,IS_HTMLDDA:a}},{}],249:[function(s,T,S){var m=s("../internals/global"),a=s("../internals/is-object"),o=m.document,r=a(o)&&a(o.createElement);T.exports=function(t){return r?o.createElement(t):{}}},{"../internals/global":274,"../internals/is-object":289}],250:[function(s,T,S){var m=s("../internals/engine-is-deno"),a=s("../internals/engine-is-node");T.exports=!m&&!a&&typeof window=="object"&&typeof document=="object"},{"../internals/engine-is-deno":251,"../internals/engine-is-node":254}],251:[function(s,T,S){T.exports=typeof Deno=="object"&&Deno&&typeof Deno.version=="object"},{}],252:[function(s,T,S){var m=s("../internals/engine-user-agent");T.exports=/ipad|iphone|ipod/i.test(m)&&typeof Pebble<"u"},{"../internals/engine-user-agent":256}],253:[function(s,T,S){var m=s("../internals/engine-user-agent");T.exports=/(?:ipad|iphone|ipod).*applewebkit/i.test(m)},{"../internals/engine-user-agent":256}],254:[function(s,T,S){var m=s("../internals/global"),a=s("../internals/classof-raw");T.exports=a(m.process)==="process"},{"../internals/classof-raw":235,"../internals/global":274}],255:[function(s,T,S){var m=s("../internals/engine-user-agent");T.exports=/web0s(?!.*chrome)/i.test(m)},{"../internals/engine-user-agent":256}],256:[function(s,T,S){T.exports=typeof navigator<"u"&&String(navigator.userAgent)||""},{}],257:[function(s,T,S){var m,a,o=s("../internals/global"),r=s("../internals/engine-user-agent"),t=o.process,e=o.Deno,l=t&&t.versions||e&&e.version,n=l&&l.v8;n&&(a=(m=n.split("."))[0]>0&&m[0]<4?1:+(m[0]+m[1])),!a&&r&&(!(m=r.match(/Edge\/(\d+)/))||m[1]>=74)&&(m=r.match(/Chrome\/(\d+)/))&&(a=+m[1]),T.exports=a},{"../internals/engine-user-agent":256,"../internals/global":274}],258:[function(s,T,S){T.exports=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"]},{}],259:[function(s,T,S){var m=s("../internals/global"),a=s("../internals/object-get-own-property-descriptor").f,o=s("../internals/create-non-enumerable-property"),r=s("../internals/define-built-in"),t=s("../internals/define-global-property"),e=s("../internals/copy-constructor-properties"),l=s("../internals/is-forced");T.exports=function(n,i){var f,c,u,d,h,w=n.target,_=n.global,A=n.stat;if(f=_?m:A?m[w]||t(w,{}):(m[w]||{}).prototype)for(c in i){if(d=i[c],u=n.dontCallGetSet?(h=a(f,c))&&h.value:f[c],!l(_?c:w+(A?".":"#")+c,n.forced)&&u!==void 0){if(typeof d==typeof u)continue;e(d,u)}(n.sham||u&&u.sham)&&o(d,"sham",!0),r(f,c,d,n)}}},{"../internals/copy-constructor-properties":237,"../internals/create-non-enumerable-property":241,"../internals/define-built-in":245,"../internals/define-global-property":246,"../internals/global":274,"../internals/is-forced":287,"../internals/object-get-own-property-descriptor":309}],260:[function(s,T,S){T.exports=function(m){try{return!!m()}catch{return!0}}},{}],261:[function(s,T,S){var m=s("../internals/function-bind-native"),a=Function.prototype,o=a.apply,r=a.call;T.exports=typeof Reflect=="object"&&Reflect.apply||(m?r.bind(o):function(){return r.apply(o,arguments)})},{"../internals/function-bind-native":263}],262:[function(s,T,S){var m=s("../internals/function-uncurry-this-clause"),a=s("../internals/a-callable"),o=s("../internals/function-bind-native"),r=m(m.bind);T.exports=function(t,e){return a(t),e===void 0?t:o?r(t,e):function(){return t.apply(e,arguments)}}},{"../internals/a-callable":222,"../internals/function-bind-native":263,"../internals/function-uncurry-this-clause":267}],263:[function(s,T,S){var m=s("../internals/fails");T.exports=!m(function(){var a=function(){}.bind();return typeof a!="function"||a.hasOwnProperty("prototype")})},{"../internals/fails":260}],264:[function(s,T,S){var m=s("../internals/function-bind-native"),a=Function.prototype.call;T.exports=m?a.bind(a):function(){return a.apply(a,arguments)}},{"../internals/function-bind-native":263}],265:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/has-own-property"),o=Function.prototype,r=m&&Object.getOwnPropertyDescriptor,t=a(o,"name"),e=t&&function(){}.name==="something",l=t&&(!m||m&&r(o,"name").configurable);T.exports={EXISTS:t,PROPER:e,CONFIGURABLE:l}},{"../internals/descriptors":247,"../internals/has-own-property":275}],266:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=s("../internals/a-callable");T.exports=function(o,r,t){try{return m(a(Object.getOwnPropertyDescriptor(o,r)[t]))}catch{}}},{"../internals/a-callable":222,"../internals/function-uncurry-this":268}],267:[function(s,T,S){var m=s("../internals/classof-raw"),a=s("../internals/function-uncurry-this");T.exports=function(o){if(m(o)==="Function")return a(o)}},{"../internals/classof-raw":235,"../internals/function-uncurry-this":268}],268:[function(s,T,S){var m=s("../internals/function-bind-native"),a=Function.prototype,o=a.call,r=m&&a.bind.bind(o,o);T.exports=m?r:function(t){return function(){return o.apply(t,arguments)}}},{"../internals/function-bind-native":263}],269:[function(s,T,S){var m=s("../internals/global"),a=s("../internals/is-callable"),o=function(r){return a(r)?r:void 0};T.exports=function(r,t){return arguments.length<2?o(m[r]):m[r]&&m[r][t]}},{"../internals/global":274,"../internals/is-callable":285}],270:[function(s,T,S){var m=s("../internals/classof"),a=s("../internals/get-method"),o=s("../internals/is-null-or-undefined"),r=s("../internals/iterators"),t=s("../internals/well-known-symbol")("iterator");T.exports=function(e){if(!o(e))return a(e,t)||a(e,"@@iterator")||r[m(e)]}},{"../internals/classof":236,"../internals/get-method":273,"../internals/is-null-or-undefined":288,"../internals/iterators":298,"../internals/well-known-symbol":357}],271:[function(s,T,S){var m=s("../internals/function-call"),a=s("../internals/a-callable"),o=s("../internals/an-object"),r=s("../internals/try-to-string"),t=s("../internals/get-iterator-method"),e=TypeError;T.exports=function(l,n){var i=arguments.length<2?t(l):n;if(a(i))return o(m(i,l));throw new e(r(l)+" is not iterable")}},{"../internals/a-callable":222,"../internals/an-object":227,"../internals/function-call":264,"../internals/get-iterator-method":270,"../internals/try-to-string":349}],272:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=s("../internals/is-array"),o=s("../internals/is-callable"),r=s("../internals/classof-raw"),t=s("../internals/to-string"),e=m([].push);T.exports=function(l){if(o(l))return l;if(a(l)){for(var n=l.length,i=[],f=0;f<n;f++){var c=l[f];typeof c=="string"?e(i,c):typeof c!="number"&&r(c)!=="Number"&&r(c)!=="String"||e(i,t(c))}var u=i.length,d=!0;return function(h,w){if(d)return d=!1,w;if(a(this))return w;for(var _=0;_<u;_++)if(i[_]===h)return w}}}},{"../internals/classof-raw":235,"../internals/function-uncurry-this":268,"../internals/is-array":284,"../internals/is-callable":285,"../internals/to-string":348}],273:[function(s,T,S){var m=s("../internals/a-callable"),a=s("../internals/is-null-or-undefined");T.exports=function(o,r){var t=o[r];return a(t)?void 0:m(t)}},{"../internals/a-callable":222,"../internals/is-null-or-undefined":288}],274:[function(s,T,S){(function(m){(function(){var a=function(o){return o&&o.Math===Math&&o};T.exports=a(typeof globalThis=="object"&&globalThis)||a(typeof window=="object"&&window)||a(typeof self=="object"&&self)||a(typeof m=="object"&&m)||function(){return this}()||this||Function("return this")()}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{}],275:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=s("../internals/to-object"),o=m({}.hasOwnProperty);T.exports=Object.hasOwn||function(r,t){return o(a(r),t)}},{"../internals/function-uncurry-this":268,"../internals/to-object":344}],276:[function(s,T,S){T.exports={}},{}],277:[function(s,T,S){T.exports=function(m,a){try{arguments.length===1?console.error(m):console.error(m,a)}catch{}}},{}],278:[function(s,T,S){var m=s("../internals/get-built-in");T.exports=m("document","documentElement")},{"../internals/get-built-in":269}],279:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/fails"),o=s("../internals/document-create-element");T.exports=!m&&!a(function(){return Object.defineProperty(o("div"),"a",{get:function(){return 7}}).a!==7})},{"../internals/descriptors":247,"../internals/document-create-element":249,"../internals/fails":260}],280:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=s("../internals/fails"),o=s("../internals/classof-raw"),r=Object,t=m("".split);T.exports=a(function(){return!r("z").propertyIsEnumerable(0)})?function(e){return o(e)==="String"?t(e,""):r(e)}:r},{"../internals/classof-raw":235,"../internals/fails":260,"../internals/function-uncurry-this":268}],281:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=s("../internals/is-callable"),o=s("../internals/shared-store"),r=m(Function.toString);a(o.inspectSource)||(o.inspectSource=function(t){return r(t)}),T.exports=o.inspectSource},{"../internals/function-uncurry-this":268,"../internals/is-callable":285,"../internals/shared-store":333}],282:[function(s,T,S){var m,a,o,r=s("../internals/weak-map-basic-detection"),t=s("../internals/global"),e=s("../internals/is-object"),l=s("../internals/create-non-enumerable-property"),n=s("../internals/has-own-property"),i=s("../internals/shared-store"),f=s("../internals/shared-key"),c=s("../internals/hidden-keys"),u=t.TypeError,d=t.WeakMap;if(r||i.state){var h=i.state||(i.state=new d);h.get=h.get,h.has=h.has,h.set=h.set,m=function(_,A){if(h.has(_))throw new u("Object already initialized");return A.facade=_,h.set(_,A),A},a=function(_){return h.get(_)||{}},o=function(_){return h.has(_)}}else{var w=f("state");c[w]=!0,m=function(_,A){if(n(_,w))throw new u("Object already initialized");return A.facade=_,l(_,w,A),A},a=function(_){return n(_,w)?_[w]:{}},o=function(_){return n(_,w)}}T.exports={set:m,get:a,has:o,enforce:function(_){return o(_)?a(_):m(_,{})},getterFor:function(_){return function(A){var N;if(!e(A)||(N=a(A)).type!==_)throw new u("Incompatible receiver, "+_+" required");return N}}}},{"../internals/create-non-enumerable-property":241,"../internals/global":274,"../internals/has-own-property":275,"../internals/hidden-keys":276,"../internals/is-object":289,"../internals/shared-key":332,"../internals/shared-store":333,"../internals/weak-map-basic-detection":354}],283:[function(s,T,S){var m=s("../internals/well-known-symbol"),a=s("../internals/iterators"),o=m("iterator"),r=Array.prototype;T.exports=function(t){return t!==void 0&&(a.Array===t||r[o]===t)}},{"../internals/iterators":298,"../internals/well-known-symbol":357}],284:[function(s,T,S){var m=s("../internals/classof-raw");T.exports=Array.isArray||function(a){return m(a)==="Array"}},{"../internals/classof-raw":235}],285:[function(s,T,S){var m=s("../internals/document-all"),a=m.all;T.exports=m.IS_HTMLDDA?function(o){return typeof o=="function"||o===a}:function(o){return typeof o=="function"}},{"../internals/document-all":248}],286:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=s("../internals/fails"),o=s("../internals/is-callable"),r=s("../internals/classof"),t=s("../internals/get-built-in"),e=s("../internals/inspect-source"),l=function(){},n=[],i=t("Reflect","construct"),f=/^\s*(?:class|function)\b/,c=m(f.exec),u=!f.test(l),d=function(w){if(!o(w))return!1;try{return i(l,n,w),!0}catch{return!1}},h=function(w){if(!o(w))return!1;switch(r(w)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return u||!!c(f,e(w))}catch{return!0}};h.sham=!0,T.exports=!i||a(function(){var w;return d(d.call)||!d(Object)||!d(function(){w=!0})||w})?h:d},{"../internals/classof":236,"../internals/fails":260,"../internals/function-uncurry-this":268,"../internals/get-built-in":269,"../internals/inspect-source":281,"../internals/is-callable":285}],287:[function(s,T,S){var m=s("../internals/fails"),a=s("../internals/is-callable"),o=/#|\.prototype\./,r=function(i,f){var c=e[t(i)];return c===n||c!==l&&(a(f)?m(f):!!f)},t=r.normalize=function(i){return String(i).replace(o,".").toLowerCase()},e=r.data={},l=r.NATIVE="N",n=r.POLYFILL="P";T.exports=r},{"../internals/fails":260,"../internals/is-callable":285}],288:[function(s,T,S){T.exports=function(m){return m==null}},{}],289:[function(s,T,S){var m=s("../internals/is-callable"),a=s("../internals/document-all"),o=a.all;T.exports=a.IS_HTMLDDA?function(r){return typeof r=="object"?r!==null:m(r)||r===o}:function(r){return typeof r=="object"?r!==null:m(r)}},{"../internals/document-all":248,"../internals/is-callable":285}],290:[function(s,T,S){T.exports=!1},{}],291:[function(s,T,S){var m=s("../internals/is-object"),a=s("../internals/classof-raw"),o=s("../internals/well-known-symbol")("match");T.exports=function(r){var t;return m(r)&&((t=r[o])!==void 0?!!t:a(r)==="RegExp")}},{"../internals/classof-raw":235,"../internals/is-object":289,"../internals/well-known-symbol":357}],292:[function(s,T,S){var m=s("../internals/get-built-in"),a=s("../internals/is-callable"),o=s("../internals/object-is-prototype-of"),r=s("../internals/use-symbol-as-uid"),t=Object;T.exports=r?function(e){return typeof e=="symbol"}:function(e){var l=m("Symbol");return a(l)&&o(l.prototype,t(e))}},{"../internals/get-built-in":269,"../internals/is-callable":285,"../internals/object-is-prototype-of":314,"../internals/use-symbol-as-uid":351}],293:[function(s,T,S){var m=s("../internals/function-bind-context"),a=s("../internals/function-call"),o=s("../internals/an-object"),r=s("../internals/try-to-string"),t=s("../internals/is-array-iterator-method"),e=s("../internals/length-of-array-like"),l=s("../internals/object-is-prototype-of"),n=s("../internals/get-iterator"),i=s("../internals/get-iterator-method"),f=s("../internals/iterator-close"),c=TypeError,u=function(h,w){this.stopped=h,this.result=w},d=u.prototype;T.exports=function(h,w,_){var A,N,L,I,P,B,U,D=_&&_.that,x=!(!_||!_.AS_ENTRIES),M=!(!_||!_.IS_RECORD),v=!(!_||!_.IS_ITERATOR),p=!(!_||!_.INTERRUPTED),b=m(w,D),g=function(k){return A&&f(A,"normal",k),new u(!0,k)},y=function(k){return x?(o(k),p?b(k[0],k[1],g):b(k[0],k[1])):p?b(k,g):b(k)};if(M)A=h.iterator;else if(v)A=h;else{if(!(N=i(h)))throw new c(r(h)+" is not iterable");if(t(N)){for(L=0,I=e(h);I>L;L++)if((P=y(h[L]))&&l(d,P))return P;return new u(!1)}A=n(h,N)}for(B=M?h.next:A.next;!(U=a(B,A)).done;){try{P=y(U.value)}catch(k){f(A,"throw",k)}if(typeof P=="object"&&P&&l(d,P))return P}return new u(!1)}},{"../internals/an-object":227,"../internals/function-bind-context":262,"../internals/function-call":264,"../internals/get-iterator":271,"../internals/get-iterator-method":270,"../internals/is-array-iterator-method":283,"../internals/iterator-close":294,"../internals/length-of-array-like":299,"../internals/object-is-prototype-of":314,"../internals/try-to-string":349}],294:[function(s,T,S){var m=s("../internals/function-call"),a=s("../internals/an-object"),o=s("../internals/get-method");T.exports=function(r,t,e){var l,n;a(r);try{if(!(l=o(r,"return"))){if(t==="throw")throw e;return e}l=m(l,r)}catch(i){n=!0,l=i}if(t==="throw")throw e;if(n)throw l;return a(l),e}},{"../internals/an-object":227,"../internals/function-call":264,"../internals/get-method":273}],295:[function(s,T,S){var m=s("../internals/iterators-core").IteratorPrototype,a=s("../internals/object-create"),o=s("../internals/create-property-descriptor"),r=s("../internals/set-to-string-tag"),t=s("../internals/iterators"),e=function(){return this};T.exports=function(l,n,i,f){var c=n+" Iterator";return l.prototype=a(m,{next:o(+!f,i)}),r(l,c,!1,!0),t[c]=e,l}},{"../internals/create-property-descriptor":242,"../internals/iterators":298,"../internals/iterators-core":297,"../internals/object-create":306,"../internals/set-to-string-tag":331}],296:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/function-call"),o=s("../internals/is-pure"),r=s("../internals/function-name"),t=s("../internals/is-callable"),e=s("../internals/iterator-create-constructor"),l=s("../internals/object-get-prototype-of"),n=s("../internals/object-set-prototype-of"),i=s("../internals/set-to-string-tag"),f=s("../internals/create-non-enumerable-property"),c=s("../internals/define-built-in"),u=s("../internals/well-known-symbol"),d=s("../internals/iterators"),h=s("../internals/iterators-core"),w=r.PROPER,_=r.CONFIGURABLE,A=h.IteratorPrototype,N=h.BUGGY_SAFARI_ITERATORS,L=u("iterator"),I=function(){return this};T.exports=function(P,B,U,D,x,M,v){e(U,B,D);var p,b,g,y=function(j){if(j===x&&$)return $;if(!N&&j&&j in O)return O[j];switch(j){case"keys":case"values":case"entries":return function(){return new U(this,j)}}return function(){return new U(this)}},k=B+" Iterator",R=!1,O=P.prototype,z=O[L]||O["@@iterator"]||x&&O[x],$=!N&&z||y(x),W=B==="Array"&&O.entries||z;if(W&&(p=l(W.call(new P)))!==Object.prototype&&p.next&&(o||l(p)===A||(n?n(p,A):t(p[L])||c(p,L,I)),i(p,k,!0,!0),o&&(d[k]=I)),w&&x==="values"&&z&&z.name!=="values"&&(!o&&_?f(O,"name","values"):(R=!0,$=function(){return a(z,this)})),x)if(b={values:y("values"),keys:M?$:y("keys"),entries:y("entries")},v)for(g in b)(N||R||!(g in O))&&c(O,g,b[g]);else m({target:B,proto:!0,forced:N||R},b);return o&&!v||O[L]===$||c(O,L,$,{name:x}),d[B]=$,b}},{"../internals/create-non-enumerable-property":241,"../internals/define-built-in":245,"../internals/export":259,"../internals/function-call":264,"../internals/function-name":265,"../internals/is-callable":285,"../internals/is-pure":290,"../internals/iterator-create-constructor":295,"../internals/iterators":298,"../internals/iterators-core":297,"../internals/object-get-prototype-of":313,"../internals/object-set-prototype-of":318,"../internals/set-to-string-tag":331,"../internals/well-known-symbol":357}],297:[function(s,T,S){var m,a,o,r=s("../internals/fails"),t=s("../internals/is-callable"),e=s("../internals/is-object"),l=s("../internals/object-create"),n=s("../internals/object-get-prototype-of"),i=s("../internals/define-built-in"),f=s("../internals/well-known-symbol"),c=s("../internals/is-pure"),u=f("iterator"),d=!1;[].keys&&("next"in(o=[].keys())?(a=n(n(o)))!==Object.prototype&&(m=a):d=!0),!e(m)||r(function(){var h={};return m[u].call(h)!==h})?m={}:c&&(m=l(m)),t(m[u])||i(m,u,function(){return this}),T.exports={IteratorPrototype:m,BUGGY_SAFARI_ITERATORS:d}},{"../internals/define-built-in":245,"../internals/fails":260,"../internals/is-callable":285,"../internals/is-object":289,"../internals/is-pure":290,"../internals/object-create":306,"../internals/object-get-prototype-of":313,"../internals/well-known-symbol":357}],298:[function(s,T,S){arguments[4][276][0].apply(S,arguments)},{dup:276}],299:[function(s,T,S){var m=s("../internals/to-length");T.exports=function(a){return m(a.length)}},{"../internals/to-length":343}],300:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=s("../internals/fails"),o=s("../internals/is-callable"),r=s("../internals/has-own-property"),t=s("../internals/descriptors"),e=s("../internals/function-name").CONFIGURABLE,l=s("../internals/inspect-source"),n=s("../internals/internal-state"),i=n.enforce,f=n.get,c=String,u=Object.defineProperty,d=m("".slice),h=m("".replace),w=m([].join),_=t&&!a(function(){return u(function(){},"length",{value:8}).length!==8}),A=String(String).split("String"),N=T.exports=function(L,I,P){d(c(I),0,7)==="Symbol("&&(I="["+h(c(I),/^Symbol\(([^)]*)\)/,"$1")+"]"),P&&P.getter&&(I="get "+I),P&&P.setter&&(I="set "+I),(!r(L,"name")||e&&L.name!==I)&&(t?u(L,"name",{value:I,configurable:!0}):L.name=I),_&&P&&r(P,"arity")&&L.length!==P.arity&&u(L,"length",{value:P.arity});try{P&&r(P,"constructor")&&P.constructor?t&&u(L,"prototype",{writable:!1}):L.prototype&&(L.prototype=void 0)}catch{}var B=i(L);return r(B,"source")||(B.source=w(A,typeof I=="string"?I:"")),L};Function.prototype.toString=N(function(){return o(this)&&f(this).source||l(this)},"toString")},{"../internals/descriptors":247,"../internals/fails":260,"../internals/function-name":265,"../internals/function-uncurry-this":268,"../internals/has-own-property":275,"../internals/inspect-source":281,"../internals/internal-state":282,"../internals/is-callable":285}],301:[function(s,T,S){var m=Math.ceil,a=Math.floor;T.exports=Math.trunc||function(o){var r=+o;return(r>0?a:m)(r)}},{}],302:[function(s,T,S){var m,a,o,r,t,e=s("../internals/global"),l=s("../internals/function-bind-context"),n=s("../internals/object-get-own-property-descriptor").f,i=s("../internals/task").set,f=s("../internals/queue"),c=s("../internals/engine-is-ios"),u=s("../internals/engine-is-ios-pebble"),d=s("../internals/engine-is-webos-webkit"),h=s("../internals/engine-is-node"),w=e.MutationObserver||e.WebKitMutationObserver,_=e.document,A=e.process,N=e.Promise,L=n(e,"queueMicrotask"),I=L&&L.value;if(!I){var P=new f,B=function(){var U,D;for(h&&(U=A.domain)&&U.exit();D=P.get();)try{D()}catch(x){throw P.head&&m(),x}U&&U.enter()};c||h||d||!w||!_?!u&&N&&N.resolve?((r=N.resolve(void 0)).constructor=N,t=l(r.then,r),m=function(){t(B)}):h?m=function(){A.nextTick(B)}:(i=l(i,e),m=function(){i(B)}):(a=!0,o=_.createTextNode(""),new w(B).observe(o,{characterData:!0}),m=function(){o.data=a=!a}),I=function(U){P.head||m(),P.add(U)}}T.exports=I},{"../internals/engine-is-ios":253,"../internals/engine-is-ios-pebble":252,"../internals/engine-is-node":254,"../internals/engine-is-webos-webkit":255,"../internals/function-bind-context":262,"../internals/global":274,"../internals/object-get-own-property-descriptor":309,"../internals/queue":328,"../internals/task":339}],303:[function(s,T,S){var m=s("../internals/a-callable"),a=TypeError,o=function(r){var t,e;this.promise=new r(function(l,n){if(t!==void 0||e!==void 0)throw new a("Bad Promise constructor");t=l,e=n}),this.resolve=m(t),this.reject=m(e)};T.exports.f=function(r){return new o(r)}},{"../internals/a-callable":222}],304:[function(s,T,S){var m=s("../internals/is-regexp"),a=TypeError;T.exports=function(o){if(m(o))throw new a("The method doesn't accept regular expressions");return o}},{"../internals/is-regexp":291}],305:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/function-uncurry-this"),o=s("../internals/function-call"),r=s("../internals/fails"),t=s("../internals/object-keys"),e=s("../internals/object-get-own-property-symbols"),l=s("../internals/object-property-is-enumerable"),n=s("../internals/to-object"),i=s("../internals/indexed-object"),f=Object.assign,c=Object.defineProperty,u=a([].concat);T.exports=!f||r(function(){if(m&&f({b:1},f(c({},"a",{enumerable:!0,get:function(){c(this,"b",{value:3,enumerable:!1})}}),{b:2})).b!==1)return!0;var d={},h={},w=Symbol("assign detection");return d[w]=7,"abcdefghijklmnopqrst".split("").forEach(function(_){h[_]=_}),f({},d)[w]!==7||t(f({},h)).join("")!=="abcdefghijklmnopqrst"})?function(d,h){for(var w=n(d),_=arguments.length,A=1,N=e.f,L=l.f;_>A;)for(var I,P=i(arguments[A++]),B=N?u(t(P),N(P)):t(P),U=B.length,D=0;U>D;)I=B[D++],m&&!o(L,P,I)||(w[I]=P[I]);return w}:f},{"../internals/descriptors":247,"../internals/fails":260,"../internals/function-call":264,"../internals/function-uncurry-this":268,"../internals/indexed-object":280,"../internals/object-get-own-property-symbols":312,"../internals/object-keys":316,"../internals/object-property-is-enumerable":317,"../internals/to-object":344}],306:[function(s,T,S){var m,a=s("../internals/an-object"),o=s("../internals/object-define-properties"),r=s("../internals/enum-bug-keys"),t=s("../internals/hidden-keys"),e=s("../internals/html"),l=s("../internals/document-create-element"),n=s("../internals/shared-key"),i=n("IE_PROTO"),f=function(){},c=function(h){return"<script>"+h+"<\/script>"},u=function(h){h.write(c("")),h.close();var w=h.parentWindow.Object;return h=null,w},d=function(){try{m=new ActiveXObject("htmlfile")}catch{}var h,w;d=typeof document<"u"?document.domain&&m?u(m):((w=l("iframe")).style.display="none",e.appendChild(w),w.src="javascript:",(h=w.contentWindow.document).open(),h.write(c("document.F=Object")),h.close(),h.F):u(m);for(var _=r.length;_--;)delete d.prototype[r[_]];return d()};t[i]=!0,T.exports=Object.create||function(h,w){var _;return h!==null?(f.prototype=a(h),_=new f,f.prototype=null,_[i]=h):_=d(),w===void 0?_:o.f(_,w)}},{"../internals/an-object":227,"../internals/document-create-element":249,"../internals/enum-bug-keys":258,"../internals/hidden-keys":276,"../internals/html":278,"../internals/object-define-properties":307,"../internals/shared-key":332}],307:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/v8-prototype-define-bug"),o=s("../internals/object-define-property"),r=s("../internals/an-object"),t=s("../internals/to-indexed-object"),e=s("../internals/object-keys");S.f=m&&!a?Object.defineProperties:function(l,n){r(l);for(var i,f=t(n),c=e(n),u=c.length,d=0;u>d;)o.f(l,i=c[d++],f[i]);return l}},{"../internals/an-object":227,"../internals/descriptors":247,"../internals/object-define-property":308,"../internals/object-keys":316,"../internals/to-indexed-object":341,"../internals/v8-prototype-define-bug":352}],308:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/ie8-dom-define"),o=s("../internals/v8-prototype-define-bug"),r=s("../internals/an-object"),t=s("../internals/to-property-key"),e=TypeError,l=Object.defineProperty,n=Object.getOwnPropertyDescriptor;S.f=m?o?function(i,f,c){if(r(i),f=t(f),r(c),typeof i=="function"&&f==="prototype"&&"value"in c&&"writable"in c&&!c.writable){var u=n(i,f);u&&u.writable&&(i[f]=c.value,c={configurable:"configurable"in c?c.configurable:u.configurable,enumerable:"enumerable"in c?c.enumerable:u.enumerable,writable:!1})}return l(i,f,c)}:l:function(i,f,c){if(r(i),f=t(f),r(c),a)try{return l(i,f,c)}catch{}if("get"in c||"set"in c)throw new e("Accessors not supported");return"value"in c&&(i[f]=c.value),i}},{"../internals/an-object":227,"../internals/descriptors":247,"../internals/ie8-dom-define":279,"../internals/to-property-key":346,"../internals/v8-prototype-define-bug":352}],309:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/function-call"),o=s("../internals/object-property-is-enumerable"),r=s("../internals/create-property-descriptor"),t=s("../internals/to-indexed-object"),e=s("../internals/to-property-key"),l=s("../internals/has-own-property"),n=s("../internals/ie8-dom-define"),i=Object.getOwnPropertyDescriptor;S.f=m?i:function(f,c){if(f=t(f),c=e(c),n)try{return i(f,c)}catch{}if(l(f,c))return r(!a(o.f,f,c),f[c])}},{"../internals/create-property-descriptor":242,"../internals/descriptors":247,"../internals/function-call":264,"../internals/has-own-property":275,"../internals/ie8-dom-define":279,"../internals/object-property-is-enumerable":317,"../internals/to-indexed-object":341,"../internals/to-property-key":346}],310:[function(s,T,S){var m=s("../internals/classof-raw"),a=s("../internals/to-indexed-object"),o=s("../internals/object-get-own-property-names").f,r=s("../internals/array-slice-simple"),t=typeof window=="object"&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[];T.exports.f=function(e){return t&&m(e)==="Window"?function(l){try{return o(l)}catch{return r(t)}}(e):o(a(e))}},{"../internals/array-slice-simple":230,"../internals/classof-raw":235,"../internals/object-get-own-property-names":311,"../internals/to-indexed-object":341}],311:[function(s,T,S){var m=s("../internals/object-keys-internal"),a=s("../internals/enum-bug-keys").concat("length","prototype");S.f=Object.getOwnPropertyNames||function(o){return m(o,a)}},{"../internals/enum-bug-keys":258,"../internals/object-keys-internal":315}],312:[function(s,T,S){S.f=Object.getOwnPropertySymbols},{}],313:[function(s,T,S){var m=s("../internals/has-own-property"),a=s("../internals/is-callable"),o=s("../internals/to-object"),r=s("../internals/shared-key"),t=s("../internals/correct-prototype-getter"),e=r("IE_PROTO"),l=Object,n=l.prototype;T.exports=t?l.getPrototypeOf:function(i){var f=o(i);if(m(f,e))return f[e];var c=f.constructor;return a(c)&&f instanceof c?c.prototype:f instanceof l?n:null}},{"../internals/correct-prototype-getter":239,"../internals/has-own-property":275,"../internals/is-callable":285,"../internals/shared-key":332,"../internals/to-object":344}],314:[function(s,T,S){var m=s("../internals/function-uncurry-this");T.exports=m({}.isPrototypeOf)},{"../internals/function-uncurry-this":268}],315:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=s("../internals/has-own-property"),o=s("../internals/to-indexed-object"),r=s("../internals/array-includes").indexOf,t=s("../internals/hidden-keys"),e=m([].push);T.exports=function(l,n){var i,f=o(l),c=0,u=[];for(i in f)!a(t,i)&&a(f,i)&&e(u,i);for(;n.length>c;)a(f,i=n[c++])&&(~r(u,i)||e(u,i));return u}},{"../internals/array-includes":228,"../internals/function-uncurry-this":268,"../internals/has-own-property":275,"../internals/hidden-keys":276,"../internals/to-indexed-object":341}],316:[function(s,T,S){var m=s("../internals/object-keys-internal"),a=s("../internals/enum-bug-keys");T.exports=Object.keys||function(o){return m(o,a)}},{"../internals/enum-bug-keys":258,"../internals/object-keys-internal":315}],317:[function(s,T,S){var m={}.propertyIsEnumerable,a=Object.getOwnPropertyDescriptor,o=a&&!m.call({1:2},1);S.f=o?function(r){var t=a(this,r);return!!t&&t.enumerable}:m},{}],318:[function(s,T,S){var m=s("../internals/function-uncurry-this-accessor"),a=s("../internals/an-object"),o=s("../internals/a-possible-prototype");T.exports=Object.setPrototypeOf||("__proto__"in{}?function(){var r,t=!1,e={};try{(r=m(Object.prototype,"__proto__","set"))(e,[]),t=e instanceof Array}catch{}return function(l,n){return a(l),o(n),t?r(l,n):l.__proto__=n,l}}():void 0)},{"../internals/a-possible-prototype":224,"../internals/an-object":227,"../internals/function-uncurry-this-accessor":266}],319:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/fails"),o=s("../internals/function-uncurry-this"),r=s("../internals/object-get-prototype-of"),t=s("../internals/object-keys"),e=s("../internals/to-indexed-object"),l=o(s("../internals/object-property-is-enumerable").f),n=o([].push),i=m&&a(function(){var c=Object.create(null);return c[2]=2,!l(c,2)}),f=function(c){return function(u){for(var d,h=e(u),w=t(h),_=i&&r(h)===null,A=w.length,N=0,L=[];A>N;)d=w[N++],m&&!(_?d in h:l(h,d))||n(L,c?[d,h[d]]:h[d]);return L}};T.exports={entries:f(!0),values:f(!1)}},{"../internals/descriptors":247,"../internals/fails":260,"../internals/function-uncurry-this":268,"../internals/object-get-prototype-of":313,"../internals/object-keys":316,"../internals/object-property-is-enumerable":317,"../internals/to-indexed-object":341}],320:[function(s,T,S){var m=s("../internals/function-call"),a=s("../internals/is-callable"),o=s("../internals/is-object"),r=TypeError;T.exports=function(t,e){var l,n;if(e==="string"&&a(l=t.toString)&&!o(n=m(l,t))||a(l=t.valueOf)&&!o(n=m(l,t))||e!=="string"&&a(l=t.toString)&&!o(n=m(l,t)))return n;throw new r("Can't convert object to primitive value")}},{"../internals/function-call":264,"../internals/is-callable":285,"../internals/is-object":289}],321:[function(s,T,S){var m=s("../internals/get-built-in"),a=s("../internals/function-uncurry-this"),o=s("../internals/object-get-own-property-names"),r=s("../internals/object-get-own-property-symbols"),t=s("../internals/an-object"),e=a([].concat);T.exports=m("Reflect","ownKeys")||function(l){var n=o.f(t(l)),i=r.f;return i?e(n,i(l)):n}},{"../internals/an-object":227,"../internals/function-uncurry-this":268,"../internals/get-built-in":269,"../internals/object-get-own-property-names":311,"../internals/object-get-own-property-symbols":312}],322:[function(s,T,S){var m=s("../internals/global");T.exports=m},{"../internals/global":274}],323:[function(s,T,S){T.exports=function(m){try{return{error:!1,value:m()}}catch(a){return{error:!0,value:a}}}},{}],324:[function(s,T,S){var m=s("../internals/global"),a=s("../internals/promise-native-constructor"),o=s("../internals/is-callable"),r=s("../internals/is-forced"),t=s("../internals/inspect-source"),e=s("../internals/well-known-symbol"),l=s("../internals/engine-is-browser"),n=s("../internals/engine-is-deno"),i=s("../internals/is-pure"),f=s("../internals/engine-v8-version"),c=a&&a.prototype,u=e("species"),d=!1,h=o(m.PromiseRejectionEvent),w=r("Promise",function(){var _=t(a),A=_!==String(a);if(!A&&f===66||i&&(!c.catch||!c.finally))return!0;if(!f||f<51||!/native code/.test(_)){var N=new a(function(I){I(1)}),L=function(I){I(function(){},function(){})};if((N.constructor={})[u]=L,!(d=N.then(function(){})instanceof L))return!0}return!A&&(l||n)&&!h});T.exports={CONSTRUCTOR:w,REJECTION_EVENT:h,SUBCLASSING:d}},{"../internals/engine-is-browser":250,"../internals/engine-is-deno":251,"../internals/engine-v8-version":257,"../internals/global":274,"../internals/inspect-source":281,"../internals/is-callable":285,"../internals/is-forced":287,"../internals/is-pure":290,"../internals/promise-native-constructor":325,"../internals/well-known-symbol":357}],325:[function(s,T,S){var m=s("../internals/global");T.exports=m.Promise},{"../internals/global":274}],326:[function(s,T,S){var m=s("../internals/an-object"),a=s("../internals/is-object"),o=s("../internals/new-promise-capability");T.exports=function(r,t){if(m(r),a(t)&&t.constructor===r)return t;var e=o.f(r);return(0,e.resolve)(t),e.promise}},{"../internals/an-object":227,"../internals/is-object":289,"../internals/new-promise-capability":303}],327:[function(s,T,S){var m=s("../internals/promise-native-constructor"),a=s("../internals/check-correctness-of-iteration"),o=s("../internals/promise-constructor-detection").CONSTRUCTOR;T.exports=o||!a(function(r){m.all(r).then(void 0,function(){})})},{"../internals/check-correctness-of-iteration":234,"../internals/promise-constructor-detection":324,"../internals/promise-native-constructor":325}],328:[function(s,T,S){var m=function(){this.head=null,this.tail=null};m.prototype={add:function(a){var o={item:a,next:null},r=this.tail;r?r.next=o:this.head=o,this.tail=o},get:function(){var a=this.head;if(a)return(this.head=a.next)===null&&(this.tail=null),a.item}},T.exports=m},{}],329:[function(s,T,S){var m=s("../internals/is-null-or-undefined"),a=TypeError;T.exports=function(o){if(m(o))throw new a("Can't call method on "+o);return o}},{"../internals/is-null-or-undefined":288}],330:[function(s,T,S){var m=s("../internals/get-built-in"),a=s("../internals/define-built-in-accessor"),o=s("../internals/well-known-symbol"),r=s("../internals/descriptors"),t=o("species");T.exports=function(e){var l=m(e);r&&l&&!l[t]&&a(l,t,{configurable:!0,get:function(){return this}})}},{"../internals/define-built-in-accessor":244,"../internals/descriptors":247,"../internals/get-built-in":269,"../internals/well-known-symbol":357}],331:[function(s,T,S){var m=s("../internals/object-define-property").f,a=s("../internals/has-own-property"),o=s("../internals/well-known-symbol")("toStringTag");T.exports=function(r,t,e){r&&!e&&(r=r.prototype),r&&!a(r,o)&&m(r,o,{configurable:!0,value:t})}},{"../internals/has-own-property":275,"../internals/object-define-property":308,"../internals/well-known-symbol":357}],332:[function(s,T,S){var m=s("../internals/shared"),a=s("../internals/uid"),o=m("keys");T.exports=function(r){return o[r]||(o[r]=a(r))}},{"../internals/shared":334,"../internals/uid":350}],333:[function(s,T,S){var m=s("../internals/global"),a=s("../internals/define-global-property"),o=m["__core-js_shared__"]||a("__core-js_shared__",{});T.exports=o},{"../internals/define-global-property":246,"../internals/global":274}],334:[function(s,T,S){var m=s("../internals/is-pure"),a=s("../internals/shared-store");(T.exports=function(o,r){return a[o]||(a[o]=r!==void 0?r:{})})("versions",[]).push({version:"3.33.0",mode:m?"pure":"global",copyright:"© 2014-2023 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.33.0/LICENSE",source:"https://github.com/zloirock/core-js"})},{"../internals/is-pure":290,"../internals/shared-store":333}],335:[function(s,T,S){var m=s("../internals/an-object"),a=s("../internals/a-constructor"),o=s("../internals/is-null-or-undefined"),r=s("../internals/well-known-symbol")("species");T.exports=function(t,e){var l,n=m(t).constructor;return n===void 0||o(l=m(n)[r])?e:a(l)}},{"../internals/a-constructor":223,"../internals/an-object":227,"../internals/is-null-or-undefined":288,"../internals/well-known-symbol":357}],336:[function(s,T,S){var m=s("../internals/engine-v8-version"),a=s("../internals/fails"),o=s("../internals/global").String;T.exports=!!Object.getOwnPropertySymbols&&!a(function(){var r=Symbol("symbol detection");return!o(r)||!(Object(r)instanceof Symbol)||!Symbol.sham&&m&&m<41})},{"../internals/engine-v8-version":257,"../internals/fails":260,"../internals/global":274}],337:[function(s,T,S){var m=s("../internals/function-call"),a=s("../internals/get-built-in"),o=s("../internals/well-known-symbol"),r=s("../internals/define-built-in");T.exports=function(){var t=a("Symbol"),e=t&&t.prototype,l=e&&e.valueOf,n=o("toPrimitive");e&&!e[n]&&r(e,n,function(i){return m(l,this)},{arity:1})}},{"../internals/define-built-in":245,"../internals/function-call":264,"../internals/get-built-in":269,"../internals/well-known-symbol":357}],338:[function(s,T,S){var m=s("../internals/symbol-constructor-detection");T.exports=m&&!!Symbol.for&&!!Symbol.keyFor},{"../internals/symbol-constructor-detection":336}],339:[function(s,T,S){var m,a,o,r,t=s("../internals/global"),e=s("../internals/function-apply"),l=s("../internals/function-bind-context"),n=s("../internals/is-callable"),i=s("../internals/has-own-property"),f=s("../internals/fails"),c=s("../internals/html"),u=s("../internals/array-slice"),d=s("../internals/document-create-element"),h=s("../internals/validate-arguments-length"),w=s("../internals/engine-is-ios"),_=s("../internals/engine-is-node"),A=t.setImmediate,N=t.clearImmediate,L=t.process,I=t.Dispatch,P=t.Function,B=t.MessageChannel,U=t.String,D=0,x={};f(function(){m=t.location});var M=function(g){if(i(x,g)){var y=x[g];delete x[g],y()}},v=function(g){return function(){M(g)}},p=function(g){M(g.data)},b=function(g){t.postMessage(U(g),m.protocol+"//"+m.host)};A&&N||(A=function(g){h(arguments.length,1);var y=n(g)?g:P(g),k=u(arguments,1);return x[++D]=function(){e(y,void 0,k)},a(D),D},N=function(g){delete x[g]},_?a=function(g){L.nextTick(v(g))}:I&&I.now?a=function(g){I.now(v(g))}:B&&!w?(r=(o=new B).port2,o.port1.onmessage=p,a=l(r.postMessage,r)):t.addEventListener&&n(t.postMessage)&&!t.importScripts&&m&&m.protocol!=="file:"&&!f(b)?(a=b,t.addEventListener("message",p,!1)):a="onreadystatechange"in d("script")?function(g){c.appendChild(d("script")).onreadystatechange=function(){c.removeChild(this),M(g)}}:function(g){setTimeout(v(g),0)}),T.exports={set:A,clear:N}},{"../internals/array-slice":231,"../internals/document-create-element":249,"../internals/engine-is-ios":253,"../internals/engine-is-node":254,"../internals/fails":260,"../internals/function-apply":261,"../internals/function-bind-context":262,"../internals/global":274,"../internals/has-own-property":275,"../internals/html":278,"../internals/is-callable":285,"../internals/validate-arguments-length":353}],340:[function(s,T,S){var m=s("../internals/to-integer-or-infinity"),a=Math.max,o=Math.min;T.exports=function(r,t){var e=m(r);return e<0?a(e+t,0):o(e,t)}},{"../internals/to-integer-or-infinity":342}],341:[function(s,T,S){var m=s("../internals/indexed-object"),a=s("../internals/require-object-coercible");T.exports=function(o){return m(a(o))}},{"../internals/indexed-object":280,"../internals/require-object-coercible":329}],342:[function(s,T,S){var m=s("../internals/math-trunc");T.exports=function(a){var o=+a;return o!=o||o===0?0:m(o)}},{"../internals/math-trunc":301}],343:[function(s,T,S){var m=s("../internals/to-integer-or-infinity"),a=Math.min;T.exports=function(o){return o>0?a(m(o),9007199254740991):0}},{"../internals/to-integer-or-infinity":342}],344:[function(s,T,S){var m=s("../internals/require-object-coercible"),a=Object;T.exports=function(o){return a(m(o))}},{"../internals/require-object-coercible":329}],345:[function(s,T,S){var m=s("../internals/function-call"),a=s("../internals/is-object"),o=s("../internals/is-symbol"),r=s("../internals/get-method"),t=s("../internals/ordinary-to-primitive"),e=s("../internals/well-known-symbol"),l=TypeError,n=e("toPrimitive");T.exports=function(i,f){if(!a(i)||o(i))return i;var c,u=r(i,n);if(u){if(f===void 0&&(f="default"),c=m(u,i,f),!a(c)||o(c))return c;throw new l("Can't convert object to primitive value")}return f===void 0&&(f="number"),t(i,f)}},{"../internals/function-call":264,"../internals/get-method":273,"../internals/is-object":289,"../internals/is-symbol":292,"../internals/ordinary-to-primitive":320,"../internals/well-known-symbol":357}],346:[function(s,T,S){var m=s("../internals/to-primitive"),a=s("../internals/is-symbol");T.exports=function(o){var r=m(o,"string");return a(r)?r:r+""}},{"../internals/is-symbol":292,"../internals/to-primitive":345}],347:[function(s,T,S){var m={};m[s("../internals/well-known-symbol")("toStringTag")]="z",T.exports=String(m)==="[object z]"},{"../internals/well-known-symbol":357}],348:[function(s,T,S){var m=s("../internals/classof"),a=String;T.exports=function(o){if(m(o)==="Symbol")throw new TypeError("Cannot convert a Symbol value to a string");return a(o)}},{"../internals/classof":236}],349:[function(s,T,S){var m=String;T.exports=function(a){try{return m(a)}catch{return"Object"}}},{}],350:[function(s,T,S){var m=s("../internals/function-uncurry-this"),a=0,o=Math.random(),r=m(1 .toString);T.exports=function(t){return"Symbol("+(t===void 0?"":t)+")_"+r(++a+o,36)}},{"../internals/function-uncurry-this":268}],351:[function(s,T,S){var m=s("../internals/symbol-constructor-detection");T.exports=m&&!Symbol.sham&&typeof Symbol.iterator=="symbol"},{"../internals/symbol-constructor-detection":336}],352:[function(s,T,S){var m=s("../internals/descriptors"),a=s("../internals/fails");T.exports=m&&a(function(){return Object.defineProperty(function(){},"prototype",{value:42,writable:!1}).prototype!==42})},{"../internals/descriptors":247,"../internals/fails":260}],353:[function(s,T,S){var m=TypeError;T.exports=function(a,o){if(a<o)throw new m("Not enough arguments");return a}},{}],354:[function(s,T,S){var m=s("../internals/global"),a=s("../internals/is-callable"),o=m.WeakMap;T.exports=a(o)&&/native code/.test(String(o))},{"../internals/global":274,"../internals/is-callable":285}],355:[function(s,T,S){var m=s("../internals/path"),a=s("../internals/has-own-property"),o=s("../internals/well-known-symbol-wrapped"),r=s("../internals/object-define-property").f;T.exports=function(t){var e=m.Symbol||(m.Symbol={});a(e,t)||r(e,t,{value:o.f(t)})}},{"../internals/has-own-property":275,"../internals/object-define-property":308,"../internals/path":322,"../internals/well-known-symbol-wrapped":356}],356:[function(s,T,S){var m=s("../internals/well-known-symbol");S.f=m},{"../internals/well-known-symbol":357}],357:[function(s,T,S){var m=s("../internals/global"),a=s("../internals/shared"),o=s("../internals/has-own-property"),r=s("../internals/uid"),t=s("../internals/symbol-constructor-detection"),e=s("../internals/use-symbol-as-uid"),l=m.Symbol,n=a("wks"),i=e?l.for||l:l&&l.withoutSetter||r;T.exports=function(f){return o(n,f)||(n[f]=t&&o(l,f)?l[f]:i("Symbol."+f)),n[f]}},{"../internals/global":274,"../internals/has-own-property":275,"../internals/shared":334,"../internals/symbol-constructor-detection":336,"../internals/uid":350,"../internals/use-symbol-as-uid":351}],358:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/array-iteration").findIndex,o=s("../internals/add-to-unscopables"),r=!0;"findIndex"in[]&&Array(1).findIndex(function(){r=!1}),m({target:"Array",proto:!0,forced:r},{findIndex:function(t){return a(this,t,arguments.length>1?arguments[1]:void 0)}}),o("findIndex")},{"../internals/add-to-unscopables":225,"../internals/array-iteration":229,"../internals/export":259}],359:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/array-iteration").find,o=s("../internals/add-to-unscopables"),r=!0;"find"in[]&&Array(1).find(function(){r=!1}),m({target:"Array",proto:!0,forced:r},{find:function(t){return a(this,t,arguments.length>1?arguments[1]:void 0)}}),o("find")},{"../internals/add-to-unscopables":225,"../internals/array-iteration":229,"../internals/export":259}],360:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/array-includes").includes,o=s("../internals/fails"),r=s("../internals/add-to-unscopables");m({target:"Array",proto:!0,forced:o(function(){return!Array(1).includes()})},{includes:function(t){return a(this,t,arguments.length>1?arguments[1]:void 0)}}),r("includes")},{"../internals/add-to-unscopables":225,"../internals/array-includes":228,"../internals/export":259,"../internals/fails":260}],361:[function(s,T,S){var m=s("../internals/to-indexed-object"),a=s("../internals/add-to-unscopables"),o=s("../internals/iterators"),r=s("../internals/internal-state"),t=s("../internals/object-define-property").f,e=s("../internals/iterator-define"),l=s("../internals/create-iter-result-object"),n=s("../internals/is-pure"),i=s("../internals/descriptors"),f=r.set,c=r.getterFor("Array Iterator");T.exports=e(Array,"Array",function(d,h){f(this,{type:"Array Iterator",target:m(d),index:0,kind:h})},function(){var d=c(this),h=d.target,w=d.kind,_=d.index++;if(!h||_>=h.length)return d.target=void 0,l(void 0,!0);switch(w){case"keys":return l(_,!1);case"values":return l(h[_],!1)}return l([_,h[_]],!1)},"values");var u=o.Arguments=o.Array;if(a("keys"),a("values"),a("entries"),!n&&i&&u.name!=="values")try{t(u,"name",{value:"values"})}catch{}},{"../internals/add-to-unscopables":225,"../internals/create-iter-result-object":240,"../internals/descriptors":247,"../internals/internal-state":282,"../internals/is-pure":290,"../internals/iterator-define":296,"../internals/iterators":298,"../internals/object-define-property":308,"../internals/to-indexed-object":341}],362:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/get-built-in"),o=s("../internals/function-apply"),r=s("../internals/function-call"),t=s("../internals/function-uncurry-this"),e=s("../internals/fails"),l=s("../internals/is-callable"),n=s("../internals/is-symbol"),i=s("../internals/array-slice"),f=s("../internals/get-json-replacer-function"),c=s("../internals/symbol-constructor-detection"),u=String,d=a("JSON","stringify"),h=t(/./.exec),w=t("".charAt),_=t("".charCodeAt),A=t("".replace),N=t(1 .toString),L=/[\uD800-\uDFFF]/g,I=/^[\uD800-\uDBFF]$/,P=/^[\uDC00-\uDFFF]$/,B=!c||e(function(){var M=a("Symbol")("stringify detection");return d([M])!=="[null]"||d({a:M})!=="{}"||d(Object(M))!=="{}"}),U=e(function(){return d("\uDF06\uD834")!=='"\\udf06\\ud834"'||d("\uDEAD")!=='"\\udead"'}),D=function(M,v){var p=i(arguments),b=f(v);if(l(b)||M!==void 0&&!n(M))return p[1]=function(g,y){if(l(b)&&(y=r(b,this,u(g),y)),!n(y))return y},o(d,null,p)},x=function(M,v,p){var b=w(p,v-1),g=w(p,v+1);return h(I,M)&&!h(P,g)||h(P,M)&&!h(I,b)?"\\u"+N(_(M,0),16):M};d&&m({target:"JSON",stat:!0,arity:3,forced:B||U},{stringify:function(M,v,p){var b=i(arguments),g=o(B?D:d,null,b);return U&&typeof g=="string"?A(g,L,x):g}})},{"../internals/array-slice":231,"../internals/export":259,"../internals/fails":260,"../internals/function-apply":261,"../internals/function-call":264,"../internals/function-uncurry-this":268,"../internals/get-built-in":269,"../internals/get-json-replacer-function":272,"../internals/is-callable":285,"../internals/is-symbol":292,"../internals/symbol-constructor-detection":336}],363:[function(s,T,S){s("../internals/export")({target:"Number",stat:!0},{isNaN:function(m){return m!=m}})},{"../internals/export":259}],364:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/object-assign");m({target:"Object",stat:!0,arity:2,forced:Object.assign!==a},{assign:a})},{"../internals/export":259,"../internals/object-assign":305}],365:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/symbol-constructor-detection"),o=s("../internals/fails"),r=s("../internals/object-get-own-property-symbols"),t=s("../internals/to-object");m({target:"Object",stat:!0,forced:!a||o(function(){r.f(1)})},{getOwnPropertySymbols:function(e){var l=r.f;return l?l(t(e)):[]}})},{"../internals/export":259,"../internals/fails":260,"../internals/object-get-own-property-symbols":312,"../internals/symbol-constructor-detection":336,"../internals/to-object":344}],366:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/to-object"),o=s("../internals/object-keys");m({target:"Object",stat:!0,forced:s("../internals/fails")(function(){o(1)})},{keys:function(r){return o(a(r))}})},{"../internals/export":259,"../internals/fails":260,"../internals/object-keys":316,"../internals/to-object":344}],367:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/object-to-array").values;m({target:"Object",stat:!0},{values:function(o){return a(o)}})},{"../internals/export":259,"../internals/object-to-array":319}],368:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/function-call"),o=s("../internals/a-callable"),r=s("../internals/new-promise-capability"),t=s("../internals/perform"),e=s("../internals/iterate");m({target:"Promise",stat:!0,forced:s("../internals/promise-statics-incorrect-iteration")},{all:function(l){var n=this,i=r.f(n),f=i.resolve,c=i.reject,u=t(function(){var d=o(n.resolve),h=[],w=0,_=1;e(l,function(A){var N=w++,L=!1;_++,a(d,n,A).then(function(I){L||(L=!0,h[N]=I,--_||f(h))},c)}),--_||f(h)});return u.error&&c(u.value),i.promise}})},{"../internals/a-callable":222,"../internals/export":259,"../internals/function-call":264,"../internals/iterate":293,"../internals/new-promise-capability":303,"../internals/perform":323,"../internals/promise-statics-incorrect-iteration":327}],369:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/is-pure"),o=s("../internals/promise-constructor-detection").CONSTRUCTOR,r=s("../internals/promise-native-constructor"),t=s("../internals/get-built-in"),e=s("../internals/is-callable"),l=s("../internals/define-built-in"),n=r&&r.prototype;if(m({target:"Promise",proto:!0,forced:o,real:!0},{catch:function(f){return this.then(void 0,f)}}),!a&&e(r)){var i=t("Promise").prototype.catch;n.catch!==i&&l(n,"catch",i,{unsafe:!0})}},{"../internals/define-built-in":245,"../internals/export":259,"../internals/get-built-in":269,"../internals/is-callable":285,"../internals/is-pure":290,"../internals/promise-constructor-detection":324,"../internals/promise-native-constructor":325}],370:[function(s,T,S){var m,a,o,r=s("../internals/export"),t=s("../internals/is-pure"),e=s("../internals/engine-is-node"),l=s("../internals/global"),n=s("../internals/function-call"),i=s("../internals/define-built-in"),f=s("../internals/object-set-prototype-of"),c=s("../internals/set-to-string-tag"),u=s("../internals/set-species"),d=s("../internals/a-callable"),h=s("../internals/is-callable"),w=s("../internals/is-object"),_=s("../internals/an-instance"),A=s("../internals/species-constructor"),N=s("../internals/task").set,L=s("../internals/microtask"),I=s("../internals/host-report-errors"),P=s("../internals/perform"),B=s("../internals/queue"),U=s("../internals/internal-state"),D=s("../internals/promise-native-constructor"),x=s("../internals/promise-constructor-detection"),M=s("../internals/new-promise-capability"),v=x.CONSTRUCTOR,p=x.REJECTION_EVENT,b=x.SUBCLASSING,g=U.getterFor("Promise"),y=U.set,k=D&&D.prototype,R=D,O=k,z=l.TypeError,$=l.document,W=l.process,j=M.f,H=j,E=!!($&&$.createEvent&&l.dispatchEvent),C=function(G){var nt;return!(!w(G)||!h(nt=G.then))&&nt},F=function(G,nt){var rt,st,ot,lt=nt.value,ct=nt.state===1,wt=ct?G.ok:G.fail,vt=G.resolve,mt=G.reject,Rt=G.domain;try{wt?(ct||(nt.rejection===2&&et(nt),nt.rejection=1),wt===!0?rt=lt:(Rt&&Rt.enter(),rt=wt(lt),Rt&&(Rt.exit(),ot=!0)),rt===G.promise?mt(new z("Promise-chain cycle")):(st=C(rt))?n(st,rt,vt,mt):vt(rt)):mt(lt)}catch(Et){Rt&&!ot&&Rt.exit(),mt(Et)}},V=function(G,nt){G.notified||(G.notified=!0,L(function(){for(var rt,st=G.reactions;rt=st.get();)F(rt,G);G.notified=!1,nt&&!G.rejection&&q(G)}))},Z=function(G,nt,rt){var st,ot;E?((st=$.createEvent("Event")).promise=nt,st.reason=rt,st.initEvent(G,!1,!0),l.dispatchEvent(st)):st={promise:nt,reason:rt},!p&&(ot=l["on"+G])?ot(st):G==="unhandledrejection"&&I("Unhandled promise rejection",rt)},q=function(G){n(N,l,function(){var nt,rt=G.facade,st=G.value;if(K(G)&&(nt=P(function(){e?W.emit("unhandledRejection",st,rt):Z("unhandledrejection",rt,st)}),G.rejection=e||K(G)?2:1,nt.error))throw nt.value})},K=function(G){return G.rejection!==1&&!G.parent},et=function(G){n(N,l,function(){var nt=G.facade;e?W.emit("rejectionHandled",nt):Z("rejectionhandled",nt,G.value)})},tt=function(G,nt,rt){return function(st){G(nt,st,rt)}},X=function(G,nt,rt){G.done||(G.done=!0,rt&&(G=rt),G.value=nt,G.state=2,V(G,!0))},J=function(G,nt,rt){if(!G.done){G.done=!0,rt&&(G=rt);try{if(G.facade===nt)throw new z("Promise can't be resolved itself");var st=C(nt);st?L(function(){var ot={done:!1};try{n(st,nt,tt(J,ot,G),tt(X,ot,G))}catch(lt){X(ot,lt,G)}}):(G.value=nt,G.state=1,V(G,!1))}catch(ot){X({done:!1},ot,G)}}};if(v&&(O=(R=function(G){_(this,O),d(G),n(m,this);var nt=g(this);try{G(tt(J,nt),tt(X,nt))}catch(rt){X(nt,rt)}}).prototype,(m=function(G){y(this,{type:"Promise",done:!1,notified:!1,parent:!1,reactions:new B,rejection:!1,state:0,value:void 0})}).prototype=i(O,"then",function(G,nt){var rt=g(this),st=j(A(this,R));return rt.parent=!0,st.ok=!h(G)||G,st.fail=h(nt)&&nt,st.domain=e?W.domain:void 0,rt.state===0?rt.reactions.add(st):L(function(){F(st,rt)}),st.promise}),a=function(){var G=new m,nt=g(G);this.promise=G,this.resolve=tt(J,nt),this.reject=tt(X,nt)},M.f=j=function(G){return G===R||G===void 0?new a(G):H(G)},!t&&h(D)&&k!==Object.prototype)){o=k.then,b||i(k,"then",function(G,nt){var rt=this;return new R(function(st,ot){n(o,rt,st,ot)}).then(G,nt)},{unsafe:!0});try{delete k.constructor}catch{}f&&f(k,O)}r({global:!0,constructor:!0,wrap:!0,forced:v},{Promise:R}),c(R,"Promise",!1,!0),u("Promise")},{"../internals/a-callable":222,"../internals/an-instance":226,"../internals/define-built-in":245,"../internals/engine-is-node":254,"../internals/export":259,"../internals/function-call":264,"../internals/global":274,"../internals/host-report-errors":277,"../internals/internal-state":282,"../internals/is-callable":285,"../internals/is-object":289,"../internals/is-pure":290,"../internals/microtask":302,"../internals/new-promise-capability":303,"../internals/object-set-prototype-of":318,"../internals/perform":323,"../internals/promise-constructor-detection":324,"../internals/promise-native-constructor":325,"../internals/queue":328,"../internals/set-species":330,"../internals/set-to-string-tag":331,"../internals/species-constructor":335,"../internals/task":339}],371:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/is-pure"),o=s("../internals/promise-native-constructor"),r=s("../internals/fails"),t=s("../internals/get-built-in"),e=s("../internals/is-callable"),l=s("../internals/species-constructor"),n=s("../internals/promise-resolve"),i=s("../internals/define-built-in"),f=o&&o.prototype;if(m({target:"Promise",proto:!0,real:!0,forced:!!o&&r(function(){f.finally.call({then:function(){}},function(){})})},{finally:function(u){var d=l(this,t("Promise")),h=e(u);return this.then(h?function(w){return n(d,u()).then(function(){return w})}:u,h?function(w){return n(d,u()).then(function(){throw w})}:u)}}),!a&&e(o)){var c=t("Promise").prototype.finally;f.finally!==c&&i(f,"finally",c,{unsafe:!0})}},{"../internals/define-built-in":245,"../internals/export":259,"../internals/fails":260,"../internals/get-built-in":269,"../internals/is-callable":285,"../internals/is-pure":290,"../internals/promise-native-constructor":325,"../internals/promise-resolve":326,"../internals/species-constructor":335}],372:[function(s,T,S){s("../modules/es.promise.constructor"),s("../modules/es.promise.all"),s("../modules/es.promise.catch"),s("../modules/es.promise.race"),s("../modules/es.promise.reject"),s("../modules/es.promise.resolve")},{"../modules/es.promise.all":368,"../modules/es.promise.catch":369,"../modules/es.promise.constructor":370,"../modules/es.promise.race":373,"../modules/es.promise.reject":374,"../modules/es.promise.resolve":375}],373:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/function-call"),o=s("../internals/a-callable"),r=s("../internals/new-promise-capability"),t=s("../internals/perform"),e=s("../internals/iterate");m({target:"Promise",stat:!0,forced:s("../internals/promise-statics-incorrect-iteration")},{race:function(l){var n=this,i=r.f(n),f=i.reject,c=t(function(){var u=o(n.resolve);e(l,function(d){a(u,n,d).then(i.resolve,f)})});return c.error&&f(c.value),i.promise}})},{"../internals/a-callable":222,"../internals/export":259,"../internals/function-call":264,"../internals/iterate":293,"../internals/new-promise-capability":303,"../internals/perform":323,"../internals/promise-statics-incorrect-iteration":327}],374:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/function-call"),o=s("../internals/new-promise-capability");m({target:"Promise",stat:!0,forced:s("../internals/promise-constructor-detection").CONSTRUCTOR},{reject:function(r){var t=o.f(this);return a(t.reject,void 0,r),t.promise}})},{"../internals/export":259,"../internals/function-call":264,"../internals/new-promise-capability":303,"../internals/promise-constructor-detection":324}],375:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/get-built-in"),o=s("../internals/is-pure"),r=s("../internals/promise-native-constructor"),t=s("../internals/promise-constructor-detection").CONSTRUCTOR,e=s("../internals/promise-resolve"),l=a("Promise"),n=o&&!t;m({target:"Promise",stat:!0,forced:o||t},{resolve:function(i){return e(n&&this===l?r:this,i)}})},{"../internals/export":259,"../internals/get-built-in":269,"../internals/is-pure":290,"../internals/promise-constructor-detection":324,"../internals/promise-native-constructor":325,"../internals/promise-resolve":326}],376:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/function-uncurry-this"),o=s("../internals/to-absolute-index"),r=RangeError,t=String.fromCharCode,e=String.fromCodePoint,l=a([].join);m({target:"String",stat:!0,arity:1,forced:!!e&&e.length!==1},{fromCodePoint:function(n){for(var i,f=[],c=arguments.length,u=0;c>u;){if(i=+arguments[u++],o(i,1114111)!==i)throw new r(i+" is not a valid code point");f[u]=i<65536?t(i):t(55296+((i-=65536)>>10),i%1024+56320)}return l(f,"")}})},{"../internals/export":259,"../internals/function-uncurry-this":268,"../internals/to-absolute-index":340}],377:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/function-uncurry-this"),o=s("../internals/not-a-regexp"),r=s("../internals/require-object-coercible"),t=s("../internals/to-string"),e=s("../internals/correct-is-regexp-logic"),l=a("".indexOf);m({target:"String",proto:!0,forced:!e("includes")},{includes:function(n){return!!~l(t(r(this)),t(o(n)),arguments.length>1?arguments[1]:void 0)}})},{"../internals/correct-is-regexp-logic":238,"../internals/export":259,"../internals/function-uncurry-this":268,"../internals/not-a-regexp":304,"../internals/require-object-coercible":329,"../internals/to-string":348}],378:[function(s,T,S){s("../internals/well-known-symbol-define")("asyncIterator")},{"../internals/well-known-symbol-define":355}],379:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/global"),o=s("../internals/function-call"),r=s("../internals/function-uncurry-this"),t=s("../internals/is-pure"),e=s("../internals/descriptors"),l=s("../internals/symbol-constructor-detection"),n=s("../internals/fails"),i=s("../internals/has-own-property"),f=s("../internals/object-is-prototype-of"),c=s("../internals/an-object"),u=s("../internals/to-indexed-object"),d=s("../internals/to-property-key"),h=s("../internals/to-string"),w=s("../internals/create-property-descriptor"),_=s("../internals/object-create"),A=s("../internals/object-keys"),N=s("../internals/object-get-own-property-names"),L=s("../internals/object-get-own-property-names-external"),I=s("../internals/object-get-own-property-symbols"),P=s("../internals/object-get-own-property-descriptor"),B=s("../internals/object-define-property"),U=s("../internals/object-define-properties"),D=s("../internals/object-property-is-enumerable"),x=s("../internals/define-built-in"),M=s("../internals/define-built-in-accessor"),v=s("../internals/shared"),p=s("../internals/shared-key"),b=s("../internals/hidden-keys"),g=s("../internals/uid"),y=s("../internals/well-known-symbol"),k=s("../internals/well-known-symbol-wrapped"),R=s("../internals/well-known-symbol-define"),O=s("../internals/symbol-define-to-primitive"),z=s("../internals/set-to-string-tag"),$=s("../internals/internal-state"),W=s("../internals/array-iteration").forEach,j=p("hidden"),H=$.set,E=$.getterFor("Symbol"),C=Object.prototype,F=a.Symbol,V=F&&F.prototype,Z=a.RangeError,q=a.TypeError,K=a.QObject,et=P.f,tt=B.f,X=L.f,J=D.f,G=r([].push),nt=v("symbols"),rt=v("op-symbols"),st=v("wks"),ot=!K||!K.prototype||!K.prototype.findChild,lt=function(_t,dt,xt){var Tt=et(C,dt);Tt&&delete C[dt],tt(_t,dt,xt),Tt&&_t!==C&&tt(C,dt,Tt)},ct=e&&n(function(){return _(tt({},"a",{get:function(){return tt(this,"a",{value:7}).a}})).a!==7})?lt:tt,wt=function(_t,dt){var xt=nt[_t]=_(V);return H(xt,{type:"Symbol",tag:_t,description:dt}),e||(xt.description=dt),xt},vt=function(_t,dt,xt){_t===C&&vt(rt,dt,xt),c(_t);var Tt=d(dt);return c(xt),i(nt,Tt)?(xt.enumerable?(i(_t,j)&&_t[j][Tt]&&(_t[j][Tt]=!1),xt=_(xt,{enumerable:w(0,!1)})):(i(_t,j)||tt(_t,j,w(1,{})),_t[j][Tt]=!0),ct(_t,Tt,xt)):tt(_t,Tt,xt)},mt=function(_t,dt){c(_t);var xt=u(dt),Tt=A(xt).concat(jt(xt));return W(Tt,function(St){e&&!o(Rt,xt,St)||vt(_t,St,xt[St])}),_t},Rt=function(_t){var dt=d(_t),xt=o(J,this,dt);return!(this===C&&i(nt,dt)&&!i(rt,dt))&&(!(xt||!i(this,dt)||!i(nt,dt)||i(this,j)&&this[j][dt])||xt)},Et=function(_t,dt){var xt=u(_t),Tt=d(dt);if(xt!==C||!i(nt,Tt)||i(rt,Tt)){var St=et(xt,Tt);return!St||!i(nt,Tt)||i(xt,j)&&xt[j][Tt]||(St.enumerable=!0),St}},At=function(_t){var dt=X(u(_t)),xt=[];return W(dt,function(Tt){i(nt,Tt)||i(b,Tt)||G(xt,Tt)}),xt},jt=function(_t){var dt=_t===C,xt=X(dt?rt:u(_t)),Tt=[];return W(xt,function(St){!i(nt,St)||dt&&!i(C,St)||G(Tt,nt[St])}),Tt};l||(x(V=(F=function(){if(f(V,this))throw new q("Symbol is not a constructor");var _t=arguments.length&&arguments[0]!==void 0?h(arguments[0]):void 0,dt=g(_t),xt=function(Tt){this===C&&o(xt,rt,Tt),i(this,j)&&i(this[j],dt)&&(this[j][dt]=!1);var St=w(1,Tt);try{ct(this,dt,St)}catch(Kt){if(!(Kt instanceof Z))throw Kt;lt(this,dt,St)}};return e&&ot&&ct(C,dt,{configurable:!0,set:xt}),wt(dt,_t)}).prototype,"toString",function(){return E(this).tag}),x(F,"withoutSetter",function(_t){return wt(g(_t),_t)}),D.f=Rt,B.f=vt,U.f=mt,P.f=Et,N.f=L.f=At,I.f=jt,k.f=function(_t){return wt(y(_t),_t)},e&&(M(V,"description",{configurable:!0,get:function(){return E(this).description}}),t||x(C,"propertyIsEnumerable",Rt,{unsafe:!0}))),m({global:!0,constructor:!0,wrap:!0,forced:!l,sham:!l},{Symbol:F}),W(A(st),function(_t){R(_t)}),m({target:"Symbol",stat:!0,forced:!l},{useSetter:function(){ot=!0},useSimple:function(){ot=!1}}),m({target:"Object",stat:!0,forced:!l,sham:!e},{create:function(_t,dt){return dt===void 0?_(_t):mt(_(_t),dt)},defineProperty:vt,defineProperties:mt,getOwnPropertyDescriptor:Et}),m({target:"Object",stat:!0,forced:!l},{getOwnPropertyNames:At}),O(),z(F,"Symbol"),b[j]=!0},{"../internals/an-object":227,"../internals/array-iteration":229,"../internals/create-property-descriptor":242,"../internals/define-built-in":245,"../internals/define-built-in-accessor":244,"../internals/descriptors":247,"../internals/export":259,"../internals/fails":260,"../internals/function-call":264,"../internals/function-uncurry-this":268,"../internals/global":274,"../internals/has-own-property":275,"../internals/hidden-keys":276,"../internals/internal-state":282,"../internals/is-pure":290,"../internals/object-create":306,"../internals/object-define-properties":307,"../internals/object-define-property":308,"../internals/object-get-own-property-descriptor":309,"../internals/object-get-own-property-names":311,"../internals/object-get-own-property-names-external":310,"../internals/object-get-own-property-symbols":312,"../internals/object-is-prototype-of":314,"../internals/object-keys":316,"../internals/object-property-is-enumerable":317,"../internals/set-to-string-tag":331,"../internals/shared":334,"../internals/shared-key":332,"../internals/symbol-constructor-detection":336,"../internals/symbol-define-to-primitive":337,"../internals/to-indexed-object":341,"../internals/to-property-key":346,"../internals/to-string":348,"../internals/uid":350,"../internals/well-known-symbol":357,"../internals/well-known-symbol-define":355,"../internals/well-known-symbol-wrapped":356}],380:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/get-built-in"),o=s("../internals/has-own-property"),r=s("../internals/to-string"),t=s("../internals/shared"),e=s("../internals/symbol-registry-detection"),l=t("string-to-symbol-registry"),n=t("symbol-to-string-registry");m({target:"Symbol",stat:!0,forced:!e},{for:function(i){var f=r(i);if(o(l,f))return l[f];var c=a("Symbol")(f);return l[f]=c,n[c]=f,c}})},{"../internals/export":259,"../internals/get-built-in":269,"../internals/has-own-property":275,"../internals/shared":334,"../internals/symbol-registry-detection":338,"../internals/to-string":348}],381:[function(s,T,S){s("../modules/es.symbol.constructor"),s("../modules/es.symbol.for"),s("../modules/es.symbol.key-for"),s("../modules/es.json.stringify"),s("../modules/es.object.get-own-property-symbols")},{"../modules/es.json.stringify":362,"../modules/es.object.get-own-property-symbols":365,"../modules/es.symbol.constructor":379,"../modules/es.symbol.for":380,"../modules/es.symbol.key-for":382}],382:[function(s,T,S){var m=s("../internals/export"),a=s("../internals/has-own-property"),o=s("../internals/is-symbol"),r=s("../internals/try-to-string"),t=s("../internals/shared"),e=s("../internals/symbol-registry-detection"),l=t("symbol-to-string-registry");m({target:"Symbol",stat:!0,forced:!e},{keyFor:function(n){if(!o(n))throw new TypeError(r(n)+" is not a symbol");if(a(l,n))return l[n]}})},{"../internals/export":259,"../internals/has-own-property":275,"../internals/is-symbol":292,"../internals/shared":334,"../internals/symbol-registry-detection":338,"../internals/try-to-string":349}],383:[function(s,T,S){function m(a){return Object.prototype.toString.call(a)}S.isArray=function(a){return Array.isArray?Array.isArray(a):m(a)==="[object Array]"},S.isBoolean=function(a){return typeof a=="boolean"},S.isNull=function(a){return a===null},S.isNullOrUndefined=function(a){return a==null},S.isNumber=function(a){return typeof a=="number"},S.isString=function(a){return typeof a=="string"},S.isSymbol=function(a){return typeof a=="symbol"},S.isUndefined=function(a){return a===void 0},S.isRegExp=function(a){return m(a)==="[object RegExp]"},S.isObject=function(a){return typeof a=="object"&&a!==null},S.isDate=function(a){return m(a)==="[object Date]"},S.isError=function(a){return m(a)==="[object Error]"||a instanceof Error},S.isFunction=function(a){return typeof a=="function"},S.isPrimitive=function(a){return a===null||typeof a=="boolean"||typeof a=="number"||typeof a=="string"||typeof a=="symbol"||a===void 0},S.isBuffer=s("buffer").Buffer.isBuffer},{buffer:220}],384:[function(s,T,S){(function(m){(function(){var a=s("elliptic"),o=s("bn.js");T.exports=function(l){return new t(l)};var r={secp256k1:{name:"secp256k1",byteLength:32},secp224r1:{name:"p224",byteLength:28},prime256v1:{name:"p256",byteLength:32},prime192v1:{name:"p192",byteLength:24},ed25519:{name:"ed25519",byteLength:32},secp384r1:{name:"p384",byteLength:48},secp521r1:{name:"p521",byteLength:66}};function t(l){this.curveType=r[l],this.curveType||(this.curveType={name:l}),this.curve=new a.ec(this.curveType.name),this.keys=void 0}function e(l,n,i){Array.isArray(l)||(l=l.toArray());var f=new m(l);if(i&&f.length<i){var c=new m(i-f.length);c.fill(0),f=m.concat([c,f])}return n?f.toString(n):f}r.p224=r.secp224r1,r.p256=r.secp256r1=r.prime256v1,r.p192=r.secp192r1=r.prime192v1,r.p384=r.secp384r1,r.p521=r.secp521r1,t.prototype.generateKeys=function(l,n){return this.keys=this.curve.genKeyPair(),this.getPublicKey(l,n)},t.prototype.computeSecret=function(l,n,i){return n=n||"utf8",m.isBuffer(l)||(l=new m(l,n)),e(this.curve.keyFromPublic(l).getPublic().mul(this.keys.getPrivate()).getX(),i,this.curveType.byteLength)},t.prototype.getPublicKey=function(l,n){var i=this.keys.getPublic(n==="compressed",!0);return n==="hybrid"&&(i[i.length-1]%2?i[0]=7:i[0]=6),e(i,l)},t.prototype.getPrivateKey=function(l){return e(this.keys.getPrivate(),l)},t.prototype.setPublicKey=function(l,n){return n=n||"utf8",m.isBuffer(l)||(l=new m(l,n)),this.keys._importPublic(l),this},t.prototype.setPrivateKey=function(l,n){n=n||"utf8",m.isBuffer(l)||(l=new m(l,n));var i=new o(l);return i=i.toString(16),this.keys=this.curve.genKeyPair(),this.keys._importPrivate(i),this}}).call(this)}).call(this,s("buffer").Buffer)},{"bn.js":385,buffer:220,elliptic:405}],385:[function(s,T,S){arguments[4][184][0].apply(S,arguments)},{buffer:188,dup:184}],386:[function(s,T,S){var m=s("inherits"),a=s("md5.js"),o=s("ripemd160"),r=s("sha.js"),t=s("cipher-base");function e(l){t.call(this,"digest"),this._hash=l}m(e,t),e.prototype._update=function(l){this._hash.update(l)},e.prototype._final=function(){return this._hash.digest()},T.exports=function(l){return(l=l.toLowerCase())==="md5"?new a:l==="rmd160"||l==="ripemd160"?new o:new e(r(l))}},{"cipher-base":221,inherits:440,"md5.js":450,ripemd160:493,"sha.js":498}],387:[function(s,T,S){var m=s("md5.js");T.exports=function(a){return new m().update(a).digest()}},{"md5.js":450}],388:[function(s,T,S){var m=s("inherits"),a=s("./legacy"),o=s("cipher-base"),r=s("safe-buffer").Buffer,t=s("create-hash/md5"),e=s("ripemd160"),l=s("sha.js"),n=r.alloc(128);function i(f,c){o.call(this,"digest"),typeof c=="string"&&(c=r.from(c));var u=f==="sha512"||f==="sha384"?128:64;this._alg=f,this._key=c,c.length>u?c=(f==="rmd160"?new e:l(f)).update(c).digest():c.length<u&&(c=r.concat([c,n],u));for(var d=this._ipad=r.allocUnsafe(u),h=this._opad=r.allocUnsafe(u),w=0;w<u;w++)d[w]=54^c[w],h[w]=92^c[w];this._hash=f==="rmd160"?new e:l(f),this._hash.update(d)}m(i,o),i.prototype._update=function(f){this._hash.update(f)},i.prototype._final=function(){var f=this._hash.digest();return(this._alg==="rmd160"?new e:l(this._alg)).update(this._opad).update(f).digest()},T.exports=function(f,c){return(f=f.toLowerCase())==="rmd160"||f==="ripemd160"?new i("rmd160",c):f==="md5"?new a(t,c):new i(f,c)}},{"./legacy":389,"cipher-base":221,"create-hash/md5":387,inherits:440,ripemd160:493,"safe-buffer":494,"sha.js":498}],389:[function(s,T,S){var m=s("inherits"),a=s("safe-buffer").Buffer,o=s("cipher-base"),r=a.alloc(128);function t(e,l){o.call(this,"digest"),typeof l=="string"&&(l=a.from(l)),this._alg=e,this._key=l,l.length>64?l=e(l):l.length<64&&(l=a.concat([l,r],64));for(var n=this._ipad=a.allocUnsafe(64),i=this._opad=a.allocUnsafe(64),f=0;f<64;f++)n[f]=54^l[f],i[f]=92^l[f];this._hash=[n]}m(t,o),t.prototype._update=function(e){this._hash.push(e)},t.prototype._final=function(){var e=this._alg(a.concat(this._hash));return this._alg(a.concat([this._opad,e]))},T.exports=t},{"cipher-base":221,inherits:440,"safe-buffer":494}],390:[function(s,T,S){S.randomBytes=S.rng=S.pseudoRandomBytes=S.prng=s("randombytes"),S.createHash=S.Hash=s("create-hash"),S.createHmac=S.Hmac=s("create-hmac");var m=s("browserify-sign/algos"),a=Object.keys(m),o=["sha1","sha224","sha256","sha384","sha512","md5","rmd160"].concat(a);S.getHashes=function(){return o};var r=s("pbkdf2");S.pbkdf2=r.pbkdf2,S.pbkdf2Sync=r.pbkdf2Sync;var t=s("browserify-cipher");S.Cipher=t.Cipher,S.createCipher=t.createCipher,S.Cipheriv=t.Cipheriv,S.createCipheriv=t.createCipheriv,S.Decipher=t.Decipher,S.createDecipher=t.createDecipher,S.Decipheriv=t.Decipheriv,S.createDecipheriv=t.createDecipheriv,S.getCiphers=t.getCiphers,S.listCiphers=t.listCiphers;var e=s("diffie-hellman");S.DiffieHellmanGroup=e.DiffieHellmanGroup,S.createDiffieHellmanGroup=e.createDiffieHellmanGroup,S.getDiffieHellman=e.getDiffieHellman,S.createDiffieHellman=e.createDiffieHellman,S.DiffieHellman=e.DiffieHellman;var l=s("browserify-sign");S.createSign=l.createSign,S.Sign=l.Sign,S.createVerify=l.createVerify,S.Verify=l.Verify,S.createECDH=s("create-ecdh");var n=s("public-encrypt");S.publicEncrypt=n.publicEncrypt,S.privateEncrypt=n.privateEncrypt,S.publicDecrypt=n.publicDecrypt,S.privateDecrypt=n.privateDecrypt;var i=s("randomfill");S.randomFill=i.randomFill,S.randomFillSync=i.randomFillSync,S.createCredentials=function(){throw new Error(["sorry, createCredentials is not implemented yet","we accept pull requests","https://github.com/crypto-browserify/crypto-browserify"].join(`
`))},S.constants={DH_CHECK_P_NOT_SAFE_PRIME:2,DH_CHECK_P_NOT_PRIME:1,DH_UNABLE_TO_CHECK_GENERATOR:4,DH_NOT_SUITABLE_GENERATOR:8,NPN_ENABLED:1,ALPN_ENABLED:1,RSA_PKCS1_PADDING:1,RSA_SSLV23_PADDING:2,RSA_NO_PADDING:3,RSA_PKCS1_OAEP_PADDING:4,RSA_X931_PADDING:5,RSA_PKCS1_PSS_PADDING:6,POINT_CONVERSION_COMPRESSED:2,POINT_CONVERSION_UNCOMPRESSED:4,POINT_CONVERSION_HYBRID:6}},{"browserify-cipher":206,"browserify-sign":213,"browserify-sign/algos":210,"create-ecdh":384,"create-hash":386,"create-hmac":388,"diffie-hellman":400,pbkdf2:460,"public-encrypt":468,randombytes:475,randomfill:476}],391:[function(s,T,S){(function(m,a){typeof S=="object"&&T!==void 0?T.exports=a():(m=typeof globalThis<"u"?globalThis:m||self).dayjs=a()})(void 0,function(){var m=6e4,a=36e5,o="millisecond",r="second",t="minute",e="hour",l="day",n="week",i="month",f="quarter",c="year",u="date",d="Invalid Date",h=/^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[Tt\s]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/,w=/\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g,_={name:"en",weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),ordinal:function(p){var b=["th","st","nd","rd"],g=p%100;return"["+p+(b[(g-20)%10]||b[g]||b[0])+"]"}},A=function(p,b,g){var y=String(p);return!y||y.length>=b?p:""+Array(b+1-y.length).join(g)+p},N={s:A,z:function(p){var b=-p.utcOffset(),g=Math.abs(b),y=Math.floor(g/60),k=g%60;return(b<=0?"+":"-")+A(y,2,"0")+":"+A(k,2,"0")},m:function p(b,g){if(b.date()<g.date())return-p(g,b);var y=12*(g.year()-b.year())+(g.month()-b.month()),k=b.clone().add(y,i),R=g-k<0,O=b.clone().add(y+(R?-1:1),i);return+(-(y+(g-k)/(R?k-O:O-k))||0)},a:function(p){return p<0?Math.ceil(p)||0:Math.floor(p)},p:function(p){return{M:i,y:c,w:n,d:l,D:u,h:e,m:t,s:r,ms:o,Q:f}[p]||String(p||"").toLowerCase().replace(/s$/,"")},u:function(p){return p===void 0}},L="en",I={};I[L]=_;var P="$isDayjsObject",B=function(p){return p instanceof M||!(!p||!p[P])},U=function p(b,g,y){var k;if(!b)return L;if(typeof b=="string"){var R=b.toLowerCase();I[R]&&(k=R),g&&(I[R]=g,k=R);var O=b.split("-");if(!k&&O.length>1)return p(O[0])}else{var z=b.name;I[z]=b,k=z}return!y&&k&&(L=k),k||!y&&L},D=function(p,b){if(B(p))return p.clone();var g=typeof b=="object"?b:{};return g.date=p,g.args=arguments,new M(g)},x=N;x.l=U,x.i=B,x.w=function(p,b){return D(p,{locale:b.$L,utc:b.$u,x:b.$x,$offset:b.$offset})};var M=function(){function p(g){this.$L=U(g.locale,null,!0),this.parse(g),this.$x=this.$x||g.x||{},this[P]=!0}var b=p.prototype;return b.parse=function(g){this.$d=function(y){var k=y.date,R=y.utc;if(k===null)return new Date(NaN);if(x.u(k))return new Date;if(k instanceof Date)return new Date(k);if(typeof k=="string"&&!/Z$/i.test(k)){var O=k.match(h);if(O){var z=O[2]-1||0,$=(O[7]||"0").substring(0,3);return R?new Date(Date.UTC(O[1],z,O[3]||1,O[4]||0,O[5]||0,O[6]||0,$)):new Date(O[1],z,O[3]||1,O[4]||0,O[5]||0,O[6]||0,$)}}return new Date(k)}(g),this.init()},b.init=function(){var g=this.$d;this.$y=g.getFullYear(),this.$M=g.getMonth(),this.$D=g.getDate(),this.$W=g.getDay(),this.$H=g.getHours(),this.$m=g.getMinutes(),this.$s=g.getSeconds(),this.$ms=g.getMilliseconds()},b.$utils=function(){return x},b.isValid=function(){return this.$d.toString()!==d},b.isSame=function(g,y){var k=D(g);return this.startOf(y)<=k&&k<=this.endOf(y)},b.isAfter=function(g,y){return D(g)<this.startOf(y)},b.isBefore=function(g,y){return this.endOf(y)<D(g)},b.$g=function(g,y,k){return x.u(g)?this[y]:this.set(k,g)},b.unix=function(){return Math.floor(this.valueOf()/1e3)},b.valueOf=function(){return this.$d.getTime()},b.startOf=function(g,y){var k=this,R=!!x.u(y)||y,O=x.p(g),z=function(V,Z){var q=x.w(k.$u?Date.UTC(k.$y,Z,V):new Date(k.$y,Z,V),k);return R?q:q.endOf(l)},$=function(V,Z){return x.w(k.toDate()[V].apply(k.toDate("s"),(R?[0,0,0,0]:[23,59,59,999]).slice(Z)),k)},W=this.$W,j=this.$M,H=this.$D,E="set"+(this.$u?"UTC":"");switch(O){case c:return R?z(1,0):z(31,11);case i:return R?z(1,j):z(0,j+1);case n:var C=this.$locale().weekStart||0,F=(W<C?W+7:W)-C;return z(R?H-F:H+(6-F),j);case l:case u:return $(E+"Hours",0);case e:return $(E+"Minutes",1);case t:return $(E+"Seconds",2);case r:return $(E+"Milliseconds",3);default:return this.clone()}},b.endOf=function(g){return this.startOf(g,!1)},b.$set=function(g,y){var k,R=x.p(g),O="set"+(this.$u?"UTC":""),z=(k={},k[l]=O+"Date",k[u]=O+"Date",k[i]=O+"Month",k[c]=O+"FullYear",k[e]=O+"Hours",k[t]=O+"Minutes",k[r]=O+"Seconds",k[o]=O+"Milliseconds",k)[R],$=R===l?this.$D+(y-this.$W):y;if(R===i||R===c){var W=this.clone().set(u,1);W.$d[z]($),W.init(),this.$d=W.set(u,Math.min(this.$D,W.daysInMonth())).$d}else z&&this.$d[z]($);return this.init(),this},b.set=function(g,y){return this.clone().$set(g,y)},b.get=function(g){return this[x.p(g)]()},b.add=function(g,y){var k,R=this;g=Number(g);var O=x.p(y),z=function(j){var H=D(R);return x.w(H.date(H.date()+Math.round(j*g)),R)};if(O===i)return this.set(i,this.$M+g);if(O===c)return this.set(c,this.$y+g);if(O===l)return z(1);if(O===n)return z(7);var $=(k={},k[t]=m,k[e]=a,k[r]=1e3,k)[O]||1,W=this.$d.getTime()+g*$;return x.w(W,this)},b.subtract=function(g,y){return this.add(-1*g,y)},b.format=function(g){var y=this,k=this.$locale();if(!this.isValid())return k.invalidDate||d;var R=g||"YYYY-MM-DDTHH:mm:ssZ",O=x.z(this),z=this.$H,$=this.$m,W=this.$M,j=k.weekdays,H=k.months,E=k.meridiem,C=function(Z,q,K,et){return Z&&(Z[q]||Z(y,R))||K[q].slice(0,et)},F=function(Z){return x.s(z%12||12,Z,"0")},V=E||function(Z,q,K){var et=Z<12?"AM":"PM";return K?et.toLowerCase():et};return R.replace(w,function(Z,q){return q||function(K){switch(K){case"YY":return String(y.$y).slice(-2);case"YYYY":return x.s(y.$y,4,"0");case"M":return W+1;case"MM":return x.s(W+1,2,"0");case"MMM":return C(k.monthsShort,W,H,3);case"MMMM":return C(H,W);case"D":return y.$D;case"DD":return x.s(y.$D,2,"0");case"d":return String(y.$W);case"dd":return C(k.weekdaysMin,y.$W,j,2);case"ddd":return C(k.weekdaysShort,y.$W,j,3);case"dddd":return j[y.$W];case"H":return String(z);case"HH":return x.s(z,2,"0");case"h":return F(1);case"hh":return F(2);case"a":return V(z,$,!0);case"A":return V(z,$,!1);case"m":return String($);case"mm":return x.s($,2,"0");case"s":return String(y.$s);case"ss":return x.s(y.$s,2,"0");case"SSS":return x.s(y.$ms,3,"0");case"Z":return O}return null}(Z)||O.replace(":","")})},b.utcOffset=function(){return 15*-Math.round(this.$d.getTimezoneOffset()/15)},b.diff=function(g,y,k){var R,O=this,z=x.p(y),$=D(g),W=($.utcOffset()-this.utcOffset())*m,j=this-$,H=function(){return x.m(O,$)};switch(z){case c:R=H()/12;break;case i:R=H();break;case f:R=H()/3;break;case n:R=(j-W)/6048e5;break;case l:R=(j-W)/864e5;break;case e:R=j/a;break;case t:R=j/m;break;case r:R=j/1e3;break;default:R=j}return k?R:x.a(R)},b.daysInMonth=function(){return this.endOf(i).$D},b.$locale=function(){return I[this.$L]},b.locale=function(g,y){if(!g)return this.$L;var k=this.clone(),R=U(g,y,!0);return R&&(k.$L=R),k},b.clone=function(){return x.w(this.$d,this)},b.toDate=function(){return new Date(this.valueOf())},b.toJSON=function(){return this.isValid()?this.toISOString():null},b.toISOString=function(){return this.$d.toISOString()},b.toString=function(){return this.$d.toUTCString()},p}(),v=M.prototype;return D.prototype=v,[["$ms",o],["$s",r],["$m",t],["$H",e],["$W",l],["$M",i],["$y",c],["$D",u]].forEach(function(p){v[p[1]]=function(b){return this.$g(b,p[0],p[1])}}),D.extend=function(p,b){return p.$i||(p(b,M,D),p.$i=!0),D},D.locale=U,D.isDayjs=B,D.unix=function(p){return D(1e3*p)},D.en=I[L],D.Ls=I,D.p={},D})},{}],392:[function(s,T,S){(function(m,a){typeof S=="object"&&T!==void 0?T.exports=a():(m=typeof globalThis<"u"?globalThis:m||self).dayjs_plugin_customParseFormat=a()})(void 0,function(){var m={LTS:"h:mm:ss A",LT:"h:mm A",L:"MM/DD/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY h:mm A",LLLL:"dddd, MMMM D, YYYY h:mm A"},a=/(\[[^[]*\])|([-_:/.,()\s]+)|(A|a|YYYY|YY?|MM?M?M?|Do|DD?|hh?|HH?|mm?|ss?|S{1,3}|z|ZZ?)/g,o=/\d\d/,r=/\d\d?/,t=/\d*[^-_:/,()\s\d]+/,e={},l=function(h){return(h=+h)+(h>68?1900:2e3)},n=function(h){return function(w){this[h]=+w}},i=[/[+-]\d\d:?(\d\d)?|Z/,function(h){(this.zone||(this.zone={})).offset=function(w){if(!w||w==="Z")return 0;var _=w.match(/([+-]|\d\d)/g),A=60*_[1]+(+_[2]||0);return A===0?0:_[0]==="+"?-A:A}(h)}],f=function(h){var w=e[h];return w&&(w.indexOf?w:w.s.concat(w.f))},c=function(h,w){var _,A=e.meridiem;if(A){for(var N=1;N<=24;N+=1)if(h.indexOf(A(N,0,w))>-1){_=N>12;break}}else _=h===(w?"pm":"PM");return _},u={A:[t,function(h){this.afternoon=c(h,!1)}],a:[t,function(h){this.afternoon=c(h,!0)}],S:[/\d/,function(h){this.milliseconds=100*+h}],SS:[o,function(h){this.milliseconds=10*+h}],SSS:[/\d{3}/,function(h){this.milliseconds=+h}],s:[r,n("seconds")],ss:[r,n("seconds")],m:[r,n("minutes")],mm:[r,n("minutes")],H:[r,n("hours")],h:[r,n("hours")],HH:[r,n("hours")],hh:[r,n("hours")],D:[r,n("day")],DD:[o,n("day")],Do:[t,function(h){var w=e.ordinal,_=h.match(/\d+/);if(this.day=_[0],w)for(var A=1;A<=31;A+=1)w(A).replace(/\[|\]/g,"")===h&&(this.day=A)}],M:[r,n("month")],MM:[o,n("month")],MMM:[t,function(h){var w=f("months"),_=(f("monthsShort")||w.map(function(A){return A.slice(0,3)})).indexOf(h)+1;if(_<1)throw new Error;this.month=_%12||_}],MMMM:[t,function(h){var w=f("months").indexOf(h)+1;if(w<1)throw new Error;this.month=w%12||w}],Y:[/[+-]?\d+/,n("year")],YY:[o,function(h){this.year=l(h)}],YYYY:[/\d{4}/,n("year")],Z:i,ZZ:i};function d(h){var w,_;w=h,_=e&&e.formats;for(var A=(h=w.replace(/(\[[^\]]+])|(LTS?|l{1,4}|L{1,4})/g,function(D,x,M){var v=M&&M.toUpperCase();return x||_[M]||m[M]||_[v].replace(/(\[[^\]]+])|(MMMM|MM|DD|dddd)/g,function(p,b,g){return b||g.slice(1)})})).match(a),N=A.length,L=0;L<N;L+=1){var I=A[L],P=u[I],B=P&&P[0],U=P&&P[1];A[L]=U?{regex:B,parser:U}:I.replace(/^\[|\]$/g,"")}return function(D){for(var x={},M=0,v=0;M<N;M+=1){var p=A[M];if(typeof p=="string")v+=p.length;else{var b=p.regex,g=p.parser,y=D.slice(v),k=b.exec(y)[0];g.call(x,k),D=D.replace(k,"")}}return function(R){var O=R.afternoon;if(O!==void 0){var z=R.hours;O?z<12&&(R.hours+=12):z===12&&(R.hours=0),delete R.afternoon}}(x),x}}return function(h,w,_){_.p.customParseFormat=!0,h&&h.parseTwoDigitYear&&(l=h.parseTwoDigitYear);var A=w.prototype,N=A.parse;A.parse=function(L){var I=L.date,P=L.utc,B=L.args;this.$u=P;var U=B[1];if(typeof U=="string"){var D=B[2]===!0,x=B[3]===!0,M=D||x,v=B[2];x&&(v=B[2]),e=this.$locale(),!D&&v&&(e=_.Ls[v]),this.$d=function(y,k,R){try{if(["x","X"].indexOf(k)>-1)return new Date((k==="X"?1e3:1)*y);var O=d(k)(y),z=O.year,$=O.month,W=O.day,j=O.hours,H=O.minutes,E=O.seconds,C=O.milliseconds,F=O.zone,V=new Date,Z=W||(z||$?1:V.getDate()),q=z||V.getFullYear(),K=0;z&&!$||(K=$>0?$-1:V.getMonth());var et=j||0,tt=H||0,X=E||0,J=C||0;return F?new Date(Date.UTC(q,K,Z,et,tt,X,J+60*F.offset*1e3)):R?new Date(Date.UTC(q,K,Z,et,tt,X,J)):new Date(q,K,Z,et,tt,X,J)}catch{return new Date("")}}(I,U,P),this.init(),v&&v!==!0&&(this.$L=this.locale(v).$L),M&&I!=this.format(U)&&(this.$d=new Date("")),e={}}else if(U instanceof Array)for(var p=U.length,b=1;b<=p;b+=1){B[1]=U[b-1];var g=_.apply(this,B);if(g.isValid()){this.$d=g.$d,this.$L=g.$L,this.init();break}b===p&&(this.$d=new Date(""))}else N.call(this,L)}}})},{}],393:[function(s,T,S){(function(m,a){typeof S=="object"&&T!==void 0?T.exports=a():(m=typeof globalThis<"u"?globalThis:m||self).dayjs_plugin_utc=a()})(void 0,function(){var m="minute",a=/[+-]\d\d(?::?\d\d)?/g,o=/([+-]|\d\d)/g;return function(r,t,e){var l=t.prototype;e.utc=function(h){var w={date:h,utc:!0,args:arguments};return new t(w)},l.utc=function(h){var w=e(this.toDate(),{locale:this.$L,utc:!0});return h?w.add(this.utcOffset(),m):w},l.local=function(){return e(this.toDate(),{locale:this.$L,utc:!1})};var n=l.parse;l.parse=function(h){h.utc&&(this.$u=!0),this.$utils().u(h.$offset)||(this.$offset=h.$offset),n.call(this,h)};var i=l.init;l.init=function(){if(this.$u){var h=this.$d;this.$y=h.getUTCFullYear(),this.$M=h.getUTCMonth(),this.$D=h.getUTCDate(),this.$W=h.getUTCDay(),this.$H=h.getUTCHours(),this.$m=h.getUTCMinutes(),this.$s=h.getUTCSeconds(),this.$ms=h.getUTCMilliseconds()}else i.call(this)};var f=l.utcOffset;l.utcOffset=function(h,w){var _=this.$utils().u;if(_(h))return this.$u?0:_(this.$offset)?f.call(this):this.$offset;if(typeof h=="string"&&(h=function(I){I===void 0&&(I="");var P=I.match(a);if(!P)return null;var B=(""+P[0]).match(o)||["-",0,0],U=B[0],D=60*+B[1]+ +B[2];return D===0?0:U==="+"?D:-D}(h))===null)return this;var A=Math.abs(h)<=16?60*h:h,N=this;if(w)return N.$offset=A,N.$u=h===0,N;if(h!==0){var L=this.$u?this.toDate().getTimezoneOffset():-1*this.utcOffset();(N=this.local().add(A+L,m)).$offset=A,N.$x.$localOffset=L}else N=this.utc();return N};var c=l.format;l.format=function(h){var w=h||(this.$u?"YYYY-MM-DDTHH:mm:ss[Z]":"");return c.call(this,w)},l.valueOf=function(){var h=this.$utils().u(this.$offset)?0:this.$offset+(this.$x.$localOffset||this.$d.getTimezoneOffset());return this.$d.valueOf()-6e4*h},l.isUTC=function(){return!!this.$u},l.toISOString=function(){return this.toDate().toISOString()},l.toString=function(){return this.toDate().toUTCString()};var u=l.toDate;l.toDate=function(h){return h==="s"&&this.$offset?e(this.format("YYYY-MM-DD HH:mm:ss:SSS")).toDate():u.call(this)};var d=l.diff;l.diff=function(h,w,_){if(h&&this.$u===h.$u)return d.call(this,h,w,_);var A=this.local(),N=e(h).local();return d.call(A,N,w,_)}}})},{}],394:[function(s,T,S){S.utils=s("./des/utils"),S.Cipher=s("./des/cipher"),S.DES=s("./des/des"),S.CBC=s("./des/cbc"),S.EDE=s("./des/ede")},{"./des/cbc":395,"./des/cipher":396,"./des/des":397,"./des/ede":398,"./des/utils":399}],395:[function(s,T,S){var m=s("minimalistic-assert"),a=s("inherits"),o={};function r(t){m.equal(t.length,8,"Invalid IV length"),this.iv=new Array(8);for(var e=0;e<this.iv.length;e++)this.iv[e]=t[e]}S.instantiate=function(t){function e(f){t.call(this,f),this._cbcInit()}a(e,t);for(var l=Object.keys(o),n=0;n<l.length;n++){var i=l[n];e.prototype[i]=o[i]}return e.create=function(f){return new e(f)},e},o._cbcInit=function(){var t=new r(this.options.iv);this._cbcState=t},o._update=function(t,e,l,n){var i=this._cbcState,f=this.constructor.super_.prototype,c=i.iv;if(this.type==="encrypt"){for(var u=0;u<this.blockSize;u++)c[u]^=t[e+u];for(f._update.call(this,c,0,l,n),u=0;u<this.blockSize;u++)c[u]=l[n+u]}else{for(f._update.call(this,t,e,l,n),u=0;u<this.blockSize;u++)l[n+u]^=c[u];for(u=0;u<this.blockSize;u++)c[u]=t[e+u]}}},{inherits:440,"minimalistic-assert":453}],396:[function(s,T,S){var m=s("minimalistic-assert");function a(o){this.options=o,this.type=this.options.type,this.blockSize=8,this._init(),this.buffer=new Array(this.blockSize),this.bufferOff=0,this.padding=o.padding!==!1}T.exports=a,a.prototype._init=function(){},a.prototype.update=function(o){return o.length===0?[]:this.type==="decrypt"?this._updateDecrypt(o):this._updateEncrypt(o)},a.prototype._buffer=function(o,r){for(var t=Math.min(this.buffer.length-this.bufferOff,o.length-r),e=0;e<t;e++)this.buffer[this.bufferOff+e]=o[r+e];return this.bufferOff+=t,t},a.prototype._flushBuffer=function(o,r){return this._update(this.buffer,0,o,r),this.bufferOff=0,this.blockSize},a.prototype._updateEncrypt=function(o){var r=0,t=0,e=(this.bufferOff+o.length)/this.blockSize|0,l=new Array(e*this.blockSize);this.bufferOff!==0&&(r+=this._buffer(o,r),this.bufferOff===this.buffer.length&&(t+=this._flushBuffer(l,t)));for(var n=o.length-(o.length-r)%this.blockSize;r<n;r+=this.blockSize)this._update(o,r,l,t),t+=this.blockSize;for(;r<o.length;r++,this.bufferOff++)this.buffer[this.bufferOff]=o[r];return l},a.prototype._updateDecrypt=function(o){for(var r=0,t=0,e=Math.ceil((this.bufferOff+o.length)/this.blockSize)-1,l=new Array(e*this.blockSize);e>0;e--)r+=this._buffer(o,r),t+=this._flushBuffer(l,t);return r+=this._buffer(o,r),l},a.prototype.final=function(o){var r,t;return o&&(r=this.update(o)),t=this.type==="encrypt"?this._finalEncrypt():this._finalDecrypt(),r?r.concat(t):t},a.prototype._pad=function(o,r){if(r===0)return!1;for(;r<o.length;)o[r++]=0;return!0},a.prototype._finalEncrypt=function(){if(!this._pad(this.buffer,this.bufferOff))return[];var o=new Array(this.blockSize);return this._update(this.buffer,0,o,0),o},a.prototype._unpad=function(o){return o},a.prototype._finalDecrypt=function(){m.equal(this.bufferOff,this.blockSize,"Not enough data to decrypt");var o=new Array(this.blockSize);return this._flushBuffer(o,0),this._unpad(o)}},{"minimalistic-assert":453}],397:[function(s,T,S){var m=s("minimalistic-assert"),a=s("inherits"),o=s("./utils"),r=s("./cipher");function t(){this.tmp=new Array(2),this.keys=null}function e(n){r.call(this,n);var i=new t;this._desState=i,this.deriveKeys(i,n.key)}a(e,r),T.exports=e,e.create=function(n){return new e(n)};var l=[1,1,2,2,2,2,2,2,1,2,2,2,2,2,2,1];e.prototype.deriveKeys=function(n,i){n.keys=new Array(32),m.equal(i.length,this.blockSize,"Invalid key length");var f=o.readUInt32BE(i,0),c=o.readUInt32BE(i,4);o.pc1(f,c,n.tmp,0),f=n.tmp[0],c=n.tmp[1];for(var u=0;u<n.keys.length;u+=2){var d=l[u>>>1];f=o.r28shl(f,d),c=o.r28shl(c,d),o.pc2(f,c,n.keys,u)}},e.prototype._update=function(n,i,f,c){var u=this._desState,d=o.readUInt32BE(n,i),h=o.readUInt32BE(n,i+4);o.ip(d,h,u.tmp,0),d=u.tmp[0],h=u.tmp[1],this.type==="encrypt"?this._encrypt(u,d,h,u.tmp,0):this._decrypt(u,d,h,u.tmp,0),d=u.tmp[0],h=u.tmp[1],o.writeUInt32BE(f,d,c),o.writeUInt32BE(f,h,c+4)},e.prototype._pad=function(n,i){if(this.padding===!1)return!1;for(var f=n.length-i,c=i;c<n.length;c++)n[c]=f;return!0},e.prototype._unpad=function(n){if(this.padding===!1)return n;for(var i=n[n.length-1],f=n.length-i;f<n.length;f++)m.equal(n[f],i);return n.slice(0,n.length-i)},e.prototype._encrypt=function(n,i,f,c,u){for(var d=i,h=f,w=0;w<n.keys.length;w+=2){var _=n.keys[w],A=n.keys[w+1];o.expand(h,n.tmp,0),_^=n.tmp[0],A^=n.tmp[1];var N=o.substitute(_,A),L=h;h=(d^o.permute(N))>>>0,d=L}o.rip(h,d,c,u)},e.prototype._decrypt=function(n,i,f,c,u){for(var d=f,h=i,w=n.keys.length-2;w>=0;w-=2){var _=n.keys[w],A=n.keys[w+1];o.expand(d,n.tmp,0),_^=n.tmp[0],A^=n.tmp[1];var N=o.substitute(_,A),L=d;d=(h^o.permute(N))>>>0,h=L}o.rip(d,h,c,u)}},{"./cipher":396,"./utils":399,inherits:440,"minimalistic-assert":453}],398:[function(s,T,S){var m=s("minimalistic-assert"),a=s("inherits"),o=s("./cipher"),r=s("./des");function t(l,n){m.equal(n.length,24,"Invalid key length");var i=n.slice(0,8),f=n.slice(8,16),c=n.slice(16,24);this.ciphers=l==="encrypt"?[r.create({type:"encrypt",key:i}),r.create({type:"decrypt",key:f}),r.create({type:"encrypt",key:c})]:[r.create({type:"decrypt",key:c}),r.create({type:"encrypt",key:f}),r.create({type:"decrypt",key:i})]}function e(l){o.call(this,l);var n=new t(this.type,this.options.key);this._edeState=n}a(e,o),T.exports=e,e.create=function(l){return new e(l)},e.prototype._update=function(l,n,i,f){var c=this._edeState;c.ciphers[0]._update(l,n,i,f),c.ciphers[1]._update(i,f,i,f),c.ciphers[2]._update(i,f,i,f)},e.prototype._pad=r.prototype._pad,e.prototype._unpad=r.prototype._unpad},{"./cipher":396,"./des":397,inherits:440,"minimalistic-assert":453}],399:[function(s,T,S){S.readUInt32BE=function(r,t){return(r[0+t]<<24|r[1+t]<<16|r[2+t]<<8|r[3+t])>>>0},S.writeUInt32BE=function(r,t,e){r[0+e]=t>>>24,r[1+e]=t>>>16&255,r[2+e]=t>>>8&255,r[3+e]=255&t},S.ip=function(r,t,e,l){for(var n=0,i=0,f=6;f>=0;f-=2){for(var c=0;c<=24;c+=8)n<<=1,n|=t>>>c+f&1;for(c=0;c<=24;c+=8)n<<=1,n|=r>>>c+f&1}for(f=6;f>=0;f-=2){for(c=1;c<=25;c+=8)i<<=1,i|=t>>>c+f&1;for(c=1;c<=25;c+=8)i<<=1,i|=r>>>c+f&1}e[l+0]=n>>>0,e[l+1]=i>>>0},S.rip=function(r,t,e,l){for(var n=0,i=0,f=0;f<4;f++)for(var c=24;c>=0;c-=8)n<<=1,n|=t>>>c+f&1,n<<=1,n|=r>>>c+f&1;for(f=4;f<8;f++)for(c=24;c>=0;c-=8)i<<=1,i|=t>>>c+f&1,i<<=1,i|=r>>>c+f&1;e[l+0]=n>>>0,e[l+1]=i>>>0},S.pc1=function(r,t,e,l){for(var n=0,i=0,f=7;f>=5;f--){for(var c=0;c<=24;c+=8)n<<=1,n|=t>>c+f&1;for(c=0;c<=24;c+=8)n<<=1,n|=r>>c+f&1}for(c=0;c<=24;c+=8)n<<=1,n|=t>>c+f&1;for(f=1;f<=3;f++){for(c=0;c<=24;c+=8)i<<=1,i|=t>>c+f&1;for(c=0;c<=24;c+=8)i<<=1,i|=r>>c+f&1}for(c=0;c<=24;c+=8)i<<=1,i|=r>>c+f&1;e[l+0]=n>>>0,e[l+1]=i>>>0},S.r28shl=function(r,t){return r<<t&268435455|r>>>28-t};var m=[14,11,17,4,27,23,25,0,13,22,7,18,5,9,16,24,2,20,12,21,1,8,15,26,15,4,25,19,9,1,26,16,5,11,23,8,12,7,17,0,22,3,10,14,6,20,27,24];S.pc2=function(r,t,e,l){for(var n=0,i=0,f=m.length>>>1,c=0;c<f;c++)n<<=1,n|=r>>>m[c]&1;for(c=f;c<m.length;c++)i<<=1,i|=t>>>m[c]&1;e[l+0]=n>>>0,e[l+1]=i>>>0},S.expand=function(r,t,e){var l=0,n=0;l=(1&r)<<5|r>>>27;for(var i=23;i>=15;i-=4)l<<=6,l|=r>>>i&63;for(i=11;i>=3;i-=4)n|=r>>>i&63,n<<=6;n|=(31&r)<<1|r>>>31,t[e+0]=l>>>0,t[e+1]=n>>>0};var a=[14,0,4,15,13,7,1,4,2,14,15,2,11,13,8,1,3,10,10,6,6,12,12,11,5,9,9,5,0,3,7,8,4,15,1,12,14,8,8,2,13,4,6,9,2,1,11,7,15,5,12,11,9,3,7,14,3,10,10,0,5,6,0,13,15,3,1,13,8,4,14,7,6,15,11,2,3,8,4,14,9,12,7,0,2,1,13,10,12,6,0,9,5,11,10,5,0,13,14,8,7,10,11,1,10,3,4,15,13,4,1,2,5,11,8,6,12,7,6,12,9,0,3,5,2,14,15,9,10,13,0,7,9,0,14,9,6,3,3,4,15,6,5,10,1,2,13,8,12,5,7,14,11,12,4,11,2,15,8,1,13,1,6,10,4,13,9,0,8,6,15,9,3,8,0,7,11,4,1,15,2,14,12,3,5,11,10,5,14,2,7,12,7,13,13,8,14,11,3,5,0,6,6,15,9,0,10,3,1,4,2,7,8,2,5,12,11,1,12,10,4,14,15,9,10,3,6,15,9,0,0,6,12,10,11,1,7,13,13,8,15,9,1,4,3,5,14,11,5,12,2,7,8,2,4,14,2,14,12,11,4,2,1,12,7,4,10,7,11,13,6,1,8,5,5,0,3,15,15,10,13,3,0,9,14,8,9,6,4,11,2,8,1,12,11,7,10,1,13,14,7,2,8,13,15,6,9,15,12,0,5,9,6,10,3,4,0,5,14,3,12,10,1,15,10,4,15,2,9,7,2,12,6,9,8,5,0,6,13,1,3,13,4,14,14,0,7,11,5,3,11,8,9,4,14,3,15,2,5,12,2,9,8,5,12,15,3,10,7,11,0,14,4,1,10,7,1,6,13,0,11,8,6,13,4,13,11,0,2,11,14,7,15,4,0,9,8,1,13,10,3,14,12,3,9,5,7,12,5,2,10,15,6,8,1,6,1,6,4,11,11,13,13,8,12,1,3,4,7,10,14,7,10,9,15,5,6,0,8,15,0,14,5,2,9,3,2,12,13,1,2,15,8,13,4,8,6,10,15,3,11,7,1,4,10,12,9,5,3,6,14,11,5,0,0,14,12,9,7,2,7,2,11,1,4,14,1,7,9,4,12,10,14,8,2,13,0,15,6,12,10,9,13,0,15,3,3,5,5,6,8,11];S.substitute=function(r,t){for(var e=0,l=0;l<4;l++)e<<=4,e|=a[64*l+(r>>>18-6*l&63)];for(l=0;l<4;l++)e<<=4,e|=a[256+64*l+(t>>>18-6*l&63)];return e>>>0};var o=[16,25,12,11,3,20,4,15,31,17,9,6,27,14,1,22,30,24,8,18,0,5,29,23,13,19,2,26,10,21,28,7];S.permute=function(r){for(var t=0,e=0;e<o.length;e++)t<<=1,t|=r>>>o[e]&1;return t>>>0},S.padSplit=function(r,t,e){for(var l=r.toString(2);l.length<t;)l="0"+l;for(var n=[],i=0;i<t;i+=e)n.push(l.slice(i,i+e));return n.join(" ")}},{}],400:[function(s,T,S){(function(m){(function(){var a=s("./lib/generatePrime"),o=s("./lib/primes.json"),r=s("./lib/dh"),t={binary:!0,hex:!0,base64:!0};S.DiffieHellmanGroup=S.createDiffieHellmanGroup=S.getDiffieHellman=function(e){var l=new m(o[e].prime,"hex"),n=new m(o[e].gen,"hex");return new r(l,n)},S.createDiffieHellman=S.DiffieHellman=function e(l,n,i,f){return m.isBuffer(n)||t[n]===void 0?e(l,"binary",n,i):(n=n||"binary",f=f||"binary",i=i||new m([2]),m.isBuffer(i)||(i=new m(i,f)),typeof l=="number"?new r(a(l,i),i,!0):(m.isBuffer(l)||(l=new m(l,n)),new r(l,i,!0)))}}).call(this)}).call(this,s("buffer").Buffer)},{"./lib/dh":401,"./lib/generatePrime":402,"./lib/primes.json":403,buffer:220}],401:[function(s,T,S){(function(m){(function(){var a=s("bn.js"),o=new(s("miller-rabin")),r=new a(24),t=new a(11),e=new a(10),l=new a(3),n=new a(7),i=s("./generatePrime"),f=s("randombytes");function c(_,A){return A=A||"utf8",m.isBuffer(_)||(_=new m(_,A)),this._pub=new a(_),this}function u(_,A){return A=A||"utf8",m.isBuffer(_)||(_=new m(_,A)),this._priv=new a(_),this}T.exports=h;var d={};function h(_,A,N){this.setGenerator(A),this.__prime=new a(_),this._prime=a.mont(this.__prime),this._primeLen=_.length,this._pub=void 0,this._priv=void 0,this._primeCode=void 0,N?(this.setPublicKey=c,this.setPrivateKey=u):this._primeCode=8}function w(_,A){var N=new m(_.toArray());return A?N.toString(A):N}Object.defineProperty(h.prototype,"verifyError",{enumerable:!0,get:function(){return typeof this._primeCode!="number"&&(this._primeCode=function(_,A){var N=A.toString("hex"),L=[N,_.toString(16)].join("_");if(L in d)return d[L];var I,P=0;if(_.isEven()||!i.simpleSieve||!i.fermatTest(_)||!o.test(_))return P+=1,P+=N==="02"||N==="05"?8:4,d[L]=P,P;switch(o.test(_.shrn(1))||(P+=2),N){case"02":_.mod(r).cmp(t)&&(P+=8);break;case"05":(I=_.mod(e)).cmp(l)&&I.cmp(n)&&(P+=8);break;default:P+=4}return d[L]=P,P}(this.__prime,this.__gen)),this._primeCode}}),h.prototype.generateKeys=function(){return this._priv||(this._priv=new a(f(this._primeLen))),this._pub=this._gen.toRed(this._prime).redPow(this._priv).fromRed(),this.getPublicKey()},h.prototype.computeSecret=function(_){var A=(_=(_=new a(_)).toRed(this._prime)).redPow(this._priv).fromRed(),N=new m(A.toArray()),L=this.getPrime();if(N.length<L.length){var I=new m(L.length-N.length);I.fill(0),N=m.concat([I,N])}return N},h.prototype.getPublicKey=function(_){return w(this._pub,_)},h.prototype.getPrivateKey=function(_){return w(this._priv,_)},h.prototype.getPrime=function(_){return w(this.__prime,_)},h.prototype.getGenerator=function(_){return w(this._gen,_)},h.prototype.setGenerator=function(_,A){return A=A||"utf8",m.isBuffer(_)||(_=new m(_,A)),this.__gen=_,this._gen=new a(_),this}}).call(this)}).call(this,s("buffer").Buffer)},{"./generatePrime":402,"bn.js":404,buffer:220,"miller-rabin":451,randombytes:475}],402:[function(s,T,S){var m=s("randombytes");T.exports=_,_.simpleSieve=h,_.fermatTest=w;var a=s("bn.js"),o=new a(24),r=new(s("miller-rabin")),t=new a(1),e=new a(2),l=new a(5),n=(new a(16),new a(8),new a(10)),i=new a(3),f=(new a(7),new a(11)),c=new a(4),u=(new a(12),null);function d(){if(u!==null)return u;var A=[];A[0]=2;for(var N=1,L=3;L<1048576;L+=2){for(var I=Math.ceil(Math.sqrt(L)),P=0;P<N&&A[P]<=I&&L%A[P]!=0;P++);N!==P&&A[P]<=I||(A[N++]=L)}return u=A,A}function h(A){for(var N=d(),L=0;L<N.length;L++)if(A.modn(N[L])===0)return A.cmpn(N[L])===0;return!0}function w(A){var N=a.mont(A);return e.toRed(N).redPow(A.subn(1)).fromRed().cmpn(1)===0}function _(A,N){if(A<16)return new a(N===2||N===5?[140,123]:[140,39]);var L,I;for(N=new a(N);;){for(L=new a(m(Math.ceil(A/8)));L.bitLength()>A;)L.ishrn(1);if(L.isEven()&&L.iadd(t),L.testn(1)||L.iadd(e),N.cmp(e)){if(!N.cmp(l))for(;L.mod(n).cmp(i);)L.iadd(c)}else for(;L.mod(o).cmp(f);)L.iadd(c);if(h(I=L.shrn(1))&&h(L)&&w(I)&&w(L)&&r.test(I)&&r.test(L))return L}}},{"bn.js":404,"miller-rabin":451,randombytes:475}],403:[function(s,T,S){T.exports={modp1:{gen:"02",prime:"ffffffffffffffffc90fdaa22168c234c4c6628b80dc1cd129024e088a67cc74020bbea63b139b22514a08798e3404ddef9519b3cd3a431b302b0a6df25f14374fe1356d6d51c245e485b576625e7ec6f44c42e9a63a3620ffffffffffffffff"},modp2:{gen:"02",prime:"ffffffffffffffffc90fdaa22168c234c4c6628b80dc1cd129024e088a67cc74020bbea63b139b22514a08798e3404ddef9519b3cd3a431b302b0a6df25f14374fe1356d6d51c245e485b576625e7ec6f44c42e9a637ed6b0bff5cb6f406b7edee386bfb5a899fa5ae9f24117c4b1fe649286651ece65381ffffffffffffffff"},modp5:{gen:"02",prime:"ffffffffffffffffc90fdaa22168c234c4c6628b80dc1cd129024e088a67cc74020bbea63b139b22514a08798e3404ddef9519b3cd3a431b302b0a6df25f14374fe1356d6d51c245e485b576625e7ec6f44c42e9a637ed6b0bff5cb6f406b7edee386bfb5a899fa5ae9f24117c4b1fe649286651ece45b3dc2007cb8a163bf0598da48361c55d39a69163fa8fd24cf5f83655d23dca3ad961c62f356208552bb9ed529077096966d670c354e4abc9804f1746c08ca237327ffffffffffffffff"},modp14:{gen:"02",prime:"ffffffffffffffffc90fdaa22168c234c4c6628b80dc1cd129024e088a67cc74020bbea63b139b22514a08798e3404ddef9519b3cd3a431b302b0a6df25f14374fe1356d6d51c245e485b576625e7ec6f44c42e9a637ed6b0bff5cb6f406b7edee386bfb5a899fa5ae9f24117c4b1fe649286651ece45b3dc2007cb8a163bf0598da48361c55d39a69163fa8fd24cf5f83655d23dca3ad961c62f356208552bb9ed529077096966d670c354e4abc9804f1746c08ca18217c32905e462e36ce3be39e772c180e86039b2783a2ec07a28fb5c55df06f4c52c9de2bcbf6955817183995497cea956ae515d2261898fa051015728e5a8aacaa68ffffffffffffffff"},modp15:{gen:"02",prime:"ffffffffffffffffc90fdaa22168c234c4c6628b80dc1cd129024e088a67cc74020bbea63b139b22514a08798e3404ddef9519b3cd3a431b302b0a6df25f14374fe1356d6d51c245e485b576625e7ec6f44c42e9a637ed6b0bff5cb6f406b7edee386bfb5a899fa5ae9f24117c4b1fe649286651ece45b3dc2007cb8a163bf0598da48361c55d39a69163fa8fd24cf5f83655d23dca3ad961c62f356208552bb9ed529077096966d670c354e4abc9804f1746c08ca18217c32905e462e36ce3be39e772c180e86039b2783a2ec07a28fb5c55df06f4c52c9de2bcbf6955817183995497cea956ae515d2261898fa051015728e5a8aaac42dad33170d04507a33a85521abdf1cba64ecfb850458dbef0a8aea71575d060c7db3970f85a6e1e4c7abf5ae8cdb0933d71e8c94e04a25619dcee3d2261ad2ee6bf12ffa06d98a0864d87602733ec86a64521f2b18177b200cbbe117577a615d6c770988c0bad946e208e24fa074e5ab3143db5bfce0fd108e4b82d120a93ad2caffffffffffffffff"},modp16:{gen:"02",prime:"ffffffffffffffffc90fdaa22168c234c4c6628b80dc1cd129024e088a67cc74020bbea63b139b22514a08798e3404ddef9519b3cd3a431b302b0a6df25f14374fe1356d6d51c245e485b576625e7ec6f44c42e9a637ed6b0bff5cb6f406b7edee386bfb5a899fa5ae9f24117c4b1fe649286651ece45b3dc2007cb8a163bf0598da48361c55d39a69163fa8fd24cf5f83655d23dca3ad961c62f356208552bb9ed529077096966d670c354e4abc9804f1746c08ca18217c32905e462e36ce3be39e772c180e86039b2783a2ec07a28fb5c55df06f4c52c9de2bcbf6955817183995497cea956ae515d2261898fa051015728e5a8aaac42dad33170d04507a33a85521abdf1cba64ecfb850458dbef0a8aea71575d060c7db3970f85a6e1e4c7abf5ae8cdb0933d71e8c94e04a25619dcee3d2261ad2ee6bf12ffa06d98a0864d87602733ec86a64521f2b18177b200cbbe117577a615d6c770988c0bad946e208e24fa074e5ab3143db5bfce0fd108e4b82d120a92108011a723c12a787e6d788719a10bdba5b2699c327186af4e23c1a946834b6150bda2583e9ca2ad44ce8dbbbc2db04de8ef92e8efc141fbecaa6287c59474e6bc05d99b2964fa090c3a2233ba186515be7ed1f612970cee2d7afb81bdd762170481cd0069127d5b05aa993b4ea988d8fddc186ffb7dc90a6c08f4df435c934063199ffffffffffffffff"},modp17:{gen:"02",prime:"ffffffffffffffffc90fdaa22168c234c4c6628b80dc1cd129024e088a67cc74020bbea63b139b22514a08798e3404ddef9519b3cd3a431b302b0a6df25f14374fe1356d6d51c245e485b576625e7ec6f44c42e9a637ed6b0bff5cb6f406b7edee386bfb5a899fa5ae9f24117c4b1fe649286651ece45b3dc2007cb8a163bf0598da48361c55d39a69163fa8fd24cf5f83655d23dca3ad961c62f356208552bb9ed529077096966d670c354e4abc9804f1746c08ca18217c32905e462e36ce3be39e772c180e86039b2783a2ec07a28fb5c55df06f4c52c9de2bcbf6955817183995497cea956ae515d2261898fa051015728e5a8aaac42dad33170d04507a33a85521abdf1cba64ecfb850458dbef0a8aea71575d060c7db3970f85a6e1e4c7abf5ae8cdb0933d71e8c94e04a25619dcee3d2261ad2ee6bf12ffa06d98a0864d87602733ec86a64521f2b18177b200cbbe117577a615d6c770988c0bad946e208e24fa074e5ab3143db5bfce0fd108e4b82d120a92108011a723c12a787e6d788719a10bdba5b2699c327186af4e23c1a946834b6150bda2583e9ca2ad44ce8dbbbc2db04de8ef92e8efc141fbecaa6287c59474e6bc05d99b2964fa090c3a2233ba186515be7ed1f612970cee2d7afb81bdd762170481cd0069127d5b05aa993b4ea988d8fddc186ffb7dc90a6c08f4df435c93402849236c3fab4d27c7026c1d4dcb2602646dec9751e763dba37bdf8ff9406ad9e530ee5db382f413001aeb06a53ed9027d831179727b0865a8918da3edbebcf9b14ed44ce6cbaced4bb1bdb7f1447e6cc254b332051512bd7af426fb8f401378cd2bf5983ca01c64b92ecf032ea15d1721d03f482d7ce6e74fef6d55e702f46980c82b5a84031900b1c9e59e7c97fbec7e8f323a97a7e36cc88be0f1d45b7ff585ac54bd407b22b4154aacc8f6d7ebf48e1d814cc5ed20f8037e0a79715eef29be32806a1d58bb7c5da76f550aa3d8a1fbff0eb19ccb1a313d55cda56c9ec2ef29632387fe8d76e3c0468043e8f663f4860ee12bf2d5b0b7474d6e694f91e6dcc4024ffffffffffffffff"},modp18:{gen:"02",prime:"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"}}},{}],404:[function(s,T,S){arguments[4][184][0].apply(S,arguments)},{buffer:188,dup:184}],405:[function(s,T,S){var m=S;m.version=s("../package.json").version,m.utils=s("./elliptic/utils"),m.rand=s("brorand"),m.curve=s("./elliptic/curve"),m.curves=s("./elliptic/curves"),m.ec=s("./elliptic/ec"),m.eddsa=s("./elliptic/eddsa")},{"../package.json":421,"./elliptic/curve":408,"./elliptic/curves":411,"./elliptic/ec":412,"./elliptic/eddsa":415,"./elliptic/utils":419,brorand:187}],406:[function(s,T,S){var m=s("bn.js"),a=s("../utils"),o=a.getNAF,r=a.getJSF,t=a.assert;function e(n,i){this.type=n,this.p=new m(i.p,16),this.red=i.prime?m.red(i.prime):m.mont(this.p),this.zero=new m(0).toRed(this.red),this.one=new m(1).toRed(this.red),this.two=new m(2).toRed(this.red),this.n=i.n&&new m(i.n,16),this.g=i.g&&this.pointFromJSON(i.g,i.gRed),this._wnafT1=new Array(4),this._wnafT2=new Array(4),this._wnafT3=new Array(4),this._wnafT4=new Array(4),this._bitLength=this.n?this.n.bitLength():0;var f=this.n&&this.p.div(this.n);!f||f.cmpn(100)>0?this.redN=null:(this._maxwellTrick=!0,this.redN=this.n.toRed(this.red))}function l(n,i){this.curve=n,this.type=i,this.precomputed=null}T.exports=e,e.prototype.point=function(){throw new Error("Not implemented")},e.prototype.validate=function(){throw new Error("Not implemented")},e.prototype._fixedNafMul=function(n,i){t(n.precomputed);var f=n._getDoubles(),c=o(i,1,this._bitLength),u=(1<<f.step+1)-(f.step%2==0?2:1);u/=3;var d,h,w=[];for(d=0;d<c.length;d+=f.step){h=0;for(var _=d+f.step-1;_>=d;_--)h=(h<<1)+c[_];w.push(h)}for(var A=this.jpoint(null,null,null),N=this.jpoint(null,null,null),L=u;L>0;L--){for(d=0;d<w.length;d++)(h=w[d])===L?N=N.mixedAdd(f.points[d]):h===-L&&(N=N.mixedAdd(f.points[d].neg()));A=A.add(N)}return A.toP()},e.prototype._wnafMul=function(n,i){var f=4,c=n._getNAFPoints(f);f=c.wnd;for(var u=c.points,d=o(i,f,this._bitLength),h=this.jpoint(null,null,null),w=d.length-1;w>=0;w--){for(var _=0;w>=0&&d[w]===0;w--)_++;if(w>=0&&_++,h=h.dblp(_),w<0)break;var A=d[w];t(A!==0),h=n.type==="affine"?A>0?h.mixedAdd(u[A-1>>1]):h.mixedAdd(u[-A-1>>1].neg()):A>0?h.add(u[A-1>>1]):h.add(u[-A-1>>1].neg())}return n.type==="affine"?h.toP():h},e.prototype._wnafMulAdd=function(n,i,f,c,u){var d,h,w,_=this._wnafT1,A=this._wnafT2,N=this._wnafT3,L=0;for(d=0;d<c;d++){var I=(w=i[d])._getNAFPoints(n);_[d]=I.wnd,A[d]=I.points}for(d=c-1;d>=1;d-=2){var P=d-1,B=d;if(_[P]===1&&_[B]===1){var U=[i[P],null,null,i[B]];i[P].y.cmp(i[B].y)===0?(U[1]=i[P].add(i[B]),U[2]=i[P].toJ().mixedAdd(i[B].neg())):i[P].y.cmp(i[B].y.redNeg())===0?(U[1]=i[P].toJ().mixedAdd(i[B]),U[2]=i[P].add(i[B].neg())):(U[1]=i[P].toJ().mixedAdd(i[B]),U[2]=i[P].toJ().mixedAdd(i[B].neg()));var D=[-3,-1,-5,-7,0,7,5,1,3],x=r(f[P],f[B]);for(L=Math.max(x[0].length,L),N[P]=new Array(L),N[B]=new Array(L),h=0;h<L;h++){var M=0|x[0][h],v=0|x[1][h];N[P][h]=D[3*(M+1)+(v+1)],N[B][h]=0,A[P]=U}}else N[P]=o(f[P],_[P],this._bitLength),N[B]=o(f[B],_[B],this._bitLength),L=Math.max(N[P].length,L),L=Math.max(N[B].length,L)}var p=this.jpoint(null,null,null),b=this._wnafT4;for(d=L;d>=0;d--){for(var g=0;d>=0;){var y=!0;for(h=0;h<c;h++)b[h]=0|N[h][d],b[h]!==0&&(y=!1);if(!y)break;g++,d--}if(d>=0&&g++,p=p.dblp(g),d<0)break;for(h=0;h<c;h++){var k=b[h];k!==0&&(k>0?w=A[h][k-1>>1]:k<0&&(w=A[h][-k-1>>1].neg()),p=w.type==="affine"?p.mixedAdd(w):p.add(w))}}for(d=0;d<c;d++)A[d]=null;return u?p:p.toP()},e.BasePoint=l,l.prototype.eq=function(){throw new Error("Not implemented")},l.prototype.validate=function(){return this.curve.validate(this)},e.prototype.decodePoint=function(n,i){n=a.toArray(n,i);var f=this.p.byteLength();if((n[0]===4||n[0]===6||n[0]===7)&&n.length-1==2*f)return n[0]===6?t(n[n.length-1]%2==0):n[0]===7&&t(n[n.length-1]%2==1),this.point(n.slice(1,1+f),n.slice(1+f,1+2*f));if((n[0]===2||n[0]===3)&&n.length-1===f)return this.pointFromX(n.slice(1,1+f),n[0]===3);throw new Error("Unknown point format")},l.prototype.encodeCompressed=function(n){return this.encode(n,!0)},l.prototype._encode=function(n){var i=this.curve.p.byteLength(),f=this.getX().toArray("be",i);return n?[this.getY().isEven()?2:3].concat(f):[4].concat(f,this.getY().toArray("be",i))},l.prototype.encode=function(n,i){return a.encode(this._encode(i),n)},l.prototype.precompute=function(n){if(this.precomputed)return this;var i={doubles:null,naf:null,beta:null};return i.naf=this._getNAFPoints(8),i.doubles=this._getDoubles(4,n),i.beta=this._getBeta(),this.precomputed=i,this},l.prototype._hasDoubles=function(n){if(!this.precomputed)return!1;var i=this.precomputed.doubles;return!!i&&i.points.length>=Math.ceil((n.bitLength()+1)/i.step)},l.prototype._getDoubles=function(n,i){if(this.precomputed&&this.precomputed.doubles)return this.precomputed.doubles;for(var f=[this],c=this,u=0;u<i;u+=n){for(var d=0;d<n;d++)c=c.dbl();f.push(c)}return{step:n,points:f}},l.prototype._getNAFPoints=function(n){if(this.precomputed&&this.precomputed.naf)return this.precomputed.naf;for(var i=[this],f=(1<<n)-1,c=f===1?null:this.dbl(),u=1;u<f;u++)i[u]=i[u-1].add(c);return{wnd:n,points:i}},l.prototype._getBeta=function(){return null},l.prototype.dblp=function(n){for(var i=this,f=0;f<n;f++)i=i.dbl();return i}},{"../utils":419,"bn.js":420}],407:[function(s,T,S){var m=s("../utils"),a=s("bn.js"),o=s("inherits"),r=s("./base"),t=m.assert;function e(n){this.twisted=(0|n.a)!=1,this.mOneA=this.twisted&&(0|n.a)==-1,this.extended=this.mOneA,r.call(this,"edwards",n),this.a=new a(n.a,16).umod(this.red.m),this.a=this.a.toRed(this.red),this.c=new a(n.c,16).toRed(this.red),this.c2=this.c.redSqr(),this.d=new a(n.d,16).toRed(this.red),this.dd=this.d.redAdd(this.d),t(!this.twisted||this.c.fromRed().cmpn(1)===0),this.oneC=(0|n.c)==1}function l(n,i,f,c,u){r.BasePoint.call(this,n,"projective"),i===null&&f===null&&c===null?(this.x=this.curve.zero,this.y=this.curve.one,this.z=this.curve.one,this.t=this.curve.zero,this.zOne=!0):(this.x=new a(i,16),this.y=new a(f,16),this.z=c?new a(c,16):this.curve.one,this.t=u&&new a(u,16),this.x.red||(this.x=this.x.toRed(this.curve.red)),this.y.red||(this.y=this.y.toRed(this.curve.red)),this.z.red||(this.z=this.z.toRed(this.curve.red)),this.t&&!this.t.red&&(this.t=this.t.toRed(this.curve.red)),this.zOne=this.z===this.curve.one,this.curve.extended&&!this.t&&(this.t=this.x.redMul(this.y),this.zOne||(this.t=this.t.redMul(this.z.redInvm()))))}o(e,r),T.exports=e,e.prototype._mulA=function(n){return this.mOneA?n.redNeg():this.a.redMul(n)},e.prototype._mulC=function(n){return this.oneC?n:this.c.redMul(n)},e.prototype.jpoint=function(n,i,f,c){return this.point(n,i,f,c)},e.prototype.pointFromX=function(n,i){(n=new a(n,16)).red||(n=n.toRed(this.red));var f=n.redSqr(),c=this.c2.redSub(this.a.redMul(f)),u=this.one.redSub(this.c2.redMul(this.d).redMul(f)),d=c.redMul(u.redInvm()),h=d.redSqrt();if(h.redSqr().redSub(d).cmp(this.zero)!==0)throw new Error("invalid point");var w=h.fromRed().isOdd();return(i&&!w||!i&&w)&&(h=h.redNeg()),this.point(n,h)},e.prototype.pointFromY=function(n,i){(n=new a(n,16)).red||(n=n.toRed(this.red));var f=n.redSqr(),c=f.redSub(this.c2),u=f.redMul(this.d).redMul(this.c2).redSub(this.a),d=c.redMul(u.redInvm());if(d.cmp(this.zero)===0){if(i)throw new Error("invalid point");return this.point(this.zero,n)}var h=d.redSqrt();if(h.redSqr().redSub(d).cmp(this.zero)!==0)throw new Error("invalid point");return h.fromRed().isOdd()!==i&&(h=h.redNeg()),this.point(h,n)},e.prototype.validate=function(n){if(n.isInfinity())return!0;n.normalize();var i=n.x.redSqr(),f=n.y.redSqr(),c=i.redMul(this.a).redAdd(f),u=this.c2.redMul(this.one.redAdd(this.d.redMul(i).redMul(f)));return c.cmp(u)===0},o(l,r.BasePoint),e.prototype.pointFromJSON=function(n){return l.fromJSON(this,n)},e.prototype.point=function(n,i,f,c){return new l(this,n,i,f,c)},l.fromJSON=function(n,i){return new l(n,i[0],i[1],i[2])},l.prototype.inspect=function(){return this.isInfinity()?"<EC Point Infinity>":"<EC Point x: "+this.x.fromRed().toString(16,2)+" y: "+this.y.fromRed().toString(16,2)+" z: "+this.z.fromRed().toString(16,2)+">"},l.prototype.isInfinity=function(){return this.x.cmpn(0)===0&&(this.y.cmp(this.z)===0||this.zOne&&this.y.cmp(this.curve.c)===0)},l.prototype._extDbl=function(){var n=this.x.redSqr(),i=this.y.redSqr(),f=this.z.redSqr();f=f.redIAdd(f);var c=this.curve._mulA(n),u=this.x.redAdd(this.y).redSqr().redISub(n).redISub(i),d=c.redAdd(i),h=d.redSub(f),w=c.redSub(i),_=u.redMul(h),A=d.redMul(w),N=u.redMul(w),L=h.redMul(d);return this.curve.point(_,A,L,N)},l.prototype._projDbl=function(){var n,i,f,c,u,d,h=this.x.redAdd(this.y).redSqr(),w=this.x.redSqr(),_=this.y.redSqr();if(this.curve.twisted){var A=(c=this.curve._mulA(w)).redAdd(_);this.zOne?(n=h.redSub(w).redSub(_).redMul(A.redSub(this.curve.two)),i=A.redMul(c.redSub(_)),f=A.redSqr().redSub(A).redSub(A)):(u=this.z.redSqr(),d=A.redSub(u).redISub(u),n=h.redSub(w).redISub(_).redMul(d),i=A.redMul(c.redSub(_)),f=A.redMul(d))}else c=w.redAdd(_),u=this.curve._mulC(this.z).redSqr(),d=c.redSub(u).redSub(u),n=this.curve._mulC(h.redISub(c)).redMul(d),i=this.curve._mulC(c).redMul(w.redISub(_)),f=c.redMul(d);return this.curve.point(n,i,f)},l.prototype.dbl=function(){return this.isInfinity()?this:this.curve.extended?this._extDbl():this._projDbl()},l.prototype._extAdd=function(n){var i=this.y.redSub(this.x).redMul(n.y.redSub(n.x)),f=this.y.redAdd(this.x).redMul(n.y.redAdd(n.x)),c=this.t.redMul(this.curve.dd).redMul(n.t),u=this.z.redMul(n.z.redAdd(n.z)),d=f.redSub(i),h=u.redSub(c),w=u.redAdd(c),_=f.redAdd(i),A=d.redMul(h),N=w.redMul(_),L=d.redMul(_),I=h.redMul(w);return this.curve.point(A,N,I,L)},l.prototype._projAdd=function(n){var i,f,c=this.z.redMul(n.z),u=c.redSqr(),d=this.x.redMul(n.x),h=this.y.redMul(n.y),w=this.curve.d.redMul(d).redMul(h),_=u.redSub(w),A=u.redAdd(w),N=this.x.redAdd(this.y).redMul(n.x.redAdd(n.y)).redISub(d).redISub(h),L=c.redMul(_).redMul(N);return this.curve.twisted?(i=c.redMul(A).redMul(h.redSub(this.curve._mulA(d))),f=_.redMul(A)):(i=c.redMul(A).redMul(h.redSub(d)),f=this.curve._mulC(_).redMul(A)),this.curve.point(L,i,f)},l.prototype.add=function(n){return this.isInfinity()?n:n.isInfinity()?this:this.curve.extended?this._extAdd(n):this._projAdd(n)},l.prototype.mul=function(n){return this._hasDoubles(n)?this.curve._fixedNafMul(this,n):this.curve._wnafMul(this,n)},l.prototype.mulAdd=function(n,i,f){return this.curve._wnafMulAdd(1,[this,i],[n,f],2,!1)},l.prototype.jmulAdd=function(n,i,f){return this.curve._wnafMulAdd(1,[this,i],[n,f],2,!0)},l.prototype.normalize=function(){if(this.zOne)return this;var n=this.z.redInvm();return this.x=this.x.redMul(n),this.y=this.y.redMul(n),this.t&&(this.t=this.t.redMul(n)),this.z=this.curve.one,this.zOne=!0,this},l.prototype.neg=function(){return this.curve.point(this.x.redNeg(),this.y,this.z,this.t&&this.t.redNeg())},l.prototype.getX=function(){return this.normalize(),this.x.fromRed()},l.prototype.getY=function(){return this.normalize(),this.y.fromRed()},l.prototype.eq=function(n){return this===n||this.getX().cmp(n.getX())===0&&this.getY().cmp(n.getY())===0},l.prototype.eqXToP=function(n){var i=n.toRed(this.curve.red).redMul(this.z);if(this.x.cmp(i)===0)return!0;for(var f=n.clone(),c=this.curve.redN.redMul(this.z);;){if(f.iadd(this.curve.n),f.cmp(this.curve.p)>=0)return!1;if(i.redIAdd(c),this.x.cmp(i)===0)return!0}},l.prototype.toP=l.prototype.normalize,l.prototype.mixedAdd=l.prototype.add},{"../utils":419,"./base":406,"bn.js":420,inherits:440}],408:[function(s,T,S){var m=S;m.base=s("./base"),m.short=s("./short"),m.mont=s("./mont"),m.edwards=s("./edwards")},{"./base":406,"./edwards":407,"./mont":409,"./short":410}],409:[function(s,T,S){var m=s("bn.js"),a=s("inherits"),o=s("./base"),r=s("../utils");function t(l){o.call(this,"mont",l),this.a=new m(l.a,16).toRed(this.red),this.b=new m(l.b,16).toRed(this.red),this.i4=new m(4).toRed(this.red).redInvm(),this.two=new m(2).toRed(this.red),this.a24=this.i4.redMul(this.a.redAdd(this.two))}function e(l,n,i){o.BasePoint.call(this,l,"projective"),n===null&&i===null?(this.x=this.curve.one,this.z=this.curve.zero):(this.x=new m(n,16),this.z=new m(i,16),this.x.red||(this.x=this.x.toRed(this.curve.red)),this.z.red||(this.z=this.z.toRed(this.curve.red)))}a(t,o),T.exports=t,t.prototype.validate=function(l){var n=l.normalize().x,i=n.redSqr(),f=i.redMul(n).redAdd(i.redMul(this.a)).redAdd(n);return f.redSqrt().redSqr().cmp(f)===0},a(e,o.BasePoint),t.prototype.decodePoint=function(l,n){return this.point(r.toArray(l,n),1)},t.prototype.point=function(l,n){return new e(this,l,n)},t.prototype.pointFromJSON=function(l){return e.fromJSON(this,l)},e.prototype.precompute=function(){},e.prototype._encode=function(){return this.getX().toArray("be",this.curve.p.byteLength())},e.fromJSON=function(l,n){return new e(l,n[0],n[1]||l.one)},e.prototype.inspect=function(){return this.isInfinity()?"<EC Point Infinity>":"<EC Point x: "+this.x.fromRed().toString(16,2)+" z: "+this.z.fromRed().toString(16,2)+">"},e.prototype.isInfinity=function(){return this.z.cmpn(0)===0},e.prototype.dbl=function(){var l=this.x.redAdd(this.z).redSqr(),n=this.x.redSub(this.z).redSqr(),i=l.redSub(n),f=l.redMul(n),c=i.redMul(n.redAdd(this.curve.a24.redMul(i)));return this.curve.point(f,c)},e.prototype.add=function(){throw new Error("Not supported on Montgomery curve")},e.prototype.diffAdd=function(l,n){var i=this.x.redAdd(this.z),f=this.x.redSub(this.z),c=l.x.redAdd(l.z),u=l.x.redSub(l.z).redMul(i),d=c.redMul(f),h=n.z.redMul(u.redAdd(d).redSqr()),w=n.x.redMul(u.redISub(d).redSqr());return this.curve.point(h,w)},e.prototype.mul=function(l){for(var n=l.clone(),i=this,f=this.curve.point(null,null),c=[];n.cmpn(0)!==0;n.iushrn(1))c.push(n.andln(1));for(var u=c.length-1;u>=0;u--)c[u]===0?(i=i.diffAdd(f,this),f=f.dbl()):(f=i.diffAdd(f,this),i=i.dbl());return f},e.prototype.mulAdd=function(){throw new Error("Not supported on Montgomery curve")},e.prototype.jumlAdd=function(){throw new Error("Not supported on Montgomery curve")},e.prototype.eq=function(l){return this.getX().cmp(l.getX())===0},e.prototype.normalize=function(){return this.x=this.x.redMul(this.z.redInvm()),this.z=this.curve.one,this},e.prototype.getX=function(){return this.normalize(),this.x.fromRed()}},{"../utils":419,"./base":406,"bn.js":420,inherits:440}],410:[function(s,T,S){var m=s("../utils"),a=s("bn.js"),o=s("inherits"),r=s("./base"),t=m.assert;function e(i){r.call(this,"short",i),this.a=new a(i.a,16).toRed(this.red),this.b=new a(i.b,16).toRed(this.red),this.tinv=this.two.redInvm(),this.zeroA=this.a.fromRed().cmpn(0)===0,this.threeA=this.a.fromRed().sub(this.p).cmpn(-3)===0,this.endo=this._getEndomorphism(i),this._endoWnafT1=new Array(4),this._endoWnafT2=new Array(4)}function l(i,f,c,u){r.BasePoint.call(this,i,"affine"),f===null&&c===null?(this.x=null,this.y=null,this.inf=!0):(this.x=new a(f,16),this.y=new a(c,16),u&&(this.x.forceRed(this.curve.red),this.y.forceRed(this.curve.red)),this.x.red||(this.x=this.x.toRed(this.curve.red)),this.y.red||(this.y=this.y.toRed(this.curve.red)),this.inf=!1)}function n(i,f,c,u){r.BasePoint.call(this,i,"jacobian"),f===null&&c===null&&u===null?(this.x=this.curve.one,this.y=this.curve.one,this.z=new a(0)):(this.x=new a(f,16),this.y=new a(c,16),this.z=new a(u,16)),this.x.red||(this.x=this.x.toRed(this.curve.red)),this.y.red||(this.y=this.y.toRed(this.curve.red)),this.z.red||(this.z=this.z.toRed(this.curve.red)),this.zOne=this.z===this.curve.one}o(e,r),T.exports=e,e.prototype._getEndomorphism=function(i){if(this.zeroA&&this.g&&this.n&&this.p.modn(3)===1){var f,c;if(i.beta)f=new a(i.beta,16).toRed(this.red);else{var u=this._getEndoRoots(this.p);f=(f=u[0].cmp(u[1])<0?u[0]:u[1]).toRed(this.red)}if(i.lambda)c=new a(i.lambda,16);else{var d=this._getEndoRoots(this.n);this.g.mul(d[0]).x.cmp(this.g.x.redMul(f))===0?c=d[0]:(c=d[1],t(this.g.mul(c).x.cmp(this.g.x.redMul(f))===0))}return{beta:f,lambda:c,basis:i.basis?i.basis.map(function(h){return{a:new a(h.a,16),b:new a(h.b,16)}}):this._getEndoBasis(c)}}},e.prototype._getEndoRoots=function(i){var f=i===this.p?this.red:a.mont(i),c=new a(2).toRed(f).redInvm(),u=c.redNeg(),d=new a(3).toRed(f).redNeg().redSqrt().redMul(c);return[u.redAdd(d).fromRed(),u.redSub(d).fromRed()]},e.prototype._getEndoBasis=function(i){for(var f,c,u,d,h,w,_,A,N,L=this.n.ushrn(Math.floor(this.n.bitLength()/2)),I=i,P=this.n.clone(),B=new a(1),U=new a(0),D=new a(0),x=new a(1),M=0;I.cmpn(0)!==0;){var v=P.div(I);A=P.sub(v.mul(I)),N=D.sub(v.mul(B));var p=x.sub(v.mul(U));if(!u&&A.cmp(L)<0)f=_.neg(),c=B,u=A.neg(),d=N;else if(u&&++M==2)break;_=A,P=I,I=A,D=B,B=N,x=U,U=p}h=A.neg(),w=N;var b=u.sqr().add(d.sqr());return h.sqr().add(w.sqr()).cmp(b)>=0&&(h=f,w=c),u.negative&&(u=u.neg(),d=d.neg()),h.negative&&(h=h.neg(),w=w.neg()),[{a:u,b:d},{a:h,b:w}]},e.prototype._endoSplit=function(i){var f=this.endo.basis,c=f[0],u=f[1],d=u.b.mul(i).divRound(this.n),h=c.b.neg().mul(i).divRound(this.n),w=d.mul(c.a),_=h.mul(u.a),A=d.mul(c.b),N=h.mul(u.b);return{k1:i.sub(w).sub(_),k2:A.add(N).neg()}},e.prototype.pointFromX=function(i,f){(i=new a(i,16)).red||(i=i.toRed(this.red));var c=i.redSqr().redMul(i).redIAdd(i.redMul(this.a)).redIAdd(this.b),u=c.redSqrt();if(u.redSqr().redSub(c).cmp(this.zero)!==0)throw new Error("invalid point");var d=u.fromRed().isOdd();return(f&&!d||!f&&d)&&(u=u.redNeg()),this.point(i,u)},e.prototype.validate=function(i){if(i.inf)return!0;var f=i.x,c=i.y,u=this.a.redMul(f),d=f.redSqr().redMul(f).redIAdd(u).redIAdd(this.b);return c.redSqr().redISub(d).cmpn(0)===0},e.prototype._endoWnafMulAdd=function(i,f,c){for(var u=this._endoWnafT1,d=this._endoWnafT2,h=0;h<i.length;h++){var w=this._endoSplit(f[h]),_=i[h],A=_._getBeta();w.k1.negative&&(w.k1.ineg(),_=_.neg(!0)),w.k2.negative&&(w.k2.ineg(),A=A.neg(!0)),u[2*h]=_,u[2*h+1]=A,d[2*h]=w.k1,d[2*h+1]=w.k2}for(var N=this._wnafMulAdd(1,u,d,2*h,c),L=0;L<2*h;L++)u[L]=null,d[L]=null;return N},o(l,r.BasePoint),e.prototype.point=function(i,f,c){return new l(this,i,f,c)},e.prototype.pointFromJSON=function(i,f){return l.fromJSON(this,i,f)},l.prototype._getBeta=function(){if(this.curve.endo){var i=this.precomputed;if(i&&i.beta)return i.beta;var f=this.curve.point(this.x.redMul(this.curve.endo.beta),this.y);if(i){var c=this.curve,u=function(d){return c.point(d.x.redMul(c.endo.beta),d.y)};i.beta=f,f.precomputed={beta:null,naf:i.naf&&{wnd:i.naf.wnd,points:i.naf.points.map(u)},doubles:i.doubles&&{step:i.doubles.step,points:i.doubles.points.map(u)}}}return f}},l.prototype.toJSON=function(){return this.precomputed?[this.x,this.y,this.precomputed&&{doubles:this.precomputed.doubles&&{step:this.precomputed.doubles.step,points:this.precomputed.doubles.points.slice(1)},naf:this.precomputed.naf&&{wnd:this.precomputed.naf.wnd,points:this.precomputed.naf.points.slice(1)}}]:[this.x,this.y]},l.fromJSON=function(i,f,c){typeof f=="string"&&(f=JSON.parse(f));var u=i.point(f[0],f[1],c);if(!f[2])return u;function d(w){return i.point(w[0],w[1],c)}var h=f[2];return u.precomputed={beta:null,doubles:h.doubles&&{step:h.doubles.step,points:[u].concat(h.doubles.points.map(d))},naf:h.naf&&{wnd:h.naf.wnd,points:[u].concat(h.naf.points.map(d))}},u},l.prototype.inspect=function(){return this.isInfinity()?"<EC Point Infinity>":"<EC Point x: "+this.x.fromRed().toString(16,2)+" y: "+this.y.fromRed().toString(16,2)+">"},l.prototype.isInfinity=function(){return this.inf},l.prototype.add=function(i){if(this.inf)return i;if(i.inf)return this;if(this.eq(i))return this.dbl();if(this.neg().eq(i))return this.curve.point(null,null);if(this.x.cmp(i.x)===0)return this.curve.point(null,null);var f=this.y.redSub(i.y);f.cmpn(0)!==0&&(f=f.redMul(this.x.redSub(i.x).redInvm()));var c=f.redSqr().redISub(this.x).redISub(i.x),u=f.redMul(this.x.redSub(c)).redISub(this.y);return this.curve.point(c,u)},l.prototype.dbl=function(){if(this.inf)return this;var i=this.y.redAdd(this.y);if(i.cmpn(0)===0)return this.curve.point(null,null);var f=this.curve.a,c=this.x.redSqr(),u=i.redInvm(),d=c.redAdd(c).redIAdd(c).redIAdd(f).redMul(u),h=d.redSqr().redISub(this.x.redAdd(this.x)),w=d.redMul(this.x.redSub(h)).redISub(this.y);return this.curve.point(h,w)},l.prototype.getX=function(){return this.x.fromRed()},l.prototype.getY=function(){return this.y.fromRed()},l.prototype.mul=function(i){return i=new a(i,16),this.isInfinity()?this:this._hasDoubles(i)?this.curve._fixedNafMul(this,i):this.curve.endo?this.curve._endoWnafMulAdd([this],[i]):this.curve._wnafMul(this,i)},l.prototype.mulAdd=function(i,f,c){var u=[this,f],d=[i,c];return this.curve.endo?this.curve._endoWnafMulAdd(u,d):this.curve._wnafMulAdd(1,u,d,2)},l.prototype.jmulAdd=function(i,f,c){var u=[this,f],d=[i,c];return this.curve.endo?this.curve._endoWnafMulAdd(u,d,!0):this.curve._wnafMulAdd(1,u,d,2,!0)},l.prototype.eq=function(i){return this===i||this.inf===i.inf&&(this.inf||this.x.cmp(i.x)===0&&this.y.cmp(i.y)===0)},l.prototype.neg=function(i){if(this.inf)return this;var f=this.curve.point(this.x,this.y.redNeg());if(i&&this.precomputed){var c=this.precomputed,u=function(d){return d.neg()};f.precomputed={naf:c.naf&&{wnd:c.naf.wnd,points:c.naf.points.map(u)},doubles:c.doubles&&{step:c.doubles.step,points:c.doubles.points.map(u)}}}return f},l.prototype.toJ=function(){return this.inf?this.curve.jpoint(null,null,null):this.curve.jpoint(this.x,this.y,this.curve.one)},o(n,r.BasePoint),e.prototype.jpoint=function(i,f,c){return new n(this,i,f,c)},n.prototype.toP=function(){if(this.isInfinity())return this.curve.point(null,null);var i=this.z.redInvm(),f=i.redSqr(),c=this.x.redMul(f),u=this.y.redMul(f).redMul(i);return this.curve.point(c,u)},n.prototype.neg=function(){return this.curve.jpoint(this.x,this.y.redNeg(),this.z)},n.prototype.add=function(i){if(this.isInfinity())return i;if(i.isInfinity())return this;var f=i.z.redSqr(),c=this.z.redSqr(),u=this.x.redMul(f),d=i.x.redMul(c),h=this.y.redMul(f.redMul(i.z)),w=i.y.redMul(c.redMul(this.z)),_=u.redSub(d),A=h.redSub(w);if(_.cmpn(0)===0)return A.cmpn(0)!==0?this.curve.jpoint(null,null,null):this.dbl();var N=_.redSqr(),L=N.redMul(_),I=u.redMul(N),P=A.redSqr().redIAdd(L).redISub(I).redISub(I),B=A.redMul(I.redISub(P)).redISub(h.redMul(L)),U=this.z.redMul(i.z).redMul(_);return this.curve.jpoint(P,B,U)},n.prototype.mixedAdd=function(i){if(this.isInfinity())return i.toJ();if(i.isInfinity())return this;var f=this.z.redSqr(),c=this.x,u=i.x.redMul(f),d=this.y,h=i.y.redMul(f).redMul(this.z),w=c.redSub(u),_=d.redSub(h);if(w.cmpn(0)===0)return _.cmpn(0)!==0?this.curve.jpoint(null,null,null):this.dbl();var A=w.redSqr(),N=A.redMul(w),L=c.redMul(A),I=_.redSqr().redIAdd(N).redISub(L).redISub(L),P=_.redMul(L.redISub(I)).redISub(d.redMul(N)),B=this.z.redMul(w);return this.curve.jpoint(I,P,B)},n.prototype.dblp=function(i){if(i===0)return this;if(this.isInfinity())return this;if(!i)return this.dbl();var f;if(this.curve.zeroA||this.curve.threeA){var c=this;for(f=0;f<i;f++)c=c.dbl();return c}var u=this.curve.a,d=this.curve.tinv,h=this.x,w=this.y,_=this.z,A=_.redSqr().redSqr(),N=w.redAdd(w);for(f=0;f<i;f++){var L=h.redSqr(),I=N.redSqr(),P=I.redSqr(),B=L.redAdd(L).redIAdd(L).redIAdd(u.redMul(A)),U=h.redMul(I),D=B.redSqr().redISub(U.redAdd(U)),x=U.redISub(D),M=B.redMul(x);M=M.redIAdd(M).redISub(P);var v=N.redMul(_);f+1<i&&(A=A.redMul(P)),h=D,_=v,N=M}return this.curve.jpoint(h,N.redMul(d),_)},n.prototype.dbl=function(){return this.isInfinity()?this:this.curve.zeroA?this._zeroDbl():this.curve.threeA?this._threeDbl():this._dbl()},n.prototype._zeroDbl=function(){var i,f,c;if(this.zOne){var u=this.x.redSqr(),d=this.y.redSqr(),h=d.redSqr(),w=this.x.redAdd(d).redSqr().redISub(u).redISub(h);w=w.redIAdd(w);var _=u.redAdd(u).redIAdd(u),A=_.redSqr().redISub(w).redISub(w),N=h.redIAdd(h);N=(N=N.redIAdd(N)).redIAdd(N),i=A,f=_.redMul(w.redISub(A)).redISub(N),c=this.y.redAdd(this.y)}else{var L=this.x.redSqr(),I=this.y.redSqr(),P=I.redSqr(),B=this.x.redAdd(I).redSqr().redISub(L).redISub(P);B=B.redIAdd(B);var U=L.redAdd(L).redIAdd(L),D=U.redSqr(),x=P.redIAdd(P);x=(x=x.redIAdd(x)).redIAdd(x),i=D.redISub(B).redISub(B),f=U.redMul(B.redISub(i)).redISub(x),c=(c=this.y.redMul(this.z)).redIAdd(c)}return this.curve.jpoint(i,f,c)},n.prototype._threeDbl=function(){var i,f,c;if(this.zOne){var u=this.x.redSqr(),d=this.y.redSqr(),h=d.redSqr(),w=this.x.redAdd(d).redSqr().redISub(u).redISub(h);w=w.redIAdd(w);var _=u.redAdd(u).redIAdd(u).redIAdd(this.curve.a),A=_.redSqr().redISub(w).redISub(w);i=A;var N=h.redIAdd(h);N=(N=N.redIAdd(N)).redIAdd(N),f=_.redMul(w.redISub(A)).redISub(N),c=this.y.redAdd(this.y)}else{var L=this.z.redSqr(),I=this.y.redSqr(),P=this.x.redMul(I),B=this.x.redSub(L).redMul(this.x.redAdd(L));B=B.redAdd(B).redIAdd(B);var U=P.redIAdd(P),D=(U=U.redIAdd(U)).redAdd(U);i=B.redSqr().redISub(D),c=this.y.redAdd(this.z).redSqr().redISub(I).redISub(L);var x=I.redSqr();x=(x=(x=x.redIAdd(x)).redIAdd(x)).redIAdd(x),f=B.redMul(U.redISub(i)).redISub(x)}return this.curve.jpoint(i,f,c)},n.prototype._dbl=function(){var i=this.curve.a,f=this.x,c=this.y,u=this.z,d=u.redSqr().redSqr(),h=f.redSqr(),w=c.redSqr(),_=h.redAdd(h).redIAdd(h).redIAdd(i.redMul(d)),A=f.redAdd(f),N=(A=A.redIAdd(A)).redMul(w),L=_.redSqr().redISub(N.redAdd(N)),I=N.redISub(L),P=w.redSqr();P=(P=(P=P.redIAdd(P)).redIAdd(P)).redIAdd(P);var B=_.redMul(I).redISub(P),U=c.redAdd(c).redMul(u);return this.curve.jpoint(L,B,U)},n.prototype.trpl=function(){if(!this.curve.zeroA)return this.dbl().add(this);var i=this.x.redSqr(),f=this.y.redSqr(),c=this.z.redSqr(),u=f.redSqr(),d=i.redAdd(i).redIAdd(i),h=d.redSqr(),w=this.x.redAdd(f).redSqr().redISub(i).redISub(u),_=(w=(w=(w=w.redIAdd(w)).redAdd(w).redIAdd(w)).redISub(h)).redSqr(),A=u.redIAdd(u);A=(A=(A=A.redIAdd(A)).redIAdd(A)).redIAdd(A);var N=d.redIAdd(w).redSqr().redISub(h).redISub(_).redISub(A),L=f.redMul(N);L=(L=L.redIAdd(L)).redIAdd(L);var I=this.x.redMul(_).redISub(L);I=(I=I.redIAdd(I)).redIAdd(I);var P=this.y.redMul(N.redMul(A.redISub(N)).redISub(w.redMul(_)));P=(P=(P=P.redIAdd(P)).redIAdd(P)).redIAdd(P);var B=this.z.redAdd(w).redSqr().redISub(c).redISub(_);return this.curve.jpoint(I,P,B)},n.prototype.mul=function(i,f){return i=new a(i,f),this.curve._wnafMul(this,i)},n.prototype.eq=function(i){if(i.type==="affine")return this.eq(i.toJ());if(this===i)return!0;var f=this.z.redSqr(),c=i.z.redSqr();if(this.x.redMul(c).redISub(i.x.redMul(f)).cmpn(0)!==0)return!1;var u=f.redMul(this.z),d=c.redMul(i.z);return this.y.redMul(d).redISub(i.y.redMul(u)).cmpn(0)===0},n.prototype.eqXToP=function(i){var f=this.z.redSqr(),c=i.toRed(this.curve.red).redMul(f);if(this.x.cmp(c)===0)return!0;for(var u=i.clone(),d=this.curve.redN.redMul(f);;){if(u.iadd(this.curve.n),u.cmp(this.curve.p)>=0)return!1;if(c.redIAdd(d),this.x.cmp(c)===0)return!0}},n.prototype.inspect=function(){return this.isInfinity()?"<EC JPoint Infinity>":"<EC JPoint x: "+this.x.toString(16,2)+" y: "+this.y.toString(16,2)+" z: "+this.z.toString(16,2)+">"},n.prototype.isInfinity=function(){return this.z.cmpn(0)===0}},{"../utils":419,"./base":406,"bn.js":420,inherits:440}],411:[function(s,T,S){var m,a=S,o=s("hash.js"),r=s("./curve"),t=s("./utils").assert;function e(n){n.type==="short"?this.curve=new r.short(n):n.type==="edwards"?this.curve=new r.edwards(n):this.curve=new r.mont(n),this.g=this.curve.g,this.n=this.curve.n,this.hash=n.hash,t(this.g.validate(),"Invalid curve"),t(this.g.mul(this.n).isInfinity(),"Invalid curve, G*N != O")}function l(n,i){Object.defineProperty(a,n,{configurable:!0,enumerable:!0,get:function(){var f=new e(i);return Object.defineProperty(a,n,{configurable:!0,enumerable:!0,value:f}),f}})}a.PresetCurve=e,l("p192",{type:"short",prime:"p192",p:"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff",a:"ffffffff ffffffff ffffffff fffffffe ffffffff fffffffc",b:"64210519 e59c80e7 0fa7e9ab 72243049 feb8deec c146b9b1",n:"ffffffff ffffffff ffffffff 99def836 146bc9b1 b4d22831",hash:o.sha256,gRed:!1,g:["188da80e b03090f6 7cbf20eb 43a18800 f4ff0afd 82ff1012","07192b95 ffc8da78 631011ed 6b24cdd5 73f977a1 1e794811"]}),l("p224",{type:"short",prime:"p224",p:"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001",a:"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff fffffffe",b:"b4050a85 0c04b3ab f5413256 5044b0b7 d7bfd8ba 270b3943 2355ffb4",n:"ffffffff ffffffff ffffffff ffff16a2 e0b8f03e 13dd2945 5c5c2a3d",hash:o.sha256,gRed:!1,g:["b70e0cbd 6bb4bf7f 321390b9 4a03c1d3 56c21122 343280d6 115c1d21","bd376388 b5f723fb 4c22dfe6 cd4375a0 5a074764 44d58199 85007e34"]}),l("p256",{type:"short",prime:null,p:"ffffffff 00000001 00000000 00000000 00000000 ffffffff ffffffff ffffffff",a:"ffffffff 00000001 00000000 00000000 00000000 ffffffff ffffffff fffffffc",b:"5ac635d8 aa3a93e7 b3ebbd55 769886bc 651d06b0 cc53b0f6 3bce3c3e 27d2604b",n:"ffffffff 00000000 ffffffff ffffffff bce6faad a7179e84 f3b9cac2 fc632551",hash:o.sha256,gRed:!1,g:["6b17d1f2 e12c4247 f8bce6e5 63a440f2 77037d81 2deb33a0 f4a13945 d898c296","4fe342e2 fe1a7f9b 8ee7eb4a 7c0f9e16 2bce3357 6b315ece cbb64068 37bf51f5"]}),l("p384",{type:"short",prime:null,p:"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe ffffffff 00000000 00000000 ffffffff",a:"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe ffffffff 00000000 00000000 fffffffc",b:"b3312fa7 e23ee7e4 988e056b e3f82d19 181d9c6e fe814112 0314088f 5013875a c656398d 8a2ed19d 2a85c8ed d3ec2aef",n:"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff c7634d81 f4372ddf 581a0db2 48b0a77a ecec196a ccc52973",hash:o.sha384,gRed:!1,g:["aa87ca22 be8b0537 8eb1c71e f320ad74 6e1d3b62 8ba79b98 59f741e0 82542a38 5502f25d bf55296c 3a545e38 72760ab7","3617de4a 96262c6f 5d9e98bf 9292dc29 f8f41dbd 289a147c e9da3113 b5f0b8c0 0a60b1ce 1d7e819d 7a431d7c 90ea0e5f"]}),l("p521",{type:"short",prime:null,p:"000001ff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff",a:"000001ff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffc",b:"00000051 953eb961 8e1c9a1f 929a21a0 b68540ee a2da725b 99b315f3 b8b48991 8ef109e1 56193951 ec7e937b 1652c0bd 3bb1bf07 3573df88 3d2c34f1 ef451fd4 6b503f00",n:"000001ff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffa 51868783 bf2f966b 7fcc0148 f709a5d0 3bb5c9b8 899c47ae bb6fb71e 91386409",hash:o.sha512,gRed:!1,g:["000000c6 858e06b7 0404e9cd 9e3ecb66 2395b442 9c648139 053fb521 f828af60 6b4d3dba a14b5e77 efe75928 fe1dc127 a2ffa8de 3348b3c1 856a429b f97e7e31 c2e5bd66","00000118 39296a78 9a3bc004 5c8a5fb4 2c7d1bd9 98f54449 579b4468 17afbd17 273e662c 97ee7299 5ef42640 c550b901 3fad0761 353c7086 a272c240 88be9476 9fd16650"]}),l("curve25519",{type:"mont",prime:"p25519",p:"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed",a:"76d06",b:"1",n:"1000000000000000 0000000000000000 14def9dea2f79cd6 5812631a5cf5d3ed",hash:o.sha256,gRed:!1,g:["9"]}),l("ed25519",{type:"edwards",prime:"p25519",p:"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed",a:"-1",c:"1",d:"52036cee2b6ffe73 8cc740797779e898 00700a4d4141d8ab 75eb4dca135978a3",n:"1000000000000000 0000000000000000 14def9dea2f79cd6 5812631a5cf5d3ed",hash:o.sha256,gRed:!1,g:["216936d3cd6e53fec0a4e231fdd6dc5c692cc7609525a7b2c9562d608f25d51a","6666666666666666666666666666666666666666666666666666666666666658"]});try{m=s("./precomputed/secp256k1")}catch{m=void 0}l("secp256k1",{type:"short",prime:"k256",p:"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f",a:"0",b:"7",n:"ffffffff ffffffff ffffffff fffffffe baaedce6 af48a03b bfd25e8c d0364141",h:"1",hash:o.sha256,beta:"7ae96a2b657c07106e64479eac3434e99cf0497512f58995c1396c28719501ee",lambda:"5363ad4cc05c30e0a5261c028812645a122e22ea20816678df02967c1b23bd72",basis:[{a:"3086d221a7d46bcde86c90e49284eb15",b:"-e4437ed6010e88286f547fa90abfe4c3"},{a:"114ca50f7a8e2f3f657c1108d9d44cfd8",b:"3086d221a7d46bcde86c90e49284eb15"}],gRed:!1,g:["79be667ef9dcbbac55a06295ce870b07029bfcdb2dce28d959f2815b16f81798","483ada7726a3c4655da4fbfc0e1108a8fd17b448a68554199c47d08ffb10d4b8",m]})},{"./curve":408,"./precomputed/secp256k1":418,"./utils":419,"hash.js":426}],412:[function(s,T,S){var m=s("bn.js"),a=s("hmac-drbg"),o=s("../utils"),r=s("../curves"),t=s("brorand"),e=o.assert,l=s("./key"),n=s("./signature");function i(f){if(!(this instanceof i))return new i(f);typeof f=="string"&&(e(Object.prototype.hasOwnProperty.call(r,f),"Unknown curve "+f),f=r[f]),f instanceof r.PresetCurve&&(f={curve:f}),this.curve=f.curve.curve,this.n=this.curve.n,this.nh=this.n.ushrn(1),this.g=this.curve.g,this.g=f.curve.g,this.g.precompute(f.curve.n.bitLength()+1),this.hash=f.hash||f.curve.hash}T.exports=i,i.prototype.keyPair=function(f){return new l(this,f)},i.prototype.keyFromPrivate=function(f,c){return l.fromPrivate(this,f,c)},i.prototype.keyFromPublic=function(f,c){return l.fromPublic(this,f,c)},i.prototype.genKeyPair=function(f){f||(f={});for(var c=new a({hash:this.hash,pers:f.pers,persEnc:f.persEnc||"utf8",entropy:f.entropy||t(this.hash.hmacStrength),entropyEnc:f.entropy&&f.entropyEnc||"utf8",nonce:this.n.toArray()}),u=this.n.byteLength(),d=this.n.sub(new m(2));;){var h=new m(c.generate(u));if(!(h.cmp(d)>0))return h.iaddn(1),this.keyFromPrivate(h)}},i.prototype._truncateToN=function(f,c){var u=8*f.byteLength()-this.n.bitLength();return u>0&&(f=f.ushrn(u)),!c&&f.cmp(this.n)>=0?f.sub(this.n):f},i.prototype.sign=function(f,c,u,d){typeof u=="object"&&(d=u,u=null),d||(d={}),c=this.keyFromPrivate(c,u),f=this._truncateToN(new m(f,16));for(var h=this.n.byteLength(),w=c.getPrivate().toArray("be",h),_=f.toArray("be",h),A=new a({hash:this.hash,entropy:w,nonce:_,pers:d.pers,persEnc:d.persEnc||"utf8"}),N=this.n.sub(new m(1)),L=0;;L++){var I=d.k?d.k(L):new m(A.generate(this.n.byteLength()));if(!((I=this._truncateToN(I,!0)).cmpn(1)<=0||I.cmp(N)>=0)){var P=this.g.mul(I);if(!P.isInfinity()){var B=P.getX(),U=B.umod(this.n);if(U.cmpn(0)!==0){var D=I.invm(this.n).mul(U.mul(c.getPrivate()).iadd(f));if((D=D.umod(this.n)).cmpn(0)!==0){var x=(P.getY().isOdd()?1:0)|(B.cmp(U)!==0?2:0);return d.canonical&&D.cmp(this.nh)>0&&(D=this.n.sub(D),x^=1),new n({r:U,s:D,recoveryParam:x})}}}}}},i.prototype.verify=function(f,c,u,d){f=this._truncateToN(new m(f,16)),u=this.keyFromPublic(u,d);var h=(c=new n(c,"hex")).r,w=c.s;if(h.cmpn(1)<0||h.cmp(this.n)>=0||w.cmpn(1)<0||w.cmp(this.n)>=0)return!1;var _,A=w.invm(this.n),N=A.mul(f).umod(this.n),L=A.mul(h).umod(this.n);return this.curve._maxwellTrick?!(_=this.g.jmulAdd(N,u.getPublic(),L)).isInfinity()&&_.eqXToP(h):!(_=this.g.mulAdd(N,u.getPublic(),L)).isInfinity()&&_.getX().umod(this.n).cmp(h)===0},i.prototype.recoverPubKey=function(f,c,u,d){e((3&u)===u,"The recovery param is more than two bits"),c=new n(c,d);var h=this.n,w=new m(f),_=c.r,A=c.s,N=1&u,L=u>>1;if(_.cmp(this.curve.p.umod(this.curve.n))>=0&&L)throw new Error("Unable to find sencond key candinate");_=L?this.curve.pointFromX(_.add(this.curve.n),N):this.curve.pointFromX(_,N);var I=c.r.invm(h),P=h.sub(w).mul(I).umod(h),B=A.mul(I).umod(h);return this.g.mulAdd(P,_,B)},i.prototype.getKeyRecoveryParam=function(f,c,u,d){if((c=new n(c,d)).recoveryParam!==null)return c.recoveryParam;for(var h=0;h<4;h++){var w;try{w=this.recoverPubKey(f,c,h)}catch{continue}if(w.eq(u))return h}throw new Error("Unable to find valid recovery factor")}},{"../curves":411,"../utils":419,"./key":413,"./signature":414,"bn.js":420,brorand:187,"hmac-drbg":438}],413:[function(s,T,S){var m=s("bn.js"),a=s("../utils").assert;function o(r,t){this.ec=r,this.priv=null,this.pub=null,t.priv&&this._importPrivate(t.priv,t.privEnc),t.pub&&this._importPublic(t.pub,t.pubEnc)}T.exports=o,o.fromPublic=function(r,t,e){return t instanceof o?t:new o(r,{pub:t,pubEnc:e})},o.fromPrivate=function(r,t,e){return t instanceof o?t:new o(r,{priv:t,privEnc:e})},o.prototype.validate=function(){var r=this.getPublic();return r.isInfinity()?{result:!1,reason:"Invalid public key"}:r.validate()?r.mul(this.ec.curve.n).isInfinity()?{result:!0,reason:null}:{result:!1,reason:"Public key * N != O"}:{result:!1,reason:"Public key is not a point"}},o.prototype.getPublic=function(r,t){return typeof r=="string"&&(t=r,r=null),this.pub||(this.pub=this.ec.g.mul(this.priv)),t?this.pub.encode(t,r):this.pub},o.prototype.getPrivate=function(r){return r==="hex"?this.priv.toString(16,2):this.priv},o.prototype._importPrivate=function(r,t){this.priv=new m(r,t||16),this.priv=this.priv.umod(this.ec.curve.n)},o.prototype._importPublic=function(r,t){if(r.x||r.y)return this.ec.curve.type==="mont"?a(r.x,"Need x coordinate"):this.ec.curve.type!=="short"&&this.ec.curve.type!=="edwards"||a(r.x&&r.y,"Need both x and y coordinate"),void(this.pub=this.ec.curve.point(r.x,r.y));this.pub=this.ec.curve.decodePoint(r,t)},o.prototype.derive=function(r){return r.validate()||a(r.validate(),"public point not validated"),r.mul(this.priv).getX()},o.prototype.sign=function(r,t,e){return this.ec.sign(r,this,t,e)},o.prototype.verify=function(r,t){return this.ec.verify(r,t,this)},o.prototype.inspect=function(){return"<Key priv: "+(this.priv&&this.priv.toString(16,2))+" pub: "+(this.pub&&this.pub.inspect())+" >"}},{"../utils":419,"bn.js":420}],414:[function(s,T,S){var m=s("bn.js"),a=s("../utils"),o=a.assert;function r(i,f){if(i instanceof r)return i;this._importDER(i,f)||(o(i.r&&i.s,"Signature without r or s"),this.r=new m(i.r,16),this.s=new m(i.s,16),i.recoveryParam===void 0?this.recoveryParam=null:this.recoveryParam=i.recoveryParam)}function t(){this.place=0}function e(i,f){var c=i[f.place++];if(!(128&c))return c;var u=15&c;if(u===0||u>4)return!1;for(var d=0,h=0,w=f.place;h<u;h++,w++)d<<=8,d|=i[w],d>>>=0;return!(d<=127)&&(f.place=w,d)}function l(i){for(var f=0,c=i.length-1;!i[f]&&!(128&i[f+1])&&f<c;)f++;return f===0?i:i.slice(f)}function n(i,f){if(f<128)i.push(f);else{var c=1+(Math.log(f)/Math.LN2>>>3);for(i.push(128|c);--c;)i.push(f>>>(c<<3)&255);i.push(f)}}T.exports=r,r.prototype._importDER=function(i,f){i=a.toArray(i,f);var c=new t;if(i[c.place++]!==48)return!1;var u=e(i,c);if(u===!1||u+c.place!==i.length||i[c.place++]!==2)return!1;var d=e(i,c);if(d===!1)return!1;var h=i.slice(c.place,d+c.place);if(c.place+=d,i[c.place++]!==2)return!1;var w=e(i,c);if(w===!1||i.length!==w+c.place)return!1;var _=i.slice(c.place,w+c.place);if(h[0]===0){if(!(128&h[1]))return!1;h=h.slice(1)}if(_[0]===0){if(!(128&_[1]))return!1;_=_.slice(1)}return this.r=new m(h),this.s=new m(_),this.recoveryParam=null,!0},r.prototype.toDER=function(i){var f=this.r.toArray(),c=this.s.toArray();for(128&f[0]&&(f=[0].concat(f)),128&c[0]&&(c=[0].concat(c)),f=l(f),c=l(c);!(c[0]||128&c[1]);)c=c.slice(1);var u=[2];n(u,f.length),(u=u.concat(f)).push(2),n(u,c.length);var d=u.concat(c),h=[48];return n(h,d.length),h=h.concat(d),a.encode(h,i)}},{"../utils":419,"bn.js":420}],415:[function(s,T,S){var m=s("hash.js"),a=s("../curves"),o=s("../utils"),r=o.assert,t=o.parseBytes,e=s("./key"),l=s("./signature");function n(i){if(r(i==="ed25519","only tested with ed25519 so far"),!(this instanceof n))return new n(i);i=a[i].curve,this.curve=i,this.g=i.g,this.g.precompute(i.n.bitLength()+1),this.pointClass=i.point().constructor,this.encodingLength=Math.ceil(i.n.bitLength()/8),this.hash=m.sha512}T.exports=n,n.prototype.sign=function(i,f){i=t(i);var c=this.keyFromSecret(f),u=this.hashInt(c.messagePrefix(),i),d=this.g.mul(u),h=this.encodePoint(d),w=this.hashInt(h,c.pubBytes(),i).mul(c.priv()),_=u.add(w).umod(this.curve.n);return this.makeSignature({R:d,S:_,Rencoded:h})},n.prototype.verify=function(i,f,c){i=t(i),f=this.makeSignature(f);var u=this.keyFromPublic(c),d=this.hashInt(f.Rencoded(),u.pubBytes(),i),h=this.g.mul(f.S());return f.R().add(u.pub().mul(d)).eq(h)},n.prototype.hashInt=function(){for(var i=this.hash(),f=0;f<arguments.length;f++)i.update(arguments[f]);return o.intFromLE(i.digest()).umod(this.curve.n)},n.prototype.keyFromPublic=function(i){return e.fromPublic(this,i)},n.prototype.keyFromSecret=function(i){return e.fromSecret(this,i)},n.prototype.makeSignature=function(i){return i instanceof l?i:new l(this,i)},n.prototype.encodePoint=function(i){var f=i.getY().toArray("le",this.encodingLength);return f[this.encodingLength-1]|=i.getX().isOdd()?128:0,f},n.prototype.decodePoint=function(i){var f=(i=o.parseBytes(i)).length-1,c=i.slice(0,f).concat(-129&i[f]),u=(128&i[f])!=0,d=o.intFromLE(c);return this.curve.pointFromY(d,u)},n.prototype.encodeInt=function(i){return i.toArray("le",this.encodingLength)},n.prototype.decodeInt=function(i){return o.intFromLE(i)},n.prototype.isPoint=function(i){return i instanceof this.pointClass}},{"../curves":411,"../utils":419,"./key":416,"./signature":417,"hash.js":426}],416:[function(s,T,S){var m=s("../utils"),a=m.assert,o=m.parseBytes,r=m.cachedProperty;function t(e,l){this.eddsa=e,this._secret=o(l.secret),e.isPoint(l.pub)?this._pub=l.pub:this._pubBytes=o(l.pub)}t.fromPublic=function(e,l){return l instanceof t?l:new t(e,{pub:l})},t.fromSecret=function(e,l){return l instanceof t?l:new t(e,{secret:l})},t.prototype.secret=function(){return this._secret},r(t,"pubBytes",function(){return this.eddsa.encodePoint(this.pub())}),r(t,"pub",function(){return this._pubBytes?this.eddsa.decodePoint(this._pubBytes):this.eddsa.g.mul(this.priv())}),r(t,"privBytes",function(){var e=this.eddsa,l=this.hash(),n=e.encodingLength-1,i=l.slice(0,e.encodingLength);return i[0]&=248,i[n]&=127,i[n]|=64,i}),r(t,"priv",function(){return this.eddsa.decodeInt(this.privBytes())}),r(t,"hash",function(){return this.eddsa.hash().update(this.secret()).digest()}),r(t,"messagePrefix",function(){return this.hash().slice(this.eddsa.encodingLength)}),t.prototype.sign=function(e){return a(this._secret,"KeyPair can only verify"),this.eddsa.sign(e,this)},t.prototype.verify=function(e,l){return this.eddsa.verify(e,l,this)},t.prototype.getSecret=function(e){return a(this._secret,"KeyPair is public only"),m.encode(this.secret(),e)},t.prototype.getPublic=function(e){return m.encode(this.pubBytes(),e)},T.exports=t},{"../utils":419}],417:[function(s,T,S){var m=s("bn.js"),a=s("../utils"),o=a.assert,r=a.cachedProperty,t=a.parseBytes;function e(l,n){this.eddsa=l,typeof n!="object"&&(n=t(n)),Array.isArray(n)&&(n={R:n.slice(0,l.encodingLength),S:n.slice(l.encodingLength)}),o(n.R&&n.S,"Signature without R or S"),l.isPoint(n.R)&&(this._R=n.R),n.S instanceof m&&(this._S=n.S),this._Rencoded=Array.isArray(n.R)?n.R:n.Rencoded,this._Sencoded=Array.isArray(n.S)?n.S:n.Sencoded}r(e,"S",function(){return this.eddsa.decodeInt(this.Sencoded())}),r(e,"R",function(){return this.eddsa.decodePoint(this.Rencoded())}),r(e,"Rencoded",function(){return this.eddsa.encodePoint(this.R())}),r(e,"Sencoded",function(){return this.eddsa.encodeInt(this.S())}),e.prototype.toBytes=function(){return this.Rencoded().concat(this.Sencoded())},e.prototype.toHex=function(){return a.encode(this.toBytes(),"hex").toUpperCase()},T.exports=e},{"../utils":419,"bn.js":420}],418:[function(s,T,S){T.exports={doubles:{step:4,points:[["e60fce93b59e9ec53011aabc21c23e97b2a31369b87a5ae9c44ee89e2a6dec0a","f7e3507399e595929db99f34f57937101296891e44d23f0be1f32cce69616821"],["8282263212c609d9ea2a6e3e172de238d8c39cabd5ac1ca10646e23fd5f51508","11f8a8098557dfe45e8256e830b60ace62d613ac2f7b17bed31b6eaff6e26caf"],["175e159f728b865a72f99cc6c6fc846de0b93833fd2222ed73fce5b551e5b739","d3506e0d9e3c79eba4ef97a51ff71f5eacb5955add24345c6efa6ffee9fed695"],["363d90d447b00c9c99ceac05b6262ee053441c7e55552ffe526bad8f83ff4640","4e273adfc732221953b445397f3363145b9a89008199ecb62003c7f3bee9de9"],["8b4b5f165df3c2be8c6244b5b745638843e4a781a15bcd1b69f79a55dffdf80c","4aad0a6f68d308b4b3fbd7813ab0da04f9e336546162ee56b3eff0c65fd4fd36"],["723cbaa6e5db996d6bf771c00bd548c7b700dbffa6c0e77bcb6115925232fcda","96e867b5595cc498a921137488824d6e2660a0653779494801dc069d9eb39f5f"],["eebfa4d493bebf98ba5feec812c2d3b50947961237a919839a533eca0e7dd7fa","5d9a8ca3970ef0f269ee7edaf178089d9ae4cdc3a711f712ddfd4fdae1de8999"],["100f44da696e71672791d0a09b7bde459f1215a29b3c03bfefd7835b39a48db0","cdd9e13192a00b772ec8f3300c090666b7ff4a18ff5195ac0fbd5cd62bc65a09"],["e1031be262c7ed1b1dc9227a4a04c017a77f8d4464f3b3852c8acde6e534fd2d","9d7061928940405e6bb6a4176597535af292dd419e1ced79a44f18f29456a00d"],["feea6cae46d55b530ac2839f143bd7ec5cf8b266a41d6af52d5e688d9094696d","e57c6b6c97dce1bab06e4e12bf3ecd5c981c8957cc41442d3155debf18090088"],["da67a91d91049cdcb367be4be6ffca3cfeed657d808583de33fa978bc1ec6cb1","9bacaa35481642bc41f463f7ec9780e5dec7adc508f740a17e9ea8e27a68be1d"],["53904faa0b334cdda6e000935ef22151ec08d0f7bb11069f57545ccc1a37b7c0","5bc087d0bc80106d88c9eccac20d3c1c13999981e14434699dcb096b022771c8"],["8e7bcd0bd35983a7719cca7764ca906779b53a043a9b8bcaeff959f43ad86047","10b7770b2a3da4b3940310420ca9514579e88e2e47fd68b3ea10047e8460372a"],["385eed34c1cdff21e6d0818689b81bde71a7f4f18397e6690a841e1599c43862","283bebc3e8ea23f56701de19e9ebf4576b304eec2086dc8cc0458fe5542e5453"],["6f9d9b803ecf191637c73a4413dfa180fddf84a5947fbc9c606ed86c3fac3a7","7c80c68e603059ba69b8e2a30e45c4d47ea4dd2f5c281002d86890603a842160"],["3322d401243c4e2582a2147c104d6ecbf774d163db0f5e5313b7e0e742d0e6bd","56e70797e9664ef5bfb019bc4ddaf9b72805f63ea2873af624f3a2e96c28b2a0"],["85672c7d2de0b7da2bd1770d89665868741b3f9af7643397721d74d28134ab83","7c481b9b5b43b2eb6374049bfa62c2e5e77f17fcc5298f44c8e3094f790313a6"],["948bf809b1988a46b06c9f1919413b10f9226c60f668832ffd959af60c82a0a","53a562856dcb6646dc6b74c5d1c3418c6d4dff08c97cd2bed4cb7f88d8c8e589"],["6260ce7f461801c34f067ce0f02873a8f1b0e44dfc69752accecd819f38fd8e8","bc2da82b6fa5b571a7f09049776a1ef7ecd292238051c198c1a84e95b2b4ae17"],["e5037de0afc1d8d43d8348414bbf4103043ec8f575bfdc432953cc8d2037fa2d","4571534baa94d3b5f9f98d09fb990bddbd5f5b03ec481f10e0e5dc841d755bda"],["e06372b0f4a207adf5ea905e8f1771b4e7e8dbd1c6a6c5b725866a0ae4fce725","7a908974bce18cfe12a27bb2ad5a488cd7484a7787104870b27034f94eee31dd"],["213c7a715cd5d45358d0bbf9dc0ce02204b10bdde2a3f58540ad6908d0559754","4b6dad0b5ae462507013ad06245ba190bb4850f5f36a7eeddff2c27534b458f2"],["4e7c272a7af4b34e8dbb9352a5419a87e2838c70adc62cddf0cc3a3b08fbd53c","17749c766c9d0b18e16fd09f6def681b530b9614bff7dd33e0b3941817dcaae6"],["fea74e3dbe778b1b10f238ad61686aa5c76e3db2be43057632427e2840fb27b6","6e0568db9b0b13297cf674deccb6af93126b596b973f7b77701d3db7f23cb96f"],["76e64113f677cf0e10a2570d599968d31544e179b760432952c02a4417bdde39","c90ddf8dee4e95cf577066d70681f0d35e2a33d2b56d2032b4b1752d1901ac01"],["c738c56b03b2abe1e8281baa743f8f9a8f7cc643df26cbee3ab150242bcbb891","893fb578951ad2537f718f2eacbfbbbb82314eef7880cfe917e735d9699a84c3"],["d895626548b65b81e264c7637c972877d1d72e5f3a925014372e9f6588f6c14b","febfaa38f2bc7eae728ec60818c340eb03428d632bb067e179363ed75d7d991f"],["b8da94032a957518eb0f6433571e8761ceffc73693e84edd49150a564f676e03","2804dfa44805a1e4d7c99cc9762808b092cc584d95ff3b511488e4e74efdf6e7"],["e80fea14441fb33a7d8adab9475d7fab2019effb5156a792f1a11778e3c0df5d","eed1de7f638e00771e89768ca3ca94472d155e80af322ea9fcb4291b6ac9ec78"],["a301697bdfcd704313ba48e51d567543f2a182031efd6915ddc07bbcc4e16070","7370f91cfb67e4f5081809fa25d40f9b1735dbf7c0a11a130c0d1a041e177ea1"],["90ad85b389d6b936463f9d0512678de208cc330b11307fffab7ac63e3fb04ed4","e507a3620a38261affdcbd9427222b839aefabe1582894d991d4d48cb6ef150"],["8f68b9d2f63b5f339239c1ad981f162ee88c5678723ea3351b7b444c9ec4c0da","662a9f2dba063986de1d90c2b6be215dbbea2cfe95510bfdf23cbf79501fff82"],["e4f3fb0176af85d65ff99ff9198c36091f48e86503681e3e6686fd5053231e11","1e63633ad0ef4f1c1661a6d0ea02b7286cc7e74ec951d1c9822c38576feb73bc"],["8c00fa9b18ebf331eb961537a45a4266c7034f2f0d4e1d0716fb6eae20eae29e","efa47267fea521a1a9dc343a3736c974c2fadafa81e36c54e7d2a4c66702414b"],["e7a26ce69dd4829f3e10cec0a9e98ed3143d084f308b92c0997fddfc60cb3e41","2a758e300fa7984b471b006a1aafbb18d0a6b2c0420e83e20e8a9421cf2cfd51"],["b6459e0ee3662ec8d23540c223bcbdc571cbcb967d79424f3cf29eb3de6b80ef","67c876d06f3e06de1dadf16e5661db3c4b3ae6d48e35b2ff30bf0b61a71ba45"],["d68a80c8280bb840793234aa118f06231d6f1fc67e73c5a5deda0f5b496943e8","db8ba9fff4b586d00c4b1f9177b0e28b5b0e7b8f7845295a294c84266b133120"],["324aed7df65c804252dc0270907a30b09612aeb973449cea4095980fc28d3d5d","648a365774b61f2ff130c0c35aec1f4f19213b0c7e332843967224af96ab7c84"],["4df9c14919cde61f6d51dfdbe5fee5dceec4143ba8d1ca888e8bd373fd054c96","35ec51092d8728050974c23a1d85d4b5d506cdc288490192ebac06cad10d5d"],["9c3919a84a474870faed8a9c1cc66021523489054d7f0308cbfc99c8ac1f98cd","ddb84f0f4a4ddd57584f044bf260e641905326f76c64c8e6be7e5e03d4fc599d"],["6057170b1dd12fdf8de05f281d8e06bb91e1493a8b91d4cc5a21382120a959e5","9a1af0b26a6a4807add9a2daf71df262465152bc3ee24c65e899be932385a2a8"],["a576df8e23a08411421439a4518da31880cef0fba7d4df12b1a6973eecb94266","40a6bf20e76640b2c92b97afe58cd82c432e10a7f514d9f3ee8be11ae1b28ec8"],["7778a78c28dec3e30a05fe9629de8c38bb30d1f5cf9a3a208f763889be58ad71","34626d9ab5a5b22ff7098e12f2ff580087b38411ff24ac563b513fc1fd9f43ac"],["928955ee637a84463729fd30e7afd2ed5f96274e5ad7e5cb09eda9c06d903ac","c25621003d3f42a827b78a13093a95eeac3d26efa8a8d83fc5180e935bcd091f"],["85d0fef3ec6db109399064f3a0e3b2855645b4a907ad354527aae75163d82751","1f03648413a38c0be29d496e582cf5663e8751e96877331582c237a24eb1f962"],["ff2b0dce97eece97c1c9b6041798b85dfdfb6d8882da20308f5404824526087e","493d13fef524ba188af4c4dc54d07936c7b7ed6fb90e2ceb2c951e01f0c29907"],["827fbbe4b1e880ea9ed2b2e6301b212b57f1ee148cd6dd28780e5e2cf856e241","c60f9c923c727b0b71bef2c67d1d12687ff7a63186903166d605b68baec293ec"],["eaa649f21f51bdbae7be4ae34ce6e5217a58fdce7f47f9aa7f3b58fa2120e2b3","be3279ed5bbbb03ac69a80f89879aa5a01a6b965f13f7e59d47a5305ba5ad93d"],["e4a42d43c5cf169d9391df6decf42ee541b6d8f0c9a137401e23632dda34d24f","4d9f92e716d1c73526fc99ccfb8ad34ce886eedfa8d8e4f13a7f7131deba9414"],["1ec80fef360cbdd954160fadab352b6b92b53576a88fea4947173b9d4300bf19","aeefe93756b5340d2f3a4958a7abbf5e0146e77f6295a07b671cdc1cc107cefd"],["146a778c04670c2f91b00af4680dfa8bce3490717d58ba889ddb5928366642be","b318e0ec3354028add669827f9d4b2870aaa971d2f7e5ed1d0b297483d83efd0"],["fa50c0f61d22e5f07e3acebb1aa07b128d0012209a28b9776d76a8793180eef9","6b84c6922397eba9b72cd2872281a68a5e683293a57a213b38cd8d7d3f4f2811"],["da1d61d0ca721a11b1a5bf6b7d88e8421a288ab5d5bba5220e53d32b5f067ec2","8157f55a7c99306c79c0766161c91e2966a73899d279b48a655fba0f1ad836f1"],["a8e282ff0c9706907215ff98e8fd416615311de0446f1e062a73b0610d064e13","7f97355b8db81c09abfb7f3c5b2515888b679a3e50dd6bd6cef7c73111f4cc0c"],["174a53b9c9a285872d39e56e6913cab15d59b1fa512508c022f382de8319497c","ccc9dc37abfc9c1657b4155f2c47f9e6646b3a1d8cb9854383da13ac079afa73"],["959396981943785c3d3e57edf5018cdbe039e730e4918b3d884fdff09475b7ba","2e7e552888c331dd8ba0386a4b9cd6849c653f64c8709385e9b8abf87524f2fd"],["d2a63a50ae401e56d645a1153b109a8fcca0a43d561fba2dbb51340c9d82b151","e82d86fb6443fcb7565aee58b2948220a70f750af484ca52d4142174dcf89405"],["64587e2335471eb890ee7896d7cfdc866bacbdbd3839317b3436f9b45617e073","d99fcdd5bf6902e2ae96dd6447c299a185b90a39133aeab358299e5e9faf6589"],["8481bde0e4e4d885b3a546d3e549de042f0aa6cea250e7fd358d6c86dd45e458","38ee7b8cba5404dd84a25bf39cecb2ca900a79c42b262e556d64b1b59779057e"],["13464a57a78102aa62b6979ae817f4637ffcfed3c4b1ce30bcd6303f6caf666b","69be159004614580ef7e433453ccb0ca48f300a81d0942e13f495a907f6ecc27"],["bc4a9df5b713fe2e9aef430bcc1dc97a0cd9ccede2f28588cada3a0d2d83f366","d3a81ca6e785c06383937adf4b798caa6e8a9fbfa547b16d758d666581f33c1"],["8c28a97bf8298bc0d23d8c749452a32e694b65e30a9472a3954ab30fe5324caa","40a30463a3305193378fedf31f7cc0eb7ae784f0451cb9459e71dc73cbef9482"],["8ea9666139527a8c1dd94ce4f071fd23c8b350c5a4bb33748c4ba111faccae0","620efabbc8ee2782e24e7c0cfb95c5d735b783be9cf0f8e955af34a30e62b945"],["dd3625faef5ba06074669716bbd3788d89bdde815959968092f76cc4eb9a9787","7a188fa3520e30d461da2501045731ca941461982883395937f68d00c644a573"],["f710d79d9eb962297e4f6232b40e8f7feb2bc63814614d692c12de752408221e","ea98e67232d3b3295d3b535532115ccac8612c721851617526ae47a9c77bfc82"]]},naf:{wnd:7,points:[["f9308a019258c31049344f85f89d5229b531c845836f99b08601f113bce036f9","388f7b0f632de8140fe337e62a37f3566500a99934c2231b6cb9fd7584b8e672"],["2f8bde4d1a07209355b4a7250a5c5128e88b84bddc619ab7cba8d569b240efe4","d8ac222636e5e3d6d4dba9dda6c9c426f788271bab0d6840dca87d3aa6ac62d6"],["5cbdf0646e5db4eaa398f365f2ea7a0e3d419b7e0330e39ce92bddedcac4f9bc","6aebca40ba255960a3178d6d861a54dba813d0b813fde7b5a5082628087264da"],["acd484e2f0c7f65309ad178a9f559abde09796974c57e714c35f110dfc27ccbe","cc338921b0a7d9fd64380971763b61e9add888a4375f8e0f05cc262ac64f9c37"],["774ae7f858a9411e5ef4246b70c65aac5649980be5c17891bbec17895da008cb","d984a032eb6b5e190243dd56d7b7b365372db1e2dff9d6a8301d74c9c953c61b"],["f28773c2d975288bc7d1d205c3748651b075fbc6610e58cddeeddf8f19405aa8","ab0902e8d880a89758212eb65cdaf473a1a06da521fa91f29b5cb52db03ed81"],["d7924d4f7d43ea965a465ae3095ff41131e5946f3c85f79e44adbcf8e27e080e","581e2872a86c72a683842ec228cc6defea40af2bd896d3a5c504dc9ff6a26b58"],["defdea4cdb677750a420fee807eacf21eb9898ae79b9768766e4faa04a2d4a34","4211ab0694635168e997b0ead2a93daeced1f4a04a95c0f6cfb199f69e56eb77"],["2b4ea0a797a443d293ef5cff444f4979f06acfebd7e86d277475656138385b6c","85e89bc037945d93b343083b5a1c86131a01f60c50269763b570c854e5c09b7a"],["352bbf4a4cdd12564f93fa332ce333301d9ad40271f8107181340aef25be59d5","321eb4075348f534d59c18259dda3e1f4a1b3b2e71b1039c67bd3d8bcf81998c"],["2fa2104d6b38d11b0230010559879124e42ab8dfeff5ff29dc9cdadd4ecacc3f","2de1068295dd865b64569335bd5dd80181d70ecfc882648423ba76b532b7d67"],["9248279b09b4d68dab21a9b066edda83263c3d84e09572e269ca0cd7f5453714","73016f7bf234aade5d1aa71bdea2b1ff3fc0de2a887912ffe54a32ce97cb3402"],["daed4f2be3a8bf278e70132fb0beb7522f570e144bf615c07e996d443dee8729","a69dce4a7d6c98e8d4a1aca87ef8d7003f83c230f3afa726ab40e52290be1c55"],["c44d12c7065d812e8acf28d7cbb19f9011ecd9e9fdf281b0e6a3b5e87d22e7db","2119a460ce326cdc76c45926c982fdac0e106e861edf61c5a039063f0e0e6482"],["6a245bf6dc698504c89a20cfded60853152b695336c28063b61c65cbd269e6b4","e022cf42c2bd4a708b3f5126f16a24ad8b33ba48d0423b6efd5e6348100d8a82"],["1697ffa6fd9de627c077e3d2fe541084ce13300b0bec1146f95ae57f0d0bd6a5","b9c398f186806f5d27561506e4557433a2cf15009e498ae7adee9d63d01b2396"],["605bdb019981718b986d0f07e834cb0d9deb8360ffb7f61df982345ef27a7479","2972d2de4f8d20681a78d93ec96fe23c26bfae84fb14db43b01e1e9056b8c49"],["62d14dab4150bf497402fdc45a215e10dcb01c354959b10cfe31c7e9d87ff33d","80fc06bd8cc5b01098088a1950eed0db01aa132967ab472235f5642483b25eaf"],["80c60ad0040f27dade5b4b06c408e56b2c50e9f56b9b8b425e555c2f86308b6f","1c38303f1cc5c30f26e66bad7fe72f70a65eed4cbe7024eb1aa01f56430bd57a"],["7a9375ad6167ad54aa74c6348cc54d344cc5dc9487d847049d5eabb0fa03c8fb","d0e3fa9eca8726909559e0d79269046bdc59ea10c70ce2b02d499ec224dc7f7"],["d528ecd9b696b54c907a9ed045447a79bb408ec39b68df504bb51f459bc3ffc9","eecf41253136e5f99966f21881fd656ebc4345405c520dbc063465b521409933"],["49370a4b5f43412ea25f514e8ecdad05266115e4a7ecb1387231808f8b45963","758f3f41afd6ed428b3081b0512fd62a54c3f3afbb5b6764b653052a12949c9a"],["77f230936ee88cbbd73df930d64702ef881d811e0e1498e2f1c13eb1fc345d74","958ef42a7886b6400a08266e9ba1b37896c95330d97077cbbe8eb3c7671c60d6"],["f2dac991cc4ce4b9ea44887e5c7c0bce58c80074ab9d4dbaeb28531b7739f530","e0dedc9b3b2f8dad4da1f32dec2531df9eb5fbeb0598e4fd1a117dba703a3c37"],["463b3d9f662621fb1b4be8fbbe2520125a216cdfc9dae3debcba4850c690d45b","5ed430d78c296c3543114306dd8622d7c622e27c970a1de31cb377b01af7307e"],["f16f804244e46e2a09232d4aff3b59976b98fac14328a2d1a32496b49998f247","cedabd9b82203f7e13d206fcdf4e33d92a6c53c26e5cce26d6579962c4e31df6"],["caf754272dc84563b0352b7a14311af55d245315ace27c65369e15f7151d41d1","cb474660ef35f5f2a41b643fa5e460575f4fa9b7962232a5c32f908318a04476"],["2600ca4b282cb986f85d0f1709979d8b44a09c07cb86d7c124497bc86f082120","4119b88753c15bd6a693b03fcddbb45d5ac6be74ab5f0ef44b0be9475a7e4b40"],["7635ca72d7e8432c338ec53cd12220bc01c48685e24f7dc8c602a7746998e435","91b649609489d613d1d5e590f78e6d74ecfc061d57048bad9e76f302c5b9c61"],["754e3239f325570cdbbf4a87deee8a66b7f2b33479d468fbc1a50743bf56cc18","673fb86e5bda30fb3cd0ed304ea49a023ee33d0197a695d0c5d98093c536683"],["e3e6bd1071a1e96aff57859c82d570f0330800661d1c952f9fe2694691d9b9e8","59c9e0bba394e76f40c0aa58379a3cb6a5a2283993e90c4167002af4920e37f5"],["186b483d056a033826ae73d88f732985c4ccb1f32ba35f4b4cc47fdcf04aa6eb","3b952d32c67cf77e2e17446e204180ab21fb8090895138b4a4a797f86e80888b"],["df9d70a6b9876ce544c98561f4be4f725442e6d2b737d9c91a8321724ce0963f","55eb2dafd84d6ccd5f862b785dc39d4ab157222720ef9da217b8c45cf2ba2417"],["5edd5cc23c51e87a497ca815d5dce0f8ab52554f849ed8995de64c5f34ce7143","efae9c8dbc14130661e8cec030c89ad0c13c66c0d17a2905cdc706ab7399a868"],["290798c2b6476830da12fe02287e9e777aa3fba1c355b17a722d362f84614fba","e38da76dcd440621988d00bcf79af25d5b29c094db2a23146d003afd41943e7a"],["af3c423a95d9f5b3054754efa150ac39cd29552fe360257362dfdecef4053b45","f98a3fd831eb2b749a93b0e6f35cfb40c8cd5aa667a15581bc2feded498fd9c6"],["766dbb24d134e745cccaa28c99bf274906bb66b26dcf98df8d2fed50d884249a","744b1152eacbe5e38dcc887980da38b897584a65fa06cedd2c924f97cbac5996"],["59dbf46f8c94759ba21277c33784f41645f7b44f6c596a58ce92e666191abe3e","c534ad44175fbc300f4ea6ce648309a042ce739a7919798cd85e216c4a307f6e"],["f13ada95103c4537305e691e74e9a4a8dd647e711a95e73cb62dc6018cfd87b8","e13817b44ee14de663bf4bc808341f326949e21a6a75c2570778419bdaf5733d"],["7754b4fa0e8aced06d4167a2c59cca4cda1869c06ebadfb6488550015a88522c","30e93e864e669d82224b967c3020b8fa8d1e4e350b6cbcc537a48b57841163a2"],["948dcadf5990e048aa3874d46abef9d701858f95de8041d2a6828c99e2262519","e491a42537f6e597d5d28a3224b1bc25df9154efbd2ef1d2cbba2cae5347d57e"],["7962414450c76c1689c7b48f8202ec37fb224cf5ac0bfa1570328a8a3d7c77ab","100b610ec4ffb4760d5c1fc133ef6f6b12507a051f04ac5760afa5b29db83437"],["3514087834964b54b15b160644d915485a16977225b8847bb0dd085137ec47ca","ef0afbb2056205448e1652c48e8127fc6039e77c15c2378b7e7d15a0de293311"],["d3cc30ad6b483e4bc79ce2c9dd8bc54993e947eb8df787b442943d3f7b527eaf","8b378a22d827278d89c5e9be8f9508ae3c2ad46290358630afb34db04eede0a4"],["1624d84780732860ce1c78fcbfefe08b2b29823db913f6493975ba0ff4847610","68651cf9b6da903e0914448c6cd9d4ca896878f5282be4c8cc06e2a404078575"],["733ce80da955a8a26902c95633e62a985192474b5af207da6df7b4fd5fc61cd4","f5435a2bd2badf7d485a4d8b8db9fcce3e1ef8e0201e4578c54673bc1dc5ea1d"],["15d9441254945064cf1a1c33bbd3b49f8966c5092171e699ef258dfab81c045c","d56eb30b69463e7234f5137b73b84177434800bacebfc685fc37bbe9efe4070d"],["a1d0fcf2ec9de675b612136e5ce70d271c21417c9d2b8aaaac138599d0717940","edd77f50bcb5a3cab2e90737309667f2641462a54070f3d519212d39c197a629"],["e22fbe15c0af8ccc5780c0735f84dbe9a790badee8245c06c7ca37331cb36980","a855babad5cd60c88b430a69f53a1a7a38289154964799be43d06d77d31da06"],["311091dd9860e8e20ee13473c1155f5f69635e394704eaa74009452246cfa9b3","66db656f87d1f04fffd1f04788c06830871ec5a64feee685bd80f0b1286d8374"],["34c1fd04d301be89b31c0442d3e6ac24883928b45a9340781867d4232ec2dbdf","9414685e97b1b5954bd46f730174136d57f1ceeb487443dc5321857ba73abee"],["f219ea5d6b54701c1c14de5b557eb42a8d13f3abbcd08affcc2a5e6b049b8d63","4cb95957e83d40b0f73af4544cccf6b1f4b08d3c07b27fb8d8c2962a400766d1"],["d7b8740f74a8fbaab1f683db8f45de26543a5490bca627087236912469a0b448","fa77968128d9c92ee1010f337ad4717eff15db5ed3c049b3411e0315eaa4593b"],["32d31c222f8f6f0ef86f7c98d3a3335ead5bcd32abdd94289fe4d3091aa824bf","5f3032f5892156e39ccd3d7915b9e1da2e6dac9e6f26e961118d14b8462e1661"],["7461f371914ab32671045a155d9831ea8793d77cd59592c4340f86cbc18347b5","8ec0ba238b96bec0cbdddcae0aa442542eee1ff50c986ea6b39847b3cc092ff6"],["ee079adb1df1860074356a25aa38206a6d716b2c3e67453d287698bad7b2b2d6","8dc2412aafe3be5c4c5f37e0ecc5f9f6a446989af04c4e25ebaac479ec1c8c1e"],["16ec93e447ec83f0467b18302ee620f7e65de331874c9dc72bfd8616ba9da6b5","5e4631150e62fb40d0e8c2a7ca5804a39d58186a50e497139626778e25b0674d"],["eaa5f980c245f6f038978290afa70b6bd8855897f98b6aa485b96065d537bd99","f65f5d3e292c2e0819a528391c994624d784869d7e6ea67fb18041024edc07dc"],["78c9407544ac132692ee1910a02439958ae04877151342ea96c4b6b35a49f51","f3e0319169eb9b85d5404795539a5e68fa1fbd583c064d2462b675f194a3ddb4"],["494f4be219a1a77016dcd838431aea0001cdc8ae7a6fc688726578d9702857a5","42242a969283a5f339ba7f075e36ba2af925ce30d767ed6e55f4b031880d562c"],["a598a8030da6d86c6bc7f2f5144ea549d28211ea58faa70ebf4c1e665c1fe9b5","204b5d6f84822c307e4b4a7140737aec23fc63b65b35f86a10026dbd2d864e6b"],["c41916365abb2b5d09192f5f2dbeafec208f020f12570a184dbadc3e58595997","4f14351d0087efa49d245b328984989d5caf9450f34bfc0ed16e96b58fa9913"],["841d6063a586fa475a724604da03bc5b92a2e0d2e0a36acfe4c73a5514742881","73867f59c0659e81904f9a1c7543698e62562d6744c169ce7a36de01a8d6154"],["5e95bb399a6971d376026947f89bde2f282b33810928be4ded112ac4d70e20d5","39f23f366809085beebfc71181313775a99c9aed7d8ba38b161384c746012865"],["36e4641a53948fd476c39f8a99fd974e5ec07564b5315d8bf99471bca0ef2f66","d2424b1b1abe4eb8164227b085c9aa9456ea13493fd563e06fd51cf5694c78fc"],["336581ea7bfbbb290c191a2f507a41cf5643842170e914faeab27c2c579f726","ead12168595fe1be99252129b6e56b3391f7ab1410cd1e0ef3dcdcabd2fda224"],["8ab89816dadfd6b6a1f2634fcf00ec8403781025ed6890c4849742706bd43ede","6fdcef09f2f6d0a044e654aef624136f503d459c3e89845858a47a9129cdd24e"],["1e33f1a746c9c5778133344d9299fcaa20b0938e8acff2544bb40284b8c5fb94","60660257dd11b3aa9c8ed618d24edff2306d320f1d03010e33a7d2057f3b3b6"],["85b7c1dcb3cec1b7ee7f30ded79dd20a0ed1f4cc18cbcfcfa410361fd8f08f31","3d98a9cdd026dd43f39048f25a8847f4fcafad1895d7a633c6fed3c35e999511"],["29df9fbd8d9e46509275f4b125d6d45d7fbe9a3b878a7af872a2800661ac5f51","b4c4fe99c775a606e2d8862179139ffda61dc861c019e55cd2876eb2a27d84b"],["a0b1cae06b0a847a3fea6e671aaf8adfdfe58ca2f768105c8082b2e449fce252","ae434102edde0958ec4b19d917a6a28e6b72da1834aff0e650f049503a296cf2"],["4e8ceafb9b3e9a136dc7ff67e840295b499dfb3b2133e4ba113f2e4c0e121e5","cf2174118c8b6d7a4b48f6d534ce5c79422c086a63460502b827ce62a326683c"],["d24a44e047e19b6f5afb81c7ca2f69080a5076689a010919f42725c2b789a33b","6fb8d5591b466f8fc63db50f1c0f1c69013f996887b8244d2cdec417afea8fa3"],["ea01606a7a6c9cdd249fdfcfacb99584001edd28abbab77b5104e98e8e3b35d4","322af4908c7312b0cfbfe369f7a7b3cdb7d4494bc2823700cfd652188a3ea98d"],["af8addbf2b661c8a6c6328655eb96651252007d8c5ea31be4ad196de8ce2131f","6749e67c029b85f52a034eafd096836b2520818680e26ac8f3dfbcdb71749700"],["e3ae1974566ca06cc516d47e0fb165a674a3dabcfca15e722f0e3450f45889","2aeabe7e4531510116217f07bf4d07300de97e4874f81f533420a72eeb0bd6a4"],["591ee355313d99721cf6993ffed1e3e301993ff3ed258802075ea8ced397e246","b0ea558a113c30bea60fc4775460c7901ff0b053d25ca2bdeee98f1a4be5d196"],["11396d55fda54c49f19aa97318d8da61fa8584e47b084945077cf03255b52984","998c74a8cd45ac01289d5833a7beb4744ff536b01b257be4c5767bea93ea57a4"],["3c5d2a1ba39c5a1790000738c9e0c40b8dcdfd5468754b6405540157e017aa7a","b2284279995a34e2f9d4de7396fc18b80f9b8b9fdd270f6661f79ca4c81bd257"],["cc8704b8a60a0defa3a99a7299f2e9c3fbc395afb04ac078425ef8a1793cc030","bdd46039feed17881d1e0862db347f8cf395b74fc4bcdc4e940b74e3ac1f1b13"],["c533e4f7ea8555aacd9777ac5cad29b97dd4defccc53ee7ea204119b2889b197","6f0a256bc5efdf429a2fb6242f1a43a2d9b925bb4a4b3a26bb8e0f45eb596096"],["c14f8f2ccb27d6f109f6d08d03cc96a69ba8c34eec07bbcf566d48e33da6593","c359d6923bb398f7fd4473e16fe1c28475b740dd098075e6c0e8649113dc3a38"],["a6cbc3046bc6a450bac24789fa17115a4c9739ed75f8f21ce441f72e0b90e6ef","21ae7f4680e889bb130619e2c0f95a360ceb573c70603139862afd617fa9b9f"],["347d6d9a02c48927ebfb86c1359b1caf130a3c0267d11ce6344b39f99d43cc38","60ea7f61a353524d1c987f6ecec92f086d565ab687870cb12689ff1e31c74448"],["da6545d2181db8d983f7dcb375ef5866d47c67b1bf31c8cf855ef7437b72656a","49b96715ab6878a79e78f07ce5680c5d6673051b4935bd897fea824b77dc208a"],["c40747cc9d012cb1a13b8148309c6de7ec25d6945d657146b9d5994b8feb1111","5ca560753be2a12fc6de6caf2cb489565db936156b9514e1bb5e83037e0fa2d4"],["4e42c8ec82c99798ccf3a610be870e78338c7f713348bd34c8203ef4037f3502","7571d74ee5e0fb92a7a8b33a07783341a5492144cc54bcc40a94473693606437"],["3775ab7089bc6af823aba2e1af70b236d251cadb0c86743287522a1b3b0dedea","be52d107bcfa09d8bcb9736a828cfa7fac8db17bf7a76a2c42ad961409018cf7"],["cee31cbf7e34ec379d94fb814d3d775ad954595d1314ba8846959e3e82f74e26","8fd64a14c06b589c26b947ae2bcf6bfa0149ef0be14ed4d80f448a01c43b1c6d"],["b4f9eaea09b6917619f6ea6a4eb5464efddb58fd45b1ebefcdc1a01d08b47986","39e5c9925b5a54b07433a4f18c61726f8bb131c012ca542eb24a8ac07200682a"],["d4263dfc3d2df923a0179a48966d30ce84e2515afc3dccc1b77907792ebcc60e","62dfaf07a0f78feb30e30d6295853ce189e127760ad6cf7fae164e122a208d54"],["48457524820fa65a4f8d35eb6930857c0032acc0a4a2de422233eeda897612c4","25a748ab367979d98733c38a1fa1c2e7dc6cc07db2d60a9ae7a76aaa49bd0f77"],["dfeeef1881101f2cb11644f3a2afdfc2045e19919152923f367a1767c11cceda","ecfb7056cf1de042f9420bab396793c0c390bde74b4bbdff16a83ae09a9a7517"],["6d7ef6b17543f8373c573f44e1f389835d89bcbc6062ced36c82df83b8fae859","cd450ec335438986dfefa10c57fea9bcc521a0959b2d80bbf74b190dca712d10"],["e75605d59102a5a2684500d3b991f2e3f3c88b93225547035af25af66e04541f","f5c54754a8f71ee540b9b48728473e314f729ac5308b06938360990e2bfad125"],["eb98660f4c4dfaa06a2be453d5020bc99a0c2e60abe388457dd43fefb1ed620c","6cb9a8876d9cb8520609af3add26cd20a0a7cd8a9411131ce85f44100099223e"],["13e87b027d8514d35939f2e6892b19922154596941888336dc3563e3b8dba942","fef5a3c68059a6dec5d624114bf1e91aac2b9da568d6abeb2570d55646b8adf1"],["ee163026e9fd6fe017c38f06a5be6fc125424b371ce2708e7bf4491691e5764a","1acb250f255dd61c43d94ccc670d0f58f49ae3fa15b96623e5430da0ad6c62b2"],["b268f5ef9ad51e4d78de3a750c2dc89b1e626d43505867999932e5db33af3d80","5f310d4b3c99b9ebb19f77d41c1dee018cf0d34fd4191614003e945a1216e423"],["ff07f3118a9df035e9fad85eb6c7bfe42b02f01ca99ceea3bf7ffdba93c4750d","438136d603e858a3a5c440c38eccbaddc1d2942114e2eddd4740d098ced1f0d8"],["8d8b9855c7c052a34146fd20ffb658bea4b9f69e0d825ebec16e8c3ce2b526a1","cdb559eedc2d79f926baf44fb84ea4d44bcf50fee51d7ceb30e2e7f463036758"],["52db0b5384dfbf05bfa9d472d7ae26dfe4b851ceca91b1eba54263180da32b63","c3b997d050ee5d423ebaf66a6db9f57b3180c902875679de924b69d84a7b375"],["e62f9490d3d51da6395efd24e80919cc7d0f29c3f3fa48c6fff543becbd43352","6d89ad7ba4876b0b22c2ca280c682862f342c8591f1daf5170e07bfd9ccafa7d"],["7f30ea2476b399b4957509c88f77d0191afa2ff5cb7b14fd6d8e7d65aaab1193","ca5ef7d4b231c94c3b15389a5f6311e9daff7bb67b103e9880ef4bff637acaec"],["5098ff1e1d9f14fb46a210fada6c903fef0fb7b4a1dd1d9ac60a0361800b7a00","9731141d81fc8f8084d37c6e7542006b3ee1b40d60dfe5362a5b132fd17ddc0"],["32b78c7de9ee512a72895be6b9cbefa6e2f3c4ccce445c96b9f2c81e2778ad58","ee1849f513df71e32efc3896ee28260c73bb80547ae2275ba497237794c8753c"],["e2cb74fddc8e9fbcd076eef2a7c72b0ce37d50f08269dfc074b581550547a4f7","d3aa2ed71c9dd2247a62df062736eb0baddea9e36122d2be8641abcb005cc4a4"],["8438447566d4d7bedadc299496ab357426009a35f235cb141be0d99cd10ae3a8","c4e1020916980a4da5d01ac5e6ad330734ef0d7906631c4f2390426b2edd791f"],["4162d488b89402039b584c6fc6c308870587d9c46f660b878ab65c82c711d67e","67163e903236289f776f22c25fb8a3afc1732f2b84b4e95dbda47ae5a0852649"],["3fad3fa84caf0f34f0f89bfd2dcf54fc175d767aec3e50684f3ba4a4bf5f683d","cd1bc7cb6cc407bb2f0ca647c718a730cf71872e7d0d2a53fa20efcdfe61826"],["674f2600a3007a00568c1a7ce05d0816c1fb84bf1370798f1c69532faeb1a86b","299d21f9413f33b3edf43b257004580b70db57da0b182259e09eecc69e0d38a5"],["d32f4da54ade74abb81b815ad1fb3b263d82d6c692714bcff87d29bd5ee9f08f","f9429e738b8e53b968e99016c059707782e14f4535359d582fc416910b3eea87"],["30e4e670435385556e593657135845d36fbb6931f72b08cb1ed954f1e3ce3ff6","462f9bce619898638499350113bbc9b10a878d35da70740dc695a559eb88db7b"],["be2062003c51cc3004682904330e4dee7f3dcd10b01e580bf1971b04d4cad297","62188bc49d61e5428573d48a74e1c655b1c61090905682a0d5558ed72dccb9bc"],["93144423ace3451ed29e0fb9ac2af211cb6e84a601df5993c419859fff5df04a","7c10dfb164c3425f5c71a3f9d7992038f1065224f72bb9d1d902a6d13037b47c"],["b015f8044f5fcbdcf21ca26d6c34fb8197829205c7b7d2a7cb66418c157b112c","ab8c1e086d04e813744a655b2df8d5f83b3cdc6faa3088c1d3aea1454e3a1d5f"],["d5e9e1da649d97d89e4868117a465a3a4f8a18de57a140d36b3f2af341a21b52","4cb04437f391ed73111a13cc1d4dd0db1693465c2240480d8955e8592f27447a"],["d3ae41047dd7ca065dbf8ed77b992439983005cd72e16d6f996a5316d36966bb","bd1aeb21ad22ebb22a10f0303417c6d964f8cdd7df0aca614b10dc14d125ac46"],["463e2763d885f958fc66cdd22800f0a487197d0a82e377b49f80af87c897b065","bfefacdb0e5d0fd7df3a311a94de062b26b80c61fbc97508b79992671ef7ca7f"],["7985fdfd127c0567c6f53ec1bb63ec3158e597c40bfe747c83cddfc910641917","603c12daf3d9862ef2b25fe1de289aed24ed291e0ec6708703a5bd567f32ed03"],["74a1ad6b5f76e39db2dd249410eac7f99e74c59cb83d2d0ed5ff1543da7703e9","cc6157ef18c9c63cd6193d83631bbea0093e0968942e8c33d5737fd790e0db08"],["30682a50703375f602d416664ba19b7fc9bab42c72747463a71d0896b22f6da3","553e04f6b018b4fa6c8f39e7f311d3176290d0e0f19ca73f17714d9977a22ff8"],["9e2158f0d7c0d5f26c3791efefa79597654e7a2b2464f52b1ee6c1347769ef57","712fcdd1b9053f09003a3481fa7762e9ffd7c8ef35a38509e2fbf2629008373"],["176e26989a43c9cfeba4029c202538c28172e566e3c4fce7322857f3be327d66","ed8cc9d04b29eb877d270b4878dc43c19aefd31f4eee09ee7b47834c1fa4b1c3"],["75d46efea3771e6e68abb89a13ad747ecf1892393dfc4f1b7004788c50374da8","9852390a99507679fd0b86fd2b39a868d7efc22151346e1a3ca4726586a6bed8"],["809a20c67d64900ffb698c4c825f6d5f2310fb0451c869345b7319f645605721","9e994980d9917e22b76b061927fa04143d096ccc54963e6a5ebfa5f3f8e286c1"],["1b38903a43f7f114ed4500b4eac7083fdefece1cf29c63528d563446f972c180","4036edc931a60ae889353f77fd53de4a2708b26b6f5da72ad3394119daf408f9"]]}}},{}],419:[function(s,T,S){var m=S,a=s("bn.js"),o=s("minimalistic-assert"),r=s("minimalistic-crypto-utils");m.assert=o,m.toArray=r.toArray,m.zero2=r.zero2,m.toHex=r.toHex,m.encode=r.encode,m.getNAF=function(t,e,l){var n=new Array(Math.max(t.bitLength(),l)+1);n.fill(0);for(var i=1<<e+1,f=t.clone(),c=0;c<n.length;c++){var u,d=f.andln(i-1);f.isOdd()?(u=d>(i>>1)-1?(i>>1)-d:d,f.isubn(u)):u=0,n[c]=u,f.iushrn(1)}return n},m.getJSF=function(t,e){var l=[[],[]];t=t.clone(),e=e.clone();for(var n,i=0,f=0;t.cmpn(-i)>0||e.cmpn(-f)>0;){var c,u,d=t.andln(3)+i&3,h=e.andln(3)+f&3;d===3&&(d=-1),h===3&&(h=-1),c=1&d?(n=t.andln(7)+i&7)!==3&&n!==5||h!==2?d:-d:0,l[0].push(c),u=1&h?(n=e.andln(7)+f&7)!==3&&n!==5||d!==2?h:-h:0,l[1].push(u),2*i===c+1&&(i=1-i),2*f===u+1&&(f=1-f),t.iushrn(1),e.iushrn(1)}return l},m.cachedProperty=function(t,e,l){var n="_"+e;t.prototype[e]=function(){return this[n]!==void 0?this[n]:this[n]=l.call(this)}},m.parseBytes=function(t){return typeof t=="string"?m.toArray(t,"hex"):t},m.intFromLE=function(t){return new a(t,"hex","le")}},{"bn.js":420,"minimalistic-assert":453,"minimalistic-crypto-utils":454}],420:[function(s,T,S){arguments[4][184][0].apply(S,arguments)},{buffer:188,dup:184}],421:[function(s,T,S){T.exports={name:"elliptic",version:"6.5.4",description:"EC cryptography",main:"lib/elliptic.js",files:["lib"],scripts:{lint:"eslint lib test","lint:fix":"npm run lint -- --fix",unit:"istanbul test _mocha --reporter=spec test/index.js",test:"npm run lint && npm run unit",version:"grunt dist && git add dist/"},repository:{type:"git",url:"git@github.com:indutny/elliptic"},keywords:["EC","Elliptic","curve","Cryptography"],author:"Fedor Indutny <fedor@indutny.com>",license:"MIT",bugs:{url:"https://github.com/indutny/elliptic/issues"},homepage:"https://github.com/indutny/elliptic",devDependencies:{brfs:"^2.0.2",coveralls:"^3.1.0",eslint:"^7.6.0",grunt:"^1.2.1","grunt-browserify":"^5.3.0","grunt-cli":"^1.3.2","grunt-contrib-connect":"^3.0.0","grunt-contrib-copy":"^1.0.0","grunt-contrib-uglify":"^5.0.0","grunt-mocha-istanbul":"^5.0.2","grunt-saucelabs":"^9.0.1",istanbul:"^0.4.5",mocha:"^8.0.1"},dependencies:{"bn.js":"^4.11.9",brorand:"^1.1.0","hash.js":"^1.0.0","hmac-drbg":"^1.0.1",inherits:"^2.0.4","minimalistic-assert":"^1.0.1","minimalistic-crypto-utils":"^1.0.1"}}},{}],422:[function(s,T,S){var m=Object.create||function(I){var P=function(){};return P.prototype=I,new P},a=Object.keys||function(I){var P=[];for(var B in I)Object.prototype.hasOwnProperty.call(I,B)&&P.push(B);return B},o=Function.prototype.bind||function(I){var P=this;return function(){return P.apply(I,arguments)}};function r(){this._events&&Object.prototype.hasOwnProperty.call(this,"_events")||(this._events=m(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}T.exports=r,r.EventEmitter=r,r.prototype._events=void 0,r.prototype._maxListeners=void 0;var t,e=10;try{var l={};Object.defineProperty&&Object.defineProperty(l,"x",{value:0}),t=l.x===0}catch{t=!1}function n(I){return I._maxListeners===void 0?r.defaultMaxListeners:I._maxListeners}function i(I,P,B){if(P)I.call(B);else for(var U=I.length,D=L(I,U),x=0;x<U;++x)D[x].call(B)}function f(I,P,B,U){if(P)I.call(B,U);else for(var D=I.length,x=L(I,D),M=0;M<D;++M)x[M].call(B,U)}function c(I,P,B,U,D){if(P)I.call(B,U,D);else for(var x=I.length,M=L(I,x),v=0;v<x;++v)M[v].call(B,U,D)}function u(I,P,B,U,D,x){if(P)I.call(B,U,D,x);else for(var M=I.length,v=L(I,M),p=0;p<M;++p)v[p].call(B,U,D,x)}function d(I,P,B,U){if(P)I.apply(B,U);else for(var D=I.length,x=L(I,D),M=0;M<D;++M)x[M].apply(B,U)}function h(I,P,B,U){var D,x,M;if(typeof B!="function")throw new TypeError('"listener" argument must be a function');if((x=I._events)?(x.newListener&&(I.emit("newListener",P,B.listener?B.listener:B),x=I._events),M=x[P]):(x=I._events=m(null),I._eventsCount=0),M){if(typeof M=="function"?M=x[P]=U?[B,M]:[M,B]:U?M.unshift(B):M.push(B),!M.warned&&(D=n(I))&&D>0&&M.length>D){M.warned=!0;var v=new Error("Possible EventEmitter memory leak detected. "+M.length+' "'+String(P)+'" listeners added. Use emitter.setMaxListeners() to increase limit.');v.name="MaxListenersExceededWarning",v.emitter=I,v.type=P,v.count=M.length,typeof console=="object"&&console.warn&&console.warn("%s: %s",v.name,v.message)}}else M=x[P]=B,++I._eventsCount;return I}function w(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var I=new Array(arguments.length),P=0;P<I.length;++P)I[P]=arguments[P];this.listener.apply(this.target,I)}}function _(I,P,B){var U={fired:!1,wrapFn:void 0,target:I,type:P,listener:B},D=o.call(w,U);return D.listener=B,U.wrapFn=D,D}function A(I,P,B){var U=I._events;if(!U)return[];var D=U[P];return D?typeof D=="function"?B?[D.listener||D]:[D]:B?function(x){for(var M=new Array(x.length),v=0;v<M.length;++v)M[v]=x[v].listener||x[v];return M}(D):L(D,D.length):[]}function N(I){var P=this._events;if(P){var B=P[I];if(typeof B=="function")return 1;if(B)return B.length}return 0}function L(I,P){for(var B=new Array(P),U=0;U<P;++U)B[U]=I[U];return B}t?Object.defineProperty(r,"defaultMaxListeners",{enumerable:!0,get:function(){return e},set:function(I){if(typeof I!="number"||I<0||I!=I)throw new TypeError('"defaultMaxListeners" must be a positive number');e=I}}):r.defaultMaxListeners=e,r.prototype.setMaxListeners=function(I){if(typeof I!="number"||I<0||isNaN(I))throw new TypeError('"n" argument must be a positive number');return this._maxListeners=I,this},r.prototype.getMaxListeners=function(){return n(this)},r.prototype.emit=function(I){var P,B,U,D,x,M,v=I==="error";if(M=this._events)v=v&&M.error==null;else if(!v)return!1;if(v){if(arguments.length>1&&(P=arguments[1]),P instanceof Error)throw P;var p=new Error('Unhandled "error" event. ('+P+")");throw p.context=P,p}if(!(B=M[I]))return!1;var b=typeof B=="function";switch(U=arguments.length){case 1:i(B,b,this);break;case 2:f(B,b,this,arguments[1]);break;case 3:c(B,b,this,arguments[1],arguments[2]);break;case 4:u(B,b,this,arguments[1],arguments[2],arguments[3]);break;default:for(D=new Array(U-1),x=1;x<U;x++)D[x-1]=arguments[x];d(B,b,this,D)}return!0},r.prototype.addListener=function(I,P){return h(this,I,P,!1)},r.prototype.on=r.prototype.addListener,r.prototype.prependListener=function(I,P){return h(this,I,P,!0)},r.prototype.once=function(I,P){if(typeof P!="function")throw new TypeError('"listener" argument must be a function');return this.on(I,_(this,I,P)),this},r.prototype.prependOnceListener=function(I,P){if(typeof P!="function")throw new TypeError('"listener" argument must be a function');return this.prependListener(I,_(this,I,P)),this},r.prototype.removeListener=function(I,P){var B,U,D,x,M;if(typeof P!="function")throw new TypeError('"listener" argument must be a function');if(!(U=this._events))return this;if(!(B=U[I]))return this;if(B===P||B.listener===P)--this._eventsCount==0?this._events=m(null):(delete U[I],U.removeListener&&this.emit("removeListener",I,B.listener||P));else if(typeof B!="function"){for(D=-1,x=B.length-1;x>=0;x--)if(B[x]===P||B[x].listener===P){M=B[x].listener,D=x;break}if(D<0)return this;D===0?B.shift():function(v,p){for(var b=p,g=b+1,y=v.length;g<y;b+=1,g+=1)v[b]=v[g];v.pop()}(B,D),B.length===1&&(U[I]=B[0]),U.removeListener&&this.emit("removeListener",I,M||P)}return this},r.prototype.removeAllListeners=function(I){var P,B,U;if(!(B=this._events))return this;if(!B.removeListener)return arguments.length===0?(this._events=m(null),this._eventsCount=0):B[I]&&(--this._eventsCount==0?this._events=m(null):delete B[I]),this;if(arguments.length===0){var D,x=a(B);for(U=0;U<x.length;++U)(D=x[U])!=="removeListener"&&this.removeAllListeners(D);return this.removeAllListeners("removeListener"),this._events=m(null),this._eventsCount=0,this}if(typeof(P=B[I])=="function")this.removeListener(I,P);else if(P)for(U=P.length-1;U>=0;U--)this.removeListener(I,P[U]);return this},r.prototype.listeners=function(I){return A(this,I,!0)},r.prototype.rawListeners=function(I){return A(this,I,!1)},r.listenerCount=function(I,P){return typeof I.listenerCount=="function"?I.listenerCount(P):N.call(I,P)},r.prototype.listenerCount=N,r.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],423:[function(s,T,S){var m=s("safe-buffer").Buffer,a=s("md5.js");T.exports=function(o,r,t,e){if(m.isBuffer(o)||(o=m.from(o,"binary")),r&&(m.isBuffer(r)||(r=m.from(r,"binary")),r.length!==8))throw new RangeError("salt should be Buffer with 8 byte length");for(var l=t/8,n=m.alloc(l),i=m.alloc(e||0),f=m.alloc(0);l>0||e>0;){var c=new a;c.update(f),c.update(o),r&&c.update(r),f=c.digest();var u=0;if(l>0){var d=n.length-l;u=Math.min(l,f.length),f.copy(n,d,0,u),l-=u}if(u<f.length&&e>0){var h=i.length-e,w=Math.min(e,f.length-u);f.copy(i,h,u,u+w),e-=w}}return f.fill(0),{key:n,iv:i}}},{"md5.js":450,"safe-buffer":494}],424:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.CsvParserStream=S.ParserOptions=S.parseFile=S.parseStream=S.parseString=S.parse=S.FormatterOptions=S.CsvFormatterStream=S.writeToPath=S.writeToString=S.writeToBuffer=S.writeToStream=S.write=S.format=void 0;var m=s("@fast-csv/format");Object.defineProperty(S,"format",{enumerable:!0,get:function(){return m.format}}),Object.defineProperty(S,"write",{enumerable:!0,get:function(){return m.write}}),Object.defineProperty(S,"writeToStream",{enumerable:!0,get:function(){return m.writeToStream}}),Object.defineProperty(S,"writeToBuffer",{enumerable:!0,get:function(){return m.writeToBuffer}}),Object.defineProperty(S,"writeToString",{enumerable:!0,get:function(){return m.writeToString}}),Object.defineProperty(S,"writeToPath",{enumerable:!0,get:function(){return m.writeToPath}}),Object.defineProperty(S,"CsvFormatterStream",{enumerable:!0,get:function(){return m.CsvFormatterStream}}),Object.defineProperty(S,"FormatterOptions",{enumerable:!0,get:function(){return m.FormatterOptions}});var a=s("@fast-csv/parse");Object.defineProperty(S,"parse",{enumerable:!0,get:function(){return a.parse}}),Object.defineProperty(S,"parseString",{enumerable:!0,get:function(){return a.parseString}}),Object.defineProperty(S,"parseStream",{enumerable:!0,get:function(){return a.parseStream}}),Object.defineProperty(S,"parseFile",{enumerable:!0,get:function(){return a.parseFile}}),Object.defineProperty(S,"ParserOptions",{enumerable:!0,get:function(){return a.ParserOptions}}),Object.defineProperty(S,"CsvParserStream",{enumerable:!0,get:function(){return a.CsvParserStream}})},{"@fast-csv/format":151,"@fast-csv/parse":155}],425:[function(s,T,S){var m=s("safe-buffer").Buffer,a=s("readable-stream").Transform;function o(r){a.call(this),this._block=m.allocUnsafe(r),this._blockSize=r,this._blockOffset=0,this._length=[0,0,0,0],this._finalized=!1}s("inherits")(o,a),o.prototype._transform=function(r,t,e){var l=null;try{this.update(r,t)}catch(n){l=n}e(l)},o.prototype._flush=function(r){var t=null;try{this.push(this.digest())}catch(e){t=e}r(t)},o.prototype.update=function(r,t){if(function(c,u){if(!m.isBuffer(c)&&typeof c!="string")throw new TypeError(u+" must be a string or a buffer")}(r,"Data"),this._finalized)throw new Error("Digest already called");m.isBuffer(r)||(r=m.from(r,t));for(var e=this._block,l=0;this._blockOffset+r.length-l>=this._blockSize;){for(var n=this._blockOffset;n<this._blockSize;)e[n++]=r[l++];this._update(),this._blockOffset=0}for(;l<r.length;)e[this._blockOffset++]=r[l++];for(var i=0,f=8*r.length;f>0;++i)this._length[i]+=f,(f=this._length[i]/4294967296|0)>0&&(this._length[i]-=4294967296*f);return this},o.prototype._update=function(){throw new Error("_update is not implemented")},o.prototype.digest=function(r){if(this._finalized)throw new Error("Digest already called");this._finalized=!0;var t=this._digest();r!==void 0&&(t=t.toString(r)),this._block.fill(0),this._blockOffset=0;for(var e=0;e<4;++e)this._length[e]=0;return t},o.prototype._digest=function(){throw new Error("_digest is not implemented")},T.exports=o},{inherits:440,"readable-stream":491,"safe-buffer":494}],426:[function(s,T,S){var m=S;m.utils=s("./hash/utils"),m.common=s("./hash/common"),m.sha=s("./hash/sha"),m.ripemd=s("./hash/ripemd"),m.hmac=s("./hash/hmac"),m.sha1=m.sha.sha1,m.sha256=m.sha.sha256,m.sha224=m.sha.sha224,m.sha384=m.sha.sha384,m.sha512=m.sha.sha512,m.ripemd160=m.ripemd.ripemd160},{"./hash/common":427,"./hash/hmac":428,"./hash/ripemd":429,"./hash/sha":430,"./hash/utils":437}],427:[function(s,T,S){var m=s("./utils"),a=s("minimalistic-assert");function o(){this.pending=null,this.pendingTotal=0,this.blockSize=this.constructor.blockSize,this.outSize=this.constructor.outSize,this.hmacStrength=this.constructor.hmacStrength,this.padLength=this.constructor.padLength/8,this.endian="big",this._delta8=this.blockSize/8,this._delta32=this.blockSize/32}S.BlockHash=o,o.prototype.update=function(r,t){if(r=m.toArray(r,t),this.pending?this.pending=this.pending.concat(r):this.pending=r,this.pendingTotal+=r.length,this.pending.length>=this._delta8){var e=(r=this.pending).length%this._delta8;this.pending=r.slice(r.length-e,r.length),this.pending.length===0&&(this.pending=null),r=m.join32(r,0,r.length-e,this.endian);for(var l=0;l<r.length;l+=this._delta32)this._update(r,l,l+this._delta32)}return this},o.prototype.digest=function(r){return this.update(this._pad()),a(this.pending===null),this._digest(r)},o.prototype._pad=function(){var r=this.pendingTotal,t=this._delta8,e=t-(r+this.padLength)%t,l=new Array(e+this.padLength);l[0]=128;for(var n=1;n<e;n++)l[n]=0;if(r<<=3,this.endian==="big"){for(var i=8;i<this.padLength;i++)l[n++]=0;l[n++]=0,l[n++]=0,l[n++]=0,l[n++]=0,l[n++]=r>>>24&255,l[n++]=r>>>16&255,l[n++]=r>>>8&255,l[n++]=255&r}else for(l[n++]=255&r,l[n++]=r>>>8&255,l[n++]=r>>>16&255,l[n++]=r>>>24&255,l[n++]=0,l[n++]=0,l[n++]=0,l[n++]=0,i=8;i<this.padLength;i++)l[n++]=0;return l}},{"./utils":437,"minimalistic-assert":453}],428:[function(s,T,S){var m=s("./utils"),a=s("minimalistic-assert");function o(r,t,e){if(!(this instanceof o))return new o(r,t,e);this.Hash=r,this.blockSize=r.blockSize/8,this.outSize=r.outSize/8,this.inner=null,this.outer=null,this._init(m.toArray(t,e))}T.exports=o,o.prototype._init=function(r){r.length>this.blockSize&&(r=new this.Hash().update(r).digest()),a(r.length<=this.blockSize);for(var t=r.length;t<this.blockSize;t++)r.push(0);for(t=0;t<r.length;t++)r[t]^=54;for(this.inner=new this.Hash().update(r),t=0;t<r.length;t++)r[t]^=106;this.outer=new this.Hash().update(r)},o.prototype.update=function(r,t){return this.inner.update(r,t),this},o.prototype.digest=function(r){return this.outer.update(this.inner.digest()),this.outer.digest(r)}},{"./utils":437,"minimalistic-assert":453}],429:[function(s,T,S){var m=s("./utils"),a=s("./common"),o=m.rotl32,r=m.sum32,t=m.sum32_3,e=m.sum32_4,l=a.BlockHash;function n(){if(!(this instanceof n))return new n;l.call(this),this.h=[1732584193,4023233417,2562383102,271733878,3285377520],this.endian="little"}function i(_,A,N,L){return _<=15?A^N^L:_<=31?A&N|~A&L:_<=47?(A|~N)^L:_<=63?A&L|N&~L:A^(N|~L)}function f(_){return _<=15?0:_<=31?1518500249:_<=47?1859775393:_<=63?2400959708:2840853838}function c(_){return _<=15?1352829926:_<=31?1548603684:_<=47?1836072691:_<=63?2053994217:0}m.inherits(n,l),S.ripemd160=n,n.blockSize=512,n.outSize=160,n.hmacStrength=192,n.padLength=64,n.prototype._update=function(_,A){for(var N=this.h[0],L=this.h[1],I=this.h[2],P=this.h[3],B=this.h[4],U=N,D=L,x=I,M=P,v=B,p=0;p<80;p++){var b=r(o(e(N,i(p,L,I,P),_[u[p]+A],f(p)),h[p]),B);N=B,B=P,P=o(I,10),I=L,L=b,b=r(o(e(U,i(79-p,D,x,M),_[d[p]+A],c(p)),w[p]),v),U=v,v=M,M=o(x,10),x=D,D=b}b=t(this.h[1],I,M),this.h[1]=t(this.h[2],P,v),this.h[2]=t(this.h[3],B,U),this.h[3]=t(this.h[4],N,D),this.h[4]=t(this.h[0],L,x),this.h[0]=b},n.prototype._digest=function(_){return _==="hex"?m.toHex32(this.h,"little"):m.split32(this.h,"little")};var u=[0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,7,4,13,1,10,6,15,3,12,0,9,5,2,14,11,8,3,10,14,4,9,15,8,1,2,7,0,6,13,11,5,12,1,9,11,10,0,8,12,4,13,3,7,15,14,5,6,2,4,0,5,9,7,12,2,10,14,1,3,8,11,6,15,13],d=[5,14,7,0,9,2,11,4,13,6,15,8,1,10,3,12,6,11,3,7,0,13,5,10,14,15,8,12,4,9,1,2,15,5,1,3,7,14,6,9,11,8,12,2,10,0,4,13,8,6,4,1,3,11,15,0,5,12,2,13,9,7,10,14,12,15,10,4,1,5,8,7,6,2,13,14,0,3,9,11],h=[11,14,15,12,5,8,7,9,11,13,14,15,6,7,9,8,7,6,8,13,11,9,7,15,7,12,15,9,11,7,13,12,11,13,6,7,14,9,13,15,14,8,13,6,5,12,7,5,11,12,14,15,14,15,9,8,9,14,5,6,8,6,5,12,9,15,5,11,6,8,13,12,5,12,13,14,11,8,5,6],w=[8,9,9,11,13,15,15,5,7,7,8,11,14,14,12,6,9,13,15,7,12,8,9,11,7,7,12,7,6,15,13,11,9,7,15,11,8,6,6,14,12,13,5,14,13,13,7,5,15,5,8,11,14,14,6,14,6,9,12,9,12,5,15,8,8,5,12,9,12,5,14,6,8,13,6,5,15,13,11,11]},{"./common":427,"./utils":437}],430:[function(s,T,S){S.sha1=s("./sha/1"),S.sha224=s("./sha/224"),S.sha256=s("./sha/256"),S.sha384=s("./sha/384"),S.sha512=s("./sha/512")},{"./sha/1":431,"./sha/224":432,"./sha/256":433,"./sha/384":434,"./sha/512":435}],431:[function(s,T,S){var m=s("../utils"),a=s("../common"),o=s("./common"),r=m.rotl32,t=m.sum32,e=m.sum32_5,l=o.ft_1,n=a.BlockHash,i=[1518500249,1859775393,2400959708,3395469782];function f(){if(!(this instanceof f))return new f;n.call(this),this.h=[1732584193,4023233417,2562383102,271733878,3285377520],this.W=new Array(80)}m.inherits(f,n),T.exports=f,f.blockSize=512,f.outSize=160,f.hmacStrength=80,f.padLength=64,f.prototype._update=function(c,u){for(var d=this.W,h=0;h<16;h++)d[h]=c[u+h];for(;h<d.length;h++)d[h]=r(d[h-3]^d[h-8]^d[h-14]^d[h-16],1);var w=this.h[0],_=this.h[1],A=this.h[2],N=this.h[3],L=this.h[4];for(h=0;h<d.length;h++){var I=~~(h/20),P=e(r(w,5),l(I,_,A,N),L,d[h],i[I]);L=N,N=A,A=r(_,30),_=w,w=P}this.h[0]=t(this.h[0],w),this.h[1]=t(this.h[1],_),this.h[2]=t(this.h[2],A),this.h[3]=t(this.h[3],N),this.h[4]=t(this.h[4],L)},f.prototype._digest=function(c){return c==="hex"?m.toHex32(this.h,"big"):m.split32(this.h,"big")}},{"../common":427,"../utils":437,"./common":436}],432:[function(s,T,S){var m=s("../utils"),a=s("./256");function o(){if(!(this instanceof o))return new o;a.call(this),this.h=[3238371032,914150663,812702999,4144912697,4290775857,1750603025,1694076839,3204075428]}m.inherits(o,a),T.exports=o,o.blockSize=512,o.outSize=224,o.hmacStrength=192,o.padLength=64,o.prototype._digest=function(r){return r==="hex"?m.toHex32(this.h.slice(0,7),"big"):m.split32(this.h.slice(0,7),"big")}},{"../utils":437,"./256":433}],433:[function(s,T,S){var m=s("../utils"),a=s("../common"),o=s("./common"),r=s("minimalistic-assert"),t=m.sum32,e=m.sum32_4,l=m.sum32_5,n=o.ch32,i=o.maj32,f=o.s0_256,c=o.s1_256,u=o.g0_256,d=o.g1_256,h=a.BlockHash,w=[1116352408,1899447441,3049323471,3921009573,961987163,1508970993,2453635748,2870763221,3624381080,310598401,607225278,1426881987,1925078388,2162078206,2614888103,3248222580,3835390401,4022224774,264347078,604807628,770255983,1249150122,1555081692,1996064986,2554220882,2821834349,2952996808,3210313671,3336571891,3584528711,113926993,338241895,666307205,773529912,1294757372,1396182291,1695183700,1986661051,2177026350,2456956037,2730485921,2820302411,3259730800,3345764771,3516065817,3600352804,4094571909,275423344,430227734,506948616,659060556,883997877,958139571,1322822218,1537002063,1747873779,1955562222,2024104815,2227730452,2361852424,2428436474,2756734187,3204031479,3329325298];function _(){if(!(this instanceof _))return new _;h.call(this),this.h=[1779033703,3144134277,1013904242,2773480762,1359893119,2600822924,528734635,1541459225],this.k=w,this.W=new Array(64)}m.inherits(_,h),T.exports=_,_.blockSize=512,_.outSize=256,_.hmacStrength=192,_.padLength=64,_.prototype._update=function(A,N){for(var L=this.W,I=0;I<16;I++)L[I]=A[N+I];for(;I<L.length;I++)L[I]=e(d(L[I-2]),L[I-7],u(L[I-15]),L[I-16]);var P=this.h[0],B=this.h[1],U=this.h[2],D=this.h[3],x=this.h[4],M=this.h[5],v=this.h[6],p=this.h[7];for(r(this.k.length===L.length),I=0;I<L.length;I++){var b=l(p,c(x),n(x,M,v),this.k[I],L[I]),g=t(f(P),i(P,B,U));p=v,v=M,M=x,x=t(D,b),D=U,U=B,B=P,P=t(b,g)}this.h[0]=t(this.h[0],P),this.h[1]=t(this.h[1],B),this.h[2]=t(this.h[2],U),this.h[3]=t(this.h[3],D),this.h[4]=t(this.h[4],x),this.h[5]=t(this.h[5],M),this.h[6]=t(this.h[6],v),this.h[7]=t(this.h[7],p)},_.prototype._digest=function(A){return A==="hex"?m.toHex32(this.h,"big"):m.split32(this.h,"big")}},{"../common":427,"../utils":437,"./common":436,"minimalistic-assert":453}],434:[function(s,T,S){var m=s("../utils"),a=s("./512");function o(){if(!(this instanceof o))return new o;a.call(this),this.h=[3418070365,3238371032,1654270250,914150663,2438529370,812702999,355462360,4144912697,1731405415,4290775857,2394180231,1750603025,3675008525,1694076839,1203062813,3204075428]}m.inherits(o,a),T.exports=o,o.blockSize=1024,o.outSize=384,o.hmacStrength=192,o.padLength=128,o.prototype._digest=function(r){return r==="hex"?m.toHex32(this.h.slice(0,12),"big"):m.split32(this.h.slice(0,12),"big")}},{"../utils":437,"./512":435}],435:[function(s,T,S){var m=s("../utils"),a=s("../common"),o=s("minimalistic-assert"),r=m.rotr64_hi,t=m.rotr64_lo,e=m.shr64_hi,l=m.shr64_lo,n=m.sum64,i=m.sum64_hi,f=m.sum64_lo,c=m.sum64_4_hi,u=m.sum64_4_lo,d=m.sum64_5_hi,h=m.sum64_5_lo,w=a.BlockHash,_=[1116352408,3609767458,1899447441,602891725,3049323471,3964484399,3921009573,2173295548,961987163,4081628472,1508970993,3053834265,2453635748,2937671579,2870763221,3664609560,3624381080,2734883394,310598401,1164996542,607225278,1323610764,1426881987,3590304994,1925078388,4068182383,2162078206,991336113,2614888103,633803317,3248222580,3479774868,3835390401,2666613458,4022224774,944711139,264347078,2341262773,604807628,2007800933,770255983,1495990901,1249150122,1856431235,1555081692,3175218132,1996064986,2198950837,2554220882,3999719339,2821834349,766784016,2952996808,2566594879,3210313671,3203337956,3336571891,1034457026,3584528711,2466948901,113926993,3758326383,338241895,168717936,666307205,1188179964,773529912,1546045734,1294757372,1522805485,1396182291,2643833823,1695183700,2343527390,1986661051,1014477480,2177026350,1206759142,2456956037,344077627,2730485921,1290863460,2820302411,3158454273,3259730800,3505952657,3345764771,106217008,3516065817,3606008344,3600352804,1432725776,4094571909,1467031594,275423344,851169720,430227734,3100823752,506948616,1363258195,659060556,3750685593,883997877,3785050280,958139571,3318307427,1322822218,3812723403,1537002063,2003034995,1747873779,3602036899,1955562222,1575990012,2024104815,1125592928,2227730452,2716904306,2361852424,442776044,2428436474,593698344,2756734187,3733110249,3204031479,2999351573,3329325298,3815920427,3391569614,3928383900,3515267271,566280711,3940187606,3454069534,4118630271,4000239992,116418474,1914138554,174292421,2731055270,289380356,3203993006,460393269,320620315,685471733,587496836,852142971,1086792851,1017036298,365543100,1126000580,2618297676,1288033470,3409855158,1501505948,4234509866,1607167915,987167468,1816402316,1246189591];function A(){if(!(this instanceof A))return new A;w.call(this),this.h=[1779033703,4089235720,3144134277,2227873595,1013904242,4271175723,2773480762,1595750129,1359893119,2917565137,2600822924,725511199,528734635,4215389547,1541459225,327033209],this.k=_,this.W=new Array(160)}function N(g,y,k,R,O){var z=g&k^~g&O;return z<0&&(z+=4294967296),z}function L(g,y,k,R,O,z){var $=y&R^~y&z;return $<0&&($+=4294967296),$}function I(g,y,k,R,O){var z=g&k^g&O^k&O;return z<0&&(z+=4294967296),z}function P(g,y,k,R,O,z){var $=y&R^y&z^R&z;return $<0&&($+=4294967296),$}function B(g,y){var k=r(g,y,28)^r(y,g,2)^r(y,g,7);return k<0&&(k+=4294967296),k}function U(g,y){var k=t(g,y,28)^t(y,g,2)^t(y,g,7);return k<0&&(k+=4294967296),k}function D(g,y){var k=r(g,y,14)^r(g,y,18)^r(y,g,9);return k<0&&(k+=4294967296),k}function x(g,y){var k=t(g,y,14)^t(g,y,18)^t(y,g,9);return k<0&&(k+=4294967296),k}function M(g,y){var k=r(g,y,1)^r(g,y,8)^e(g,y,7);return k<0&&(k+=4294967296),k}function v(g,y){var k=t(g,y,1)^t(g,y,8)^l(g,y,7);return k<0&&(k+=4294967296),k}function p(g,y){var k=r(g,y,19)^r(y,g,29)^e(g,y,6);return k<0&&(k+=4294967296),k}function b(g,y){var k=t(g,y,19)^t(y,g,29)^l(g,y,6);return k<0&&(k+=4294967296),k}m.inherits(A,w),T.exports=A,A.blockSize=1024,A.outSize=512,A.hmacStrength=192,A.padLength=128,A.prototype._prepareBlock=function(g,y){for(var k=this.W,R=0;R<32;R++)k[R]=g[y+R];for(;R<k.length;R+=2){var O=p(k[R-4],k[R-3]),z=b(k[R-4],k[R-3]),$=k[R-14],W=k[R-13],j=M(k[R-30],k[R-29]),H=v(k[R-30],k[R-29]),E=k[R-32],C=k[R-31];k[R]=c(O,z,$,W,j,H,E,C),k[R+1]=u(O,z,$,W,j,H,E,C)}},A.prototype._update=function(g,y){this._prepareBlock(g,y);var k=this.W,R=this.h[0],O=this.h[1],z=this.h[2],$=this.h[3],W=this.h[4],j=this.h[5],H=this.h[6],E=this.h[7],C=this.h[8],F=this.h[9],V=this.h[10],Z=this.h[11],q=this.h[12],K=this.h[13],et=this.h[14],tt=this.h[15];o(this.k.length===k.length);for(var X=0;X<k.length;X+=2){var J=et,G=tt,nt=D(C,F),rt=x(C,F),st=N(C,F,V,Z,q),ot=L(C,F,V,Z,q,K),lt=this.k[X],ct=this.k[X+1],wt=k[X],vt=k[X+1],mt=d(J,G,nt,rt,st,ot,lt,ct,wt,vt),Rt=h(J,G,nt,rt,st,ot,lt,ct,wt,vt);J=B(R,O),G=U(R,O),nt=I(R,O,z,$,W),rt=P(R,O,z,$,W,j);var Et=i(J,G,nt,rt),At=f(J,G,nt,rt);et=q,tt=K,q=V,K=Z,V=C,Z=F,C=i(H,E,mt,Rt),F=f(E,E,mt,Rt),H=W,E=j,W=z,j=$,z=R,$=O,R=i(mt,Rt,Et,At),O=f(mt,Rt,Et,At)}n(this.h,0,R,O),n(this.h,2,z,$),n(this.h,4,W,j),n(this.h,6,H,E),n(this.h,8,C,F),n(this.h,10,V,Z),n(this.h,12,q,K),n(this.h,14,et,tt)},A.prototype._digest=function(g){return g==="hex"?m.toHex32(this.h,"big"):m.split32(this.h,"big")}},{"../common":427,"../utils":437,"minimalistic-assert":453}],436:[function(s,T,S){var m=s("../utils").rotr32;function a(t,e,l){return t&e^~t&l}function o(t,e,l){return t&e^t&l^e&l}function r(t,e,l){return t^e^l}S.ft_1=function(t,e,l,n){return t===0?a(e,l,n):t===1||t===3?r(e,l,n):t===2?o(e,l,n):void 0},S.ch32=a,S.maj32=o,S.p32=r,S.s0_256=function(t){return m(t,2)^m(t,13)^m(t,22)},S.s1_256=function(t){return m(t,6)^m(t,11)^m(t,25)},S.g0_256=function(t){return m(t,7)^m(t,18)^t>>>3},S.g1_256=function(t){return m(t,17)^m(t,19)^t>>>10}},{"../utils":437}],437:[function(s,T,S){var m=s("minimalistic-assert"),a=s("inherits");function o(l,n){return(64512&l.charCodeAt(n))==55296&&!(n<0||n+1>=l.length)&&(64512&l.charCodeAt(n+1))==56320}function r(l){return(l>>>24|l>>>8&65280|l<<8&16711680|(255&l)<<24)>>>0}function t(l){return l.length===1?"0"+l:l}function e(l){return l.length===7?"0"+l:l.length===6?"00"+l:l.length===5?"000"+l:l.length===4?"0000"+l:l.length===3?"00000"+l:l.length===2?"000000"+l:l.length===1?"0000000"+l:l}S.inherits=a,S.toArray=function(l,n){if(Array.isArray(l))return l.slice();if(!l)return[];var i=[];if(typeof l=="string")if(n){if(n==="hex")for((l=l.replace(/[^a-z0-9]+/gi,"")).length%2!=0&&(l="0"+l),c=0;c<l.length;c+=2)i.push(parseInt(l[c]+l[c+1],16))}else for(var f=0,c=0;c<l.length;c++){var u=l.charCodeAt(c);u<128?i[f++]=u:u<2048?(i[f++]=u>>6|192,i[f++]=63&u|128):o(l,c)?(u=65536+((1023&u)<<10)+(1023&l.charCodeAt(++c)),i[f++]=u>>18|240,i[f++]=u>>12&63|128,i[f++]=u>>6&63|128,i[f++]=63&u|128):(i[f++]=u>>12|224,i[f++]=u>>6&63|128,i[f++]=63&u|128)}else for(c=0;c<l.length;c++)i[c]=0|l[c];return i},S.toHex=function(l){for(var n="",i=0;i<l.length;i++)n+=t(l[i].toString(16));return n},S.htonl=r,S.toHex32=function(l,n){for(var i="",f=0;f<l.length;f++){var c=l[f];n==="little"&&(c=r(c)),i+=e(c.toString(16))}return i},S.zero2=t,S.zero8=e,S.join32=function(l,n,i,f){var c=i-n;m(c%4==0);for(var u=new Array(c/4),d=0,h=n;d<u.length;d++,h+=4){var w;w=f==="big"?l[h]<<24|l[h+1]<<16|l[h+2]<<8|l[h+3]:l[h+3]<<24|l[h+2]<<16|l[h+1]<<8|l[h],u[d]=w>>>0}return u},S.split32=function(l,n){for(var i=new Array(4*l.length),f=0,c=0;f<l.length;f++,c+=4){var u=l[f];n==="big"?(i[c]=u>>>24,i[c+1]=u>>>16&255,i[c+2]=u>>>8&255,i[c+3]=255&u):(i[c+3]=u>>>24,i[c+2]=u>>>16&255,i[c+1]=u>>>8&255,i[c]=255&u)}return i},S.rotr32=function(l,n){return l>>>n|l<<32-n},S.rotl32=function(l,n){return l<<n|l>>>32-n},S.sum32=function(l,n){return l+n>>>0},S.sum32_3=function(l,n,i){return l+n+i>>>0},S.sum32_4=function(l,n,i,f){return l+n+i+f>>>0},S.sum32_5=function(l,n,i,f,c){return l+n+i+f+c>>>0},S.sum64=function(l,n,i,f){var c=l[n],u=f+l[n+1]>>>0,d=(u<f?1:0)+i+c;l[n]=d>>>0,l[n+1]=u},S.sum64_hi=function(l,n,i,f){return(n+f>>>0<n?1:0)+l+i>>>0},S.sum64_lo=function(l,n,i,f){return n+f>>>0},S.sum64_4_hi=function(l,n,i,f,c,u,d,h){var w=0,_=n;return w+=(_=_+f>>>0)<n?1:0,w+=(_=_+u>>>0)<u?1:0,l+i+c+d+(w+=(_=_+h>>>0)<h?1:0)>>>0},S.sum64_4_lo=function(l,n,i,f,c,u,d,h){return n+f+u+h>>>0},S.sum64_5_hi=function(l,n,i,f,c,u,d,h,w,_){var A=0,N=n;return A+=(N=N+f>>>0)<n?1:0,A+=(N=N+u>>>0)<u?1:0,A+=(N=N+h>>>0)<h?1:0,l+i+c+d+w+(A+=(N=N+_>>>0)<_?1:0)>>>0},S.sum64_5_lo=function(l,n,i,f,c,u,d,h,w,_){return n+f+u+h+_>>>0},S.rotr64_hi=function(l,n,i){return(n<<32-i|l>>>i)>>>0},S.rotr64_lo=function(l,n,i){return(l<<32-i|n>>>i)>>>0},S.shr64_hi=function(l,n,i){return l>>>i},S.shr64_lo=function(l,n,i){return(l<<32-i|n>>>i)>>>0}},{inherits:440,"minimalistic-assert":453}],438:[function(s,T,S){var m=s("hash.js"),a=s("minimalistic-crypto-utils"),o=s("minimalistic-assert");function r(t){if(!(this instanceof r))return new r(t);this.hash=t.hash,this.predResist=!!t.predResist,this.outLen=this.hash.outSize,this.minEntropy=t.minEntropy||this.hash.hmacStrength,this._reseed=null,this.reseedInterval=null,this.K=null,this.V=null;var e=a.toArray(t.entropy,t.entropyEnc||"hex"),l=a.toArray(t.nonce,t.nonceEnc||"hex"),n=a.toArray(t.pers,t.persEnc||"hex");o(e.length>=this.minEntropy/8,"Not enough entropy. Minimum is: "+this.minEntropy+" bits"),this._init(e,l,n)}T.exports=r,r.prototype._init=function(t,e,l){var n=t.concat(e).concat(l);this.K=new Array(this.outLen/8),this.V=new Array(this.outLen/8);for(var i=0;i<this.V.length;i++)this.K[i]=0,this.V[i]=1;this._update(n),this._reseed=1,this.reseedInterval=281474976710656},r.prototype._hmac=function(){return new m.hmac(this.hash,this.K)},r.prototype._update=function(t){var e=this._hmac().update(this.V).update([0]);t&&(e=e.update(t)),this.K=e.digest(),this.V=this._hmac().update(this.V).digest(),t&&(this.K=this._hmac().update(this.V).update([1]).update(t).digest(),this.V=this._hmac().update(this.V).digest())},r.prototype.reseed=function(t,e,l,n){typeof e!="string"&&(n=l,l=e,e=null),t=a.toArray(t,e),l=a.toArray(l,n),o(t.length>=this.minEntropy/8,"Not enough entropy. Minimum is: "+this.minEntropy+" bits"),this._update(t.concat(l||[])),this._reseed=1},r.prototype.generate=function(t,e,l,n){if(this._reseed>this.reseedInterval)throw new Error("Reseed is required");typeof e!="string"&&(n=l,l=e,e=null),l&&(l=a.toArray(l,n||"hex"),this._update(l));for(var i=[];i.length<t;)this.V=this._hmac().update(this.V).digest(),i=i.concat(this.V);var f=i.slice(0,t);return this._update(l),this._reseed++,a.encode(f,e)}},{"hash.js":426,"minimalistic-assert":453,"minimalistic-crypto-utils":454}],439:[function(s,T,S){/*! ieee754. BSD-3-Clause License. Feross Aboukhadijeh <https://feross.org/opensource> */S.read=function(m,a,o,r,t){var e,l,n=8*t-r-1,i=(1<<n)-1,f=i>>1,c=-7,u=o?t-1:0,d=o?-1:1,h=m[a+u];for(u+=d,e=h&(1<<-c)-1,h>>=-c,c+=n;c>0;e=256*e+m[a+u],u+=d,c-=8);for(l=e&(1<<-c)-1,e>>=-c,c+=r;c>0;l=256*l+m[a+u],u+=d,c-=8);if(e===0)e=1-f;else{if(e===i)return l?NaN:1/0*(h?-1:1);l+=Math.pow(2,r),e-=f}return(h?-1:1)*l*Math.pow(2,e-r)},S.write=function(m,a,o,r,t,e){var l,n,i,f=8*e-t-1,c=(1<<f)-1,u=c>>1,d=t===23?Math.pow(2,-24)-Math.pow(2,-77):0,h=r?0:e-1,w=r?1:-1,_=a<0||a===0&&1/a<0?1:0;for(a=Math.abs(a),isNaN(a)||a===1/0?(n=isNaN(a)?1:0,l=c):(l=Math.floor(Math.log(a)/Math.LN2),a*(i=Math.pow(2,-l))<1&&(l--,i*=2),(a+=l+u>=1?d/i:d*Math.pow(2,1-u))*i>=2&&(l++,i/=2),l+u>=c?(n=0,l=c):l+u>=1?(n=(a*i-1)*Math.pow(2,t),l+=u):(n=a*Math.pow(2,u-1)*Math.pow(2,t),l=0));t>=8;m[o+h]=255&n,h+=w,n/=256,t-=8);for(l=l<<t|n,f+=t;f>0;m[o+h]=255&l,h+=w,l/=256,f-=8);m[o+h-w]|=128*_}},{}],440:[function(s,T,S){typeof Object.create=="function"?T.exports=function(m,a){a&&(m.super_=a,m.prototype=Object.create(a.prototype,{constructor:{value:m,enumerable:!1,writable:!0,configurable:!0}}))}:T.exports=function(m,a){if(a){m.super_=a;var o=function(){};o.prototype=a.prototype,m.prototype=new o,m.prototype.constructor=m}}},{}],441:[function(s,T,S){(function(m,a,o,r,t,e,l,n){(function(){/*!

	JSZip v3.10.1 - A JavaScript class for generating and reading zip files
	<http://stuartk.com/jszip>

	(c) 2009-2016 Stuart Knightley <stuart [at] stuartk.com>
	Dual licenced under the MIT license or GPLv3. See https://raw.github.com/Stuk/jszip/main/LICENSE.markdown.

	JSZip uses the library pako released under the MIT license :
	https://github.com/nodeca/pako/blob/main/LICENSE
	*/(function(i){typeof S=="object"&&T!==void 0?T.exports=i():(typeof window<"u"?window:a!==void 0?a:typeof self<"u"?self:this).JSZip=i()})(function(){return function i(f,c,u){function d(_,A){if(!c[_]){if(!f[_]){var N=typeof s=="function"&&s;if(!A&&N)return N(_,!0);if(h)return h(_,!0);var L=new Error("Cannot find module '"+_+"'");throw L.code="MODULE_NOT_FOUND",L}var I=c[_]={exports:{}};f[_][0].call(I.exports,function(P){return d(f[_][1][P]||P)},I,I.exports,i,f,c,u)}return c[_].exports}for(var h=typeof s=="function"&&s,w=0;w<u.length;w++)d(u[w]);return d}({1:[function(i,f,c){var u=i("./utils"),d=i("./support"),h="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";c.encode=function(w){for(var _,A,N,L,I,P,B,U=[],D=0,x=w.length,M=x,v=u.getTypeOf(w)!=="string";D<w.length;)M=x-D,N=v?(_=w[D++],A=D<x?w[D++]:0,D<x?w[D++]:0):(_=w.charCodeAt(D++),A=D<x?w.charCodeAt(D++):0,D<x?w.charCodeAt(D++):0),L=_>>2,I=(3&_)<<4|A>>4,P=1<M?(15&A)<<2|N>>6:64,B=2<M?63&N:64,U.push(h.charAt(L)+h.charAt(I)+h.charAt(P)+h.charAt(B));return U.join("")},c.decode=function(w){var _,A,N,L,I,P,B=0,U=0,D="data:";if(w.substr(0,D.length)===D)throw new Error("Invalid base64 input, it looks like a data url.");var x,M=3*(w=w.replace(/[^A-Za-z0-9+/=]/g,"")).length/4;if(w.charAt(w.length-1)===h.charAt(64)&&M--,w.charAt(w.length-2)===h.charAt(64)&&M--,M%1!=0)throw new Error("Invalid base64 input, bad content length.");for(x=d.uint8array?new Uint8Array(0|M):new Array(0|M);B<w.length;)_=h.indexOf(w.charAt(B++))<<2|(L=h.indexOf(w.charAt(B++)))>>4,A=(15&L)<<4|(I=h.indexOf(w.charAt(B++)))>>2,N=(3&I)<<6|(P=h.indexOf(w.charAt(B++))),x[U++]=_,I!==64&&(x[U++]=A),P!==64&&(x[U++]=N);return x}},{"./support":30,"./utils":32}],2:[function(i,f,c){var u=i("./external"),d=i("./stream/DataWorker"),h=i("./stream/Crc32Probe"),w=i("./stream/DataLengthProbe");function _(A,N,L,I,P){this.compressedSize=A,this.uncompressedSize=N,this.crc32=L,this.compression=I,this.compressedContent=P}_.prototype={getContentWorker:function(){var A=new d(u.Promise.resolve(this.compressedContent)).pipe(this.compression.uncompressWorker()).pipe(new w("data_length")),N=this;return A.on("end",function(){if(this.streamInfo.data_length!==N.uncompressedSize)throw new Error("Bug : uncompressed data size mismatch")}),A},getCompressedWorker:function(){return new d(u.Promise.resolve(this.compressedContent)).withStreamInfo("compressedSize",this.compressedSize).withStreamInfo("uncompressedSize",this.uncompressedSize).withStreamInfo("crc32",this.crc32).withStreamInfo("compression",this.compression)}},_.createWorkerFrom=function(A,N,L){return A.pipe(new h).pipe(new w("uncompressedSize")).pipe(N.compressWorker(L)).pipe(new w("compressedSize")).withStreamInfo("compression",N)},f.exports=_},{"./external":6,"./stream/Crc32Probe":25,"./stream/DataLengthProbe":26,"./stream/DataWorker":27}],3:[function(i,f,c){var u=i("./stream/GenericWorker");c.STORE={magic:"\0\0",compressWorker:function(){return new u("STORE compression")},uncompressWorker:function(){return new u("STORE decompression")}},c.DEFLATE=i("./flate")},{"./flate":7,"./stream/GenericWorker":28}],4:[function(i,f,c){var u=i("./utils"),d=function(){for(var h,w=[],_=0;_<256;_++){h=_;for(var A=0;A<8;A++)h=1&h?3988292384^h>>>1:h>>>1;w[_]=h}return w}();f.exports=function(h,w){return h!==void 0&&h.length?u.getTypeOf(h)!=="string"?function(_,A,N,L){var I=d,P=0+N;_^=-1;for(var B=0;B<P;B++)_=_>>>8^I[255&(_^A[B])];return-1^_}(0|w,h,h.length):function(_,A,N,L){var I=d,P=0+N;_^=-1;for(var B=0;B<P;B++)_=_>>>8^I[255&(_^A.charCodeAt(B))];return-1^_}(0|w,h,h.length):0}},{"./utils":32}],5:[function(i,f,c){c.base64=!1,c.binary=!1,c.dir=!1,c.createFolders=!0,c.date=null,c.compression=null,c.compressionOptions=null,c.comment=null,c.unixPermissions=null,c.dosPermissions=null},{}],6:[function(i,f,c){var u;u=typeof Promise<"u"?Promise:i("lie"),f.exports={Promise:u}},{lie:37}],7:[function(i,f,c){var u=typeof Uint8Array<"u"&&typeof Uint16Array<"u"&&typeof Uint32Array<"u",d=i("pako"),h=i("./utils"),w=i("./stream/GenericWorker"),_=u?"uint8array":"array";function A(N,L){w.call(this,"FlateWorker/"+N),this._pako=null,this._pakoAction=N,this._pakoOptions=L,this.meta={}}c.magic="\b\0",h.inherits(A,w),A.prototype.processChunk=function(N){this.meta=N.meta,this._pako===null&&this._createPako(),this._pako.push(h.transformTo(_,N.data),!1)},A.prototype.flush=function(){w.prototype.flush.call(this),this._pako===null&&this._createPako(),this._pako.push([],!0)},A.prototype.cleanUp=function(){w.prototype.cleanUp.call(this),this._pako=null},A.prototype._createPako=function(){this._pako=new d[this._pakoAction]({raw:!0,level:this._pakoOptions.level||-1});var N=this;this._pako.onData=function(L){N.push({data:L,meta:N.meta})}},c.compressWorker=function(N){return new A("Deflate",N)},c.uncompressWorker=function(){return new A("Inflate",{})}},{"./stream/GenericWorker":28,"./utils":32,pako:38}],8:[function(i,f,c){function u(I,P){var B,U="";for(B=0;B<P;B++)U+=String.fromCharCode(255&I),I>>>=8;return U}function d(I,P,B,U,D,x){var M,v,p=I.file,b=I.compression,g=x!==_.utf8encode,y=h.transformTo("string",x(p.name)),k=h.transformTo("string",_.utf8encode(p.name)),R=p.comment,O=h.transformTo("string",x(R)),z=h.transformTo("string",_.utf8encode(R)),$=k.length!==p.name.length,W=z.length!==R.length,j="",H="",E="",C=p.dir,F=p.date,V={crc32:0,compressedSize:0,uncompressedSize:0};P&&!B||(V.crc32=I.crc32,V.compressedSize=I.compressedSize,V.uncompressedSize=I.uncompressedSize);var Z=0;P&&(Z|=8),g||!$&&!W||(Z|=2048);var q=0,K=0;C&&(q|=16),D==="UNIX"?(K=798,q|=function(tt,X){var J=tt;return tt||(J=X?16893:33204),(65535&J)<<16}(p.unixPermissions,C)):(K=20,q|=function(tt){return 63&(tt||0)}(p.dosPermissions)),M=F.getUTCHours(),M<<=6,M|=F.getUTCMinutes(),M<<=5,M|=F.getUTCSeconds()/2,v=F.getUTCFullYear()-1980,v<<=4,v|=F.getUTCMonth()+1,v<<=5,v|=F.getUTCDate(),$&&(H=u(1,1)+u(A(y),4)+k,j+="up"+u(H.length,2)+H),W&&(E=u(1,1)+u(A(O),4)+z,j+="uc"+u(E.length,2)+E);var et="";return et+=`
\0`,et+=u(Z,2),et+=b.magic,et+=u(M,2),et+=u(v,2),et+=u(V.crc32,4),et+=u(V.compressedSize,4),et+=u(V.uncompressedSize,4),et+=u(y.length,2),et+=u(j.length,2),{fileRecord:N.LOCAL_FILE_HEADER+et+y+j,dirRecord:N.CENTRAL_FILE_HEADER+u(K,2)+et+u(O.length,2)+"\0\0\0\0"+u(q,4)+u(U,4)+y+j+O}}var h=i("../utils"),w=i("../stream/GenericWorker"),_=i("../utf8"),A=i("../crc32"),N=i("../signature");function L(I,P,B,U){w.call(this,"ZipFileWorker"),this.bytesWritten=0,this.zipComment=P,this.zipPlatform=B,this.encodeFileName=U,this.streamFiles=I,this.accumulate=!1,this.contentBuffer=[],this.dirRecords=[],this.currentSourceOffset=0,this.entriesCount=0,this.currentFile=null,this._sources=[]}h.inherits(L,w),L.prototype.push=function(I){var P=I.meta.percent||0,B=this.entriesCount,U=this._sources.length;this.accumulate?this.contentBuffer.push(I):(this.bytesWritten+=I.data.length,w.prototype.push.call(this,{data:I.data,meta:{currentFile:this.currentFile,percent:B?(P+100*(B-U-1))/B:100}}))},L.prototype.openedSource=function(I){this.currentSourceOffset=this.bytesWritten,this.currentFile=I.file.name;var P=this.streamFiles&&!I.file.dir;if(P){var B=d(I,P,!1,this.currentSourceOffset,this.zipPlatform,this.encodeFileName);this.push({data:B.fileRecord,meta:{percent:0}})}else this.accumulate=!0},L.prototype.closedSource=function(I){this.accumulate=!1;var P=this.streamFiles&&!I.file.dir,B=d(I,P,!0,this.currentSourceOffset,this.zipPlatform,this.encodeFileName);if(this.dirRecords.push(B.dirRecord),P)this.push({data:function(U){return N.DATA_DESCRIPTOR+u(U.crc32,4)+u(U.compressedSize,4)+u(U.uncompressedSize,4)}(I),meta:{percent:100}});else for(this.push({data:B.fileRecord,meta:{percent:0}});this.contentBuffer.length;)this.push(this.contentBuffer.shift());this.currentFile=null},L.prototype.flush=function(){for(var I=this.bytesWritten,P=0;P<this.dirRecords.length;P++)this.push({data:this.dirRecords[P],meta:{percent:100}});var B=this.bytesWritten-I,U=function(D,x,M,v,p){var b=h.transformTo("string",p(v));return N.CENTRAL_DIRECTORY_END+"\0\0\0\0"+u(D,2)+u(D,2)+u(x,4)+u(M,4)+u(b.length,2)+b}(this.dirRecords.length,B,I,this.zipComment,this.encodeFileName);this.push({data:U,meta:{percent:100}})},L.prototype.prepareNextSource=function(){this.previous=this._sources.shift(),this.openedSource(this.previous.streamInfo),this.isPaused?this.previous.pause():this.previous.resume()},L.prototype.registerPrevious=function(I){this._sources.push(I);var P=this;return I.on("data",function(B){P.processChunk(B)}),I.on("end",function(){P.closedSource(P.previous.streamInfo),P._sources.length?P.prepareNextSource():P.end()}),I.on("error",function(B){P.error(B)}),this},L.prototype.resume=function(){return!!w.prototype.resume.call(this)&&(!this.previous&&this._sources.length?(this.prepareNextSource(),!0):this.previous||this._sources.length||this.generatedError?void 0:(this.end(),!0))},L.prototype.error=function(I){var P=this._sources;if(!w.prototype.error.call(this,I))return!1;for(var B=0;B<P.length;B++)try{P[B].error(I)}catch{}return!0},L.prototype.lock=function(){w.prototype.lock.call(this);for(var I=this._sources,P=0;P<I.length;P++)I[P].lock()},f.exports=L},{"../crc32":4,"../signature":23,"../stream/GenericWorker":28,"../utf8":31,"../utils":32}],9:[function(i,f,c){var u=i("../compressions"),d=i("./ZipFileWorker");c.generateWorker=function(h,w,_){var A=new d(w.streamFiles,_,w.platform,w.encodeFileName),N=0;try{h.forEach(function(L,I){N++;var P=function(x,M){var v=x||M,p=u[v];if(!p)throw new Error(v+" is not a valid compression method !");return p}(I.options.compression,w.compression),B=I.options.compressionOptions||w.compressionOptions||{},U=I.dir,D=I.date;I._compressWorker(P,B).withStreamInfo("file",{name:L,dir:U,date:D,comment:I.comment||"",unixPermissions:I.unixPermissions,dosPermissions:I.dosPermissions}).pipe(A)}),A.entriesCount=N}catch(L){A.error(L)}return A}},{"../compressions":3,"./ZipFileWorker":8}],10:[function(i,f,c){function u(){if(!(this instanceof u))return new u;if(arguments.length)throw new Error("The constructor with parameters has been removed in JSZip 3.0, please check the upgrade guide.");this.files=Object.create(null),this.comment=null,this.root="",this.clone=function(){var d=new u;for(var h in this)typeof this[h]!="function"&&(d[h]=this[h]);return d}}(u.prototype=i("./object")).loadAsync=i("./load"),u.support=i("./support"),u.defaults=i("./defaults"),u.version="3.10.1",u.loadAsync=function(d,h){return new u().loadAsync(d,h)},u.external=i("./external"),f.exports=u},{"./defaults":5,"./external":6,"./load":11,"./object":15,"./support":30}],11:[function(i,f,c){var u=i("./utils"),d=i("./external"),h=i("./utf8"),w=i("./zipEntries"),_=i("./stream/Crc32Probe"),A=i("./nodejsUtils");function N(L){return new d.Promise(function(I,P){var B=L.decompressed.getContentWorker().pipe(new _);B.on("error",function(U){P(U)}).on("end",function(){B.streamInfo.crc32!==L.decompressed.crc32?P(new Error("Corrupted zip : CRC32 mismatch")):I()}).resume()})}f.exports=function(L,I){var P=this;return I=u.extend(I||{},{base64:!1,checkCRC32:!1,optimizedBinaryString:!1,createFolders:!1,decodeFileName:h.utf8decode}),A.isNode&&A.isStream(L)?d.Promise.reject(new Error("JSZip can't accept a stream when loading a zip file.")):u.prepareContent("the loaded zip file",L,!0,I.optimizedBinaryString,I.base64).then(function(B){var U=new w(I);return U.load(B),U}).then(function(B){var U=[d.Promise.resolve(B)],D=B.files;if(I.checkCRC32)for(var x=0;x<D.length;x++)U.push(N(D[x]));return d.Promise.all(U)}).then(function(B){for(var U=B.shift(),D=U.files,x=0;x<D.length;x++){var M=D[x],v=M.fileNameStr,p=u.resolve(M.fileNameStr);P.file(p,M.decompressed,{binary:!0,optimizedBinaryString:!0,date:M.date,dir:M.dir,comment:M.fileCommentStr.length?M.fileCommentStr:null,unixPermissions:M.unixPermissions,dosPermissions:M.dosPermissions,createFolders:I.createFolders}),M.dir||(P.file(p).unsafeOriginalName=v)}return U.zipComment.length&&(P.comment=U.zipComment),P})}},{"./external":6,"./nodejsUtils":14,"./stream/Crc32Probe":25,"./utf8":31,"./utils":32,"./zipEntries":33}],12:[function(i,f,c){var u=i("../utils"),d=i("../stream/GenericWorker");function h(w,_){d.call(this,"Nodejs stream input adapter for "+w),this._upstreamEnded=!1,this._bindStream(_)}u.inherits(h,d),h.prototype._bindStream=function(w){var _=this;(this._stream=w).pause(),w.on("data",function(A){_.push({data:A,meta:{percent:0}})}).on("error",function(A){_.isPaused?this.generatedError=A:_.error(A)}).on("end",function(){_.isPaused?_._upstreamEnded=!0:_.end()})},h.prototype.pause=function(){return!!d.prototype.pause.call(this)&&(this._stream.pause(),!0)},h.prototype.resume=function(){return!!d.prototype.resume.call(this)&&(this._upstreamEnded?this.end():this._stream.resume(),!0)},f.exports=h},{"../stream/GenericWorker":28,"../utils":32}],13:[function(i,f,c){var u=i("readable-stream").Readable;function d(h,w,_){u.call(this,w),this._helper=h;var A=this;h.on("data",function(N,L){A.push(N)||A._helper.pause(),_&&_(L)}).on("error",function(N){A.emit("error",N)}).on("end",function(){A.push(null)})}i("../utils").inherits(d,u),d.prototype._read=function(){this._helper.resume()},f.exports=d},{"../utils":32,"readable-stream":16}],14:[function(i,f,c){f.exports={isNode:o!==void 0,newBufferFrom:function(u,d){if(o.from&&o.from!==Uint8Array.from)return o.from(u,d);if(typeof u=="number")throw new Error('The "data" argument must not be a number');return new o(u,d)},allocBuffer:function(u){if(o.alloc)return o.alloc(u);var d=new o(u);return d.fill(0),d},isBuffer:function(u){return o.isBuffer(u)},isStream:function(u){return u&&typeof u.on=="function"&&typeof u.pause=="function"&&typeof u.resume=="function"}}},{}],15:[function(i,f,c){function u(p,b,g){var y,k=h.getTypeOf(b),R=h.extend(g||{},A);R.date=R.date||new Date,R.compression!==null&&(R.compression=R.compression.toUpperCase()),typeof R.unixPermissions=="string"&&(R.unixPermissions=parseInt(R.unixPermissions,8)),R.unixPermissions&&16384&R.unixPermissions&&(R.dir=!0),R.dosPermissions&&16&R.dosPermissions&&(R.dir=!0),R.dir&&(p=D(p)),R.createFolders&&(y=U(p))&&x.call(this,y,!0);var O=k==="string"&&R.binary===!1&&R.base64===!1;g&&g.binary!==void 0||(R.binary=!O),(b instanceof N&&b.uncompressedSize===0||R.dir||!b||b.length===0)&&(R.base64=!1,R.binary=!0,b="",R.compression="STORE",k="string");var z;z=b instanceof N||b instanceof w?b:P.isNode&&P.isStream(b)?new B(p,b):h.prepareContent(p,b,R.binary,R.optimizedBinaryString,R.base64);var $=new L(p,z,R);this.files[p]=$}var d=i("./utf8"),h=i("./utils"),w=i("./stream/GenericWorker"),_=i("./stream/StreamHelper"),A=i("./defaults"),N=i("./compressedObject"),L=i("./zipObject"),I=i("./generate"),P=i("./nodejsUtils"),B=i("./nodejs/NodejsStreamInputAdapter"),U=function(p){p.slice(-1)==="/"&&(p=p.substring(0,p.length-1));var b=p.lastIndexOf("/");return 0<b?p.substring(0,b):""},D=function(p){return p.slice(-1)!=="/"&&(p+="/"),p},x=function(p,b){return b=b!==void 0?b:A.createFolders,p=D(p),this.files[p]||u.call(this,p,null,{dir:!0,createFolders:b}),this.files[p]};function M(p){return Object.prototype.toString.call(p)==="[object RegExp]"}var v={load:function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},forEach:function(p){var b,g,y;for(b in this.files)y=this.files[b],(g=b.slice(this.root.length,b.length))&&b.slice(0,this.root.length)===this.root&&p(g,y)},filter:function(p){var b=[];return this.forEach(function(g,y){p(g,y)&&b.push(y)}),b},file:function(p,b,g){if(arguments.length!==1)return p=this.root+p,u.call(this,p,b,g),this;if(M(p)){var y=p;return this.filter(function(R,O){return!O.dir&&y.test(R)})}var k=this.files[this.root+p];return k&&!k.dir?k:null},folder:function(p){if(!p)return this;if(M(p))return this.filter(function(k,R){return R.dir&&p.test(k)});var b=this.root+p,g=x.call(this,b),y=this.clone();return y.root=g.name,y},remove:function(p){p=this.root+p;var b=this.files[p];if(b||(p.slice(-1)!=="/"&&(p+="/"),b=this.files[p]),b&&!b.dir)delete this.files[p];else for(var g=this.filter(function(k,R){return R.name.slice(0,p.length)===p}),y=0;y<g.length;y++)delete this.files[g[y].name];return this},generate:function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},generateInternalStream:function(p){var b,g={};try{if((g=h.extend(p||{},{streamFiles:!1,compression:"STORE",compressionOptions:null,type:"",platform:"DOS",comment:null,mimeType:"application/zip",encodeFileName:d.utf8encode})).type=g.type.toLowerCase(),g.compression=g.compression.toUpperCase(),g.type==="binarystring"&&(g.type="string"),!g.type)throw new Error("No output type specified.");h.checkSupport(g.type),g.platform!=="darwin"&&g.platform!=="freebsd"&&g.platform!=="linux"&&g.platform!=="sunos"||(g.platform="UNIX"),g.platform==="win32"&&(g.platform="DOS");var y=g.comment||this.comment||"";b=I.generateWorker(this,g,y)}catch(k){(b=new w("error")).error(k)}return new _(b,g.type||"string",g.mimeType)},generateAsync:function(p,b){return this.generateInternalStream(p).accumulate(b)},generateNodeStream:function(p,b){return(p=p||{}).type||(p.type="nodebuffer"),this.generateInternalStream(p).toNodejsStream(b)}};f.exports=v},{"./compressedObject":2,"./defaults":5,"./generate":9,"./nodejs/NodejsStreamInputAdapter":12,"./nodejsUtils":14,"./stream/GenericWorker":28,"./stream/StreamHelper":29,"./utf8":31,"./utils":32,"./zipObject":35}],16:[function(i,f,c){f.exports=i("stream")},{stream:void 0}],17:[function(i,f,c){var u=i("./DataReader");function d(h){u.call(this,h);for(var w=0;w<this.data.length;w++)h[w]=255&h[w]}i("../utils").inherits(d,u),d.prototype.byteAt=function(h){return this.data[this.zero+h]},d.prototype.lastIndexOfSignature=function(h){for(var w=h.charCodeAt(0),_=h.charCodeAt(1),A=h.charCodeAt(2),N=h.charCodeAt(3),L=this.length-4;0<=L;--L)if(this.data[L]===w&&this.data[L+1]===_&&this.data[L+2]===A&&this.data[L+3]===N)return L-this.zero;return-1},d.prototype.readAndCheckSignature=function(h){var w=h.charCodeAt(0),_=h.charCodeAt(1),A=h.charCodeAt(2),N=h.charCodeAt(3),L=this.readData(4);return w===L[0]&&_===L[1]&&A===L[2]&&N===L[3]},d.prototype.readData=function(h){if(this.checkOffset(h),h===0)return[];var w=this.data.slice(this.zero+this.index,this.zero+this.index+h);return this.index+=h,w},f.exports=d},{"../utils":32,"./DataReader":18}],18:[function(i,f,c){var u=i("../utils");function d(h){this.data=h,this.length=h.length,this.index=0,this.zero=0}d.prototype={checkOffset:function(h){this.checkIndex(this.index+h)},checkIndex:function(h){if(this.length<this.zero+h||h<0)throw new Error("End of data reached (data length = "+this.length+", asked index = "+h+"). Corrupted zip ?")},setIndex:function(h){this.checkIndex(h),this.index=h},skip:function(h){this.setIndex(this.index+h)},byteAt:function(){},readInt:function(h){var w,_=0;for(this.checkOffset(h),w=this.index+h-1;w>=this.index;w--)_=(_<<8)+this.byteAt(w);return this.index+=h,_},readString:function(h){return u.transformTo("string",this.readData(h))},readData:function(){},lastIndexOfSignature:function(){},readAndCheckSignature:function(){},readDate:function(){var h=this.readInt(4);return new Date(Date.UTC(1980+(h>>25&127),(h>>21&15)-1,h>>16&31,h>>11&31,h>>5&63,(31&h)<<1))}},f.exports=d},{"../utils":32}],19:[function(i,f,c){var u=i("./Uint8ArrayReader");function d(h){u.call(this,h)}i("../utils").inherits(d,u),d.prototype.readData=function(h){this.checkOffset(h);var w=this.data.slice(this.zero+this.index,this.zero+this.index+h);return this.index+=h,w},f.exports=d},{"../utils":32,"./Uint8ArrayReader":21}],20:[function(i,f,c){var u=i("./DataReader");function d(h){u.call(this,h)}i("../utils").inherits(d,u),d.prototype.byteAt=function(h){return this.data.charCodeAt(this.zero+h)},d.prototype.lastIndexOfSignature=function(h){return this.data.lastIndexOf(h)-this.zero},d.prototype.readAndCheckSignature=function(h){return h===this.readData(4)},d.prototype.readData=function(h){this.checkOffset(h);var w=this.data.slice(this.zero+this.index,this.zero+this.index+h);return this.index+=h,w},f.exports=d},{"../utils":32,"./DataReader":18}],21:[function(i,f,c){var u=i("./ArrayReader");function d(h){u.call(this,h)}i("../utils").inherits(d,u),d.prototype.readData=function(h){if(this.checkOffset(h),h===0)return new Uint8Array(0);var w=this.data.subarray(this.zero+this.index,this.zero+this.index+h);return this.index+=h,w},f.exports=d},{"../utils":32,"./ArrayReader":17}],22:[function(i,f,c){var u=i("../utils"),d=i("../support"),h=i("./ArrayReader"),w=i("./StringReader"),_=i("./NodeBufferReader"),A=i("./Uint8ArrayReader");f.exports=function(N){var L=u.getTypeOf(N);return u.checkSupport(L),L!=="string"||d.uint8array?L==="nodebuffer"?new _(N):d.uint8array?new A(u.transformTo("uint8array",N)):new h(u.transformTo("array",N)):new w(N)}},{"../support":30,"../utils":32,"./ArrayReader":17,"./NodeBufferReader":19,"./StringReader":20,"./Uint8ArrayReader":21}],23:[function(i,f,c){c.LOCAL_FILE_HEADER="PK",c.CENTRAL_FILE_HEADER="PK",c.CENTRAL_DIRECTORY_END="PK",c.ZIP64_CENTRAL_DIRECTORY_LOCATOR="PK\x07",c.ZIP64_CENTRAL_DIRECTORY_END="PK",c.DATA_DESCRIPTOR="PK\x07\b"},{}],24:[function(i,f,c){var u=i("./GenericWorker"),d=i("../utils");function h(w){u.call(this,"ConvertWorker to "+w),this.destType=w}d.inherits(h,u),h.prototype.processChunk=function(w){this.push({data:d.transformTo(this.destType,w.data),meta:w.meta})},f.exports=h},{"../utils":32,"./GenericWorker":28}],25:[function(i,f,c){var u=i("./GenericWorker"),d=i("../crc32");function h(){u.call(this,"Crc32Probe"),this.withStreamInfo("crc32",0)}i("../utils").inherits(h,u),h.prototype.processChunk=function(w){this.streamInfo.crc32=d(w.data,this.streamInfo.crc32||0),this.push(w)},f.exports=h},{"../crc32":4,"../utils":32,"./GenericWorker":28}],26:[function(i,f,c){var u=i("../utils"),d=i("./GenericWorker");function h(w){d.call(this,"DataLengthProbe for "+w),this.propName=w,this.withStreamInfo(w,0)}u.inherits(h,d),h.prototype.processChunk=function(w){if(w){var _=this.streamInfo[this.propName]||0;this.streamInfo[this.propName]=_+w.data.length}d.prototype.processChunk.call(this,w)},f.exports=h},{"../utils":32,"./GenericWorker":28}],27:[function(i,f,c){var u=i("../utils"),d=i("./GenericWorker");function h(w){d.call(this,"DataWorker");var _=this;this.dataIsReady=!1,this.index=0,this.max=0,this.data=null,this.type="",this._tickScheduled=!1,w.then(function(A){_.dataIsReady=!0,_.data=A,_.max=A&&A.length||0,_.type=u.getTypeOf(A),_.isPaused||_._tickAndRepeat()},function(A){_.error(A)})}u.inherits(h,d),h.prototype.cleanUp=function(){d.prototype.cleanUp.call(this),this.data=null},h.prototype.resume=function(){return!!d.prototype.resume.call(this)&&(!this._tickScheduled&&this.dataIsReady&&(this._tickScheduled=!0,u.delay(this._tickAndRepeat,[],this)),!0)},h.prototype._tickAndRepeat=function(){this._tickScheduled=!1,this.isPaused||this.isFinished||(this._tick(),this.isFinished||(u.delay(this._tickAndRepeat,[],this),this._tickScheduled=!0))},h.prototype._tick=function(){if(this.isPaused||this.isFinished)return!1;var w=null,_=Math.min(this.max,this.index+16384);if(this.index>=this.max)return this.end();switch(this.type){case"string":w=this.data.substring(this.index,_);break;case"uint8array":w=this.data.subarray(this.index,_);break;case"array":case"nodebuffer":w=this.data.slice(this.index,_)}return this.index=_,this.push({data:w,meta:{percent:this.max?this.index/this.max*100:0}})},f.exports=h},{"../utils":32,"./GenericWorker":28}],28:[function(i,f,c){function u(d){this.name=d||"default",this.streamInfo={},this.generatedError=null,this.extraStreamInfo={},this.isPaused=!0,this.isFinished=!1,this.isLocked=!1,this._listeners={data:[],end:[],error:[]},this.previous=null}u.prototype={push:function(d){this.emit("data",d)},end:function(){if(this.isFinished)return!1;this.flush();try{this.emit("end"),this.cleanUp(),this.isFinished=!0}catch(d){this.emit("error",d)}return!0},error:function(d){return!this.isFinished&&(this.isPaused?this.generatedError=d:(this.isFinished=!0,this.emit("error",d),this.previous&&this.previous.error(d),this.cleanUp()),!0)},on:function(d,h){return this._listeners[d].push(h),this},cleanUp:function(){this.streamInfo=this.generatedError=this.extraStreamInfo=null,this._listeners=[]},emit:function(d,h){if(this._listeners[d])for(var w=0;w<this._listeners[d].length;w++)this._listeners[d][w].call(this,h)},pipe:function(d){return d.registerPrevious(this)},registerPrevious:function(d){if(this.isLocked)throw new Error("The stream '"+this+"' has already been used.");this.streamInfo=d.streamInfo,this.mergeStreamInfo(),this.previous=d;var h=this;return d.on("data",function(w){h.processChunk(w)}),d.on("end",function(){h.end()}),d.on("error",function(w){h.error(w)}),this},pause:function(){return!this.isPaused&&!this.isFinished&&(this.isPaused=!0,this.previous&&this.previous.pause(),!0)},resume:function(){if(!this.isPaused||this.isFinished)return!1;var d=this.isPaused=!1;return this.generatedError&&(this.error(this.generatedError),d=!0),this.previous&&this.previous.resume(),!d},flush:function(){},processChunk:function(d){this.push(d)},withStreamInfo:function(d,h){return this.extraStreamInfo[d]=h,this.mergeStreamInfo(),this},mergeStreamInfo:function(){for(var d in this.extraStreamInfo)Object.prototype.hasOwnProperty.call(this.extraStreamInfo,d)&&(this.streamInfo[d]=this.extraStreamInfo[d])},lock:function(){if(this.isLocked)throw new Error("The stream '"+this+"' has already been used.");this.isLocked=!0,this.previous&&this.previous.lock()},toString:function(){var d="Worker "+this.name;return this.previous?this.previous+" -> "+d:d}},f.exports=u},{}],29:[function(i,f,c){var u=i("../utils"),d=i("./ConvertWorker"),h=i("./GenericWorker"),w=i("../base64"),_=i("../support"),A=i("../external"),N=null;if(_.nodestream)try{N=i("../nodejs/NodejsStreamOutputAdapter")}catch{}function L(I,P,B){var U=P;switch(P){case"blob":case"arraybuffer":U="uint8array";break;case"base64":U="string"}try{this._internalType=U,this._outputType=P,this._mimeType=B,u.checkSupport(U),this._worker=I.pipe(new d(U)),I.lock()}catch(D){this._worker=new h("error"),this._worker.error(D)}}L.prototype={accumulate:function(I){return function(P,B){return new A.Promise(function(U,D){var x=[],M=P._internalType,v=P._outputType,p=P._mimeType;P.on("data",function(b,g){x.push(b),B&&B(g)}).on("error",function(b){x=[],D(b)}).on("end",function(){try{var b=function(g,y,k){switch(g){case"blob":return u.newBlob(u.transformTo("arraybuffer",y),k);case"base64":return w.encode(y);default:return u.transformTo(g,y)}}(v,function(g,y){var k,R=0,O=null,z=0;for(k=0;k<y.length;k++)z+=y[k].length;switch(g){case"string":return y.join("");case"array":return Array.prototype.concat.apply([],y);case"uint8array":for(O=new Uint8Array(z),k=0;k<y.length;k++)O.set(y[k],R),R+=y[k].length;return O;case"nodebuffer":return o.concat(y);default:throw new Error("concat : unsupported type '"+g+"'")}}(M,x),p);U(b)}catch(g){D(g)}x=[]}).resume()})}(this,I)},on:function(I,P){var B=this;return I==="data"?this._worker.on(I,function(U){P.call(B,U.data,U.meta)}):this._worker.on(I,function(){u.delay(P,arguments,B)}),this},resume:function(){return u.delay(this._worker.resume,[],this._worker),this},pause:function(){return this._worker.pause(),this},toNodejsStream:function(I){if(u.checkSupport("nodestream"),this._outputType!=="nodebuffer")throw new Error(this._outputType+" is not supported by this method");return new N(this,{objectMode:this._outputType!=="nodebuffer"},I)}},f.exports=L},{"../base64":1,"../external":6,"../nodejs/NodejsStreamOutputAdapter":13,"../support":30,"../utils":32,"./ConvertWorker":24,"./GenericWorker":28}],30:[function(i,f,c){if(c.base64=!0,c.array=!0,c.string=!0,c.arraybuffer=typeof ArrayBuffer<"u"&&typeof Uint8Array<"u",c.nodebuffer=o!==void 0,c.uint8array=typeof Uint8Array<"u",typeof ArrayBuffer>"u")c.blob=!1;else{var u=new ArrayBuffer(0);try{c.blob=new Blob([u],{type:"application/zip"}).size===0}catch{try{var d=new(self.BlobBuilder||self.WebKitBlobBuilder||self.MozBlobBuilder||self.MSBlobBuilder);d.append(u),c.blob=d.getBlob("application/zip").size===0}catch{c.blob=!1}}}try{c.nodestream=!!i("readable-stream").Readable}catch{c.nodestream=!1}},{"readable-stream":16}],31:[function(i,f,c){for(var u=i("./utils"),d=i("./support"),h=i("./nodejsUtils"),w=i("./stream/GenericWorker"),_=new Array(256),A=0;A<256;A++)_[A]=252<=A?6:248<=A?5:240<=A?4:224<=A?3:192<=A?2:1;function N(){w.call(this,"utf-8 decode"),this.leftOver=null}function L(){w.call(this,"utf-8 encode")}_[254]=_[254]=1,c.utf8encode=function(I){return d.nodebuffer?h.newBufferFrom(I,"utf-8"):function(P){var B,U,D,x,M,v=P.length,p=0;for(x=0;x<v;x++)(64512&(U=P.charCodeAt(x)))==55296&&x+1<v&&(64512&(D=P.charCodeAt(x+1)))==56320&&(U=65536+(U-55296<<10)+(D-56320),x++),p+=U<128?1:U<2048?2:U<65536?3:4;for(B=d.uint8array?new Uint8Array(p):new Array(p),x=M=0;M<p;x++)(64512&(U=P.charCodeAt(x)))==55296&&x+1<v&&(64512&(D=P.charCodeAt(x+1)))==56320&&(U=65536+(U-55296<<10)+(D-56320),x++),U<128?B[M++]=U:(U<2048?B[M++]=192|U>>>6:(U<65536?B[M++]=224|U>>>12:(B[M++]=240|U>>>18,B[M++]=128|U>>>12&63),B[M++]=128|U>>>6&63),B[M++]=128|63&U);return B}(I)},c.utf8decode=function(I){return d.nodebuffer?u.transformTo("nodebuffer",I).toString("utf-8"):function(P){var B,U,D,x,M=P.length,v=new Array(2*M);for(B=U=0;B<M;)if((D=P[B++])<128)v[U++]=D;else if(4<(x=_[D]))v[U++]=65533,B+=x-1;else{for(D&=x===2?31:x===3?15:7;1<x&&B<M;)D=D<<6|63&P[B++],x--;1<x?v[U++]=65533:D<65536?v[U++]=D:(D-=65536,v[U++]=55296|D>>10&1023,v[U++]=56320|1023&D)}return v.length!==U&&(v.subarray?v=v.subarray(0,U):v.length=U),u.applyFromCharCode(v)}(I=u.transformTo(d.uint8array?"uint8array":"array",I))},u.inherits(N,w),N.prototype.processChunk=function(I){var P=u.transformTo(d.uint8array?"uint8array":"array",I.data);if(this.leftOver&&this.leftOver.length){if(d.uint8array){var B=P;(P=new Uint8Array(B.length+this.leftOver.length)).set(this.leftOver,0),P.set(B,this.leftOver.length)}else P=this.leftOver.concat(P);this.leftOver=null}var U=function(x,M){var v;for((M=M||x.length)>x.length&&(M=x.length),v=M-1;0<=v&&(192&x[v])==128;)v--;return v<0||v===0?M:v+_[x[v]]>M?v:M}(P),D=P;U!==P.length&&(d.uint8array?(D=P.subarray(0,U),this.leftOver=P.subarray(U,P.length)):(D=P.slice(0,U),this.leftOver=P.slice(U,P.length))),this.push({data:c.utf8decode(D),meta:I.meta})},N.prototype.flush=function(){this.leftOver&&this.leftOver.length&&(this.push({data:c.utf8decode(this.leftOver),meta:{}}),this.leftOver=null)},c.Utf8DecodeWorker=N,u.inherits(L,w),L.prototype.processChunk=function(I){this.push({data:c.utf8encode(I.data),meta:I.meta})},c.Utf8EncodeWorker=L},{"./nodejsUtils":14,"./stream/GenericWorker":28,"./support":30,"./utils":32}],32:[function(i,f,c){var u=i("./support"),d=i("./base64"),h=i("./nodejsUtils"),w=i("./external");function _(B){return B}function A(B,U){for(var D=0;D<B.length;++D)U[D]=255&B.charCodeAt(D);return U}i("setimmediate"),c.newBlob=function(B,U){c.checkSupport("blob");try{return new Blob([B],{type:U})}catch{try{var D=new(self.BlobBuilder||self.WebKitBlobBuilder||self.MozBlobBuilder||self.MSBlobBuilder);return D.append(B),D.getBlob(U)}catch{throw new Error("Bug : can't construct the Blob.")}}};var N={stringifyByChunk:function(B,U,D){var x=[],M=0,v=B.length;if(v<=D)return String.fromCharCode.apply(null,B);for(;M<v;)U==="array"||U==="nodebuffer"?x.push(String.fromCharCode.apply(null,B.slice(M,Math.min(M+D,v)))):x.push(String.fromCharCode.apply(null,B.subarray(M,Math.min(M+D,v)))),M+=D;return x.join("")},stringifyByChar:function(B){for(var U="",D=0;D<B.length;D++)U+=String.fromCharCode(B[D]);return U},applyCanBeUsed:{uint8array:function(){try{return u.uint8array&&String.fromCharCode.apply(null,new Uint8Array(1)).length===1}catch{return!1}}(),nodebuffer:function(){try{return u.nodebuffer&&String.fromCharCode.apply(null,h.allocBuffer(1)).length===1}catch{return!1}}()}};function L(B){var U=65536,D=c.getTypeOf(B),x=!0;if(D==="uint8array"?x=N.applyCanBeUsed.uint8array:D==="nodebuffer"&&(x=N.applyCanBeUsed.nodebuffer),x)for(;1<U;)try{return N.stringifyByChunk(B,D,U)}catch{U=Math.floor(U/2)}return N.stringifyByChar(B)}function I(B,U){for(var D=0;D<B.length;D++)U[D]=B[D];return U}c.applyFromCharCode=L;var P={};P.string={string:_,array:function(B){return A(B,new Array(B.length))},arraybuffer:function(B){return P.string.uint8array(B).buffer},uint8array:function(B){return A(B,new Uint8Array(B.length))},nodebuffer:function(B){return A(B,h.allocBuffer(B.length))}},P.array={string:L,array:_,arraybuffer:function(B){return new Uint8Array(B).buffer},uint8array:function(B){return new Uint8Array(B)},nodebuffer:function(B){return h.newBufferFrom(B)}},P.arraybuffer={string:function(B){return L(new Uint8Array(B))},array:function(B){return I(new Uint8Array(B),new Array(B.byteLength))},arraybuffer:_,uint8array:function(B){return new Uint8Array(B)},nodebuffer:function(B){return h.newBufferFrom(new Uint8Array(B))}},P.uint8array={string:L,array:function(B){return I(B,new Array(B.length))},arraybuffer:function(B){return B.buffer},uint8array:_,nodebuffer:function(B){return h.newBufferFrom(B)}},P.nodebuffer={string:L,array:function(B){return I(B,new Array(B.length))},arraybuffer:function(B){return P.nodebuffer.uint8array(B).buffer},uint8array:function(B){return I(B,new Uint8Array(B.length))},nodebuffer:_},c.transformTo=function(B,U){if(U=U||"",!B)return U;c.checkSupport(B);var D=c.getTypeOf(U);return P[D][B](U)},c.resolve=function(B){for(var U=B.split("/"),D=[],x=0;x<U.length;x++){var M=U[x];M==="."||M===""&&x!==0&&x!==U.length-1||(M===".."?D.pop():D.push(M))}return D.join("/")},c.getTypeOf=function(B){return typeof B=="string"?"string":Object.prototype.toString.call(B)==="[object Array]"?"array":u.nodebuffer&&h.isBuffer(B)?"nodebuffer":u.uint8array&&B instanceof Uint8Array?"uint8array":u.arraybuffer&&B instanceof ArrayBuffer?"arraybuffer":void 0},c.checkSupport=function(B){if(!u[B.toLowerCase()])throw new Error(B+" is not supported by this platform")},c.MAX_VALUE_16BITS=65535,c.MAX_VALUE_32BITS=-1,c.pretty=function(B){var U,D,x="";for(D=0;D<(B||"").length;D++)x+="\\x"+((U=B.charCodeAt(D))<16?"0":"")+U.toString(16).toUpperCase();return x},c.delay=function(B,U,D){n(function(){B.apply(D||null,U||[])})},c.inherits=function(B,U){function D(){}D.prototype=U.prototype,B.prototype=new D},c.extend=function(){var B,U,D={};for(B=0;B<arguments.length;B++)for(U in arguments[B])Object.prototype.hasOwnProperty.call(arguments[B],U)&&D[U]===void 0&&(D[U]=arguments[B][U]);return D},c.prepareContent=function(B,U,D,x,M){return w.Promise.resolve(U).then(function(v){return u.blob&&(v instanceof Blob||["[object File]","[object Blob]"].indexOf(Object.prototype.toString.call(v))!==-1)&&typeof FileReader<"u"?new w.Promise(function(p,b){var g=new FileReader;g.onload=function(y){p(y.target.result)},g.onerror=function(y){b(y.target.error)},g.readAsArrayBuffer(v)}):v}).then(function(v){var p=c.getTypeOf(v);return p?(p==="arraybuffer"?v=c.transformTo("uint8array",v):p==="string"&&(M?v=d.decode(v):D&&x!==!0&&(v=function(b){return A(b,u.uint8array?new Uint8Array(b.length):new Array(b.length))}(v))),v):w.Promise.reject(new Error("Can't read the data of '"+B+"'. Is it in a supported JavaScript type (String, Blob, ArrayBuffer, etc) ?"))})}},{"./base64":1,"./external":6,"./nodejsUtils":14,"./support":30,setimmediate:54}],33:[function(i,f,c){var u=i("./reader/readerFor"),d=i("./utils"),h=i("./signature"),w=i("./zipEntry"),_=i("./support");function A(N){this.files=[],this.loadOptions=N}A.prototype={checkSignature:function(N){if(!this.reader.readAndCheckSignature(N)){this.reader.index-=4;var L=this.reader.readString(4);throw new Error("Corrupted zip or bug: unexpected signature ("+d.pretty(L)+", expected "+d.pretty(N)+")")}},isSignature:function(N,L){var I=this.reader.index;this.reader.setIndex(N);var P=this.reader.readString(4)===L;return this.reader.setIndex(I),P},readBlockEndOfCentral:function(){this.diskNumber=this.reader.readInt(2),this.diskWithCentralDirStart=this.reader.readInt(2),this.centralDirRecordsOnThisDisk=this.reader.readInt(2),this.centralDirRecords=this.reader.readInt(2),this.centralDirSize=this.reader.readInt(4),this.centralDirOffset=this.reader.readInt(4),this.zipCommentLength=this.reader.readInt(2);var N=this.reader.readData(this.zipCommentLength),L=_.uint8array?"uint8array":"array",I=d.transformTo(L,N);this.zipComment=this.loadOptions.decodeFileName(I)},readBlockZip64EndOfCentral:function(){this.zip64EndOfCentralSize=this.reader.readInt(8),this.reader.skip(4),this.diskNumber=this.reader.readInt(4),this.diskWithCentralDirStart=this.reader.readInt(4),this.centralDirRecordsOnThisDisk=this.reader.readInt(8),this.centralDirRecords=this.reader.readInt(8),this.centralDirSize=this.reader.readInt(8),this.centralDirOffset=this.reader.readInt(8),this.zip64ExtensibleData={};for(var N,L,I,P=this.zip64EndOfCentralSize-44;0<P;)N=this.reader.readInt(2),L=this.reader.readInt(4),I=this.reader.readData(L),this.zip64ExtensibleData[N]={id:N,length:L,value:I}},readBlockZip64EndOfCentralLocator:function(){if(this.diskWithZip64CentralDirStart=this.reader.readInt(4),this.relativeOffsetEndOfZip64CentralDir=this.reader.readInt(8),this.disksCount=this.reader.readInt(4),1<this.disksCount)throw new Error("Multi-volumes zip are not supported")},readLocalFiles:function(){var N,L;for(N=0;N<this.files.length;N++)L=this.files[N],this.reader.setIndex(L.localHeaderOffset),this.checkSignature(h.LOCAL_FILE_HEADER),L.readLocalPart(this.reader),L.handleUTF8(),L.processAttributes()},readCentralDir:function(){var N;for(this.reader.setIndex(this.centralDirOffset);this.reader.readAndCheckSignature(h.CENTRAL_FILE_HEADER);)(N=new w({zip64:this.zip64},this.loadOptions)).readCentralPart(this.reader),this.files.push(N);if(this.centralDirRecords!==this.files.length&&this.centralDirRecords!==0&&this.files.length===0)throw new Error("Corrupted zip or bug: expected "+this.centralDirRecords+" records in central dir, got "+this.files.length)},readEndOfCentral:function(){var N=this.reader.lastIndexOfSignature(h.CENTRAL_DIRECTORY_END);if(N<0)throw this.isSignature(0,h.LOCAL_FILE_HEADER)?new Error("Corrupted zip: can't find end of central directory"):new Error("Can't find end of central directory : is this a zip file ? If it is, see https://stuk.github.io/jszip/documentation/howto/read_zip.html");this.reader.setIndex(N);var L=N;if(this.checkSignature(h.CENTRAL_DIRECTORY_END),this.readBlockEndOfCentral(),this.diskNumber===d.MAX_VALUE_16BITS||this.diskWithCentralDirStart===d.MAX_VALUE_16BITS||this.centralDirRecordsOnThisDisk===d.MAX_VALUE_16BITS||this.centralDirRecords===d.MAX_VALUE_16BITS||this.centralDirSize===d.MAX_VALUE_32BITS||this.centralDirOffset===d.MAX_VALUE_32BITS){if(this.zip64=!0,(N=this.reader.lastIndexOfSignature(h.ZIP64_CENTRAL_DIRECTORY_LOCATOR))<0)throw new Error("Corrupted zip: can't find the ZIP64 end of central directory locator");if(this.reader.setIndex(N),this.checkSignature(h.ZIP64_CENTRAL_DIRECTORY_LOCATOR),this.readBlockZip64EndOfCentralLocator(),!this.isSignature(this.relativeOffsetEndOfZip64CentralDir,h.ZIP64_CENTRAL_DIRECTORY_END)&&(this.relativeOffsetEndOfZip64CentralDir=this.reader.lastIndexOfSignature(h.ZIP64_CENTRAL_DIRECTORY_END),this.relativeOffsetEndOfZip64CentralDir<0))throw new Error("Corrupted zip: can't find the ZIP64 end of central directory");this.reader.setIndex(this.relativeOffsetEndOfZip64CentralDir),this.checkSignature(h.ZIP64_CENTRAL_DIRECTORY_END),this.readBlockZip64EndOfCentral()}var I=this.centralDirOffset+this.centralDirSize;this.zip64&&(I+=20,I+=12+this.zip64EndOfCentralSize);var P=L-I;if(0<P)this.isSignature(L,h.CENTRAL_FILE_HEADER)||(this.reader.zero=P);else if(P<0)throw new Error("Corrupted zip: missing "+Math.abs(P)+" bytes.")},prepareReader:function(N){this.reader=u(N)},load:function(N){this.prepareReader(N),this.readEndOfCentral(),this.readCentralDir(),this.readLocalFiles()}},f.exports=A},{"./reader/readerFor":22,"./signature":23,"./support":30,"./utils":32,"./zipEntry":34}],34:[function(i,f,c){var u=i("./reader/readerFor"),d=i("./utils"),h=i("./compressedObject"),w=i("./crc32"),_=i("./utf8"),A=i("./compressions"),N=i("./support");function L(I,P){this.options=I,this.loadOptions=P}L.prototype={isEncrypted:function(){return(1&this.bitFlag)==1},useUTF8:function(){return(2048&this.bitFlag)==2048},readLocalPart:function(I){var P,B;if(I.skip(22),this.fileNameLength=I.readInt(2),B=I.readInt(2),this.fileName=I.readData(this.fileNameLength),I.skip(B),this.compressedSize===-1||this.uncompressedSize===-1)throw new Error("Bug or corrupted zip : didn't get enough information from the central directory (compressedSize === -1 || uncompressedSize === -1)");if((P=function(U){for(var D in A)if(Object.prototype.hasOwnProperty.call(A,D)&&A[D].magic===U)return A[D];return null}(this.compressionMethod))===null)throw new Error("Corrupted zip : compression "+d.pretty(this.compressionMethod)+" unknown (inner file : "+d.transformTo("string",this.fileName)+")");this.decompressed=new h(this.compressedSize,this.uncompressedSize,this.crc32,P,I.readData(this.compressedSize))},readCentralPart:function(I){this.versionMadeBy=I.readInt(2),I.skip(2),this.bitFlag=I.readInt(2),this.compressionMethod=I.readString(2),this.date=I.readDate(),this.crc32=I.readInt(4),this.compressedSize=I.readInt(4),this.uncompressedSize=I.readInt(4);var P=I.readInt(2);if(this.extraFieldsLength=I.readInt(2),this.fileCommentLength=I.readInt(2),this.diskNumberStart=I.readInt(2),this.internalFileAttributes=I.readInt(2),this.externalFileAttributes=I.readInt(4),this.localHeaderOffset=I.readInt(4),this.isEncrypted())throw new Error("Encrypted zip are not supported");I.skip(P),this.readExtraFields(I),this.parseZIP64ExtraField(I),this.fileComment=I.readData(this.fileCommentLength)},processAttributes:function(){this.unixPermissions=null,this.dosPermissions=null;var I=this.versionMadeBy>>8;this.dir=!!(16&this.externalFileAttributes),I==0&&(this.dosPermissions=63&this.externalFileAttributes),I==3&&(this.unixPermissions=this.externalFileAttributes>>16&65535),this.dir||this.fileNameStr.slice(-1)!=="/"||(this.dir=!0)},parseZIP64ExtraField:function(){if(this.extraFields[1]){var I=u(this.extraFields[1].value);this.uncompressedSize===d.MAX_VALUE_32BITS&&(this.uncompressedSize=I.readInt(8)),this.compressedSize===d.MAX_VALUE_32BITS&&(this.compressedSize=I.readInt(8)),this.localHeaderOffset===d.MAX_VALUE_32BITS&&(this.localHeaderOffset=I.readInt(8)),this.diskNumberStart===d.MAX_VALUE_32BITS&&(this.diskNumberStart=I.readInt(4))}},readExtraFields:function(I){var P,B,U,D=I.index+this.extraFieldsLength;for(this.extraFields||(this.extraFields={});I.index+4<D;)P=I.readInt(2),B=I.readInt(2),U=I.readData(B),this.extraFields[P]={id:P,length:B,value:U};I.setIndex(D)},handleUTF8:function(){var I=N.uint8array?"uint8array":"array";if(this.useUTF8())this.fileNameStr=_.utf8decode(this.fileName),this.fileCommentStr=_.utf8decode(this.fileComment);else{var P=this.findExtraFieldUnicodePath();if(P!==null)this.fileNameStr=P;else{var B=d.transformTo(I,this.fileName);this.fileNameStr=this.loadOptions.decodeFileName(B)}var U=this.findExtraFieldUnicodeComment();if(U!==null)this.fileCommentStr=U;else{var D=d.transformTo(I,this.fileComment);this.fileCommentStr=this.loadOptions.decodeFileName(D)}}},findExtraFieldUnicodePath:function(){var I=this.extraFields[28789];if(I){var P=u(I.value);return P.readInt(1)!==1||w(this.fileName)!==P.readInt(4)?null:_.utf8decode(P.readData(I.length-5))}return null},findExtraFieldUnicodeComment:function(){var I=this.extraFields[25461];if(I){var P=u(I.value);return P.readInt(1)!==1||w(this.fileComment)!==P.readInt(4)?null:_.utf8decode(P.readData(I.length-5))}return null}},f.exports=L},{"./compressedObject":2,"./compressions":3,"./crc32":4,"./reader/readerFor":22,"./support":30,"./utf8":31,"./utils":32}],35:[function(i,f,c){function u(P,B,U){this.name=P,this.dir=U.dir,this.date=U.date,this.comment=U.comment,this.unixPermissions=U.unixPermissions,this.dosPermissions=U.dosPermissions,this._data=B,this._dataBinary=U.binary,this.options={compression:U.compression,compressionOptions:U.compressionOptions}}var d=i("./stream/StreamHelper"),h=i("./stream/DataWorker"),w=i("./utf8"),_=i("./compressedObject"),A=i("./stream/GenericWorker");u.prototype={internalStream:function(P){var B=null,U="string";try{if(!P)throw new Error("No output type specified.");var D=(U=P.toLowerCase())==="string"||U==="text";U!=="binarystring"&&U!=="text"||(U="string"),B=this._decompressWorker();var x=!this._dataBinary;x&&!D&&(B=B.pipe(new w.Utf8EncodeWorker)),!x&&D&&(B=B.pipe(new w.Utf8DecodeWorker))}catch(M){(B=new A("error")).error(M)}return new d(B,U,"")},async:function(P,B){return this.internalStream(P).accumulate(B)},nodeStream:function(P,B){return this.internalStream(P||"nodebuffer").toNodejsStream(B)},_compressWorker:function(P,B){if(this._data instanceof _&&this._data.compression.magic===P.magic)return this._data.getCompressedWorker();var U=this._decompressWorker();return this._dataBinary||(U=U.pipe(new w.Utf8EncodeWorker)),_.createWorkerFrom(U,P,B)},_decompressWorker:function(){return this._data instanceof _?this._data.getContentWorker():this._data instanceof A?this._data:new h(this._data)}};for(var N=["asText","asBinary","asNodeBuffer","asUint8Array","asArrayBuffer"],L=function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},I=0;I<N.length;I++)u.prototype[N[I]]=L;f.exports=u},{"./compressedObject":2,"./stream/DataWorker":27,"./stream/GenericWorker":28,"./stream/StreamHelper":29,"./utf8":31}],36:[function(i,f,c){(function(u){var d,h,w=u.MutationObserver||u.WebKitMutationObserver;if(w){var _=0,A=new w(P),N=u.document.createTextNode("");A.observe(N,{characterData:!0}),d=function(){N.data=_=++_%2}}else if(u.setImmediate||u.MessageChannel===void 0)d="document"in u&&"onreadystatechange"in u.document.createElement("script")?function(){var B=u.document.createElement("script");B.onreadystatechange=function(){P(),B.onreadystatechange=null,B.parentNode.removeChild(B),B=null},u.document.documentElement.appendChild(B)}:function(){setTimeout(P,0)};else{var L=new u.MessageChannel;L.port1.onmessage=P,d=function(){L.port2.postMessage(0)}}var I=[];function P(){var B,U;h=!0;for(var D=I.length;D;){for(U=I,I=[],B=-1;++B<D;)U[B]();D=I.length}h=!1}f.exports=function(B){I.push(B)!==1||h||d()}}).call(this,a!==void 0?a:typeof self<"u"?self:typeof window<"u"?window:{})},{}],37:[function(i,f,c){var u=i("immediate");function d(){}var h={},w=["REJECTED"],_=["FULFILLED"],A=["PENDING"];function N(D){if(typeof D!="function")throw new TypeError("resolver must be a function");this.state=A,this.queue=[],this.outcome=void 0,D!==d&&B(this,D)}function L(D,x,M){this.promise=D,typeof x=="function"&&(this.onFulfilled=x,this.callFulfilled=this.otherCallFulfilled),typeof M=="function"&&(this.onRejected=M,this.callRejected=this.otherCallRejected)}function I(D,x,M){u(function(){var v;try{v=x(M)}catch(p){return h.reject(D,p)}v===D?h.reject(D,new TypeError("Cannot resolve promise with itself")):h.resolve(D,v)})}function P(D){var x=D&&D.then;if(D&&(typeof D=="object"||typeof D=="function")&&typeof x=="function")return function(){x.apply(D,arguments)}}function B(D,x){var M=!1;function v(g){M||(M=!0,h.reject(D,g))}function p(g){M||(M=!0,h.resolve(D,g))}var b=U(function(){x(p,v)});b.status==="error"&&v(b.value)}function U(D,x){var M={};try{M.value=D(x),M.status="success"}catch(v){M.status="error",M.value=v}return M}(f.exports=N).prototype.finally=function(D){if(typeof D!="function")return this;var x=this.constructor;return this.then(function(M){return x.resolve(D()).then(function(){return M})},function(M){return x.resolve(D()).then(function(){throw M})})},N.prototype.catch=function(D){return this.then(null,D)},N.prototype.then=function(D,x){if(typeof D!="function"&&this.state===_||typeof x!="function"&&this.state===w)return this;var M=new this.constructor(d);return this.state!==A?I(M,this.state===_?D:x,this.outcome):this.queue.push(new L(M,D,x)),M},L.prototype.callFulfilled=function(D){h.resolve(this.promise,D)},L.prototype.otherCallFulfilled=function(D){I(this.promise,this.onFulfilled,D)},L.prototype.callRejected=function(D){h.reject(this.promise,D)},L.prototype.otherCallRejected=function(D){I(this.promise,this.onRejected,D)},h.resolve=function(D,x){var M=U(P,x);if(M.status==="error")return h.reject(D,M.value);var v=M.value;if(v)B(D,v);else{D.state=_,D.outcome=x;for(var p=-1,b=D.queue.length;++p<b;)D.queue[p].callFulfilled(x)}return D},h.reject=function(D,x){D.state=w,D.outcome=x;for(var M=-1,v=D.queue.length;++M<v;)D.queue[M].callRejected(x);return D},N.resolve=function(D){return D instanceof this?D:h.resolve(new this(d),D)},N.reject=function(D){var x=new this(d);return h.reject(x,D)},N.all=function(D){var x=this;if(Object.prototype.toString.call(D)!=="[object Array]")return this.reject(new TypeError("must be an array"));var M=D.length,v=!1;if(!M)return this.resolve([]);for(var p=new Array(M),b=0,g=-1,y=new this(d);++g<M;)k(D[g],g);return y;function k(R,O){x.resolve(R).then(function(z){p[O]=z,++b!==M||v||(v=!0,h.resolve(y,p))},function(z){v||(v=!0,h.reject(y,z))})}},N.race=function(D){if(Object.prototype.toString.call(D)!=="[object Array]")return this.reject(new TypeError("must be an array"));var x=D.length,M=!1;if(!x)return this.resolve([]);for(var v,p=-1,b=new this(d);++p<x;)v=D[p],this.resolve(v).then(function(g){M||(M=!0,h.resolve(b,g))},function(g){M||(M=!0,h.reject(b,g))});return b}},{immediate:36}],38:[function(i,f,c){var u={};(0,i("./lib/utils/common").assign)(u,i("./lib/deflate"),i("./lib/inflate"),i("./lib/zlib/constants")),f.exports=u},{"./lib/deflate":39,"./lib/inflate":40,"./lib/utils/common":41,"./lib/zlib/constants":44}],39:[function(i,f,c){var u=i("./zlib/deflate"),d=i("./utils/common"),h=i("./utils/strings"),w=i("./zlib/messages"),_=i("./zlib/zstream"),A=Object.prototype.toString;function N(I){if(!(this instanceof N))return new N(I);this.options=d.assign({level:-1,method:8,chunkSize:16384,windowBits:15,memLevel:8,strategy:0,to:""},I||{});var P=this.options;P.raw&&0<P.windowBits?P.windowBits=-P.windowBits:P.gzip&&0<P.windowBits&&P.windowBits<16&&(P.windowBits+=16),this.err=0,this.msg="",this.ended=!1,this.chunks=[],this.strm=new _,this.strm.avail_out=0;var B=u.deflateInit2(this.strm,P.level,P.method,P.windowBits,P.memLevel,P.strategy);if(B!==0)throw new Error(w[B]);if(P.header&&u.deflateSetHeader(this.strm,P.header),P.dictionary){var U;if(U=typeof P.dictionary=="string"?h.string2buf(P.dictionary):A.call(P.dictionary)==="[object ArrayBuffer]"?new Uint8Array(P.dictionary):P.dictionary,(B=u.deflateSetDictionary(this.strm,U))!==0)throw new Error(w[B]);this._dict_set=!0}}function L(I,P){var B=new N(P);if(B.push(I,!0),B.err)throw B.msg||w[B.err];return B.result}N.prototype.push=function(I,P){var B,U,D=this.strm,x=this.options.chunkSize;if(this.ended)return!1;U=P===~~P?P:P===!0?4:0,typeof I=="string"?D.input=h.string2buf(I):A.call(I)==="[object ArrayBuffer]"?D.input=new Uint8Array(I):D.input=I,D.next_in=0,D.avail_in=D.input.length;do{if(D.avail_out===0&&(D.output=new d.Buf8(x),D.next_out=0,D.avail_out=x),(B=u.deflate(D,U))!==1&&B!==0)return this.onEnd(B),!(this.ended=!0);D.avail_out!==0&&(D.avail_in!==0||U!==4&&U!==2)||(this.options.to==="string"?this.onData(h.buf2binstring(d.shrinkBuf(D.output,D.next_out))):this.onData(d.shrinkBuf(D.output,D.next_out)))}while((0<D.avail_in||D.avail_out===0)&&B!==1);return U===4?(B=u.deflateEnd(this.strm),this.onEnd(B),this.ended=!0,B===0):U!==2||(this.onEnd(0),!(D.avail_out=0))},N.prototype.onData=function(I){this.chunks.push(I)},N.prototype.onEnd=function(I){I===0&&(this.options.to==="string"?this.result=this.chunks.join(""):this.result=d.flattenChunks(this.chunks)),this.chunks=[],this.err=I,this.msg=this.strm.msg},c.Deflate=N,c.deflate=L,c.deflateRaw=function(I,P){return(P=P||{}).raw=!0,L(I,P)},c.gzip=function(I,P){return(P=P||{}).gzip=!0,L(I,P)}},{"./utils/common":41,"./utils/strings":42,"./zlib/deflate":46,"./zlib/messages":51,"./zlib/zstream":53}],40:[function(i,f,c){var u=i("./zlib/inflate"),d=i("./utils/common"),h=i("./utils/strings"),w=i("./zlib/constants"),_=i("./zlib/messages"),A=i("./zlib/zstream"),N=i("./zlib/gzheader"),L=Object.prototype.toString;function I(B){if(!(this instanceof I))return new I(B);this.options=d.assign({chunkSize:16384,windowBits:0,to:""},B||{});var U=this.options;U.raw&&0<=U.windowBits&&U.windowBits<16&&(U.windowBits=-U.windowBits,U.windowBits===0&&(U.windowBits=-15)),!(0<=U.windowBits&&U.windowBits<16)||B&&B.windowBits||(U.windowBits+=32),15<U.windowBits&&U.windowBits<48&&!(15&U.windowBits)&&(U.windowBits|=15),this.err=0,this.msg="",this.ended=!1,this.chunks=[],this.strm=new A,this.strm.avail_out=0;var D=u.inflateInit2(this.strm,U.windowBits);if(D!==w.Z_OK)throw new Error(_[D]);this.header=new N,u.inflateGetHeader(this.strm,this.header)}function P(B,U){var D=new I(U);if(D.push(B,!0),D.err)throw D.msg||_[D.err];return D.result}I.prototype.push=function(B,U){var D,x,M,v,p,b,g=this.strm,y=this.options.chunkSize,k=this.options.dictionary,R=!1;if(this.ended)return!1;x=U===~~U?U:U===!0?w.Z_FINISH:w.Z_NO_FLUSH,typeof B=="string"?g.input=h.binstring2buf(B):L.call(B)==="[object ArrayBuffer]"?g.input=new Uint8Array(B):g.input=B,g.next_in=0,g.avail_in=g.input.length;do{if(g.avail_out===0&&(g.output=new d.Buf8(y),g.next_out=0,g.avail_out=y),(D=u.inflate(g,w.Z_NO_FLUSH))===w.Z_NEED_DICT&&k&&(b=typeof k=="string"?h.string2buf(k):L.call(k)==="[object ArrayBuffer]"?new Uint8Array(k):k,D=u.inflateSetDictionary(this.strm,b)),D===w.Z_BUF_ERROR&&R===!0&&(D=w.Z_OK,R=!1),D!==w.Z_STREAM_END&&D!==w.Z_OK)return this.onEnd(D),!(this.ended=!0);g.next_out&&(g.avail_out!==0&&D!==w.Z_STREAM_END&&(g.avail_in!==0||x!==w.Z_FINISH&&x!==w.Z_SYNC_FLUSH)||(this.options.to==="string"?(M=h.utf8border(g.output,g.next_out),v=g.next_out-M,p=h.buf2string(g.output,M),g.next_out=v,g.avail_out=y-v,v&&d.arraySet(g.output,g.output,M,v,0),this.onData(p)):this.onData(d.shrinkBuf(g.output,g.next_out)))),g.avail_in===0&&g.avail_out===0&&(R=!0)}while((0<g.avail_in||g.avail_out===0)&&D!==w.Z_STREAM_END);return D===w.Z_STREAM_END&&(x=w.Z_FINISH),x===w.Z_FINISH?(D=u.inflateEnd(this.strm),this.onEnd(D),this.ended=!0,D===w.Z_OK):x!==w.Z_SYNC_FLUSH||(this.onEnd(w.Z_OK),!(g.avail_out=0))},I.prototype.onData=function(B){this.chunks.push(B)},I.prototype.onEnd=function(B){B===w.Z_OK&&(this.options.to==="string"?this.result=this.chunks.join(""):this.result=d.flattenChunks(this.chunks)),this.chunks=[],this.err=B,this.msg=this.strm.msg},c.Inflate=I,c.inflate=P,c.inflateRaw=function(B,U){return(U=U||{}).raw=!0,P(B,U)},c.ungzip=P},{"./utils/common":41,"./utils/strings":42,"./zlib/constants":44,"./zlib/gzheader":47,"./zlib/inflate":49,"./zlib/messages":51,"./zlib/zstream":53}],41:[function(i,f,c){var u=typeof Uint8Array<"u"&&typeof Uint16Array<"u"&&typeof Int32Array<"u";c.assign=function(w){for(var _=Array.prototype.slice.call(arguments,1);_.length;){var A=_.shift();if(A){if(typeof A!="object")throw new TypeError(A+"must be non-object");for(var N in A)A.hasOwnProperty(N)&&(w[N]=A[N])}}return w},c.shrinkBuf=function(w,_){return w.length===_?w:w.subarray?w.subarray(0,_):(w.length=_,w)};var d={arraySet:function(w,_,A,N,L){if(_.subarray&&w.subarray)w.set(_.subarray(A,A+N),L);else for(var I=0;I<N;I++)w[L+I]=_[A+I]},flattenChunks:function(w){var _,A,N,L,I,P;for(_=N=0,A=w.length;_<A;_++)N+=w[_].length;for(P=new Uint8Array(N),_=L=0,A=w.length;_<A;_++)I=w[_],P.set(I,L),L+=I.length;return P}},h={arraySet:function(w,_,A,N,L){for(var I=0;I<N;I++)w[L+I]=_[A+I]},flattenChunks:function(w){return[].concat.apply([],w)}};c.setTyped=function(w){w?(c.Buf8=Uint8Array,c.Buf16=Uint16Array,c.Buf32=Int32Array,c.assign(c,d)):(c.Buf8=Array,c.Buf16=Array,c.Buf32=Array,c.assign(c,h))},c.setTyped(u)},{}],42:[function(i,f,c){var u=i("./common"),d=!0,h=!0;try{String.fromCharCode.apply(null,[0])}catch{d=!1}try{String.fromCharCode.apply(null,new Uint8Array(1))}catch{h=!1}for(var w=new u.Buf8(256),_=0;_<256;_++)w[_]=252<=_?6:248<=_?5:240<=_?4:224<=_?3:192<=_?2:1;function A(N,L){if(L<65537&&(N.subarray&&h||!N.subarray&&d))return String.fromCharCode.apply(null,u.shrinkBuf(N,L));for(var I="",P=0;P<L;P++)I+=String.fromCharCode(N[P]);return I}w[254]=w[254]=1,c.string2buf=function(N){var L,I,P,B,U,D=N.length,x=0;for(B=0;B<D;B++)(64512&(I=N.charCodeAt(B)))==55296&&B+1<D&&(64512&(P=N.charCodeAt(B+1)))==56320&&(I=65536+(I-55296<<10)+(P-56320),B++),x+=I<128?1:I<2048?2:I<65536?3:4;for(L=new u.Buf8(x),B=U=0;U<x;B++)(64512&(I=N.charCodeAt(B)))==55296&&B+1<D&&(64512&(P=N.charCodeAt(B+1)))==56320&&(I=65536+(I-55296<<10)+(P-56320),B++),I<128?L[U++]=I:(I<2048?L[U++]=192|I>>>6:(I<65536?L[U++]=224|I>>>12:(L[U++]=240|I>>>18,L[U++]=128|I>>>12&63),L[U++]=128|I>>>6&63),L[U++]=128|63&I);return L},c.buf2binstring=function(N){return A(N,N.length)},c.binstring2buf=function(N){for(var L=new u.Buf8(N.length),I=0,P=L.length;I<P;I++)L[I]=N.charCodeAt(I);return L},c.buf2string=function(N,L){var I,P,B,U,D=L||N.length,x=new Array(2*D);for(I=P=0;I<D;)if((B=N[I++])<128)x[P++]=B;else if(4<(U=w[B]))x[P++]=65533,I+=U-1;else{for(B&=U===2?31:U===3?15:7;1<U&&I<D;)B=B<<6|63&N[I++],U--;1<U?x[P++]=65533:B<65536?x[P++]=B:(B-=65536,x[P++]=55296|B>>10&1023,x[P++]=56320|1023&B)}return A(x,P)},c.utf8border=function(N,L){var I;for((L=L||N.length)>N.length&&(L=N.length),I=L-1;0<=I&&(192&N[I])==128;)I--;return I<0||I===0?L:I+w[N[I]]>L?I:L}},{"./common":41}],43:[function(i,f,c){f.exports=function(u,d,h,w){for(var _=65535&u|0,A=u>>>16&65535|0,N=0;h!==0;){for(h-=N=2e3<h?2e3:h;A=A+(_=_+d[w++]|0)|0,--N;);_%=65521,A%=65521}return _|A<<16|0}},{}],44:[function(i,f,c){f.exports={Z_NO_FLUSH:0,Z_PARTIAL_FLUSH:1,Z_SYNC_FLUSH:2,Z_FULL_FLUSH:3,Z_FINISH:4,Z_BLOCK:5,Z_TREES:6,Z_OK:0,Z_STREAM_END:1,Z_NEED_DICT:2,Z_ERRNO:-1,Z_STREAM_ERROR:-2,Z_DATA_ERROR:-3,Z_BUF_ERROR:-5,Z_NO_COMPRESSION:0,Z_BEST_SPEED:1,Z_BEST_COMPRESSION:9,Z_DEFAULT_COMPRESSION:-1,Z_FILTERED:1,Z_HUFFMAN_ONLY:2,Z_RLE:3,Z_FIXED:4,Z_DEFAULT_STRATEGY:0,Z_BINARY:0,Z_TEXT:1,Z_UNKNOWN:2,Z_DEFLATED:8}},{}],45:[function(i,f,c){var u=function(){for(var d,h=[],w=0;w<256;w++){d=w;for(var _=0;_<8;_++)d=1&d?3988292384^d>>>1:d>>>1;h[w]=d}return h}();f.exports=function(d,h,w,_){var A=u,N=_+w;d^=-1;for(var L=_;L<N;L++)d=d>>>8^A[255&(d^h[L])];return-1^d}},{}],46:[function(i,f,c){var u,d=i("../utils/common"),h=i("./trees"),w=i("./adler32"),_=i("./crc32"),A=i("./messages"),N=-2,L=258,I=262,P=113;function B(j,H){return j.msg=A[H],H}function U(j){return(j<<1)-(4<j?9:0)}function D(j){for(var H=j.length;0<=--H;)j[H]=0}function x(j){var H=j.state,E=H.pending;E>j.avail_out&&(E=j.avail_out),E!==0&&(d.arraySet(j.output,H.pending_buf,H.pending_out,E,j.next_out),j.next_out+=E,H.pending_out+=E,j.total_out+=E,j.avail_out-=E,H.pending-=E,H.pending===0&&(H.pending_out=0))}function M(j,H){h._tr_flush_block(j,0<=j.block_start?j.block_start:-1,j.strstart-j.block_start,H),j.block_start=j.strstart,x(j.strm)}function v(j,H){j.pending_buf[j.pending++]=H}function p(j,H){j.pending_buf[j.pending++]=H>>>8&255,j.pending_buf[j.pending++]=255&H}function b(j,H){var E,C,F=j.max_chain_length,V=j.strstart,Z=j.prev_length,q=j.nice_match,K=j.strstart>j.w_size-I?j.strstart-(j.w_size-I):0,et=j.window,tt=j.w_mask,X=j.prev,J=j.strstart+L,G=et[V+Z-1],nt=et[V+Z];j.prev_length>=j.good_match&&(F>>=2),q>j.lookahead&&(q=j.lookahead);do if(et[(E=H)+Z]===nt&&et[E+Z-1]===G&&et[E]===et[V]&&et[++E]===et[V+1]){V+=2,E++;do;while(et[++V]===et[++E]&&et[++V]===et[++E]&&et[++V]===et[++E]&&et[++V]===et[++E]&&et[++V]===et[++E]&&et[++V]===et[++E]&&et[++V]===et[++E]&&et[++V]===et[++E]&&V<J);if(C=L-(J-V),V=J-L,Z<C){if(j.match_start=H,q<=(Z=C))break;G=et[V+Z-1],nt=et[V+Z]}}while((H=X[H&tt])>K&&--F!=0);return Z<=j.lookahead?Z:j.lookahead}function g(j){var H,E,C,F,V,Z,q,K,et,tt,X=j.w_size;do{if(F=j.window_size-j.lookahead-j.strstart,j.strstart>=X+(X-I)){for(d.arraySet(j.window,j.window,X,X,0),j.match_start-=X,j.strstart-=X,j.block_start-=X,H=E=j.hash_size;C=j.head[--H],j.head[H]=X<=C?C-X:0,--E;);for(H=E=X;C=j.prev[--H],j.prev[H]=X<=C?C-X:0,--E;);F+=X}if(j.strm.avail_in===0)break;if(Z=j.strm,q=j.window,K=j.strstart+j.lookahead,tt=void 0,(et=F)<(tt=Z.avail_in)&&(tt=et),E=tt===0?0:(Z.avail_in-=tt,d.arraySet(q,Z.input,Z.next_in,tt,K),Z.state.wrap===1?Z.adler=w(Z.adler,q,tt,K):Z.state.wrap===2&&(Z.adler=_(Z.adler,q,tt,K)),Z.next_in+=tt,Z.total_in+=tt,tt),j.lookahead+=E,j.lookahead+j.insert>=3)for(V=j.strstart-j.insert,j.ins_h=j.window[V],j.ins_h=(j.ins_h<<j.hash_shift^j.window[V+1])&j.hash_mask;j.insert&&(j.ins_h=(j.ins_h<<j.hash_shift^j.window[V+3-1])&j.hash_mask,j.prev[V&j.w_mask]=j.head[j.ins_h],j.head[j.ins_h]=V,V++,j.insert--,!(j.lookahead+j.insert<3)););}while(j.lookahead<I&&j.strm.avail_in!==0)}function y(j,H){for(var E,C;;){if(j.lookahead<I){if(g(j),j.lookahead<I&&H===0)return 1;if(j.lookahead===0)break}if(E=0,j.lookahead>=3&&(j.ins_h=(j.ins_h<<j.hash_shift^j.window[j.strstart+3-1])&j.hash_mask,E=j.prev[j.strstart&j.w_mask]=j.head[j.ins_h],j.head[j.ins_h]=j.strstart),E!==0&&j.strstart-E<=j.w_size-I&&(j.match_length=b(j,E)),j.match_length>=3)if(C=h._tr_tally(j,j.strstart-j.match_start,j.match_length-3),j.lookahead-=j.match_length,j.match_length<=j.max_lazy_match&&j.lookahead>=3){for(j.match_length--;j.strstart++,j.ins_h=(j.ins_h<<j.hash_shift^j.window[j.strstart+3-1])&j.hash_mask,E=j.prev[j.strstart&j.w_mask]=j.head[j.ins_h],j.head[j.ins_h]=j.strstart,--j.match_length!=0;);j.strstart++}else j.strstart+=j.match_length,j.match_length=0,j.ins_h=j.window[j.strstart],j.ins_h=(j.ins_h<<j.hash_shift^j.window[j.strstart+1])&j.hash_mask;else C=h._tr_tally(j,0,j.window[j.strstart]),j.lookahead--,j.strstart++;if(C&&(M(j,!1),j.strm.avail_out===0))return 1}return j.insert=j.strstart<2?j.strstart:2,H===4?(M(j,!0),j.strm.avail_out===0?3:4):j.last_lit&&(M(j,!1),j.strm.avail_out===0)?1:2}function k(j,H){for(var E,C,F;;){if(j.lookahead<I){if(g(j),j.lookahead<I&&H===0)return 1;if(j.lookahead===0)break}if(E=0,j.lookahead>=3&&(j.ins_h=(j.ins_h<<j.hash_shift^j.window[j.strstart+3-1])&j.hash_mask,E=j.prev[j.strstart&j.w_mask]=j.head[j.ins_h],j.head[j.ins_h]=j.strstart),j.prev_length=j.match_length,j.prev_match=j.match_start,j.match_length=2,E!==0&&j.prev_length<j.max_lazy_match&&j.strstart-E<=j.w_size-I&&(j.match_length=b(j,E),j.match_length<=5&&(j.strategy===1||j.match_length===3&&4096<j.strstart-j.match_start)&&(j.match_length=2)),j.prev_length>=3&&j.match_length<=j.prev_length){for(F=j.strstart+j.lookahead-3,C=h._tr_tally(j,j.strstart-1-j.prev_match,j.prev_length-3),j.lookahead-=j.prev_length-1,j.prev_length-=2;++j.strstart<=F&&(j.ins_h=(j.ins_h<<j.hash_shift^j.window[j.strstart+3-1])&j.hash_mask,E=j.prev[j.strstart&j.w_mask]=j.head[j.ins_h],j.head[j.ins_h]=j.strstart),--j.prev_length!=0;);if(j.match_available=0,j.match_length=2,j.strstart++,C&&(M(j,!1),j.strm.avail_out===0))return 1}else if(j.match_available){if((C=h._tr_tally(j,0,j.window[j.strstart-1]))&&M(j,!1),j.strstart++,j.lookahead--,j.strm.avail_out===0)return 1}else j.match_available=1,j.strstart++,j.lookahead--}return j.match_available&&(C=h._tr_tally(j,0,j.window[j.strstart-1]),j.match_available=0),j.insert=j.strstart<2?j.strstart:2,H===4?(M(j,!0),j.strm.avail_out===0?3:4):j.last_lit&&(M(j,!1),j.strm.avail_out===0)?1:2}function R(j,H,E,C,F){this.good_length=j,this.max_lazy=H,this.nice_length=E,this.max_chain=C,this.func=F}function O(){this.strm=null,this.status=0,this.pending_buf=null,this.pending_buf_size=0,this.pending_out=0,this.pending=0,this.wrap=0,this.gzhead=null,this.gzindex=0,this.method=8,this.last_flush=-1,this.w_size=0,this.w_bits=0,this.w_mask=0,this.window=null,this.window_size=0,this.prev=null,this.head=null,this.ins_h=0,this.hash_size=0,this.hash_bits=0,this.hash_mask=0,this.hash_shift=0,this.block_start=0,this.match_length=0,this.prev_match=0,this.match_available=0,this.strstart=0,this.match_start=0,this.lookahead=0,this.prev_length=0,this.max_chain_length=0,this.max_lazy_match=0,this.level=0,this.strategy=0,this.good_match=0,this.nice_match=0,this.dyn_ltree=new d.Buf16(1146),this.dyn_dtree=new d.Buf16(122),this.bl_tree=new d.Buf16(78),D(this.dyn_ltree),D(this.dyn_dtree),D(this.bl_tree),this.l_desc=null,this.d_desc=null,this.bl_desc=null,this.bl_count=new d.Buf16(16),this.heap=new d.Buf16(573),D(this.heap),this.heap_len=0,this.heap_max=0,this.depth=new d.Buf16(573),D(this.depth),this.l_buf=0,this.lit_bufsize=0,this.last_lit=0,this.d_buf=0,this.opt_len=0,this.static_len=0,this.matches=0,this.insert=0,this.bi_buf=0,this.bi_valid=0}function z(j){var H;return j&&j.state?(j.total_in=j.total_out=0,j.data_type=2,(H=j.state).pending=0,H.pending_out=0,H.wrap<0&&(H.wrap=-H.wrap),H.status=H.wrap?42:P,j.adler=H.wrap===2?0:1,H.last_flush=0,h._tr_init(H),0):B(j,N)}function $(j){var H=z(j);return H===0&&function(E){E.window_size=2*E.w_size,D(E.head),E.max_lazy_match=u[E.level].max_lazy,E.good_match=u[E.level].good_length,E.nice_match=u[E.level].nice_length,E.max_chain_length=u[E.level].max_chain,E.strstart=0,E.block_start=0,E.lookahead=0,E.insert=0,E.match_length=E.prev_length=2,E.match_available=0,E.ins_h=0}(j.state),H}function W(j,H,E,C,F,V){if(!j)return N;var Z=1;if(H===-1&&(H=6),C<0?(Z=0,C=-C):15<C&&(Z=2,C-=16),F<1||9<F||E!==8||C<8||15<C||H<0||9<H||V<0||4<V)return B(j,N);C===8&&(C=9);var q=new O;return(j.state=q).strm=j,q.wrap=Z,q.gzhead=null,q.w_bits=C,q.w_size=1<<q.w_bits,q.w_mask=q.w_size-1,q.hash_bits=F+7,q.hash_size=1<<q.hash_bits,q.hash_mask=q.hash_size-1,q.hash_shift=~~((q.hash_bits+3-1)/3),q.window=new d.Buf8(2*q.w_size),q.head=new d.Buf16(q.hash_size),q.prev=new d.Buf16(q.w_size),q.lit_bufsize=1<<F+6,q.pending_buf_size=4*q.lit_bufsize,q.pending_buf=new d.Buf8(q.pending_buf_size),q.d_buf=1*q.lit_bufsize,q.l_buf=3*q.lit_bufsize,q.level=H,q.strategy=V,q.method=E,$(j)}u=[new R(0,0,0,0,function(j,H){var E=65535;for(E>j.pending_buf_size-5&&(E=j.pending_buf_size-5);;){if(j.lookahead<=1){if(g(j),j.lookahead===0&&H===0)return 1;if(j.lookahead===0)break}j.strstart+=j.lookahead,j.lookahead=0;var C=j.block_start+E;if((j.strstart===0||j.strstart>=C)&&(j.lookahead=j.strstart-C,j.strstart=C,M(j,!1),j.strm.avail_out===0)||j.strstart-j.block_start>=j.w_size-I&&(M(j,!1),j.strm.avail_out===0))return 1}return j.insert=0,H===4?(M(j,!0),j.strm.avail_out===0?3:4):(j.strstart>j.block_start&&(M(j,!1),j.strm.avail_out),1)}),new R(4,4,8,4,y),new R(4,5,16,8,y),new R(4,6,32,32,y),new R(4,4,16,16,k),new R(8,16,32,32,k),new R(8,16,128,128,k),new R(8,32,128,256,k),new R(32,128,258,1024,k),new R(32,258,258,4096,k)],c.deflateInit=function(j,H){return W(j,H,8,15,8,0)},c.deflateInit2=W,c.deflateReset=$,c.deflateResetKeep=z,c.deflateSetHeader=function(j,H){return j&&j.state?j.state.wrap!==2?N:(j.state.gzhead=H,0):N},c.deflate=function(j,H){var E,C,F,V;if(!j||!j.state||5<H||H<0)return j?B(j,N):N;if(C=j.state,!j.output||!j.input&&j.avail_in!==0||C.status===666&&H!==4)return B(j,j.avail_out===0?-5:N);if(C.strm=j,E=C.last_flush,C.last_flush=H,C.status===42)if(C.wrap===2)j.adler=0,v(C,31),v(C,139),v(C,8),C.gzhead?(v(C,(C.gzhead.text?1:0)+(C.gzhead.hcrc?2:0)+(C.gzhead.extra?4:0)+(C.gzhead.name?8:0)+(C.gzhead.comment?16:0)),v(C,255&C.gzhead.time),v(C,C.gzhead.time>>8&255),v(C,C.gzhead.time>>16&255),v(C,C.gzhead.time>>24&255),v(C,C.level===9?2:2<=C.strategy||C.level<2?4:0),v(C,255&C.gzhead.os),C.gzhead.extra&&C.gzhead.extra.length&&(v(C,255&C.gzhead.extra.length),v(C,C.gzhead.extra.length>>8&255)),C.gzhead.hcrc&&(j.adler=_(j.adler,C.pending_buf,C.pending,0)),C.gzindex=0,C.status=69):(v(C,0),v(C,0),v(C,0),v(C,0),v(C,0),v(C,C.level===9?2:2<=C.strategy||C.level<2?4:0),v(C,3),C.status=P);else{var Z=8+(C.w_bits-8<<4)<<8;Z|=(2<=C.strategy||C.level<2?0:C.level<6?1:C.level===6?2:3)<<6,C.strstart!==0&&(Z|=32),Z+=31-Z%31,C.status=P,p(C,Z),C.strstart!==0&&(p(C,j.adler>>>16),p(C,65535&j.adler)),j.adler=1}if(C.status===69)if(C.gzhead.extra){for(F=C.pending;C.gzindex<(65535&C.gzhead.extra.length)&&(C.pending!==C.pending_buf_size||(C.gzhead.hcrc&&C.pending>F&&(j.adler=_(j.adler,C.pending_buf,C.pending-F,F)),x(j),F=C.pending,C.pending!==C.pending_buf_size));)v(C,255&C.gzhead.extra[C.gzindex]),C.gzindex++;C.gzhead.hcrc&&C.pending>F&&(j.adler=_(j.adler,C.pending_buf,C.pending-F,F)),C.gzindex===C.gzhead.extra.length&&(C.gzindex=0,C.status=73)}else C.status=73;if(C.status===73)if(C.gzhead.name){F=C.pending;do{if(C.pending===C.pending_buf_size&&(C.gzhead.hcrc&&C.pending>F&&(j.adler=_(j.adler,C.pending_buf,C.pending-F,F)),x(j),F=C.pending,C.pending===C.pending_buf_size)){V=1;break}V=C.gzindex<C.gzhead.name.length?255&C.gzhead.name.charCodeAt(C.gzindex++):0,v(C,V)}while(V!==0);C.gzhead.hcrc&&C.pending>F&&(j.adler=_(j.adler,C.pending_buf,C.pending-F,F)),V===0&&(C.gzindex=0,C.status=91)}else C.status=91;if(C.status===91)if(C.gzhead.comment){F=C.pending;do{if(C.pending===C.pending_buf_size&&(C.gzhead.hcrc&&C.pending>F&&(j.adler=_(j.adler,C.pending_buf,C.pending-F,F)),x(j),F=C.pending,C.pending===C.pending_buf_size)){V=1;break}V=C.gzindex<C.gzhead.comment.length?255&C.gzhead.comment.charCodeAt(C.gzindex++):0,v(C,V)}while(V!==0);C.gzhead.hcrc&&C.pending>F&&(j.adler=_(j.adler,C.pending_buf,C.pending-F,F)),V===0&&(C.status=103)}else C.status=103;if(C.status===103&&(C.gzhead.hcrc?(C.pending+2>C.pending_buf_size&&x(j),C.pending+2<=C.pending_buf_size&&(v(C,255&j.adler),v(C,j.adler>>8&255),j.adler=0,C.status=P)):C.status=P),C.pending!==0){if(x(j),j.avail_out===0)return C.last_flush=-1,0}else if(j.avail_in===0&&U(H)<=U(E)&&H!==4)return B(j,-5);if(C.status===666&&j.avail_in!==0)return B(j,-5);if(j.avail_in!==0||C.lookahead!==0||H!==0&&C.status!==666){var q=C.strategy===2?function(K,et){for(var tt;;){if(K.lookahead===0&&(g(K),K.lookahead===0)){if(et===0)return 1;break}if(K.match_length=0,tt=h._tr_tally(K,0,K.window[K.strstart]),K.lookahead--,K.strstart++,tt&&(M(K,!1),K.strm.avail_out===0))return 1}return K.insert=0,et===4?(M(K,!0),K.strm.avail_out===0?3:4):K.last_lit&&(M(K,!1),K.strm.avail_out===0)?1:2}(C,H):C.strategy===3?function(K,et){for(var tt,X,J,G,nt=K.window;;){if(K.lookahead<=L){if(g(K),K.lookahead<=L&&et===0)return 1;if(K.lookahead===0)break}if(K.match_length=0,K.lookahead>=3&&0<K.strstart&&(X=nt[J=K.strstart-1])===nt[++J]&&X===nt[++J]&&X===nt[++J]){G=K.strstart+L;do;while(X===nt[++J]&&X===nt[++J]&&X===nt[++J]&&X===nt[++J]&&X===nt[++J]&&X===nt[++J]&&X===nt[++J]&&X===nt[++J]&&J<G);K.match_length=L-(G-J),K.match_length>K.lookahead&&(K.match_length=K.lookahead)}if(K.match_length>=3?(tt=h._tr_tally(K,1,K.match_length-3),K.lookahead-=K.match_length,K.strstart+=K.match_length,K.match_length=0):(tt=h._tr_tally(K,0,K.window[K.strstart]),K.lookahead--,K.strstart++),tt&&(M(K,!1),K.strm.avail_out===0))return 1}return K.insert=0,et===4?(M(K,!0),K.strm.avail_out===0?3:4):K.last_lit&&(M(K,!1),K.strm.avail_out===0)?1:2}(C,H):u[C.level].func(C,H);if(q!==3&&q!==4||(C.status=666),q===1||q===3)return j.avail_out===0&&(C.last_flush=-1),0;if(q===2&&(H===1?h._tr_align(C):H!==5&&(h._tr_stored_block(C,0,0,!1),H===3&&(D(C.head),C.lookahead===0&&(C.strstart=0,C.block_start=0,C.insert=0))),x(j),j.avail_out===0))return C.last_flush=-1,0}return H!==4?0:C.wrap<=0?1:(C.wrap===2?(v(C,255&j.adler),v(C,j.adler>>8&255),v(C,j.adler>>16&255),v(C,j.adler>>24&255),v(C,255&j.total_in),v(C,j.total_in>>8&255),v(C,j.total_in>>16&255),v(C,j.total_in>>24&255)):(p(C,j.adler>>>16),p(C,65535&j.adler)),x(j),0<C.wrap&&(C.wrap=-C.wrap),C.pending!==0?0:1)},c.deflateEnd=function(j){var H;return j&&j.state?(H=j.state.status)!==42&&H!==69&&H!==73&&H!==91&&H!==103&&H!==P&&H!==666?B(j,N):(j.state=null,H===P?B(j,-3):0):N},c.deflateSetDictionary=function(j,H){var E,C,F,V,Z,q,K,et,tt=H.length;if(!j||!j.state||(V=(E=j.state).wrap)===2||V===1&&E.status!==42||E.lookahead)return N;for(V===1&&(j.adler=w(j.adler,H,tt,0)),E.wrap=0,tt>=E.w_size&&(V===0&&(D(E.head),E.strstart=0,E.block_start=0,E.insert=0),et=new d.Buf8(E.w_size),d.arraySet(et,H,tt-E.w_size,E.w_size,0),H=et,tt=E.w_size),Z=j.avail_in,q=j.next_in,K=j.input,j.avail_in=tt,j.next_in=0,j.input=H,g(E);E.lookahead>=3;){for(C=E.strstart,F=E.lookahead-2;E.ins_h=(E.ins_h<<E.hash_shift^E.window[C+3-1])&E.hash_mask,E.prev[C&E.w_mask]=E.head[E.ins_h],E.head[E.ins_h]=C,C++,--F;);E.strstart=C,E.lookahead=2,g(E)}return E.strstart+=E.lookahead,E.block_start=E.strstart,E.insert=E.lookahead,E.lookahead=0,E.match_length=E.prev_length=2,E.match_available=0,j.next_in=q,j.input=K,j.avail_in=Z,E.wrap=V,0},c.deflateInfo="pako deflate (from Nodeca project)"},{"../utils/common":41,"./adler32":43,"./crc32":45,"./messages":51,"./trees":52}],47:[function(i,f,c){f.exports=function(){this.text=0,this.time=0,this.xflags=0,this.os=0,this.extra=null,this.extra_len=0,this.name="",this.comment="",this.hcrc=0,this.done=!1}},{}],48:[function(i,f,c){f.exports=function(u,d){var h,w,_,A,N,L,I,P,B,U,D,x,M,v,p,b,g,y,k,R,O,z,$,W,j;h=u.state,w=u.next_in,W=u.input,_=w+(u.avail_in-5),A=u.next_out,j=u.output,N=A-(d-u.avail_out),L=A+(u.avail_out-257),I=h.dmax,P=h.wsize,B=h.whave,U=h.wnext,D=h.window,x=h.hold,M=h.bits,v=h.lencode,p=h.distcode,b=(1<<h.lenbits)-1,g=(1<<h.distbits)-1;t:do{M<15&&(x+=W[w++]<<M,M+=8,x+=W[w++]<<M,M+=8),y=v[x&b];e:for(;;){if(x>>>=k=y>>>24,M-=k,(k=y>>>16&255)==0)j[A++]=65535&y;else{if(!(16&k)){if(!(64&k)){y=v[(65535&y)+(x&(1<<k)-1)];continue e}if(32&k){h.mode=12;break t}u.msg="invalid literal/length code",h.mode=30;break t}R=65535&y,(k&=15)&&(M<k&&(x+=W[w++]<<M,M+=8),R+=x&(1<<k)-1,x>>>=k,M-=k),M<15&&(x+=W[w++]<<M,M+=8,x+=W[w++]<<M,M+=8),y=p[x&g];r:for(;;){if(x>>>=k=y>>>24,M-=k,!(16&(k=y>>>16&255))){if(!(64&k)){y=p[(65535&y)+(x&(1<<k)-1)];continue r}u.msg="invalid distance code",h.mode=30;break t}if(O=65535&y,M<(k&=15)&&(x+=W[w++]<<M,(M+=8)<k&&(x+=W[w++]<<M,M+=8)),I<(O+=x&(1<<k)-1)){u.msg="invalid distance too far back",h.mode=30;break t}if(x>>>=k,M-=k,(k=A-N)<O){if(B<(k=O-k)&&h.sane){u.msg="invalid distance too far back",h.mode=30;break t}if($=D,(z=0)===U){if(z+=P-k,k<R){for(R-=k;j[A++]=D[z++],--k;);z=A-O,$=j}}else if(U<k){if(z+=P+U-k,(k-=U)<R){for(R-=k;j[A++]=D[z++],--k;);if(z=0,U<R){for(R-=k=U;j[A++]=D[z++],--k;);z=A-O,$=j}}}else if(z+=U-k,k<R){for(R-=k;j[A++]=D[z++],--k;);z=A-O,$=j}for(;2<R;)j[A++]=$[z++],j[A++]=$[z++],j[A++]=$[z++],R-=3;R&&(j[A++]=$[z++],1<R&&(j[A++]=$[z++]))}else{for(z=A-O;j[A++]=j[z++],j[A++]=j[z++],j[A++]=j[z++],2<(R-=3););R&&(j[A++]=j[z++],1<R&&(j[A++]=j[z++]))}break}}break}}while(w<_&&A<L);w-=R=M>>3,x&=(1<<(M-=R<<3))-1,u.next_in=w,u.next_out=A,u.avail_in=w<_?_-w+5:5-(w-_),u.avail_out=A<L?L-A+257:257-(A-L),h.hold=x,h.bits=M}},{}],49:[function(i,f,c){var u=i("../utils/common"),d=i("./adler32"),h=i("./crc32"),w=i("./inffast"),_=i("./inftrees"),A=-2;function N(b){return(b>>>24&255)+(b>>>8&65280)+((65280&b)<<8)+((255&b)<<24)}function L(){this.mode=0,this.last=!1,this.wrap=0,this.havedict=!1,this.flags=0,this.dmax=0,this.check=0,this.total=0,this.head=null,this.wbits=0,this.wsize=0,this.whave=0,this.wnext=0,this.window=null,this.hold=0,this.bits=0,this.length=0,this.offset=0,this.extra=0,this.lencode=null,this.distcode=null,this.lenbits=0,this.distbits=0,this.ncode=0,this.nlen=0,this.ndist=0,this.have=0,this.next=null,this.lens=new u.Buf16(320),this.work=new u.Buf16(288),this.lendyn=null,this.distdyn=null,this.sane=0,this.back=0,this.was=0}function I(b){var g;return b&&b.state?(g=b.state,b.total_in=b.total_out=g.total=0,b.msg="",g.wrap&&(b.adler=1&g.wrap),g.mode=1,g.last=0,g.havedict=0,g.dmax=32768,g.head=null,g.hold=0,g.bits=0,g.lencode=g.lendyn=new u.Buf32(852),g.distcode=g.distdyn=new u.Buf32(592),g.sane=1,g.back=-1,0):A}function P(b){var g;return b&&b.state?((g=b.state).wsize=0,g.whave=0,g.wnext=0,I(b)):A}function B(b,g){var y,k;return b&&b.state?(k=b.state,g<0?(y=0,g=-g):(y=1+(g>>4),g<48&&(g&=15)),g&&(g<8||15<g)?A:(k.window!==null&&k.wbits!==g&&(k.window=null),k.wrap=y,k.wbits=g,P(b))):A}function U(b,g){var y,k;return b?(k=new L,(b.state=k).window=null,(y=B(b,g))!==0&&(b.state=null),y):A}var D,x,M=!0;function v(b){if(M){var g;for(D=new u.Buf32(512),x=new u.Buf32(32),g=0;g<144;)b.lens[g++]=8;for(;g<256;)b.lens[g++]=9;for(;g<280;)b.lens[g++]=7;for(;g<288;)b.lens[g++]=8;for(_(1,b.lens,0,288,D,0,b.work,{bits:9}),g=0;g<32;)b.lens[g++]=5;_(2,b.lens,0,32,x,0,b.work,{bits:5}),M=!1}b.lencode=D,b.lenbits=9,b.distcode=x,b.distbits=5}function p(b,g,y,k){var R,O=b.state;return O.window===null&&(O.wsize=1<<O.wbits,O.wnext=0,O.whave=0,O.window=new u.Buf8(O.wsize)),k>=O.wsize?(u.arraySet(O.window,g,y-O.wsize,O.wsize,0),O.wnext=0,O.whave=O.wsize):(k<(R=O.wsize-O.wnext)&&(R=k),u.arraySet(O.window,g,y-k,R,O.wnext),(k-=R)?(u.arraySet(O.window,g,y-k,k,0),O.wnext=k,O.whave=O.wsize):(O.wnext+=R,O.wnext===O.wsize&&(O.wnext=0),O.whave<O.wsize&&(O.whave+=R))),0}c.inflateReset=P,c.inflateReset2=B,c.inflateResetKeep=I,c.inflateInit=function(b){return U(b,15)},c.inflateInit2=U,c.inflate=function(b,g){var y,k,R,O,z,$,W,j,H,E,C,F,V,Z,q,K,et,tt,X,J,G,nt,rt,st,ot=0,lt=new u.Buf8(4),ct=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15];if(!b||!b.state||!b.output||!b.input&&b.avail_in!==0)return A;(y=b.state).mode===12&&(y.mode=13),z=b.next_out,R=b.output,W=b.avail_out,O=b.next_in,k=b.input,$=b.avail_in,j=y.hold,H=y.bits,E=$,C=W,nt=0;t:for(;;)switch(y.mode){case 1:if(y.wrap===0){y.mode=13;break}for(;H<16;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(2&y.wrap&&j===35615){lt[y.check=0]=255&j,lt[1]=j>>>8&255,y.check=h(y.check,lt,2,0),H=j=0,y.mode=2;break}if(y.flags=0,y.head&&(y.head.done=!1),!(1&y.wrap)||(((255&j)<<8)+(j>>8))%31){b.msg="incorrect header check",y.mode=30;break}if((15&j)!=8){b.msg="unknown compression method",y.mode=30;break}if(H-=4,G=8+(15&(j>>>=4)),y.wbits===0)y.wbits=G;else if(G>y.wbits){b.msg="invalid window size",y.mode=30;break}y.dmax=1<<G,b.adler=y.check=1,y.mode=512&j?10:12,H=j=0;break;case 2:for(;H<16;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(y.flags=j,(255&y.flags)!=8){b.msg="unknown compression method",y.mode=30;break}if(57344&y.flags){b.msg="unknown header flags set",y.mode=30;break}y.head&&(y.head.text=j>>8&1),512&y.flags&&(lt[0]=255&j,lt[1]=j>>>8&255,y.check=h(y.check,lt,2,0)),H=j=0,y.mode=3;case 3:for(;H<32;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}y.head&&(y.head.time=j),512&y.flags&&(lt[0]=255&j,lt[1]=j>>>8&255,lt[2]=j>>>16&255,lt[3]=j>>>24&255,y.check=h(y.check,lt,4,0)),H=j=0,y.mode=4;case 4:for(;H<16;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}y.head&&(y.head.xflags=255&j,y.head.os=j>>8),512&y.flags&&(lt[0]=255&j,lt[1]=j>>>8&255,y.check=h(y.check,lt,2,0)),H=j=0,y.mode=5;case 5:if(1024&y.flags){for(;H<16;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}y.length=j,y.head&&(y.head.extra_len=j),512&y.flags&&(lt[0]=255&j,lt[1]=j>>>8&255,y.check=h(y.check,lt,2,0)),H=j=0}else y.head&&(y.head.extra=null);y.mode=6;case 6:if(1024&y.flags&&($<(F=y.length)&&(F=$),F&&(y.head&&(G=y.head.extra_len-y.length,y.head.extra||(y.head.extra=new Array(y.head.extra_len)),u.arraySet(y.head.extra,k,O,F,G)),512&y.flags&&(y.check=h(y.check,k,F,O)),$-=F,O+=F,y.length-=F),y.length))break t;y.length=0,y.mode=7;case 7:if(2048&y.flags){if($===0)break t;for(F=0;G=k[O+F++],y.head&&G&&y.length<65536&&(y.head.name+=String.fromCharCode(G)),G&&F<$;);if(512&y.flags&&(y.check=h(y.check,k,F,O)),$-=F,O+=F,G)break t}else y.head&&(y.head.name=null);y.length=0,y.mode=8;case 8:if(4096&y.flags){if($===0)break t;for(F=0;G=k[O+F++],y.head&&G&&y.length<65536&&(y.head.comment+=String.fromCharCode(G)),G&&F<$;);if(512&y.flags&&(y.check=h(y.check,k,F,O)),$-=F,O+=F,G)break t}else y.head&&(y.head.comment=null);y.mode=9;case 9:if(512&y.flags){for(;H<16;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(j!==(65535&y.check)){b.msg="header crc mismatch",y.mode=30;break}H=j=0}y.head&&(y.head.hcrc=y.flags>>9&1,y.head.done=!0),b.adler=y.check=0,y.mode=12;break;case 10:for(;H<32;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}b.adler=y.check=N(j),H=j=0,y.mode=11;case 11:if(y.havedict===0)return b.next_out=z,b.avail_out=W,b.next_in=O,b.avail_in=$,y.hold=j,y.bits=H,2;b.adler=y.check=1,y.mode=12;case 12:if(g===5||g===6)break t;case 13:if(y.last){j>>>=7&H,H-=7&H,y.mode=27;break}for(;H<3;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}switch(y.last=1&j,H-=1,3&(j>>>=1)){case 0:y.mode=14;break;case 1:if(v(y),y.mode=20,g!==6)break;j>>>=2,H-=2;break t;case 2:y.mode=17;break;case 3:b.msg="invalid block type",y.mode=30}j>>>=2,H-=2;break;case 14:for(j>>>=7&H,H-=7&H;H<32;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if((65535&j)!=(j>>>16^65535)){b.msg="invalid stored block lengths",y.mode=30;break}if(y.length=65535&j,H=j=0,y.mode=15,g===6)break t;case 15:y.mode=16;case 16:if(F=y.length){if($<F&&(F=$),W<F&&(F=W),F===0)break t;u.arraySet(R,k,O,F,z),$-=F,O+=F,W-=F,z+=F,y.length-=F;break}y.mode=12;break;case 17:for(;H<14;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(y.nlen=257+(31&j),j>>>=5,H-=5,y.ndist=1+(31&j),j>>>=5,H-=5,y.ncode=4+(15&j),j>>>=4,H-=4,286<y.nlen||30<y.ndist){b.msg="too many length or distance symbols",y.mode=30;break}y.have=0,y.mode=18;case 18:for(;y.have<y.ncode;){for(;H<3;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}y.lens[ct[y.have++]]=7&j,j>>>=3,H-=3}for(;y.have<19;)y.lens[ct[y.have++]]=0;if(y.lencode=y.lendyn,y.lenbits=7,rt={bits:y.lenbits},nt=_(0,y.lens,0,19,y.lencode,0,y.work,rt),y.lenbits=rt.bits,nt){b.msg="invalid code lengths set",y.mode=30;break}y.have=0,y.mode=19;case 19:for(;y.have<y.nlen+y.ndist;){for(;K=(ot=y.lencode[j&(1<<y.lenbits)-1])>>>16&255,et=65535&ot,!((q=ot>>>24)<=H);){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(et<16)j>>>=q,H-=q,y.lens[y.have++]=et;else{if(et===16){for(st=q+2;H<st;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(j>>>=q,H-=q,y.have===0){b.msg="invalid bit length repeat",y.mode=30;break}G=y.lens[y.have-1],F=3+(3&j),j>>>=2,H-=2}else if(et===17){for(st=q+3;H<st;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}H-=q,G=0,F=3+(7&(j>>>=q)),j>>>=3,H-=3}else{for(st=q+7;H<st;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}H-=q,G=0,F=11+(127&(j>>>=q)),j>>>=7,H-=7}if(y.have+F>y.nlen+y.ndist){b.msg="invalid bit length repeat",y.mode=30;break}for(;F--;)y.lens[y.have++]=G}}if(y.mode===30)break;if(y.lens[256]===0){b.msg="invalid code -- missing end-of-block",y.mode=30;break}if(y.lenbits=9,rt={bits:y.lenbits},nt=_(1,y.lens,0,y.nlen,y.lencode,0,y.work,rt),y.lenbits=rt.bits,nt){b.msg="invalid literal/lengths set",y.mode=30;break}if(y.distbits=6,y.distcode=y.distdyn,rt={bits:y.distbits},nt=_(2,y.lens,y.nlen,y.ndist,y.distcode,0,y.work,rt),y.distbits=rt.bits,nt){b.msg="invalid distances set",y.mode=30;break}if(y.mode=20,g===6)break t;case 20:y.mode=21;case 21:if(6<=$&&258<=W){b.next_out=z,b.avail_out=W,b.next_in=O,b.avail_in=$,y.hold=j,y.bits=H,w(b,C),z=b.next_out,R=b.output,W=b.avail_out,O=b.next_in,k=b.input,$=b.avail_in,j=y.hold,H=y.bits,y.mode===12&&(y.back=-1);break}for(y.back=0;K=(ot=y.lencode[j&(1<<y.lenbits)-1])>>>16&255,et=65535&ot,!((q=ot>>>24)<=H);){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(K&&!(240&K)){for(tt=q,X=K,J=et;K=(ot=y.lencode[J+((j&(1<<tt+X)-1)>>tt)])>>>16&255,et=65535&ot,!(tt+(q=ot>>>24)<=H);){if($===0)break t;$--,j+=k[O++]<<H,H+=8}j>>>=tt,H-=tt,y.back+=tt}if(j>>>=q,H-=q,y.back+=q,y.length=et,K===0){y.mode=26;break}if(32&K){y.back=-1,y.mode=12;break}if(64&K){b.msg="invalid literal/length code",y.mode=30;break}y.extra=15&K,y.mode=22;case 22:if(y.extra){for(st=y.extra;H<st;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}y.length+=j&(1<<y.extra)-1,j>>>=y.extra,H-=y.extra,y.back+=y.extra}y.was=y.length,y.mode=23;case 23:for(;K=(ot=y.distcode[j&(1<<y.distbits)-1])>>>16&255,et=65535&ot,!((q=ot>>>24)<=H);){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(!(240&K)){for(tt=q,X=K,J=et;K=(ot=y.distcode[J+((j&(1<<tt+X)-1)>>tt)])>>>16&255,et=65535&ot,!(tt+(q=ot>>>24)<=H);){if($===0)break t;$--,j+=k[O++]<<H,H+=8}j>>>=tt,H-=tt,y.back+=tt}if(j>>>=q,H-=q,y.back+=q,64&K){b.msg="invalid distance code",y.mode=30;break}y.offset=et,y.extra=15&K,y.mode=24;case 24:if(y.extra){for(st=y.extra;H<st;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}y.offset+=j&(1<<y.extra)-1,j>>>=y.extra,H-=y.extra,y.back+=y.extra}if(y.offset>y.dmax){b.msg="invalid distance too far back",y.mode=30;break}y.mode=25;case 25:if(W===0)break t;if(F=C-W,y.offset>F){if((F=y.offset-F)>y.whave&&y.sane){b.msg="invalid distance too far back",y.mode=30;break}V=F>y.wnext?(F-=y.wnext,y.wsize-F):y.wnext-F,F>y.length&&(F=y.length),Z=y.window}else Z=R,V=z-y.offset,F=y.length;for(W<F&&(F=W),W-=F,y.length-=F;R[z++]=Z[V++],--F;);y.length===0&&(y.mode=21);break;case 26:if(W===0)break t;R[z++]=y.length,W--,y.mode=21;break;case 27:if(y.wrap){for(;H<32;){if($===0)break t;$--,j|=k[O++]<<H,H+=8}if(C-=W,b.total_out+=C,y.total+=C,C&&(b.adler=y.check=y.flags?h(y.check,R,C,z-C):d(y.check,R,C,z-C)),C=W,(y.flags?j:N(j))!==y.check){b.msg="incorrect data check",y.mode=30;break}H=j=0}y.mode=28;case 28:if(y.wrap&&y.flags){for(;H<32;){if($===0)break t;$--,j+=k[O++]<<H,H+=8}if(j!==(4294967295&y.total)){b.msg="incorrect length check",y.mode=30;break}H=j=0}y.mode=29;case 29:nt=1;break t;case 30:nt=-3;break t;case 31:return-4;case 32:default:return A}return b.next_out=z,b.avail_out=W,b.next_in=O,b.avail_in=$,y.hold=j,y.bits=H,(y.wsize||C!==b.avail_out&&y.mode<30&&(y.mode<27||g!==4))&&p(b,b.output,b.next_out,C-b.avail_out)?(y.mode=31,-4):(E-=b.avail_in,C-=b.avail_out,b.total_in+=E,b.total_out+=C,y.total+=C,y.wrap&&C&&(b.adler=y.check=y.flags?h(y.check,R,C,b.next_out-C):d(y.check,R,C,b.next_out-C)),b.data_type=y.bits+(y.last?64:0)+(y.mode===12?128:0)+(y.mode===20||y.mode===15?256:0),(E==0&&C===0||g===4)&&nt===0&&(nt=-5),nt)},c.inflateEnd=function(b){if(!b||!b.state)return A;var g=b.state;return g.window&&(g.window=null),b.state=null,0},c.inflateGetHeader=function(b,g){var y;return b&&b.state&&2&(y=b.state).wrap?((y.head=g).done=!1,0):A},c.inflateSetDictionary=function(b,g){var y,k=g.length;return b&&b.state?(y=b.state).wrap!==0&&y.mode!==11?A:y.mode===11&&d(1,g,k,0)!==y.check?-3:p(b,g,k,k)?(y.mode=31,-4):(y.havedict=1,0):A},c.inflateInfo="pako inflate (from Nodeca project)"},{"../utils/common":41,"./adler32":43,"./crc32":45,"./inffast":48,"./inftrees":50}],50:[function(i,f,c){var u=i("../utils/common"),d=[3,4,5,6,7,8,9,10,11,13,15,17,19,23,27,31,35,43,51,59,67,83,99,115,131,163,195,227,258,0,0],h=[16,16,16,16,16,16,16,16,17,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,16,72,78],w=[1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,257,385,513,769,1025,1537,2049,3073,4097,6145,8193,12289,16385,24577,0,0],_=[16,16,16,16,17,17,18,18,19,19,20,20,21,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,64,64];f.exports=function(A,N,L,I,P,B,U,D){var x,M,v,p,b,g,y,k,R,O=D.bits,z=0,$=0,W=0,j=0,H=0,E=0,C=0,F=0,V=0,Z=0,q=null,K=0,et=new u.Buf16(16),tt=new u.Buf16(16),X=null,J=0;for(z=0;z<=15;z++)et[z]=0;for($=0;$<I;$++)et[N[L+$]]++;for(H=O,j=15;1<=j&&et[j]===0;j--);if(j<H&&(H=j),j===0)return P[B++]=20971520,P[B++]=20971520,D.bits=1,0;for(W=1;W<j&&et[W]===0;W++);for(H<W&&(H=W),z=F=1;z<=15;z++)if(F<<=1,(F-=et[z])<0)return-1;if(0<F&&(A===0||j!==1))return-1;for(tt[1]=0,z=1;z<15;z++)tt[z+1]=tt[z]+et[z];for($=0;$<I;$++)N[L+$]!==0&&(U[tt[N[L+$]]++]=$);if(g=A===0?(q=X=U,19):A===1?(q=d,K-=257,X=h,J-=257,256):(q=w,X=_,-1),z=W,b=B,C=$=Z=0,v=-1,p=(V=1<<(E=H))-1,A===1&&852<V||A===2&&592<V)return 1;for(;;){for(y=z-C,R=U[$]<g?(k=0,U[$]):U[$]>g?(k=X[J+U[$]],q[K+U[$]]):(k=96,0),x=1<<z-C,W=M=1<<E;P[b+(Z>>C)+(M-=x)]=y<<24|k<<16|R|0,M!==0;);for(x=1<<z-1;Z&x;)x>>=1;if(x!==0?(Z&=x-1,Z+=x):Z=0,$++,--et[z]==0){if(z===j)break;z=N[L+U[$]]}if(H<z&&(Z&p)!==v){for(C===0&&(C=H),b+=W,F=1<<(E=z-C);E+C<j&&!((F-=et[E+C])<=0);)E++,F<<=1;if(V+=1<<E,A===1&&852<V||A===2&&592<V)return 1;P[v=Z&p]=H<<24|E<<16|b-B|0}}return Z!==0&&(P[b+Z]=z-C<<24|64<<16|0),D.bits=H,0}},{"../utils/common":41}],51:[function(i,f,c){f.exports={2:"need dictionary",1:"stream end",0:"","-1":"file error","-2":"stream error","-3":"data error","-4":"insufficient memory","-5":"buffer error","-6":"incompatible version"}},{}],52:[function(i,f,c){var u=i("../utils/common");function d(X){for(var J=X.length;0<=--J;)X[J]=0}var h=256,w=286,_=30,A=15,N=[0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0],L=[0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13],I=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7],P=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],B=new Array(576);d(B);var U=new Array(60);d(U);var D=new Array(512);d(D);var x=new Array(256);d(x);var M=new Array(29);d(M);var v,p,b,g=new Array(_);function y(X,J,G,nt,rt){this.static_tree=X,this.extra_bits=J,this.extra_base=G,this.elems=nt,this.max_length=rt,this.has_stree=X&&X.length}function k(X,J){this.dyn_tree=X,this.max_code=0,this.stat_desc=J}function R(X){return X<256?D[X]:D[256+(X>>>7)]}function O(X,J){X.pending_buf[X.pending++]=255&J,X.pending_buf[X.pending++]=J>>>8&255}function z(X,J,G){X.bi_valid>16-G?(X.bi_buf|=J<<X.bi_valid&65535,O(X,X.bi_buf),X.bi_buf=J>>16-X.bi_valid,X.bi_valid+=G-16):(X.bi_buf|=J<<X.bi_valid&65535,X.bi_valid+=G)}function $(X,J,G){z(X,G[2*J],G[2*J+1])}function W(X,J){for(var G=0;G|=1&X,X>>>=1,G<<=1,0<--J;);return G>>>1}function j(X,J,G){var nt,rt,st=new Array(16),ot=0;for(nt=1;nt<=A;nt++)st[nt]=ot=ot+G[nt-1]<<1;for(rt=0;rt<=J;rt++){var lt=X[2*rt+1];lt!==0&&(X[2*rt]=W(st[lt]++,lt))}}function H(X){var J;for(J=0;J<w;J++)X.dyn_ltree[2*J]=0;for(J=0;J<_;J++)X.dyn_dtree[2*J]=0;for(J=0;J<19;J++)X.bl_tree[2*J]=0;X.dyn_ltree[512]=1,X.opt_len=X.static_len=0,X.last_lit=X.matches=0}function E(X){8<X.bi_valid?O(X,X.bi_buf):0<X.bi_valid&&(X.pending_buf[X.pending++]=X.bi_buf),X.bi_buf=0,X.bi_valid=0}function C(X,J,G,nt){var rt=2*J,st=2*G;return X[rt]<X[st]||X[rt]===X[st]&&nt[J]<=nt[G]}function F(X,J,G){for(var nt=X.heap[G],rt=G<<1;rt<=X.heap_len&&(rt<X.heap_len&&C(J,X.heap[rt+1],X.heap[rt],X.depth)&&rt++,!C(J,nt,X.heap[rt],X.depth));)X.heap[G]=X.heap[rt],G=rt,rt<<=1;X.heap[G]=nt}function V(X,J,G){var nt,rt,st,ot,lt=0;if(X.last_lit!==0)for(;nt=X.pending_buf[X.d_buf+2*lt]<<8|X.pending_buf[X.d_buf+2*lt+1],rt=X.pending_buf[X.l_buf+lt],lt++,nt===0?$(X,rt,J):($(X,(st=x[rt])+h+1,J),(ot=N[st])!==0&&z(X,rt-=M[st],ot),$(X,st=R(--nt),G),(ot=L[st])!==0&&z(X,nt-=g[st],ot)),lt<X.last_lit;);$(X,256,J)}function Z(X,J){var G,nt,rt,st=J.dyn_tree,ot=J.stat_desc.static_tree,lt=J.stat_desc.has_stree,ct=J.stat_desc.elems,wt=-1;for(X.heap_len=0,X.heap_max=573,G=0;G<ct;G++)st[2*G]!==0?(X.heap[++X.heap_len]=wt=G,X.depth[G]=0):st[2*G+1]=0;for(;X.heap_len<2;)st[2*(rt=X.heap[++X.heap_len]=wt<2?++wt:0)]=1,X.depth[rt]=0,X.opt_len--,lt&&(X.static_len-=ot[2*rt+1]);for(J.max_code=wt,G=X.heap_len>>1;1<=G;G--)F(X,st,G);for(rt=ct;G=X.heap[1],X.heap[1]=X.heap[X.heap_len--],F(X,st,1),nt=X.heap[1],X.heap[--X.heap_max]=G,X.heap[--X.heap_max]=nt,st[2*rt]=st[2*G]+st[2*nt],X.depth[rt]=(X.depth[G]>=X.depth[nt]?X.depth[G]:X.depth[nt])+1,st[2*G+1]=st[2*nt+1]=rt,X.heap[1]=rt++,F(X,st,1),2<=X.heap_len;);X.heap[--X.heap_max]=X.heap[1],function(vt,mt){var Rt,Et,At,jt,_t,dt,xt=mt.dyn_tree,Tt=mt.max_code,St=mt.stat_desc.static_tree,Kt=mt.stat_desc.has_stree,re=mt.stat_desc.extra_bits,It=mt.stat_desc.extra_base,Qt=mt.stat_desc.max_length,Xt=0;for(jt=0;jt<=A;jt++)vt.bl_count[jt]=0;for(xt[2*vt.heap[vt.heap_max]+1]=0,Rt=vt.heap_max+1;Rt<573;Rt++)Qt<(jt=xt[2*xt[2*(Et=vt.heap[Rt])+1]+1]+1)&&(jt=Qt,Xt++),xt[2*Et+1]=jt,Tt<Et||(vt.bl_count[jt]++,_t=0,It<=Et&&(_t=re[Et-It]),dt=xt[2*Et],vt.opt_len+=dt*(jt+_t),Kt&&(vt.static_len+=dt*(St[2*Et+1]+_t)));if(Xt!==0){do{for(jt=Qt-1;vt.bl_count[jt]===0;)jt--;vt.bl_count[jt]--,vt.bl_count[jt+1]+=2,vt.bl_count[Qt]--,Xt-=2}while(0<Xt);for(jt=Qt;jt!==0;jt--)for(Et=vt.bl_count[jt];Et!==0;)Tt<(At=vt.heap[--Rt])||(xt[2*At+1]!==jt&&(vt.opt_len+=(jt-xt[2*At+1])*xt[2*At],xt[2*At+1]=jt),Et--)}}(X,J),j(st,wt,X.bl_count)}function q(X,J,G){var nt,rt,st=-1,ot=J[1],lt=0,ct=7,wt=4;for(ot===0&&(ct=138,wt=3),J[2*(G+1)+1]=65535,nt=0;nt<=G;nt++)rt=ot,ot=J[2*(nt+1)+1],++lt<ct&&rt===ot||(lt<wt?X.bl_tree[2*rt]+=lt:rt!==0?(rt!==st&&X.bl_tree[2*rt]++,X.bl_tree[32]++):lt<=10?X.bl_tree[34]++:X.bl_tree[36]++,st=rt,wt=(lt=0)===ot?(ct=138,3):rt===ot?(ct=6,3):(ct=7,4))}function K(X,J,G){var nt,rt,st=-1,ot=J[1],lt=0,ct=7,wt=4;for(ot===0&&(ct=138,wt=3),nt=0;nt<=G;nt++)if(rt=ot,ot=J[2*(nt+1)+1],!(++lt<ct&&rt===ot)){if(lt<wt)for(;$(X,rt,X.bl_tree),--lt!=0;);else rt!==0?(rt!==st&&($(X,rt,X.bl_tree),lt--),$(X,16,X.bl_tree),z(X,lt-3,2)):lt<=10?($(X,17,X.bl_tree),z(X,lt-3,3)):($(X,18,X.bl_tree),z(X,lt-11,7));st=rt,wt=(lt=0)===ot?(ct=138,3):rt===ot?(ct=6,3):(ct=7,4)}}d(g);var et=!1;function tt(X,J,G,nt){z(X,0+(nt?1:0),3),function(rt,st,ot,lt){E(rt),O(rt,ot),O(rt,~ot),u.arraySet(rt.pending_buf,rt.window,st,ot,rt.pending),rt.pending+=ot}(X,J,G)}c._tr_init=function(X){et||(function(){var J,G,nt,rt,st,ot=new Array(16);for(rt=nt=0;rt<28;rt++)for(M[rt]=nt,J=0;J<1<<N[rt];J++)x[nt++]=rt;for(x[nt-1]=rt,rt=st=0;rt<16;rt++)for(g[rt]=st,J=0;J<1<<L[rt];J++)D[st++]=rt;for(st>>=7;rt<_;rt++)for(g[rt]=st<<7,J=0;J<1<<L[rt]-7;J++)D[256+st++]=rt;for(G=0;G<=A;G++)ot[G]=0;for(J=0;J<=143;)B[2*J+1]=8,J++,ot[8]++;for(;J<=255;)B[2*J+1]=9,J++,ot[9]++;for(;J<=279;)B[2*J+1]=7,J++,ot[7]++;for(;J<=287;)B[2*J+1]=8,J++,ot[8]++;for(j(B,287,ot),J=0;J<_;J++)U[2*J+1]=5,U[2*J]=W(J,5);v=new y(B,N,257,w,A),p=new y(U,L,0,_,A),b=new y(new Array(0),I,0,19,7)}(),et=!0),X.l_desc=new k(X.dyn_ltree,v),X.d_desc=new k(X.dyn_dtree,p),X.bl_desc=new k(X.bl_tree,b),X.bi_buf=0,X.bi_valid=0,H(X)},c._tr_stored_block=tt,c._tr_flush_block=function(X,J,G,nt){var rt,st,ot=0;0<X.level?(X.strm.data_type===2&&(X.strm.data_type=function(lt){var ct,wt=4093624447;for(ct=0;ct<=31;ct++,wt>>>=1)if(1&wt&&lt.dyn_ltree[2*ct]!==0)return 0;if(lt.dyn_ltree[18]!==0||lt.dyn_ltree[20]!==0||lt.dyn_ltree[26]!==0)return 1;for(ct=32;ct<h;ct++)if(lt.dyn_ltree[2*ct]!==0)return 1;return 0}(X)),Z(X,X.l_desc),Z(X,X.d_desc),ot=function(lt){var ct;for(q(lt,lt.dyn_ltree,lt.l_desc.max_code),q(lt,lt.dyn_dtree,lt.d_desc.max_code),Z(lt,lt.bl_desc),ct=18;3<=ct&&lt.bl_tree[2*P[ct]+1]===0;ct--);return lt.opt_len+=3*(ct+1)+5+5+4,ct}(X),rt=X.opt_len+3+7>>>3,(st=X.static_len+3+7>>>3)<=rt&&(rt=st)):rt=st=G+5,G+4<=rt&&J!==-1?tt(X,J,G,nt):X.strategy===4||st===rt?(z(X,2+(nt?1:0),3),V(X,B,U)):(z(X,4+(nt?1:0),3),function(lt,ct,wt,vt){var mt;for(z(lt,ct-257,5),z(lt,wt-1,5),z(lt,vt-4,4),mt=0;mt<vt;mt++)z(lt,lt.bl_tree[2*P[mt]+1],3);K(lt,lt.dyn_ltree,ct-1),K(lt,lt.dyn_dtree,wt-1)}(X,X.l_desc.max_code+1,X.d_desc.max_code+1,ot+1),V(X,X.dyn_ltree,X.dyn_dtree)),H(X),nt&&E(X)},c._tr_tally=function(X,J,G){return X.pending_buf[X.d_buf+2*X.last_lit]=J>>>8&255,X.pending_buf[X.d_buf+2*X.last_lit+1]=255&J,X.pending_buf[X.l_buf+X.last_lit]=255&G,X.last_lit++,J===0?X.dyn_ltree[2*G]++:(X.matches++,J--,X.dyn_ltree[2*(x[G]+h+1)]++,X.dyn_dtree[2*R(J)]++),X.last_lit===X.lit_bufsize-1},c._tr_align=function(X){z(X,2,3),$(X,256,B),function(J){J.bi_valid===16?(O(J,J.bi_buf),J.bi_buf=0,J.bi_valid=0):8<=J.bi_valid&&(J.pending_buf[J.pending++]=255&J.bi_buf,J.bi_buf>>=8,J.bi_valid-=8)}(X)}},{"../utils/common":41}],53:[function(i,f,c){f.exports=function(){this.input=null,this.next_in=0,this.avail_in=0,this.total_in=0,this.output=null,this.next_out=0,this.avail_out=0,this.total_out=0,this.msg="",this.state=null,this.data_type=2,this.adler=0}},{}],54:[function(i,f,c){(function(u){(function(d,h){if(!d.setImmediate){var w,_,A,N,L=1,I={},P=!1,B=d.document,U=Object.getPrototypeOf&&Object.getPrototypeOf(d);U=U&&U.setTimeout?U:d,w={}.toString.call(d.process)==="[object process]"?function(v){m.nextTick(function(){x(v)})}:function(){if(d.postMessage&&!d.importScripts){var v=!0,p=d.onmessage;return d.onmessage=function(){v=!1},d.postMessage("","*"),d.onmessage=p,v}}()?(N="setImmediate$"+Math.random()+"$",d.addEventListener?d.addEventListener("message",M,!1):d.attachEvent("onmessage",M),function(v){d.postMessage(N+v,"*")}):d.MessageChannel?((A=new MessageChannel).port1.onmessage=function(v){x(v.data)},function(v){A.port2.postMessage(v)}):B&&"onreadystatechange"in B.createElement("script")?(_=B.documentElement,function(v){var p=B.createElement("script");p.onreadystatechange=function(){x(v),p.onreadystatechange=null,_.removeChild(p),p=null},_.appendChild(p)}):function(v){setTimeout(x,0,v)},U.setImmediate=function(v){typeof v!="function"&&(v=new Function(""+v));for(var p=new Array(arguments.length-1),b=0;b<p.length;b++)p[b]=arguments[b+1];var g={callback:v,args:p};return I[L]=g,w(L),L++},U.clearImmediate=D}function D(v){delete I[v]}function x(v){if(P)setTimeout(x,0,v);else{var p=I[v];if(p){P=!0;try{(function(b){var g=b.callback,y=b.args;switch(y.length){case 0:g();break;case 1:g(y[0]);break;case 2:g(y[0],y[1]);break;case 3:g(y[0],y[1],y[2]);break;default:g.apply(void 0,y)}})(p)}finally{D(v),P=!1}}}}function M(v){v.source===d&&typeof v.data=="string"&&v.data.indexOf(N)===0&&x(+v.data.slice(N.length))}})(typeof self>"u"?u===void 0?this:u:self)}).call(this,a!==void 0?a:typeof self<"u"?self:typeof window<"u"?window:{})},{}]},{},[10])(10)})}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{},s("buffer").Buffer,arguments[3],arguments[4],arguments[5],arguments[6],s("timers").setImmediate)},{_process:467,buffer:220,timers:523}],442:[function(s,T,S){(function(m){(function(){var a=/[\\^$.*+?()[\]{}|]/g,o=RegExp(a.source),r=typeof m=="object"&&m&&m.Object===Object&&m,t=typeof self=="object"&&self&&self.Object===Object&&self,e=r||t||Function("return this")(),l=Object.prototype.toString,n=e.Symbol,i=n?n.prototype:void 0,f=i?i.toString:void 0;function c(u){if(typeof u=="string")return u;if(function(h){return typeof h=="symbol"||function(w){return!!w&&typeof w=="object"}(h)&&l.call(h)=="[object Symbol]"}(u))return f?f.call(u):"";var d=u+"";return d=="0"&&1/u==-1/0?"-0":d}T.exports=function(u){var d;return(u=(d=u)==null?"":c(d))&&o.test(u)?u.replace(a,"\\$&"):u}}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{}],443:[function(s,T,S){(function(m){(function(){var a="[object Arguments]",o="[object Map]",r="[object Object]",t="[object Set]",e=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,l=/^\w*$/,n=/^\./,i=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g,f=/\\(\\)?/g,c=/^\[object .+?Constructor\]$/,u=/^(?:0|[1-9]\d*)$/,d={};d["[object Float32Array]"]=d["[object Float64Array]"]=d["[object Int8Array]"]=d["[object Int16Array]"]=d["[object Int32Array]"]=d["[object Uint8Array]"]=d["[object Uint8ClampedArray]"]=d["[object Uint16Array]"]=d["[object Uint32Array]"]=!0,d[a]=d["[object Array]"]=d["[object ArrayBuffer]"]=d["[object Boolean]"]=d["[object DataView]"]=d["[object Date]"]=d["[object Error]"]=d["[object Function]"]=d[o]=d["[object Number]"]=d[r]=d["[object RegExp]"]=d[t]=d["[object String]"]=d["[object WeakMap]"]=!1;var h=typeof m=="object"&&m&&m.Object===Object&&m,w=typeof self=="object"&&self&&self.Object===Object&&self,_=h||w||Function("return this")(),A=typeof S=="object"&&S&&!S.nodeType&&S,N=A&&typeof T=="object"&&T&&!T.nodeType&&T,L=N&&N.exports===A&&h.process,I=function(){try{return L&&L.binding("util")}catch{}}(),P=I&&I.isTypedArray;function B(Y,at,ft,ht){for(var kt=-1,pt=Y?Y.length:0;++kt<pt;){var gt=Y[kt];at(ht,gt,ft(gt),Y)}return ht}function U(Y,at){for(var ft=-1,ht=Y?Y.length:0;++ft<ht;)if(at(Y[ft],ft,Y))return!0;return!1}function D(Y){var at=!1;if(Y!=null&&typeof Y.toString!="function")try{at=!!(Y+"")}catch{}return at}function x(Y){var at=-1,ft=Array(Y.size);return Y.forEach(function(ht,kt){ft[++at]=[kt,ht]}),ft}function M(Y){var at=-1,ft=Array(Y.size);return Y.forEach(function(ht){ft[++at]=ht}),ft}var v,p,b,g=Array.prototype,y=Function.prototype,k=Object.prototype,R=_["__core-js_shared__"],O=(v=/[^.]+$/.exec(R&&R.keys&&R.keys.IE_PROTO||""))?"Symbol(src)_1."+v:"",z=y.toString,$=k.hasOwnProperty,W=k.toString,j=RegExp("^"+z.call($).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),H=_.Symbol,E=_.Uint8Array,C=k.propertyIsEnumerable,F=g.splice,V=(p=Object.keys,b=Object,function(Y){return p(b(Y))}),Z=Dt(_,"DataView"),q=Dt(_,"Map"),K=Dt(_,"Promise"),et=Dt(_,"Set"),tt=Dt(_,"WeakMap"),X=Dt(Object,"create"),J=it(Z),G=it(q),nt=it(K),rt=it(et),st=it(tt),ot=H?H.prototype:void 0,lt=ot?ot.valueOf:void 0,ct=ot?ot.toString:void 0;function wt(Y){var at=-1,ft=Y?Y.length:0;for(this.clear();++at<ft;){var ht=Y[at];this.set(ht[0],ht[1])}}function vt(Y){var at=-1,ft=Y?Y.length:0;for(this.clear();++at<ft;){var ht=Y[at];this.set(ht[0],ht[1])}}function mt(Y){var at=-1,ft=Y?Y.length:0;for(this.clear();++at<ft;){var ht=Y[at];this.set(ht[0],ht[1])}}function Rt(Y){var at=-1,ft=Y?Y.length:0;for(this.__data__=new mt;++at<ft;)this.add(Y[at])}function Et(Y){this.__data__=new vt(Y)}function At(Y,at){var ft=Pt(Y)||Lt(Y)?function(gt,Zt){for(var Vt=-1,Wt=Array(gt);++Vt<gt;)Wt[Vt]=Zt(Vt);return Wt}(Y.length,String):[],ht=ft.length,kt=!!ht;for(var pt in Y)!$.call(Y,pt)||kt&&(pt=="length"||ae(pt,ht))||ft.push(pt);return ft}function jt(Y,at){for(var ft=Y.length;ft--;)if(yt(Y[ft][0],at))return ft;return-1}function _t(Y,at,ft,ht){return xt(Y,function(kt,pt,gt){at(ht,kt,ft(kt),gt)}),ht}wt.prototype.clear=function(){this.__data__=X?X(null):{}},wt.prototype.delete=function(Y){return this.has(Y)&&delete this.__data__[Y]},wt.prototype.get=function(Y){var at=this.__data__;if(X){var ft=at[Y];return ft==="__lodash_hash_undefined__"?void 0:ft}return $.call(at,Y)?at[Y]:void 0},wt.prototype.has=function(Y){var at=this.__data__;return X?at[Y]!==void 0:$.call(at,Y)},wt.prototype.set=function(Y,at){return this.__data__[Y]=X&&at===void 0?"__lodash_hash_undefined__":at,this},vt.prototype.clear=function(){this.__data__=[]},vt.prototype.delete=function(Y){var at=this.__data__,ft=jt(at,Y);return!(ft<0)&&(ft==at.length-1?at.pop():F.call(at,ft,1),!0)},vt.prototype.get=function(Y){var at=this.__data__,ft=jt(at,Y);return ft<0?void 0:at[ft][1]},vt.prototype.has=function(Y){return jt(this.__data__,Y)>-1},vt.prototype.set=function(Y,at){var ft=this.__data__,ht=jt(ft,Y);return ht<0?ft.push([Y,at]):ft[ht][1]=at,this},mt.prototype.clear=function(){this.__data__={hash:new wt,map:new(q||vt),string:new wt}},mt.prototype.delete=function(Y){return te(this,Y).delete(Y)},mt.prototype.get=function(Y){return te(this,Y).get(Y)},mt.prototype.has=function(Y){return te(this,Y).has(Y)},mt.prototype.set=function(Y,at){return te(this,Y).set(Y,at),this},Rt.prototype.add=Rt.prototype.push=function(Y){return this.__data__.set(Y,"__lodash_hash_undefined__"),this},Rt.prototype.has=function(Y){return this.__data__.has(Y)},Et.prototype.clear=function(){this.__data__=new vt},Et.prototype.delete=function(Y){return this.__data__.delete(Y)},Et.prototype.get=function(Y){return this.__data__.get(Y)},Et.prototype.has=function(Y){return this.__data__.has(Y)},Et.prototype.set=function(Y,at){var ft=this.__data__;if(ft instanceof vt){var ht=ft.__data__;if(!q||ht.length<199)return ht.push([Y,at]),this;ft=this.__data__=new mt(ht)}return ft.set(Y,at),this};var dt,xt=(dt=function(Y,at){return Y&&Tt(Y,at,pe)},function(Y,at){if(Y==null)return Y;if(!Ot(Y))return dt(Y,at);for(var ft=Y.length,ht=-1,kt=Object(Y);++ht<ft&&at(kt[ht],ht,kt)!==!1;);return Y}),Tt=function(Y){return function(at,ft,ht){for(var kt=-1,pt=Object(at),gt=ht(at),Zt=gt.length;Zt--;){var Vt=gt[++kt];if(ft(pt[Vt],Vt,pt)===!1)break}return at}}();function St(Y,at){for(var ft=0,ht=(at=Ft(at,Y)?[at]:Ut(at)).length;Y!=null&&ft<ht;)Y=Y[Q(at[ft++])];return ft&&ft==ht?Y:void 0}function Kt(Y,at){return Y!=null&&at in Object(Y)}function re(Y,at,ft,ht,kt){return Y===at||(Y==null||at==null||!qt(Y)&&!he(at)?Y!=Y&&at!=at:function(pt,gt,Zt,Vt,Wt,Bt){var ne=Pt(pt),ie=Pt(gt),le="[object Array]",ce="[object Array]";ne||(le=(le=Gt(pt))==a?r:le),ie||(ce=(ce=Gt(gt))==a?r:ce);var me=le==r&&!D(pt),be=ce==r&&!D(gt),ve=le==ce;if(ve&&!me)return Bt||(Bt=new Et),ne||de(pt)?ue(pt,gt,Zt,Vt,Wt,Bt):function(se,Jt,_e,Ce,Oe,ye,we){switch(_e){case"[object DataView]":if(se.byteLength!=Jt.byteLength||se.byteOffset!=Jt.byteOffset)return!1;se=se.buffer,Jt=Jt.buffer;case"[object ArrayBuffer]":return!(se.byteLength!=Jt.byteLength||!Ce(new E(se),new E(Jt)));case"[object Boolean]":case"[object Date]":case"[object Number]":return yt(+se,+Jt);case"[object Error]":return se.name==Jt.name&&se.message==Jt.message;case"[object RegExp]":case"[object String]":return se==Jt+"";case o:var xe=x;case t:var Re=2&ye;if(xe||(xe=M),se.size!=Jt.size&&!Re)return!1;var je=we.get(se);if(je)return je==Jt;ye|=1,we.set(se,Jt);var Ae=ue(xe(se),xe(Jt),Ce,Oe,ye,we);return we.delete(se),Ae;case"[object Symbol]":if(lt)return lt.call(se)==lt.call(Jt)}return!1}(pt,gt,le,Zt,Vt,Wt,Bt);if(!(2&Wt)){var ke=me&&$.call(pt,"__wrapped__"),Me=be&&$.call(gt,"__wrapped__");if(ke||Me){var Te=ke?pt.value():pt,Ee=Me?gt.value():gt;return Bt||(Bt=new Et),Zt(Te,Ee,Vt,Wt,Bt)}}return ve?(Bt||(Bt=new Et),function(se,Jt,_e,Ce,Oe,ye){var we=2&Oe,xe=pe(se),Re=xe.length,je=pe(Jt).length;if(Re!=je&&!we)return!1;for(var Ae=Re;Ae--;){var Se=xe[Ae];if(!(we?Se in Jt:$.call(Jt,Se)))return!1}var $e=ye.get(se);if($e&&ye.get(Jt))return $e==Jt;var Ie=!0;ye.set(se,Jt),ye.set(Jt,se);for(var Le=we;++Ae<Re;){Se=xe[Ae];var Ne=se[Se],Pe=Jt[Se];if(Ce)var He=we?Ce(Pe,Ne,Se,Jt,se,ye):Ce(Ne,Pe,Se,se,Jt,ye);if(!(He===void 0?Ne===Pe||_e(Ne,Pe,Ce,Oe,ye):He)){Ie=!1;break}Le||(Le=Se=="constructor")}if(Ie&&!Le){var Be=se.constructor,De=Jt.constructor;Be==De||!("constructor"in se)||!("constructor"in Jt)||typeof Be=="function"&&Be instanceof Be&&typeof De=="function"&&De instanceof De||(Ie=!1)}return ye.delete(se),ye.delete(Jt),Ie}(pt,gt,Zt,Vt,Wt,Bt)):!1}(Y,at,re,ft,ht,kt))}function It(Y){return!(!qt(Y)||function(at){return!!O&&O in at}(Y))&&($t(Y)||D(Y)?j:c).test(it(Y))}function Qt(Y){return typeof Y=="function"?Y:Y==null?ge:typeof Y=="object"?Pt(Y)?function(ht,kt){return Ft(ht)&&ee(kt)?oe(Q(ht),kt):function(pt){var gt=function(Zt,Vt,Wt){var Bt=Zt==null?void 0:St(Zt,Vt);return Bt===void 0?Wt:Bt}(pt,ht);return gt===void 0&&gt===kt?function(Zt,Vt){return Zt!=null&&function(Wt,Bt,ne){Bt=Ft(Bt,Wt)?[Bt]:Ut(Bt);for(var ie,le=-1,ce=Bt.length;++le<ce;){var me=Q(Bt[le]);if(!(ie=Wt!=null&&ne(Wt,me)))break;Wt=Wt[me]}return ie||!!(ce=Wt?Wt.length:0)&&zt(ce)&&ae(me,ce)&&(Pt(Wt)||Lt(Wt))}(Zt,Vt,Kt)}(pt,ht):re(kt,gt,void 0,3)}}(Y[0],Y[1]):function(ht){var kt=function(pt){for(var gt=pe(pt),Zt=gt.length;Zt--;){var Vt=gt[Zt],Wt=pt[Vt];gt[Zt]=[Vt,Wt,ee(Wt)]}return gt}(ht);return kt.length==1&&kt[0][2]?oe(kt[0][0],kt[0][1]):function(pt){return pt===ht||function(gt,Zt,Vt,Wt){var Bt=Vt.length,ne=Bt;if(gt==null)return!ne;for(gt=Object(gt);Bt--;){var ie=Vt[Bt];if(ie[2]?ie[1]!==gt[ie[0]]:!(ie[0]in gt))return!1}for(;++Bt<ne;){var le=(ie=Vt[Bt])[0],ce=gt[le],me=ie[1];if(ie[2]){if(ce===void 0&&!(le in gt))return!1}else{var be=new Et,ve;if(!(ve===void 0?re(me,ce,Wt,3,be):ve))return!1}}return!0}(pt,ht,kt)}}(Y):Ft(at=Y)?(ft=Q(at),function(ht){return ht?.[ft]}):function(ht){return function(kt){return St(kt,ht)}}(at);var at,ft}function Xt(Y){if(ft=(at=Y)&&at.constructor,ht=typeof ft=="function"&&ft.prototype||k,at!==ht)return V(Y);var at,ft,ht,kt=[];for(var pt in Object(Y))$.call(Y,pt)&&pt!="constructor"&&kt.push(pt);return kt}function Ut(Y){return Pt(Y)?Y:Ht(Y)}function ue(Y,at,ft,ht,kt,pt){var gt=2&kt,Zt=Y.length,Vt=at.length;if(Zt!=Vt&&!(gt&&Vt>Zt))return!1;var Wt=pt.get(Y);if(Wt&&pt.get(at))return Wt==at;var Bt=-1,ne=!0,ie=1&kt?new Rt:void 0;for(pt.set(Y,at),pt.set(at,Y);++Bt<Zt;){var le=Y[Bt],ce=at[Bt];if(ht)var me=gt?ht(ce,le,Bt,at,Y,pt):ht(le,ce,Bt,Y,at,pt);if(me!==void 0){if(me)continue;ne=!1;break}if(ie){if(!U(at,function(be,ve){if(!ie.has(ve)&&(le===be||ft(le,be,ht,kt,pt)))return ie.add(ve)})){ne=!1;break}}else if(le!==ce&&!ft(le,ce,ht,kt,pt)){ne=!1;break}}return pt.delete(Y),pt.delete(at),ne}function te(Y,at){var ft,ht,kt=Y.__data__;return((ht=typeof(ft=at))=="string"||ht=="number"||ht=="symbol"||ht=="boolean"?ft!=="__proto__":ft===null)?kt[typeof at=="string"?"string":"hash"]:kt.map}function Dt(Y,at){var ft=function(ht,kt){return ht?.[kt]}(Y,at);return It(ft)?ft:void 0}var Gt=function(Y){return W.call(Y)};function ae(Y,at){return!!(at=at??9007199254740991)&&(typeof Y=="number"||u.test(Y))&&Y>-1&&Y%1==0&&Y<at}function Ft(Y,at){if(Pt(Y))return!1;var ft=typeof Y;return!(ft!="number"&&ft!="symbol"&&ft!="boolean"&&Y!=null&&!fe(Y))||l.test(Y)||!e.test(Y)||at!=null&&Y in Object(at)}function ee(Y){return Y==Y&&!qt(Y)}function oe(Y,at){return function(ft){return ft!=null&&ft[Y]===at&&(at!==void 0||Y in Object(ft))}}(Z&&Gt(new Z(new ArrayBuffer(1)))!="[object DataView]"||q&&Gt(new q)!=o||K&&Gt(K.resolve())!="[object Promise]"||et&&Gt(new et)!=t||tt&&Gt(new tt)!="[object WeakMap]")&&(Gt=function(Y){var at=W.call(Y),ft=at==r?Y.constructor:void 0,ht=ft?it(ft):void 0;if(ht)switch(ht){case J:return"[object DataView]";case G:return o;case nt:return"[object Promise]";case rt:return t;case st:return"[object WeakMap]"}return at});var Ht=Nt(function(Y){var at;Y=(at=Y)==null?"":function(ht){if(typeof ht=="string")return ht;if(fe(ht))return ct?ct.call(ht):"";var kt=ht+"";return kt=="0"&&1/ht==-1/0?"-0":kt}(at);var ft=[];return n.test(Y)&&ft.push(""),Y.replace(i,function(ht,kt,pt,gt){ft.push(pt?gt.replace(f,"$1"):kt||ht)}),ft});function Q(Y){if(typeof Y=="string"||fe(Y))return Y;var at=Y+"";return at=="0"&&1/Y==-1/0?"-0":at}function it(Y){if(Y!=null){try{return z.call(Y)}catch{}try{return Y+""}catch{}}return""}var ut,bt=(ut=function(Y,at,ft){$.call(Y,ft)?Y[ft].push(at):Y[ft]=[at]},function(Y,at){var ft=Pt(Y)?B:_t,ht={};return ft(Y,ut,Qt(at),ht)});function Nt(Y,at){if(typeof Y!="function"||at&&typeof at!="function")throw new TypeError("Expected a function");var ft=function(){var ht=arguments,kt=at?at.apply(this,ht):ht[0],pt=ft.cache;if(pt.has(kt))return pt.get(kt);var gt=Y.apply(this,ht);return ft.cache=pt.set(kt,gt),gt};return ft.cache=new(Nt.Cache||mt),ft}function yt(Y,at){return Y===at||Y!=Y&&at!=at}function Lt(Y){return function(at){return he(at)&&Ot(at)}(Y)&&$.call(Y,"callee")&&(!C.call(Y,"callee")||W.call(Y)==a)}Nt.Cache=mt;var Pt=Array.isArray;function Ot(Y){return Y!=null&&zt(Y.length)&&!$t(Y)}function $t(Y){var at=qt(Y)?W.call(Y):"";return at=="[object Function]"||at=="[object GeneratorFunction]"}function zt(Y){return typeof Y=="number"&&Y>-1&&Y%1==0&&Y<=9007199254740991}function qt(Y){var at=typeof Y;return!!Y&&(at=="object"||at=="function")}function he(Y){return!!Y&&typeof Y=="object"}function fe(Y){return typeof Y=="symbol"||he(Y)&&W.call(Y)=="[object Symbol]"}var de=P?function(Y){return function(at){return Y(at)}}(P):function(Y){return he(Y)&&zt(Y.length)&&!!d[W.call(Y)]};function pe(Y){return Ot(Y)?At(Y):Xt(Y)}function ge(Y){return Y}T.exports=bt}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{}],444:[function(s,T,S){var m=Object.prototype.toString;T.exports=function(a){return a===!0||a===!1||function(o){return!!o&&typeof o=="object"}(a)&&m.call(a)=="[object Boolean]"}},{}],445:[function(s,T,S){(function(m){(function(){var a="[object Arguments]",o="[object Map]",r="[object Object]",t="[object Set]",e=/^\[object .+?Constructor\]$/,l=/^(?:0|[1-9]\d*)$/,n={};n["[object Float32Array]"]=n["[object Float64Array]"]=n["[object Int8Array]"]=n["[object Int16Array]"]=n["[object Int32Array]"]=n["[object Uint8Array]"]=n["[object Uint8ClampedArray]"]=n["[object Uint16Array]"]=n["[object Uint32Array]"]=!0,n[a]=n["[object Array]"]=n["[object ArrayBuffer]"]=n["[object Boolean]"]=n["[object DataView]"]=n["[object Date]"]=n["[object Error]"]=n["[object Function]"]=n[o]=n["[object Number]"]=n[r]=n["[object RegExp]"]=n[t]=n["[object String]"]=n["[object WeakMap]"]=!1;var i=typeof m=="object"&&m&&m.Object===Object&&m,f=typeof self=="object"&&self&&self.Object===Object&&self,c=i||f||Function("return this")(),u=typeof S=="object"&&S&&!S.nodeType&&S,d=u&&typeof T=="object"&&T&&!T.nodeType&&T,h=d&&d.exports===u,w=h&&i.process,_=function(){try{return w&&w.binding&&w.binding("util")}catch{}}(),A=_&&_.isTypedArray;function N(Q,it){for(var ut=-1,bt=Q==null?0:Q.length;++ut<bt;)if(it(Q[ut],ut,Q))return!0;return!1}function L(Q){var it=-1,ut=Array(Q.size);return Q.forEach(function(bt,Nt){ut[++it]=[Nt,bt]}),ut}function I(Q){var it=-1,ut=Array(Q.size);return Q.forEach(function(bt){ut[++it]=bt}),ut}var P,B,U,D=Array.prototype,x=Function.prototype,M=Object.prototype,v=c["__core-js_shared__"],p=x.toString,b=M.hasOwnProperty,g=(P=/[^.]+$/.exec(v&&v.keys&&v.keys.IE_PROTO||""))?"Symbol(src)_1."+P:"",y=M.toString,k=RegExp("^"+p.call(b).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),R=h?c.Buffer:void 0,O=c.Symbol,z=c.Uint8Array,$=M.propertyIsEnumerable,W=D.splice,j=O?O.toStringTag:void 0,H=Object.getOwnPropertySymbols,E=R?R.isBuffer:void 0,C=(B=Object.keys,U=Object,function(Q){return B(U(Q))}),F=Kt(c,"DataView"),V=Kt(c,"Map"),Z=Kt(c,"Promise"),q=Kt(c,"Set"),K=Kt(c,"WeakMap"),et=Kt(Object,"create"),tt=Xt(F),X=Xt(V),J=Xt(Z),G=Xt(q),nt=Xt(K),rt=O?O.prototype:void 0,st=rt?rt.valueOf:void 0;function ot(Q){var it=-1,ut=Q==null?0:Q.length;for(this.clear();++it<ut;){var bt=Q[it];this.set(bt[0],bt[1])}}function lt(Q){var it=-1,ut=Q==null?0:Q.length;for(this.clear();++it<ut;){var bt=Q[it];this.set(bt[0],bt[1])}}function ct(Q){var it=-1,ut=Q==null?0:Q.length;for(this.clear();++it<ut;){var bt=Q[it];this.set(bt[0],bt[1])}}function wt(Q){var it=-1,ut=Q==null?0:Q.length;for(this.__data__=new ct;++it<ut;)this.add(Q[it])}function vt(Q){var it=this.__data__=new lt(Q);this.size=it.size}function mt(Q,it){var ut=te(Q),bt=!ut&&ue(Q),Nt=!ut&&!bt&&Dt(Q),yt=!ut&&!bt&&!Nt&&oe(Q),Lt=ut||bt||Nt||yt,Pt=Lt?function(zt,qt){for(var he=-1,fe=Array(zt);++he<zt;)fe[he]=qt(he);return fe}(Q.length,String):[],Ot=Pt.length;for(var $t in Q)!b.call(Q,$t)||Lt&&($t=="length"||Nt&&($t=="offset"||$t=="parent")||yt&&($t=="buffer"||$t=="byteLength"||$t=="byteOffset")||Qt($t,Ot))||Pt.push($t);return Pt}function Rt(Q,it){for(var ut=Q.length;ut--;)if(Ut(Q[ut][0],it))return ut;return-1}function Et(Q){return Q==null?Q===void 0?"[object Undefined]":"[object Null]":j&&j in Object(Q)?function(it){var ut=b.call(it,j),bt=it[j];try{it[j]=void 0;var Nt=!0}catch{}var yt=y.call(it);return Nt&&(ut?it[j]=bt:delete it[j]),yt}(Q):function(it){return y.call(it)}(Q)}function At(Q){return ee(Q)&&Et(Q)==a}function jt(Q,it,ut,bt,Nt){return Q===it||(Q==null||it==null||!ee(Q)&&!ee(it)?Q!=Q&&it!=it:function(yt,Lt,Pt,Ot,$t,zt){var qt=te(yt),he=te(Lt),fe=qt?"[object Array]":It(yt),de=he?"[object Array]":It(Lt),pe=(fe=fe==a?r:fe)==r,ge=(de=de==a?r:de)==r,Y=fe==de;if(Y&&Dt(yt)){if(!Dt(Lt))return!1;qt=!0,pe=!1}if(Y&&!pe)return zt||(zt=new vt),qt||oe(yt)?xt(yt,Lt,Pt,Ot,$t,zt):function(pt,gt,Zt,Vt,Wt,Bt,ne){switch(Zt){case"[object DataView]":if(pt.byteLength!=gt.byteLength||pt.byteOffset!=gt.byteOffset)return!1;pt=pt.buffer,gt=gt.buffer;case"[object ArrayBuffer]":return!(pt.byteLength!=gt.byteLength||!Bt(new z(pt),new z(gt)));case"[object Boolean]":case"[object Date]":case"[object Number]":return Ut(+pt,+gt);case"[object Error]":return pt.name==gt.name&&pt.message==gt.message;case"[object RegExp]":case"[object String]":return pt==gt+"";case o:var ie=L;case t:var le=1&Vt;if(ie||(ie=I),pt.size!=gt.size&&!le)return!1;var ce=ne.get(pt);if(ce)return ce==gt;Vt|=2,ne.set(pt,gt);var me=xt(ie(pt),ie(gt),Vt,Wt,Bt,ne);return ne.delete(pt),me;case"[object Symbol]":if(st)return st.call(pt)==st.call(gt)}return!1}(yt,Lt,fe,Pt,Ot,$t,zt);if(!(1&Pt)){var at=pe&&b.call(yt,"__wrapped__"),ft=ge&&b.call(Lt,"__wrapped__");if(at||ft){var ht=at?yt.value():yt,kt=ft?Lt.value():Lt;return zt||(zt=new vt),$t(ht,kt,Pt,Ot,zt)}}return Y?(zt||(zt=new vt),function(pt,gt,Zt,Vt,Wt,Bt){var ne=1&Zt,ie=Tt(pt),le=ie.length,ce=Tt(gt).length;if(le!=ce&&!ne)return!1;for(var me=le;me--;){var be=ie[me];if(!(ne?be in gt:b.call(gt,be)))return!1}var ve=Bt.get(pt);if(ve&&Bt.get(gt))return ve==gt;var ke=!0;Bt.set(pt,gt),Bt.set(gt,pt);for(var Me=ne;++me<le;){be=ie[me];var Te=pt[be],Ee=gt[be];if(Vt)var se=ne?Vt(Ee,Te,be,gt,pt,Bt):Vt(Te,Ee,be,pt,gt,Bt);if(!(se===void 0?Te===Ee||Wt(Te,Ee,Zt,Vt,Bt):se)){ke=!1;break}Me||(Me=be=="constructor")}if(ke&&!Me){var Jt=pt.constructor,_e=gt.constructor;Jt==_e||!("constructor"in pt)||!("constructor"in gt)||typeof Jt=="function"&&Jt instanceof Jt&&typeof _e=="function"&&_e instanceof _e||(ke=!1)}return Bt.delete(pt),Bt.delete(gt),ke}(yt,Lt,Pt,Ot,$t,zt)):!1}(Q,it,ut,bt,jt,Nt))}function _t(Q){return!(!Ft(Q)||function(it){return!!g&&g in it}(Q))&&(Gt(Q)?k:e).test(Xt(Q))}function dt(Q){if(ut=(it=Q)&&it.constructor,bt=typeof ut=="function"&&ut.prototype||M,it!==bt)return C(Q);var it,ut,bt,Nt=[];for(var yt in Object(Q))b.call(Q,yt)&&yt!="constructor"&&Nt.push(yt);return Nt}function xt(Q,it,ut,bt,Nt,yt){var Lt=1&ut,Pt=Q.length,Ot=it.length;if(Pt!=Ot&&!(Lt&&Ot>Pt))return!1;var $t=yt.get(Q);if($t&&yt.get(it))return $t==it;var zt=-1,qt=!0,he=2&ut?new wt:void 0;for(yt.set(Q,it),yt.set(it,Q);++zt<Pt;){var fe=Q[zt],de=it[zt];if(bt)var pe=Lt?bt(de,fe,zt,it,Q,yt):bt(fe,de,zt,Q,it,yt);if(pe!==void 0){if(pe)continue;qt=!1;break}if(he){if(!N(it,function(ge,Y){if(at=Y,!he.has(at)&&(fe===ge||Nt(fe,ge,ut,bt,yt)))return he.push(Y);var at})){qt=!1;break}}else if(fe!==de&&!Nt(fe,de,ut,bt,yt)){qt=!1;break}}return yt.delete(Q),yt.delete(it),qt}function Tt(Q){return function(it,ut,bt){var Nt=ut(it);return te(it)?Nt:function(yt,Lt){for(var Pt=-1,Ot=Lt.length,$t=yt.length;++Pt<Ot;)yt[$t+Pt]=Lt[Pt];return yt}(Nt,bt(it))}(Q,Ht,re)}function St(Q,it){var ut,bt,Nt=Q.__data__;return((bt=typeof(ut=it))=="string"||bt=="number"||bt=="symbol"||bt=="boolean"?ut!=="__proto__":ut===null)?Nt[typeof it=="string"?"string":"hash"]:Nt.map}function Kt(Q,it){var ut=function(bt,Nt){return bt?.[Nt]}(Q,it);return _t(ut)?ut:void 0}ot.prototype.clear=function(){this.__data__=et?et(null):{},this.size=0},ot.prototype.delete=function(Q){var it=this.has(Q)&&delete this.__data__[Q];return this.size-=it?1:0,it},ot.prototype.get=function(Q){var it=this.__data__;if(et){var ut=it[Q];return ut==="__lodash_hash_undefined__"?void 0:ut}return b.call(it,Q)?it[Q]:void 0},ot.prototype.has=function(Q){var it=this.__data__;return et?it[Q]!==void 0:b.call(it,Q)},ot.prototype.set=function(Q,it){var ut=this.__data__;return this.size+=this.has(Q)?0:1,ut[Q]=et&&it===void 0?"__lodash_hash_undefined__":it,this},lt.prototype.clear=function(){this.__data__=[],this.size=0},lt.prototype.delete=function(Q){var it=this.__data__,ut=Rt(it,Q);return!(ut<0)&&(ut==it.length-1?it.pop():W.call(it,ut,1),--this.size,!0)},lt.prototype.get=function(Q){var it=this.__data__,ut=Rt(it,Q);return ut<0?void 0:it[ut][1]},lt.prototype.has=function(Q){return Rt(this.__data__,Q)>-1},lt.prototype.set=function(Q,it){var ut=this.__data__,bt=Rt(ut,Q);return bt<0?(++this.size,ut.push([Q,it])):ut[bt][1]=it,this},ct.prototype.clear=function(){this.size=0,this.__data__={hash:new ot,map:new(V||lt),string:new ot}},ct.prototype.delete=function(Q){var it=St(this,Q).delete(Q);return this.size-=it?1:0,it},ct.prototype.get=function(Q){return St(this,Q).get(Q)},ct.prototype.has=function(Q){return St(this,Q).has(Q)},ct.prototype.set=function(Q,it){var ut=St(this,Q),bt=ut.size;return ut.set(Q,it),this.size+=ut.size==bt?0:1,this},wt.prototype.add=wt.prototype.push=function(Q){return this.__data__.set(Q,"__lodash_hash_undefined__"),this},wt.prototype.has=function(Q){return this.__data__.has(Q)},vt.prototype.clear=function(){this.__data__=new lt,this.size=0},vt.prototype.delete=function(Q){var it=this.__data__,ut=it.delete(Q);return this.size=it.size,ut},vt.prototype.get=function(Q){return this.__data__.get(Q)},vt.prototype.has=function(Q){return this.__data__.has(Q)},vt.prototype.set=function(Q,it){var ut=this.__data__;if(ut instanceof lt){var bt=ut.__data__;if(!V||bt.length<199)return bt.push([Q,it]),this.size=++ut.size,this;ut=this.__data__=new ct(bt)}return ut.set(Q,it),this.size=ut.size,this};var re=H?function(Q){return Q==null?[]:(Q=Object(Q),function(it,ut){for(var bt=-1,Nt=it==null?0:it.length,yt=0,Lt=[];++bt<Nt;){var Pt=it[bt];ut(Pt,bt,it)&&(Lt[yt++]=Pt)}return Lt}(H(Q),function(it){return $.call(Q,it)}))}:function(){return[]},It=Et;function Qt(Q,it){return!!(it=it??9007199254740991)&&(typeof Q=="number"||l.test(Q))&&Q>-1&&Q%1==0&&Q<it}function Xt(Q){if(Q!=null){try{return p.call(Q)}catch{}try{return Q+""}catch{}}return""}function Ut(Q,it){return Q===it||Q!=Q&&it!=it}(F&&It(new F(new ArrayBuffer(1)))!="[object DataView]"||V&&It(new V)!=o||Z&&It(Z.resolve())!="[object Promise]"||q&&It(new q)!=t||K&&It(new K)!="[object WeakMap]")&&(It=function(Q){var it=Et(Q),ut=it==r?Q.constructor:void 0,bt=ut?Xt(ut):"";if(bt)switch(bt){case tt:return"[object DataView]";case X:return o;case J:return"[object Promise]";case G:return t;case nt:return"[object WeakMap]"}return it});var ue=At(function(){return arguments}())?At:function(Q){return ee(Q)&&b.call(Q,"callee")&&!$.call(Q,"callee")},te=Array.isArray,Dt=E||function(){return!1};function Gt(Q){if(!Ft(Q))return!1;var it=Et(Q);return it=="[object Function]"||it=="[object GeneratorFunction]"||it=="[object AsyncFunction]"||it=="[object Proxy]"}function ae(Q){return typeof Q=="number"&&Q>-1&&Q%1==0&&Q<=9007199254740991}function Ft(Q){var it=typeof Q;return Q!=null&&(it=="object"||it=="function")}function ee(Q){return Q!=null&&typeof Q=="object"}var oe=A?function(Q){return function(it){return Q(it)}}(A):function(Q){return ee(Q)&&ae(Q.length)&&!!n[Et(Q)]};function Ht(Q){return(it=Q)!=null&&ae(it.length)&&!Gt(it)?mt(Q):dt(Q);var it}T.exports=function(Q,it){return jt(Q,it)}}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{}],446:[function(s,T,S){(function(m){(function(){var a=typeof m=="object"&&m&&m.Object===Object&&m,o=typeof self=="object"&&self&&self.Object===Object&&self,r=a||o||Function("return this")(),t=Object.prototype,e=t.hasOwnProperty,l=t.toString,n=r.Symbol,i=n?n.toStringTag:void 0;function f(c){return c==null?c===void 0?"[object Undefined]":"[object Null]":i&&i in Object(c)?function(u){var d=e.call(u,i),h=u[i];try{u[i]=void 0;var w=!0}catch{}var _=l.call(u);return w&&(d?u[i]=h:delete u[i]),_}(c):function(u){return l.call(u)}(c)}T.exports=function(c){if(!function(d){var h=typeof d;return d!=null&&(h=="object"||h=="function")}(c))return!1;var u=f(c);return u=="[object Function]"||u=="[object GeneratorFunction]"||u=="[object AsyncFunction]"||u=="[object Proxy]"}}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{}],447:[function(s,T,S){T.exports=function(m){return m==null}},{}],448:[function(s,T,S){T.exports=function(m){return m===void 0}},{}],449:[function(s,T,S){(function(m){(function(){var a=/^\[object .+?Constructor\]$/,o=typeof m=="object"&&m&&m.Object===Object&&m,r=typeof self=="object"&&self&&self.Object===Object&&self,t=o||r||Function("return this")();function e(O,z){return!!(O&&O.length)&&function($,W,j){if(W!=W)return function(C,F,V,Z){for(var q=C.length,K=V+-1;++K<q;)if(F(C[K],K,C))return K;return-1}($,l,j);for(var H=j-1,E=$.length;++H<E;)if($[H]===W)return H;return-1}(O,z,0)>-1}function l(O){return O!=O}function n(O,z){return O.has(z)}function i(O){var z=-1,$=Array(O.size);return O.forEach(function(W){$[++z]=W}),$}var f,c=Array.prototype,u=Function.prototype,d=Object.prototype,h=t["__core-js_shared__"],w=(f=/[^.]+$/.exec(h&&h.keys&&h.keys.IE_PROTO||""))?"Symbol(src)_1."+f:"",_=u.toString,A=d.hasOwnProperty,N=d.toString,L=RegExp("^"+_.call(A).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),I=c.splice,P=k(t,"Map"),B=k(t,"Set"),U=k(Object,"create");function D(O){var z=-1,$=O?O.length:0;for(this.clear();++z<$;){var W=O[z];this.set(W[0],W[1])}}function x(O){var z=-1,$=O?O.length:0;for(this.clear();++z<$;){var W=O[z];this.set(W[0],W[1])}}function M(O){var z=-1,$=O?O.length:0;for(this.clear();++z<$;){var W=O[z];this.set(W[0],W[1])}}function v(O){var z=-1,$=O?O.length:0;for(this.__data__=new M;++z<$;)this.add(O[z])}function p(O,z){for(var $,W,j=O.length;j--;)if(($=O[j][0])===(W=z)||$!=$&&W!=W)return j;return-1}function b(O){return!(!R(O)||(z=O,w&&w in z))&&(function($){var W=R($)?N.call($):"";return W=="[object Function]"||W=="[object GeneratorFunction]"}(O)||function($){var W=!1;if($!=null&&typeof $.toString!="function")try{W=!!($+"")}catch{}return W}(O)?L:a).test(function($){if($!=null){try{return _.call($)}catch{}try{return $+""}catch{}}return""}(O));var z}D.prototype.clear=function(){this.__data__=U?U(null):{}},D.prototype.delete=function(O){return this.has(O)&&delete this.__data__[O]},D.prototype.get=function(O){var z=this.__data__;if(U){var $=z[O];return $==="__lodash_hash_undefined__"?void 0:$}return A.call(z,O)?z[O]:void 0},D.prototype.has=function(O){var z=this.__data__;return U?z[O]!==void 0:A.call(z,O)},D.prototype.set=function(O,z){return this.__data__[O]=U&&z===void 0?"__lodash_hash_undefined__":z,this},x.prototype.clear=function(){this.__data__=[]},x.prototype.delete=function(O){var z=this.__data__,$=p(z,O);return!($<0)&&($==z.length-1?z.pop():I.call(z,$,1),!0)},x.prototype.get=function(O){var z=this.__data__,$=p(z,O);return $<0?void 0:z[$][1]},x.prototype.has=function(O){return p(this.__data__,O)>-1},x.prototype.set=function(O,z){var $=this.__data__,W=p($,O);return W<0?$.push([O,z]):$[W][1]=z,this},M.prototype.clear=function(){this.__data__={hash:new D,map:new(P||x),string:new D}},M.prototype.delete=function(O){return y(this,O).delete(O)},M.prototype.get=function(O){return y(this,O).get(O)},M.prototype.has=function(O){return y(this,O).has(O)},M.prototype.set=function(O,z){return y(this,O).set(O,z),this},v.prototype.add=v.prototype.push=function(O){return this.__data__.set(O,"__lodash_hash_undefined__"),this},v.prototype.has=function(O){return this.__data__.has(O)};var g=B&&1/i(new B([,-0]))[1]==1/0?function(O){return new B(O)}:function(){};function y(O,z){var $,W,j=O.__data__;return((W=typeof($=z))=="string"||W=="number"||W=="symbol"||W=="boolean"?$!=="__proto__":$===null)?j[typeof z=="string"?"string":"hash"]:j.map}function k(O,z){var $=function(W,j){return W?.[j]}(O,z);return b($)?$:void 0}function R(O){var z=typeof O;return!!O&&(z=="object"||z=="function")}T.exports=function(O){return O&&O.length?function(z,$,W){var j=-1,H=e,E=z.length,C=!0,F=[],V=F;if(E>=200){var Z=g(z);if(Z)return i(Z);C=!1,H=n,V=new v}else V=F;t:for(;++j<E;){var q=z[j],K=q;if(q=q!==0?q:0,C&&K==K){for(var et=V.length;et--;)if(V[et]===K)continue t;F.push(q)}else H(V,K,W)||(V!==F&&V.push(K),F.push(q))}return F}(O):[]}}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{}],450:[function(s,T,S){var m=s("inherits"),a=s("hash-base"),o=s("safe-buffer").Buffer,r=new Array(16);function t(){a.call(this,64),this._a=1732584193,this._b=4023233417,this._c=2562383102,this._d=271733878}function e(c,u){return c<<u|c>>>32-u}function l(c,u,d,h,w,_,A){return e(c+(u&d|~u&h)+w+_|0,A)+u|0}function n(c,u,d,h,w,_,A){return e(c+(u&h|d&~h)+w+_|0,A)+u|0}function i(c,u,d,h,w,_,A){return e(c+(u^d^h)+w+_|0,A)+u|0}function f(c,u,d,h,w,_,A){return e(c+(d^(u|~h))+w+_|0,A)+u|0}m(t,a),t.prototype._update=function(){for(var c=r,u=0;u<16;++u)c[u]=this._block.readInt32LE(4*u);var d=this._a,h=this._b,w=this._c,_=this._d;d=l(d,h,w,_,c[0],3614090360,7),_=l(_,d,h,w,c[1],3905402710,12),w=l(w,_,d,h,c[2],606105819,17),h=l(h,w,_,d,c[3],3250441966,22),d=l(d,h,w,_,c[4],4118548399,7),_=l(_,d,h,w,c[5],1200080426,12),w=l(w,_,d,h,c[6],2821735955,17),h=l(h,w,_,d,c[7],4249261313,22),d=l(d,h,w,_,c[8],1770035416,7),_=l(_,d,h,w,c[9],2336552879,12),w=l(w,_,d,h,c[10],4294925233,17),h=l(h,w,_,d,c[11],2304563134,22),d=l(d,h,w,_,c[12],1804603682,7),_=l(_,d,h,w,c[13],4254626195,12),w=l(w,_,d,h,c[14],2792965006,17),d=n(d,h=l(h,w,_,d,c[15],1236535329,22),w,_,c[1],4129170786,5),_=n(_,d,h,w,c[6],3225465664,9),w=n(w,_,d,h,c[11],643717713,14),h=n(h,w,_,d,c[0],3921069994,20),d=n(d,h,w,_,c[5],3593408605,5),_=n(_,d,h,w,c[10],38016083,9),w=n(w,_,d,h,c[15],3634488961,14),h=n(h,w,_,d,c[4],3889429448,20),d=n(d,h,w,_,c[9],568446438,5),_=n(_,d,h,w,c[14],3275163606,9),w=n(w,_,d,h,c[3],4107603335,14),h=n(h,w,_,d,c[8],1163531501,20),d=n(d,h,w,_,c[13],2850285829,5),_=n(_,d,h,w,c[2],4243563512,9),w=n(w,_,d,h,c[7],1735328473,14),d=i(d,h=n(h,w,_,d,c[12],2368359562,20),w,_,c[5],4294588738,4),_=i(_,d,h,w,c[8],2272392833,11),w=i(w,_,d,h,c[11],1839030562,16),h=i(h,w,_,d,c[14],4259657740,23),d=i(d,h,w,_,c[1],2763975236,4),_=i(_,d,h,w,c[4],1272893353,11),w=i(w,_,d,h,c[7],4139469664,16),h=i(h,w,_,d,c[10],3200236656,23),d=i(d,h,w,_,c[13],681279174,4),_=i(_,d,h,w,c[0],3936430074,11),w=i(w,_,d,h,c[3],3572445317,16),h=i(h,w,_,d,c[6],76029189,23),d=i(d,h,w,_,c[9],3654602809,4),_=i(_,d,h,w,c[12],3873151461,11),w=i(w,_,d,h,c[15],530742520,16),d=f(d,h=i(h,w,_,d,c[2],3299628645,23),w,_,c[0],4096336452,6),_=f(_,d,h,w,c[7],1126891415,10),w=f(w,_,d,h,c[14],2878612391,15),h=f(h,w,_,d,c[5],4237533241,21),d=f(d,h,w,_,c[12],1700485571,6),_=f(_,d,h,w,c[3],2399980690,10),w=f(w,_,d,h,c[10],4293915773,15),h=f(h,w,_,d,c[1],2240044497,21),d=f(d,h,w,_,c[8],1873313359,6),_=f(_,d,h,w,c[15],4264355552,10),w=f(w,_,d,h,c[6],2734768916,15),h=f(h,w,_,d,c[13],1309151649,21),d=f(d,h,w,_,c[4],4149444226,6),_=f(_,d,h,w,c[11],3174756917,10),w=f(w,_,d,h,c[2],718787259,15),h=f(h,w,_,d,c[9],3951481745,21),this._a=this._a+d|0,this._b=this._b+h|0,this._c=this._c+w|0,this._d=this._d+_|0},t.prototype._digest=function(){this._block[this._blockOffset++]=128,this._blockOffset>56&&(this._block.fill(0,this._blockOffset,64),this._update(),this._blockOffset=0),this._block.fill(0,this._blockOffset,56),this._block.writeUInt32LE(this._length[0],56),this._block.writeUInt32LE(this._length[1],60),this._update();var c=o.allocUnsafe(16);return c.writeInt32LE(this._a,0),c.writeInt32LE(this._b,4),c.writeInt32LE(this._c,8),c.writeInt32LE(this._d,12),c},T.exports=t},{"hash-base":425,inherits:440,"safe-buffer":494}],451:[function(s,T,S){var m=s("bn.js"),a=s("brorand");function o(r){this.rand=r||new a.Rand}T.exports=o,o.create=function(r){return new o(r)},o.prototype._randbelow=function(r){var t=r.bitLength(),e=Math.ceil(t/8);do var l=new m(this.rand.generate(e));while(l.cmp(r)>=0);return l},o.prototype._randrange=function(r,t){var e=t.sub(r);return r.add(this._randbelow(e))},o.prototype.test=function(r,t,e){var l=r.bitLength(),n=m.mont(r),i=new m(1).toRed(n);t||(t=Math.max(1,l/48|0));for(var f=r.subn(1),c=0;!f.testn(c);c++);for(var u=r.shrn(c),d=f.toRed(n);t>0;t--){var h=this._randrange(new m(2),f);e&&e(h);var w=h.toRed(n).redPow(u);if(w.cmp(i)!==0&&w.cmp(d)!==0){for(var _=1;_<c;_++){if((w=w.redSqr()).cmp(i)===0)return!1;if(w.cmp(d)===0)break}if(_===c)return!1}}return!0},o.prototype.getDivisor=function(r,t){var e=r.bitLength(),l=m.mont(r),n=new m(1).toRed(l);t||(t=Math.max(1,e/48|0));for(var i=r.subn(1),f=0;!i.testn(f);f++);for(var c=r.shrn(f),u=i.toRed(l);t>0;t--){var d=this._randrange(new m(2),i),h=r.gcd(d);if(h.cmpn(1)!==0)return h;var w=d.toRed(l).redPow(c);if(w.cmp(n)!==0&&w.cmp(u)!==0){for(var _=1;_<f;_++){if((w=w.redSqr()).cmp(n)===0)return w.fromRed().subn(1).gcd(r);if(w.cmp(u)===0)break}if(_===f)return(w=w.redSqr()).fromRed().subn(1).gcd(r)}}return!1}},{"bn.js":452,brorand:187}],452:[function(s,T,S){arguments[4][184][0].apply(S,arguments)},{buffer:188,dup:184}],453:[function(s,T,S){function m(a,o){if(!a)throw new Error(o||"Assertion failed")}T.exports=m,m.equal=function(a,o,r){if(a!=o)throw new Error(r||"Assertion failed: "+a+" != "+o)}},{}],454:[function(s,T,S){var m=S;function a(r){return r.length===1?"0"+r:r}function o(r){for(var t="",e=0;e<r.length;e++)t+=a(r[e].toString(16));return t}m.toArray=function(r,t){if(Array.isArray(r))return r.slice();if(!r)return[];var e=[];if(typeof r!="string"){for(var l=0;l<r.length;l++)e[l]=0|r[l];return e}if(t==="hex")for((r=r.replace(/[^a-z0-9]+/gi,"")).length%2!=0&&(r="0"+r),l=0;l<r.length;l+=2)e.push(parseInt(r[l]+r[l+1],16));else for(l=0;l<r.length;l++){var n=r.charCodeAt(l),i=n>>8,f=255&n;i?e.push(i,f):e.push(f)}return e},m.zero2=a,m.toHex=o,m.encode=function(r,t){return t==="hex"?o(r):r}},{}],455:[function(s,T,S){T.exports={"2.16.840.1.101.3.4.1.1":"aes-128-ecb","2.16.840.1.101.3.4.1.2":"aes-128-cbc","2.16.840.1.101.3.4.1.3":"aes-128-ofb","2.16.840.1.101.3.4.1.4":"aes-128-cfb","2.16.840.1.101.3.4.1.21":"aes-192-ecb","2.16.840.1.101.3.4.1.22":"aes-192-cbc","2.16.840.1.101.3.4.1.23":"aes-192-ofb","2.16.840.1.101.3.4.1.24":"aes-192-cfb","2.16.840.1.101.3.4.1.41":"aes-256-ecb","2.16.840.1.101.3.4.1.42":"aes-256-cbc","2.16.840.1.101.3.4.1.43":"aes-256-ofb","2.16.840.1.101.3.4.1.44":"aes-256-cfb"}},{}],456:[function(s,T,S){var m=s("asn1.js");S.certificate=s("./certificate");var a=m.define("RSAPrivateKey",function(){this.seq().obj(this.key("version").int(),this.key("modulus").int(),this.key("publicExponent").int(),this.key("privateExponent").int(),this.key("prime1").int(),this.key("prime2").int(),this.key("exponent1").int(),this.key("exponent2").int(),this.key("coefficient").int())});S.RSAPrivateKey=a;var o=m.define("RSAPublicKey",function(){this.seq().obj(this.key("modulus").int(),this.key("publicExponent").int())});S.RSAPublicKey=o;var r=m.define("SubjectPublicKeyInfo",function(){this.seq().obj(this.key("algorithm").use(t),this.key("subjectPublicKey").bitstr())});S.PublicKey=r;var t=m.define("AlgorithmIdentifier",function(){this.seq().obj(this.key("algorithm").objid(),this.key("none").null_().optional(),this.key("curve").objid().optional(),this.key("params").seq().obj(this.key("p").int(),this.key("q").int(),this.key("g").int()).optional())}),e=m.define("PrivateKeyInfo",function(){this.seq().obj(this.key("version").int(),this.key("algorithm").use(t),this.key("subjectPrivateKey").octstr())});S.PrivateKey=e;var l=m.define("EncryptedPrivateKeyInfo",function(){this.seq().obj(this.key("algorithm").seq().obj(this.key("id").objid(),this.key("decrypt").seq().obj(this.key("kde").seq().obj(this.key("id").objid(),this.key("kdeparams").seq().obj(this.key("salt").octstr(),this.key("iters").int())),this.key("cipher").seq().obj(this.key("algo").objid(),this.key("iv").octstr()))),this.key("subjectPrivateKey").octstr())});S.EncryptedPrivateKey=l;var n=m.define("DSAPrivateKey",function(){this.seq().obj(this.key("version").int(),this.key("p").int(),this.key("q").int(),this.key("g").int(),this.key("pub_key").int(),this.key("priv_key").int())});S.DSAPrivateKey=n,S.DSAparam=m.define("DSAparam",function(){this.int()});var i=m.define("ECPrivateKey",function(){this.seq().obj(this.key("version").int(),this.key("privateKey").octstr(),this.key("parameters").optional().explicit(0).use(f),this.key("publicKey").optional().explicit(1).bitstr())});S.ECPrivateKey=i;var f=m.define("ECParameters",function(){this.choice({namedCurve:this.objid()})});S.signature=m.define("signature",function(){this.seq().obj(this.key("r").int(),this.key("s").int())})},{"./certificate":457,"asn1.js":170}],457:[function(s,T,S){var m=s("asn1.js"),a=m.define("Time",function(){this.choice({utcTime:this.utctime(),generalTime:this.gentime()})}),o=m.define("AttributeTypeValue",function(){this.seq().obj(this.key("type").objid(),this.key("value").any())}),r=m.define("AlgorithmIdentifier",function(){this.seq().obj(this.key("algorithm").objid(),this.key("parameters").optional(),this.key("curve").objid().optional())}),t=m.define("SubjectPublicKeyInfo",function(){this.seq().obj(this.key("algorithm").use(r),this.key("subjectPublicKey").bitstr())}),e=m.define("RelativeDistinguishedName",function(){this.setof(o)}),l=m.define("RDNSequence",function(){this.seqof(e)}),n=m.define("Name",function(){this.choice({rdnSequence:this.use(l)})}),i=m.define("Validity",function(){this.seq().obj(this.key("notBefore").use(a),this.key("notAfter").use(a))}),f=m.define("Extension",function(){this.seq().obj(this.key("extnID").objid(),this.key("critical").bool().def(!1),this.key("extnValue").octstr())}),c=m.define("TBSCertificate",function(){this.seq().obj(this.key("version").explicit(0).int().optional(),this.key("serialNumber").int(),this.key("signature").use(r),this.key("issuer").use(n),this.key("validity").use(i),this.key("subject").use(n),this.key("subjectPublicKeyInfo").use(t),this.key("issuerUniqueID").implicit(1).bitstr().optional(),this.key("subjectUniqueID").implicit(2).bitstr().optional(),this.key("extensions").explicit(3).seqof(f).optional())}),u=m.define("X509Certificate",function(){this.seq().obj(this.key("tbsCertificate").use(c),this.key("signatureAlgorithm").use(r),this.key("signatureValue").bitstr())});T.exports=u},{"asn1.js":170}],458:[function(s,T,S){var m=/Proc-Type: 4,ENCRYPTED[\n\r]+DEK-Info: AES-((?:128)|(?:192)|(?:256))-CBC,([0-9A-H]+)[\n\r]+([0-9A-z\n\r+/=]+)[\n\r]+/m,a=/^-----BEGIN ((?:.*? KEY)|CERTIFICATE)-----/m,o=/^-----BEGIN ((?:.*? KEY)|CERTIFICATE)-----([0-9A-z\n\r+/=]+)-----END \1-----$/m,r=s("evp_bytestokey"),t=s("browserify-aes"),e=s("safe-buffer").Buffer;T.exports=function(l,n){var i,f=l.toString(),c=f.match(m);if(c){var u="aes"+c[1],d=e.from(c[2],"hex"),h=e.from(c[3].replace(/[\r\n]/g,""),"base64"),w=r(n,d.slice(0,8),parseInt(c[1],10)).key,_=[],A=t.createDecipheriv(u,w,d);_.push(A.update(h)),_.push(A.final()),i=e.concat(_)}else{var N=f.match(o);i=e.from(N[2].replace(/[\r\n]/g,""),"base64")}return{tag:f.match(a)[1],data:i}}},{"browserify-aes":191,evp_bytestokey:423,"safe-buffer":494}],459:[function(s,T,S){var m=s("./asn1"),a=s("./aesid.json"),o=s("./fixProc"),r=s("browserify-aes"),t=s("pbkdf2"),e=s("safe-buffer").Buffer;function l(n){var i;typeof n!="object"||e.isBuffer(n)||(i=n.passphrase,n=n.key),typeof n=="string"&&(n=e.from(n));var f,c,u=o(n,i),d=u.tag,h=u.data;switch(d){case"CERTIFICATE":c=m.certificate.decode(h,"der").tbsCertificate.subjectPublicKeyInfo;case"PUBLIC KEY":switch(c||(c=m.PublicKey.decode(h,"der")),f=c.algorithm.algorithm.join(".")){case"1.2.840.113549.1.1.1":return m.RSAPublicKey.decode(c.subjectPublicKey.data,"der");case"1.2.840.10045.2.1":return c.subjectPrivateKey=c.subjectPublicKey,{type:"ec",data:c};case"1.2.840.10040.4.1":return c.algorithm.params.pub_key=m.DSAparam.decode(c.subjectPublicKey.data,"der"),{type:"dsa",data:c.algorithm.params};default:throw new Error("unknown key id "+f)}case"ENCRYPTED PRIVATE KEY":h=function(w,_){var A=w.algorithm.decrypt.kde.kdeparams.salt,N=parseInt(w.algorithm.decrypt.kde.kdeparams.iters.toString(),10),L=a[w.algorithm.decrypt.cipher.algo.join(".")],I=w.algorithm.decrypt.cipher.iv,P=w.subjectPrivateKey,B=parseInt(L.split("-")[1],10)/8,U=t.pbkdf2Sync(_,A,N,B,"sha1"),D=r.createDecipheriv(L,U,I),x=[];return x.push(D.update(P)),x.push(D.final()),e.concat(x)}(h=m.EncryptedPrivateKey.decode(h,"der"),i);case"PRIVATE KEY":switch(f=(c=m.PrivateKey.decode(h,"der")).algorithm.algorithm.join(".")){case"1.2.840.113549.1.1.1":return m.RSAPrivateKey.decode(c.subjectPrivateKey,"der");case"1.2.840.10045.2.1":return{curve:c.algorithm.curve,privateKey:m.ECPrivateKey.decode(c.subjectPrivateKey,"der").privateKey};case"1.2.840.10040.4.1":return c.algorithm.params.priv_key=m.DSAparam.decode(c.subjectPrivateKey,"der"),{type:"dsa",params:c.algorithm.params};default:throw new Error("unknown key id "+f)}case"RSA PUBLIC KEY":return m.RSAPublicKey.decode(h,"der");case"RSA PRIVATE KEY":return m.RSAPrivateKey.decode(h,"der");case"DSA PRIVATE KEY":return{type:"dsa",params:m.DSAPrivateKey.decode(h,"der")};case"EC PRIVATE KEY":return{curve:(h=m.ECPrivateKey.decode(h,"der")).parameters.value,privateKey:h.privateKey};default:throw new Error("unknown key type "+d)}}T.exports=l,l.signature=m.signature},{"./aesid.json":455,"./asn1":456,"./fixProc":458,"browserify-aes":191,pbkdf2:460,"safe-buffer":494}],460:[function(s,T,S){S.pbkdf2=s("./lib/async"),S.pbkdf2Sync=s("./lib/sync")},{"./lib/async":461,"./lib/sync":464}],461:[function(s,T,S){(function(m){(function(){var a,o,r=s("safe-buffer").Buffer,t=s("./precondition"),e=s("./default-encoding"),l=s("./sync"),n=s("./to-buffer"),i=m.crypto&&m.crypto.subtle,f={sha:"SHA-1","sha-1":"SHA-1",sha1:"SHA-1",sha256:"SHA-256","sha-256":"SHA-256",sha384:"SHA-384","sha-384":"SHA-384","sha-512":"SHA-512",sha512:"SHA-512"},c=[];function u(){return o||(o=m.process&&m.process.nextTick?m.process.nextTick:m.queueMicrotask?m.queueMicrotask:m.setImmediate?m.setImmediate:m.setTimeout)}function d(h,w,_,A,N){return i.importKey("raw",h,{name:"PBKDF2"},!1,["deriveBits"]).then(function(L){return i.deriveBits({name:"PBKDF2",salt:w,iterations:_,hash:{name:N}},L,A<<3)}).then(function(L){return r.from(L)})}T.exports=function(h,w,_,A,N,L){typeof N=="function"&&(L=N,N=void 0);var I=f[(N=N||"sha1").toLowerCase()];if(I&&typeof m.Promise=="function"){if(t(_,A),h=n(h,e,"Password"),w=n(w,e,"Salt"),typeof L!="function")throw new Error("No callback provided to pbkdf2");(function(P,B){P.then(function(U){u()(function(){B(null,U)})},function(U){u()(function(){B(U)})})})(function(P){if(m.process&&!m.process.browser||!i||!i.importKey||!i.deriveBits)return Promise.resolve(!1);if(c[P]!==void 0)return c[P];var B=d(a=a||r.alloc(8),a,10,128,P).then(function(){return!0}).catch(function(){return!1});return c[P]=B,B}(I).then(function(P){return P?d(h,w,_,A,I):l(h,w,_,A,N)}),L)}else u()(function(){var P;try{P=l(h,w,_,A,N)}catch(B){return L(B)}L(null,P)})}}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{"./default-encoding":462,"./precondition":463,"./sync":464,"./to-buffer":465,"safe-buffer":494}],462:[function(s,T,S){(function(m,a){(function(){var o;a.process&&a.process.browser?o="utf-8":a.process&&a.process.version?o=parseInt(m.version.split(".")[0].slice(1),10)>=6?"utf-8":"binary":o="utf-8",T.exports=o}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{_process:467}],463:[function(s,T,S){var m=Math.pow(2,30)-1;T.exports=function(a,o){if(typeof a!="number")throw new TypeError("Iterations not a number");if(a<0)throw new TypeError("Bad iterations");if(typeof o!="number")throw new TypeError("Key length not a number");if(o<0||o>m||o!=o)throw new TypeError("Bad key length")}},{}],464:[function(s,T,S){var m=s("create-hash/md5"),a=s("ripemd160"),o=s("sha.js"),r=s("safe-buffer").Buffer,t=s("./precondition"),e=s("./default-encoding"),l=s("./to-buffer"),n=r.alloc(128),i={md5:16,sha1:20,sha224:28,sha256:32,sha384:48,sha512:64,rmd160:20,ripemd160:20};function f(c,u,d){var h=function(I){function P(B){return o(I).update(B).digest()}return I==="rmd160"||I==="ripemd160"?function(B){return new a().update(B).digest()}:I==="md5"?m:P}(c),w=c==="sha512"||c==="sha384"?128:64;u.length>w?u=h(u):u.length<w&&(u=r.concat([u,n],w));for(var _=r.allocUnsafe(w+i[c]),A=r.allocUnsafe(w+i[c]),N=0;N<w;N++)_[N]=54^u[N],A[N]=92^u[N];var L=r.allocUnsafe(w+d+4);_.copy(L,0,0,w),this.ipad1=L,this.ipad2=_,this.opad=A,this.alg=c,this.blocksize=w,this.hash=h,this.size=i[c]}f.prototype.run=function(c,u){return c.copy(u,this.blocksize),this.hash(u).copy(this.opad,this.blocksize),this.hash(this.opad)},T.exports=function(c,u,d,h,w){t(d,h);var _=new f(w=w||"sha1",c=l(c,e,"Password"),(u=l(u,e,"Salt")).length),A=r.allocUnsafe(h),N=r.allocUnsafe(u.length+4);u.copy(N,0,0,u.length);for(var L=0,I=i[w],P=Math.ceil(h/I),B=1;B<=P;B++){N.writeUInt32BE(B,u.length);for(var U=_.run(N,_.ipad1),D=U,x=1;x<d;x++){D=_.run(D,_.ipad2);for(var M=0;M<I;M++)U[M]^=D[M]}U.copy(A,L),L+=I}return A}},{"./default-encoding":462,"./precondition":463,"./to-buffer":465,"create-hash/md5":387,ripemd160:493,"safe-buffer":494,"sha.js":498}],465:[function(s,T,S){var m=s("safe-buffer").Buffer;T.exports=function(a,o,r){if(m.isBuffer(a))return a;if(typeof a=="string")return m.from(a,o);if(ArrayBuffer.isView(a))return m.from(a.buffer);throw new TypeError(r+" must be a string, a Buffer, a typed array or a DataView")}},{"safe-buffer":494}],466:[function(s,T,S){(function(m){(function(){m===void 0||!m.version||m.version.indexOf("v0.")===0||m.version.indexOf("v1.")===0&&m.version.indexOf("v1.8.")!==0?T.exports={nextTick:function(a,o,r,t){if(typeof a!="function")throw new TypeError('"callback" argument must be a function');var e,l,n=arguments.length;switch(n){case 0:case 1:return m.nextTick(a);case 2:return m.nextTick(function(){a.call(null,o)});case 3:return m.nextTick(function(){a.call(null,o,r)});case 4:return m.nextTick(function(){a.call(null,o,r,t)});default:for(e=new Array(n-1),l=0;l<e.length;)e[l++]=arguments[l];return m.nextTick(function(){a.apply(null,e)})}}}:T.exports=m}).call(this)}).call(this,s("_process"))},{_process:467}],467:[function(s,T,S){var m,a,o=T.exports={};function r(){throw new Error("setTimeout has not been defined")}function t(){throw new Error("clearTimeout has not been defined")}function e(w){if(m===setTimeout)return setTimeout(w,0);if((m===r||!m)&&setTimeout)return m=setTimeout,setTimeout(w,0);try{return m(w,0)}catch{try{return m.call(null,w,0)}catch{return m.call(this,w,0)}}}(function(){try{m=typeof setTimeout=="function"?setTimeout:r}catch{m=r}try{a=typeof clearTimeout=="function"?clearTimeout:t}catch{a=t}})();var l,n=[],i=!1,f=-1;function c(){i&&l&&(i=!1,l.length?n=l.concat(n):f=-1,n.length&&u())}function u(){if(!i){var w=e(c);i=!0;for(var _=n.length;_;){for(l=n,n=[];++f<_;)l&&l[f].run();f=-1,_=n.length}l=null,i=!1,function(A){if(a===clearTimeout)return clearTimeout(A);if((a===t||!a)&&clearTimeout)return a=clearTimeout,clearTimeout(A);try{a(A)}catch{try{return a.call(null,A)}catch{return a.call(this,A)}}}(w)}}function d(w,_){this.fun=w,this.array=_}function h(){}o.nextTick=function(w){var _=new Array(arguments.length-1);if(arguments.length>1)for(var A=1;A<arguments.length;A++)_[A-1]=arguments[A];n.push(new d(w,_)),n.length!==1||i||e(u)},d.prototype.run=function(){this.fun.apply(null,this.array)},o.title="browser",o.browser=!0,o.env={},o.argv=[],o.version="",o.versions={},o.on=h,o.addListener=h,o.once=h,o.off=h,o.removeListener=h,o.removeAllListeners=h,o.emit=h,o.prependListener=h,o.prependOnceListener=h,o.listeners=function(w){return[]},o.binding=function(w){throw new Error("process.binding is not supported")},o.cwd=function(){return"/"},o.chdir=function(w){throw new Error("process.chdir is not supported")},o.umask=function(){return 0}},{}],468:[function(s,T,S){S.publicEncrypt=s("./publicEncrypt"),S.privateDecrypt=s("./privateDecrypt"),S.privateEncrypt=function(m,a){return S.publicEncrypt(m,a,!0)},S.publicDecrypt=function(m,a){return S.privateDecrypt(m,a,!0)}},{"./privateDecrypt":471,"./publicEncrypt":472}],469:[function(s,T,S){var m=s("create-hash"),a=s("safe-buffer").Buffer;function o(r){var t=a.allocUnsafe(4);return t.writeUInt32BE(r,0),t}T.exports=function(r,t){for(var e,l=a.alloc(0),n=0;l.length<t;)e=o(n++),l=a.concat([l,m("sha1").update(r).update(e).digest()]);return l.slice(0,t)}},{"create-hash":386,"safe-buffer":494}],470:[function(s,T,S){arguments[4][184][0].apply(S,arguments)},{buffer:188,dup:184}],471:[function(s,T,S){var m=s("parse-asn1"),a=s("./mgf"),o=s("./xor"),r=s("bn.js"),t=s("browserify-rsa"),e=s("create-hash"),l=s("./withPublic"),n=s("safe-buffer").Buffer;T.exports=function(i,f,c){var u;u=i.padding?i.padding:c?1:4;var d,h=m(i),w=h.modulus.byteLength();if(f.length>w||new r(f).cmp(h.modulus)>=0)throw new Error("decryption error");d=c?l(new r(f),h):t(f,h);var _=n.alloc(w-d.length);if(d=n.concat([_,d],w),u===4)return function(A,N){var L=A.modulus.byteLength(),I=e("sha1").update(n.alloc(0)).digest(),P=I.length;if(N[0]!==0)throw new Error("decryption error");var B=N.slice(1,P+1),U=N.slice(P+1),D=o(B,a(U,P)),x=o(U,a(D,L-P-1));if(function(v,p){v=n.from(v),p=n.from(p);var b=0,g=v.length;v.length!==p.length&&(b++,g=Math.min(v.length,p.length));for(var y=-1;++y<g;)b+=v[y]^p[y];return b}(I,x.slice(0,P)))throw new Error("decryption error");for(var M=P;x[M]===0;)M++;if(x[M++]!==1)throw new Error("decryption error");return x.slice(M)}(h,d);if(u===1)return function(A,N,L){for(var I=N.slice(0,2),P=2,B=0;N[P++]!==0;)if(P>=N.length){B++;break}var U=N.slice(2,P-1);if((I.toString("hex")!=="0002"&&!L||I.toString("hex")!=="0001"&&L)&&B++,U.length<8&&B++,B)throw new Error("decryption error");return N.slice(P)}(0,d,c);if(u===3)return d;throw new Error("unknown padding")}},{"./mgf":469,"./withPublic":473,"./xor":474,"bn.js":470,"browserify-rsa":209,"create-hash":386,"parse-asn1":459,"safe-buffer":494}],472:[function(s,T,S){var m=s("parse-asn1"),a=s("randombytes"),o=s("create-hash"),r=s("./mgf"),t=s("./xor"),e=s("bn.js"),l=s("./withPublic"),n=s("browserify-rsa"),i=s("safe-buffer").Buffer;T.exports=function(f,c,u){var d;d=f.padding?f.padding:u?1:4;var h,w=m(f);if(d===4)h=function(_,A){var N=_.modulus.byteLength(),L=A.length,I=o("sha1").update(i.alloc(0)).digest(),P=I.length,B=2*P;if(L>N-B-2)throw new Error("message too long");var U=i.alloc(N-L-B-2),D=N-P-1,x=a(P),M=t(i.concat([I,U,i.alloc(1,1),A],D),r(x,D)),v=t(x,r(M,P));return new e(i.concat([i.alloc(1),v,M],N))}(w,c);else if(d===1)h=function(_,A,N){var L,I=A.length,P=_.modulus.byteLength();if(I>P-11)throw new Error("message too long");return L=N?i.alloc(P-I-3,255):function(B){for(var U,D=i.allocUnsafe(B),x=0,M=a(2*B),v=0;x<B;)v===M.length&&(M=a(2*B),v=0),(U=M[v++])&&(D[x++]=U);return D}(P-I-3),new e(i.concat([i.from([0,N?1:2]),L,i.alloc(1),A],P))}(w,c,u);else{if(d!==3)throw new Error("unknown padding");if((h=new e(c)).cmp(w.modulus)>=0)throw new Error("data too long for modulus")}return u?n(h,w):l(h,w)}},{"./mgf":469,"./withPublic":473,"./xor":474,"bn.js":470,"browserify-rsa":209,"create-hash":386,"parse-asn1":459,randombytes:475,"safe-buffer":494}],473:[function(s,T,S){var m=s("bn.js"),a=s("safe-buffer").Buffer;T.exports=function(o,r){return a.from(o.toRed(m.mont(r.modulus)).redPow(new m(r.publicExponent)).fromRed().toArray())}},{"bn.js":470,"safe-buffer":494}],474:[function(s,T,S){T.exports=function(m,a){for(var o=m.length,r=-1;++r<o;)m[r]^=a[r];return m}},{}],475:[function(s,T,S){(function(m,a){(function(){var o=s("safe-buffer").Buffer,r=a.crypto||a.msCrypto;r&&r.getRandomValues?T.exports=function(t,e){if(t>4294967295)throw new RangeError("requested too many random bytes");var l=o.allocUnsafe(t);if(t>0)if(t>65536)for(var n=0;n<t;n+=65536)r.getRandomValues(l.slice(n,n+65536));else r.getRandomValues(l);return typeof e=="function"?m.nextTick(function(){e(null,l)}):l}:T.exports=function(){throw new Error(`Secure random number generation is not supported by this browser.
Use Chrome, Firefox or Internet Explorer 11`)}}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{_process:467,"safe-buffer":494}],476:[function(s,T,S){(function(m,a){(function(){function o(){throw new Error(`secure random number generation not supported by this browser
use chrome, FireFox or Internet Explorer 11`)}var r=s("safe-buffer"),t=s("randombytes"),e=r.Buffer,l=r.kMaxLength,n=a.crypto||a.msCrypto,i=Math.pow(2,32)-1;function f(d,h){if(typeof d!="number"||d!=d)throw new TypeError("offset must be a number");if(d>i||d<0)throw new TypeError("offset must be a uint32");if(d>l||d>h)throw new RangeError("offset out of range")}function c(d,h,w){if(typeof d!="number"||d!=d)throw new TypeError("size must be a number");if(d>i||d<0)throw new TypeError("size must be a uint32");if(d+h>w||d>l)throw new RangeError("buffer too small")}function u(d,h,w,_){if(m.browser){var A=d.buffer,N=new Uint8Array(A,h,w);return n.getRandomValues(N),_?void m.nextTick(function(){_(null,d)}):d}if(!_)return t(w).copy(d,h),d;t(w,function(L,I){if(L)return _(L);I.copy(d,h),_(null,d)})}n&&n.getRandomValues||!m.browser?(S.randomFill=function(d,h,w,_){if(!(e.isBuffer(d)||d instanceof a.Uint8Array))throw new TypeError('"buf" argument must be a Buffer or Uint8Array');if(typeof h=="function")_=h,h=0,w=d.length;else if(typeof w=="function")_=w,w=d.length-h;else if(typeof _!="function")throw new TypeError('"cb" argument must be a function');return f(h,d.length),c(w,h,d.length),u(d,h,w,_)},S.randomFillSync=function(d,h,w){if(h===void 0&&(h=0),!(e.isBuffer(d)||d instanceof a.Uint8Array))throw new TypeError('"buf" argument must be a Buffer or Uint8Array');return f(h,d.length),w===void 0&&(w=d.length-h),c(w,h,d.length),u(d,h,w)}):(S.randomFill=o,S.randomFillSync=o)}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{_process:467,randombytes:475,"safe-buffer":494}],477:[function(s,T,S){var m={};function a(r,t,e){e||(e=Error);var l=function(n){var i,f;function c(u,d,h){return n.call(this,function(w,_,A){return typeof t=="string"?t:t(w,_,A)}(u,d,h))||this}return f=n,(i=c).prototype=Object.create(f.prototype),i.prototype.constructor=i,i.__proto__=f,c}(e);l.prototype.name=e.name,l.prototype.code=r,m[r]=l}function o(r,t){if(Array.isArray(r)){var e=r.length;return r=r.map(function(l){return String(l)}),e>2?"one of ".concat(t," ").concat(r.slice(0,e-1).join(", "),", or ")+r[e-1]:e===2?"one of ".concat(t," ").concat(r[0]," or ").concat(r[1]):"of ".concat(t," ").concat(r[0])}return"of ".concat(t," ").concat(String(r))}a("ERR_INVALID_OPT_VALUE",function(r,t){return'The value "'+t+'" is invalid for option "'+r+'"'},TypeError),a("ERR_INVALID_ARG_TYPE",function(r,t,e){var l,n,i;if(typeof t=="string"&&(n="not ",t.substr(0,n.length)===n)?(l="must not be",t=t.replace(/^not /,"")):l="must be",function(c,u,d){return(d===void 0||d>c.length)&&(d=c.length),c.substring(d-u.length,d)===u}(r," argument"))i="The ".concat(r," ").concat(l," ").concat(o(t,"type"));else{var f=function(c,u,d){return typeof d!="number"&&(d=0),!(d+u.length>c.length)&&c.indexOf(u,d)!==-1}(r,".")?"property":"argument";i='The "'.concat(r,'" ').concat(f," ").concat(l," ").concat(o(t,"type"))}return i+=". Received type ".concat(typeof e)},TypeError),a("ERR_STREAM_PUSH_AFTER_EOF","stream.push() after EOF"),a("ERR_METHOD_NOT_IMPLEMENTED",function(r){return"The "+r+" method is not implemented"}),a("ERR_STREAM_PREMATURE_CLOSE","Premature close"),a("ERR_STREAM_DESTROYED",function(r){return"Cannot call "+r+" after a stream was destroyed"}),a("ERR_MULTIPLE_CALLBACK","Callback called multiple times"),a("ERR_STREAM_CANNOT_PIPE","Cannot pipe, not readable"),a("ERR_STREAM_WRITE_AFTER_END","write after end"),a("ERR_STREAM_NULL_VALUES","May not write null values to stream",TypeError),a("ERR_UNKNOWN_ENCODING",function(r){return"Unknown encoding: "+r},TypeError),a("ERR_STREAM_UNSHIFT_AFTER_END_EVENT","stream.unshift() after end event"),T.exports.codes=m},{}],478:[function(s,T,S){(function(m){(function(){var a=Object.keys||function(c){var u=[];for(var d in c)u.push(d);return u};T.exports=n;var o=s("./_stream_readable"),r=s("./_stream_writable");s("inherits")(n,o);for(var t=a(r.prototype),e=0;e<t.length;e++){var l=t[e];n.prototype[l]||(n.prototype[l]=r.prototype[l])}function n(c){if(!(this instanceof n))return new n(c);o.call(this,c),r.call(this,c),this.allowHalfOpen=!0,c&&(c.readable===!1&&(this.readable=!1),c.writable===!1&&(this.writable=!1),c.allowHalfOpen===!1&&(this.allowHalfOpen=!1,this.once("end",i)))}function i(){this._writableState.ended||m.nextTick(f,this)}function f(c){c.end()}Object.defineProperty(n.prototype,"writableHighWaterMark",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),Object.defineProperty(n.prototype,"writableBuffer",{enumerable:!1,get:function(){return this._writableState&&this._writableState.getBuffer()}}),Object.defineProperty(n.prototype,"writableLength",{enumerable:!1,get:function(){return this._writableState.length}}),Object.defineProperty(n.prototype,"destroyed",{enumerable:!1,get:function(){return this._readableState!==void 0&&this._writableState!==void 0&&this._readableState.destroyed&&this._writableState.destroyed},set:function(c){this._readableState!==void 0&&this._writableState!==void 0&&(this._readableState.destroyed=c,this._writableState.destroyed=c)}})}).call(this)}).call(this,s("_process"))},{"./_stream_readable":480,"./_stream_writable":482,_process:467,inherits:440}],479:[function(s,T,S){T.exports=a;var m=s("./_stream_transform");function a(o){if(!(this instanceof a))return new a(o);m.call(this,o)}s("inherits")(a,m),a.prototype._transform=function(o,r,t){t(null,o)}},{"./_stream_transform":481,inherits:440}],480:[function(s,T,S){(function(m,a){(function(){var o;T.exports=D,D.ReadableState=U,s("events").EventEmitter;var r=function(E,C){return E.listeners(C).length},t=s("./internal/streams/stream"),e=s("buffer").Buffer,l=(a!==void 0?a:typeof window<"u"?window:typeof self<"u"?self:{}).Uint8Array||function(){},n,i=s("util");n=i&&i.debuglog?i.debuglog("stream"):function(){};var f,c,u,d=s("./internal/streams/buffer_list"),h=s("./internal/streams/destroy"),w=s("./internal/streams/state").getHighWaterMark,_=s("../errors").codes,A=_.ERR_INVALID_ARG_TYPE,N=_.ERR_STREAM_PUSH_AFTER_EOF,L=_.ERR_METHOD_NOT_IMPLEMENTED,I=_.ERR_STREAM_UNSHIFT_AFTER_END_EVENT;s("inherits")(D,t);var P=h.errorOrDestroy,B=["error","close","destroy","pause","resume"];function U(E,C,F){o=o||s("./_stream_duplex"),E=E||{},typeof F!="boolean"&&(F=C instanceof o),this.objectMode=!!E.objectMode,F&&(this.objectMode=this.objectMode||!!E.readableObjectMode),this.highWaterMark=w(this,E,"readableHighWaterMark",F),this.buffer=new d,this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.resumeScheduled=!1,this.paused=!0,this.emitClose=E.emitClose!==!1,this.autoDestroy=!!E.autoDestroy,this.destroyed=!1,this.defaultEncoding=E.defaultEncoding||"utf8",this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,E.encoding&&(f||(f=s("string_decoder/").StringDecoder),this.decoder=new f(E.encoding),this.encoding=E.encoding)}function D(E){if(o=o||s("./_stream_duplex"),!(this instanceof D))return new D(E);var C=this instanceof o;this._readableState=new U(E,this,C),this.readable=!0,E&&(typeof E.read=="function"&&(this._read=E.read),typeof E.destroy=="function"&&(this._destroy=E.destroy)),t.call(this)}function x(E,C,F,V,Z){n("readableAddChunk",C);var q,K=E._readableState;if(C===null)K.reading=!1,function(et,tt){if(n("onEofChunk"),!tt.ended){if(tt.decoder){var X=tt.decoder.end();X&&X.length&&(tt.buffer.push(X),tt.length+=tt.objectMode?1:X.length)}tt.ended=!0,tt.sync?p(et):(tt.needReadable=!1,tt.emittedReadable||(tt.emittedReadable=!0,b(et)))}}(E,K);else if(Z||(q=function(et,tt){var X;J=tt,e.isBuffer(J)||J instanceof l||typeof tt=="string"||tt===void 0||et.objectMode||(X=new A("chunk",["string","Buffer","Uint8Array"],tt));var J;return X}(K,C)),q)P(E,q);else if(K.objectMode||C&&C.length>0)if(typeof C=="string"||K.objectMode||Object.getPrototypeOf(C)===e.prototype||(C=function(et){return e.from(et)}(C)),V)K.endEmitted?P(E,new I):M(E,K,C,!0);else if(K.ended)P(E,new N);else{if(K.destroyed)return!1;K.reading=!1,K.decoder&&!F?(C=K.decoder.write(C),K.objectMode||C.length!==0?M(E,K,C,!1):g(E,K)):M(E,K,C,!1)}else V||(K.reading=!1,g(E,K));return!K.ended&&(K.length<K.highWaterMark||K.length===0)}function M(E,C,F,V){C.flowing&&C.length===0&&!C.sync?(C.awaitDrain=0,E.emit("data",F)):(C.length+=C.objectMode?1:F.length,V?C.buffer.unshift(F):C.buffer.push(F),C.needReadable&&p(E)),g(E,C)}Object.defineProperty(D.prototype,"destroyed",{enumerable:!1,get:function(){return this._readableState!==void 0&&this._readableState.destroyed},set:function(E){this._readableState&&(this._readableState.destroyed=E)}}),D.prototype.destroy=h.destroy,D.prototype._undestroy=h.undestroy,D.prototype._destroy=function(E,C){C(E)},D.prototype.push=function(E,C){var F,V=this._readableState;return V.objectMode?F=!0:typeof E=="string"&&((C=C||V.defaultEncoding)!==V.encoding&&(E=e.from(E,C),C=""),F=!0),x(this,E,C,!1,F)},D.prototype.unshift=function(E){return x(this,E,null,!0,!1)},D.prototype.isPaused=function(){return this._readableState.flowing===!1},D.prototype.setEncoding=function(E){f||(f=s("string_decoder/").StringDecoder);var C=new f(E);this._readableState.decoder=C,this._readableState.encoding=this._readableState.decoder.encoding;for(var F=this._readableState.buffer.head,V="";F!==null;)V+=C.write(F.data),F=F.next;return this._readableState.buffer.clear(),V!==""&&this._readableState.buffer.push(V),this._readableState.length=V.length,this};function v(E,C){return E<=0||C.length===0&&C.ended?0:C.objectMode?1:E!=E?C.flowing&&C.length?C.buffer.head.data.length:C.length:(E>C.highWaterMark&&(C.highWaterMark=function(F){return F>=1073741824?F=1073741824:(F--,F|=F>>>1,F|=F>>>2,F|=F>>>4,F|=F>>>8,F|=F>>>16,F++),F}(E)),E<=C.length?E:C.ended?C.length:(C.needReadable=!0,0))}function p(E){var C=E._readableState;n("emitReadable",C.needReadable,C.emittedReadable),C.needReadable=!1,C.emittedReadable||(n("emitReadable",C.flowing),C.emittedReadable=!0,m.nextTick(b,E))}function b(E){var C=E._readableState;n("emitReadable_",C.destroyed,C.length,C.ended),C.destroyed||!C.length&&!C.ended||(E.emit("readable"),C.emittedReadable=!1),C.needReadable=!C.flowing&&!C.ended&&C.length<=C.highWaterMark,z(E)}function g(E,C){C.readingMore||(C.readingMore=!0,m.nextTick(y,E,C))}function y(E,C){for(;!C.reading&&!C.ended&&(C.length<C.highWaterMark||C.flowing&&C.length===0);){var F=C.length;if(n("maybeReadMore read 0"),E.read(0),F===C.length)break}C.readingMore=!1}function k(E){var C=E._readableState;C.readableListening=E.listenerCount("readable")>0,C.resumeScheduled&&!C.paused?C.flowing=!0:E.listenerCount("data")>0&&E.resume()}function R(E){n("readable nexttick read 0"),E.read(0)}function O(E,C){n("resume",C.reading),C.reading||E.read(0),C.resumeScheduled=!1,E.emit("resume"),z(E),C.flowing&&!C.reading&&E.read(0)}function z(E){var C=E._readableState;for(n("flow",C.flowing);C.flowing&&E.read()!==null;);}function $(E,C){return C.length===0?null:(C.objectMode?F=C.buffer.shift():!E||E>=C.length?(F=C.decoder?C.buffer.join(""):C.buffer.length===1?C.buffer.first():C.buffer.concat(C.length),C.buffer.clear()):F=C.buffer.consume(E,C.decoder),F);var F}function W(E){var C=E._readableState;n("endReadable",C.endEmitted),C.endEmitted||(C.ended=!0,m.nextTick(j,C,E))}function j(E,C){if(n("endReadableNT",E.endEmitted,E.length),!E.endEmitted&&E.length===0&&(E.endEmitted=!0,C.readable=!1,C.emit("end"),E.autoDestroy)){var F=C._writableState;(!F||F.autoDestroy&&F.finished)&&C.destroy()}}function H(E,C){for(var F=0,V=E.length;F<V;F++)if(E[F]===C)return F;return-1}D.prototype.read=function(E){n("read",E),E=parseInt(E,10);var C=this._readableState,F=E;if(E!==0&&(C.emittedReadable=!1),E===0&&C.needReadable&&((C.highWaterMark!==0?C.length>=C.highWaterMark:C.length>0)||C.ended))return n("read: emitReadable",C.length,C.ended),C.length===0&&C.ended?W(this):p(this),null;if((E=v(E,C))===0&&C.ended)return C.length===0&&W(this),null;var V,Z=C.needReadable;return n("need readable",Z),(C.length===0||C.length-E<C.highWaterMark)&&n("length less than watermark",Z=!0),C.ended||C.reading?n("reading or ended",Z=!1):Z&&(n("do read"),C.reading=!0,C.sync=!0,C.length===0&&(C.needReadable=!0),this._read(C.highWaterMark),C.sync=!1,C.reading||(E=v(F,C))),(V=E>0?$(E,C):null)===null?(C.needReadable=C.length<=C.highWaterMark,E=0):(C.length-=E,C.awaitDrain=0),C.length===0&&(C.ended||(C.needReadable=!0),F!==E&&C.ended&&W(this)),V!==null&&this.emit("data",V),V},D.prototype._read=function(E){P(this,new L("_read()"))},D.prototype.pipe=function(E,C){var F=this,V=this._readableState;switch(V.pipesCount){case 0:V.pipes=E;break;case 1:V.pipes=[V.pipes,E];break;default:V.pipes.push(E)}V.pipesCount+=1,n("pipe count=%d opts=%j",V.pipesCount,C);var Z=(!C||C.end!==!1)&&E!==m.stdout&&E!==m.stderr?K:rt;function q(st,ot){n("onunpipe"),st===F&&ot&&ot.hasUnpiped===!1&&(ot.hasUnpiped=!0,n("cleanup"),E.removeListener("close",G),E.removeListener("finish",nt),E.removeListener("drain",et),E.removeListener("error",J),E.removeListener("unpipe",q),F.removeListener("end",K),F.removeListener("end",rt),F.removeListener("data",X),tt=!0,!V.awaitDrain||E._writableState&&!E._writableState.needDrain||et())}function K(){n("onend"),E.end()}V.endEmitted?m.nextTick(Z):F.once("end",Z),E.on("unpipe",q);var et=function(st){return function(){var ot=st._readableState;n("pipeOnDrain",ot.awaitDrain),ot.awaitDrain&&ot.awaitDrain--,ot.awaitDrain===0&&r(st,"data")&&(ot.flowing=!0,z(st))}}(F);E.on("drain",et);var tt=!1;function X(st){n("ondata");var ot=E.write(st);n("dest.write",ot),ot===!1&&((V.pipesCount===1&&V.pipes===E||V.pipesCount>1&&H(V.pipes,E)!==-1)&&!tt&&(n("false write response, pause",V.awaitDrain),V.awaitDrain++),F.pause())}function J(st){n("onerror",st),rt(),E.removeListener("error",J),r(E,"error")===0&&P(E,st)}function G(){E.removeListener("finish",nt),rt()}function nt(){n("onfinish"),E.removeListener("close",G),rt()}function rt(){n("unpipe"),F.unpipe(E)}return F.on("data",X),function(st,ot,lt){if(typeof st.prependListener=="function")return st.prependListener(ot,lt);st._events&&st._events[ot]?Array.isArray(st._events[ot])?st._events[ot].unshift(lt):st._events[ot]=[lt,st._events[ot]]:st.on(ot,lt)}(E,"error",J),E.once("close",G),E.once("finish",nt),E.emit("pipe",F),V.flowing||(n("pipe resume"),F.resume()),E},D.prototype.unpipe=function(E){var C=this._readableState,F={hasUnpiped:!1};if(C.pipesCount===0)return this;if(C.pipesCount===1)return E&&E!==C.pipes||(E||(E=C.pipes),C.pipes=null,C.pipesCount=0,C.flowing=!1,E&&E.emit("unpipe",this,F)),this;if(!E){var V=C.pipes,Z=C.pipesCount;C.pipes=null,C.pipesCount=0,C.flowing=!1;for(var q=0;q<Z;q++)V[q].emit("unpipe",this,{hasUnpiped:!1});return this}var K=H(C.pipes,E);return K===-1||(C.pipes.splice(K,1),C.pipesCount-=1,C.pipesCount===1&&(C.pipes=C.pipes[0]),E.emit("unpipe",this,F)),this},D.prototype.on=function(E,C){var F=t.prototype.on.call(this,E,C),V=this._readableState;return E==="data"?(V.readableListening=this.listenerCount("readable")>0,V.flowing!==!1&&this.resume()):E==="readable"&&(V.endEmitted||V.readableListening||(V.readableListening=V.needReadable=!0,V.flowing=!1,V.emittedReadable=!1,n("on readable",V.length,V.reading),V.length?p(this):V.reading||m.nextTick(R,this))),F},D.prototype.addListener=D.prototype.on,D.prototype.removeListener=function(E,C){var F=t.prototype.removeListener.call(this,E,C);return E==="readable"&&m.nextTick(k,this),F},D.prototype.removeAllListeners=function(E){var C=t.prototype.removeAllListeners.apply(this,arguments);return E!=="readable"&&E!==void 0||m.nextTick(k,this),C},D.prototype.resume=function(){var E=this._readableState;return E.flowing||(n("resume"),E.flowing=!E.readableListening,function(C,F){F.resumeScheduled||(F.resumeScheduled=!0,m.nextTick(O,C,F))}(this,E)),E.paused=!1,this},D.prototype.pause=function(){return n("call pause flowing=%j",this._readableState.flowing),this._readableState.flowing!==!1&&(n("pause"),this._readableState.flowing=!1,this.emit("pause")),this._readableState.paused=!0,this},D.prototype.wrap=function(E){var C=this,F=this._readableState,V=!1;for(var Z in E.on("end",function(){if(n("wrapped end"),F.decoder&&!F.ended){var K=F.decoder.end();K&&K.length&&C.push(K)}C.push(null)}),E.on("data",function(K){n("wrapped data"),F.decoder&&(K=F.decoder.write(K)),F.objectMode&&K==null||(F.objectMode||K&&K.length)&&(C.push(K)||(V=!0,E.pause()))}),E)this[Z]===void 0&&typeof E[Z]=="function"&&(this[Z]=function(K){return function(){return E[K].apply(E,arguments)}}(Z));for(var q=0;q<B.length;q++)E.on(B[q],this.emit.bind(this,B[q]));return this._read=function(K){n("wrapped _read",K),V&&(V=!1,E.resume())},this},typeof Symbol=="function"&&(D.prototype[Symbol.asyncIterator]=function(){return c===void 0&&(c=s("./internal/streams/async_iterator")),c(this)}),Object.defineProperty(D.prototype,"readableHighWaterMark",{enumerable:!1,get:function(){return this._readableState.highWaterMark}}),Object.defineProperty(D.prototype,"readableBuffer",{enumerable:!1,get:function(){return this._readableState&&this._readableState.buffer}}),Object.defineProperty(D.prototype,"readableFlowing",{enumerable:!1,get:function(){return this._readableState.flowing},set:function(E){this._readableState&&(this._readableState.flowing=E)}}),D._fromList=$,Object.defineProperty(D.prototype,"readableLength",{enumerable:!1,get:function(){return this._readableState.length}}),typeof Symbol=="function"&&(D.from=function(E,C){return u===void 0&&(u=s("./internal/streams/from")),u(D,E,C)})}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{"../errors":477,"./_stream_duplex":478,"./internal/streams/async_iterator":483,"./internal/streams/buffer_list":484,"./internal/streams/destroy":485,"./internal/streams/from":487,"./internal/streams/state":489,"./internal/streams/stream":490,_process:467,buffer:220,events:422,inherits:440,"string_decoder/":522,util:188}],481:[function(s,T,S){T.exports=n;var m=s("../errors").codes,a=m.ERR_METHOD_NOT_IMPLEMENTED,o=m.ERR_MULTIPLE_CALLBACK,r=m.ERR_TRANSFORM_ALREADY_TRANSFORMING,t=m.ERR_TRANSFORM_WITH_LENGTH_0,e=s("./_stream_duplex");function l(c,u){var d=this._transformState;d.transforming=!1;var h=d.writecb;if(h===null)return this.emit("error",new o);d.writechunk=null,d.writecb=null,u!=null&&this.push(u),h(c);var w=this._readableState;w.reading=!1,(w.needReadable||w.length<w.highWaterMark)&&this._read(w.highWaterMark)}function n(c){if(!(this instanceof n))return new n(c);e.call(this,c),this._transformState={afterTransform:l.bind(this),needTransform:!1,transforming:!1,writecb:null,writechunk:null,writeencoding:null},this._readableState.needReadable=!0,this._readableState.sync=!1,c&&(typeof c.transform=="function"&&(this._transform=c.transform),typeof c.flush=="function"&&(this._flush=c.flush)),this.on("prefinish",i)}function i(){var c=this;typeof this._flush!="function"||this._readableState.destroyed?f(this,null,null):this._flush(function(u,d){f(c,u,d)})}function f(c,u,d){if(u)return c.emit("error",u);if(d!=null&&c.push(d),c._writableState.length)throw new t;if(c._transformState.transforming)throw new r;return c.push(null)}s("inherits")(n,e),n.prototype.push=function(c,u){return this._transformState.needTransform=!1,e.prototype.push.call(this,c,u)},n.prototype._transform=function(c,u,d){d(new a("_transform()"))},n.prototype._write=function(c,u,d){var h=this._transformState;if(h.writecb=d,h.writechunk=c,h.writeencoding=u,!h.transforming){var w=this._readableState;(h.needTransform||w.needReadable||w.length<w.highWaterMark)&&this._read(w.highWaterMark)}},n.prototype._read=function(c){var u=this._transformState;u.writechunk===null||u.transforming?u.needTransform=!0:(u.transforming=!0,this._transform(u.writechunk,u.writeencoding,u.afterTransform))},n.prototype._destroy=function(c,u){e.prototype._destroy.call(this,c,function(d){u(d)})}},{"../errors":477,"./_stream_duplex":478,inherits:440}],482:[function(s,T,S){(function(m,a){(function(){function o(y){var k=this;this.next=null,this.entry=null,this.finish=function(){(function(R,O,z){var $=R.entry;for(R.entry=null;$;){var W=$.callback;O.pendingcb--,W(z),$=$.next}O.corkedRequestsFree.next=R})(k,y)}}var r;T.exports=D,D.WritableState=U;var t={deprecate:s("util-deprecate")},e=s("./internal/streams/stream"),l=s("buffer").Buffer,n=(a!==void 0?a:typeof window<"u"?window:typeof self<"u"?self:{}).Uint8Array||function(){},i,f=s("./internal/streams/destroy"),c=s("./internal/streams/state").getHighWaterMark,u=s("../errors").codes,d=u.ERR_INVALID_ARG_TYPE,h=u.ERR_METHOD_NOT_IMPLEMENTED,w=u.ERR_MULTIPLE_CALLBACK,_=u.ERR_STREAM_CANNOT_PIPE,A=u.ERR_STREAM_DESTROYED,N=u.ERR_STREAM_NULL_VALUES,L=u.ERR_STREAM_WRITE_AFTER_END,I=u.ERR_UNKNOWN_ENCODING,P=f.errorOrDestroy;function B(){}function U(y,k,R){r=r||s("./_stream_duplex"),y=y||{},typeof R!="boolean"&&(R=k instanceof r),this.objectMode=!!y.objectMode,R&&(this.objectMode=this.objectMode||!!y.writableObjectMode),this.highWaterMark=c(this,y,"writableHighWaterMark",R),this.finalCalled=!1,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1,this.destroyed=!1;var O=y.decodeStrings===!1;this.decodeStrings=!O,this.defaultEncoding=y.defaultEncoding||"utf8",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(z){(function($,W){var j=$._writableState,H=j.sync,E=j.writecb;if(typeof E!="function")throw new w;if(function(F){F.writing=!1,F.writecb=null,F.length-=F.writelen,F.writelen=0}(j),W)(function(F,V,Z,q,K){--V.pendingcb,Z?(m.nextTick(K,q),m.nextTick(g,F,V),F._writableState.errorEmitted=!0,P(F,q)):(K(q),F._writableState.errorEmitted=!0,P(F,q),g(F,V))})($,j,H,W,E);else{var C=p(j)||$.destroyed;C||j.corked||j.bufferProcessing||!j.bufferedRequest||v($,j),H?m.nextTick(M,$,j,C,E):M($,j,C,E)}})(k,z)},this.writecb=null,this.writelen=0,this.bufferedRequest=null,this.lastBufferedRequest=null,this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1,this.emitClose=y.emitClose!==!1,this.autoDestroy=!!y.autoDestroy,this.bufferedRequestCount=0,this.corkedRequestsFree=new o(this)}function D(y){var k=this instanceof(r=r||s("./_stream_duplex"));if(!k&&!i.call(D,this))return new D(y);this._writableState=new U(y,this,k),this.writable=!0,y&&(typeof y.write=="function"&&(this._write=y.write),typeof y.writev=="function"&&(this._writev=y.writev),typeof y.destroy=="function"&&(this._destroy=y.destroy),typeof y.final=="function"&&(this._final=y.final)),e.call(this)}function x(y,k,R,O,z,$,W){k.writelen=O,k.writecb=W,k.writing=!0,k.sync=!0,k.destroyed?k.onwrite(new A("write")):R?y._writev(z,k.onwrite):y._write(z,$,k.onwrite),k.sync=!1}function M(y,k,R,O){R||function(z,$){$.length===0&&$.needDrain&&($.needDrain=!1,z.emit("drain"))}(y,k),k.pendingcb--,O(),g(y,k)}function v(y,k){k.bufferProcessing=!0;var R=k.bufferedRequest;if(y._writev&&R&&R.next){var O=k.bufferedRequestCount,z=new Array(O),$=k.corkedRequestsFree;$.entry=R;for(var W=0,j=!0;R;)z[W]=R,R.isBuf||(j=!1),R=R.next,W+=1;z.allBuffers=j,x(y,k,!0,k.length,z,"",$.finish),k.pendingcb++,k.lastBufferedRequest=null,$.next?(k.corkedRequestsFree=$.next,$.next=null):k.corkedRequestsFree=new o(k),k.bufferedRequestCount=0}else{for(;R;){var H=R.chunk,E=R.encoding,C=R.callback;if(x(y,k,!1,k.objectMode?1:H.length,H,E,C),R=R.next,k.bufferedRequestCount--,k.writing)break}R===null&&(k.lastBufferedRequest=null)}k.bufferedRequest=R,k.bufferProcessing=!1}function p(y){return y.ending&&y.length===0&&y.bufferedRequest===null&&!y.finished&&!y.writing}function b(y,k){y._final(function(R){k.pendingcb--,R&&P(y,R),k.prefinished=!0,y.emit("prefinish"),g(y,k)})}function g(y,k){var R=p(k);if(R&&(function(z,$){$.prefinished||$.finalCalled||(typeof z._final!="function"||$.destroyed?($.prefinished=!0,z.emit("prefinish")):($.pendingcb++,$.finalCalled=!0,m.nextTick(b,z,$)))}(y,k),k.pendingcb===0&&(k.finished=!0,y.emit("finish"),k.autoDestroy))){var O=y._readableState;(!O||O.autoDestroy&&O.endEmitted)&&y.destroy()}return R}s("inherits")(D,e),U.prototype.getBuffer=function(){for(var y=this.bufferedRequest,k=[];y;)k.push(y),y=y.next;return k},function(){try{Object.defineProperty(U.prototype,"buffer",{get:t.deprecate(function(){return this.getBuffer()},"_writableState.buffer is deprecated. Use _writableState.getBuffer instead.","DEP0003")})}catch{}}(),typeof Symbol=="function"&&Symbol.hasInstance&&typeof Function.prototype[Symbol.hasInstance]=="function"?(i=Function.prototype[Symbol.hasInstance],Object.defineProperty(D,Symbol.hasInstance,{value:function(y){return!!i.call(this,y)||this===D&&y&&y._writableState instanceof U}})):i=function(y){return y instanceof this},D.prototype.pipe=function(){P(this,new _)},D.prototype.write=function(y,k,R){var O,z=this._writableState,$=!1,W=!z.objectMode&&(O=y,l.isBuffer(O)||O instanceof n);return W&&!l.isBuffer(y)&&(y=function(j){return l.from(j)}(y)),typeof k=="function"&&(R=k,k=null),W?k="buffer":k||(k=z.defaultEncoding),typeof R!="function"&&(R=B),z.ending?function(j,H){var E=new L;P(j,E),m.nextTick(H,E)}(this,R):(W||function(j,H,E,C){var F;return E===null?F=new N:typeof E=="string"||H.objectMode||(F=new d("chunk",["string","Buffer"],E)),!F||(P(j,F),m.nextTick(C,F),!1)}(this,z,y,R))&&(z.pendingcb++,$=function(j,H,E,C,F,V){if(!E){var Z=function(tt,X,J){return tt.objectMode||tt.decodeStrings===!1||typeof X!="string"||(X=l.from(X,J)),X}(H,C,F);C!==Z&&(E=!0,F="buffer",C=Z)}var q=H.objectMode?1:C.length;H.length+=q;var K=H.length<H.highWaterMark;if(K||(H.needDrain=!0),H.writing||H.corked){var et=H.lastBufferedRequest;H.lastBufferedRequest={chunk:C,encoding:F,isBuf:E,callback:V,next:null},et?et.next=H.lastBufferedRequest:H.bufferedRequest=H.lastBufferedRequest,H.bufferedRequestCount+=1}else x(j,H,!1,q,C,F,V);return K}(this,z,W,y,k,R)),$},D.prototype.cork=function(){this._writableState.corked++},D.prototype.uncork=function(){var y=this._writableState;y.corked&&(y.corked--,y.writing||y.corked||y.bufferProcessing||!y.bufferedRequest||v(this,y))},D.prototype.setDefaultEncoding=function(y){if(typeof y=="string"&&(y=y.toLowerCase()),!(["hex","utf8","utf-8","ascii","binary","base64","ucs2","ucs-2","utf16le","utf-16le","raw"].indexOf((y+"").toLowerCase())>-1))throw new I(y);return this._writableState.defaultEncoding=y,this},Object.defineProperty(D.prototype,"writableBuffer",{enumerable:!1,get:function(){return this._writableState&&this._writableState.getBuffer()}}),Object.defineProperty(D.prototype,"writableHighWaterMark",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),D.prototype._write=function(y,k,R){R(new h("_write()"))},D.prototype._writev=null,D.prototype.end=function(y,k,R){var O=this._writableState;return typeof y=="function"?(R=y,y=null,k=null):typeof k=="function"&&(R=k,k=null),y!=null&&this.write(y,k),O.corked&&(O.corked=1,this.uncork()),O.ending||function(z,$,W){$.ending=!0,g(z,$),W&&($.finished?m.nextTick(W):z.once("finish",W)),$.ended=!0,z.writable=!1}(this,O,R),this},Object.defineProperty(D.prototype,"writableLength",{enumerable:!1,get:function(){return this._writableState.length}}),Object.defineProperty(D.prototype,"destroyed",{enumerable:!1,get:function(){return this._writableState!==void 0&&this._writableState.destroyed},set:function(y){this._writableState&&(this._writableState.destroyed=y)}}),D.prototype.destroy=f.destroy,D.prototype._undestroy=f.undestroy,D.prototype._destroy=function(y,k){k(y)}}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{"../errors":477,"./_stream_duplex":478,"./internal/streams/destroy":485,"./internal/streams/state":489,"./internal/streams/stream":490,_process:467,buffer:220,inherits:440,"util-deprecate":524}],483:[function(s,T,S){(function(m){(function(){var a;function o(A,N,L){return(N=function(I){var P=function(B,U){if(typeof B!="object"||B===null)return B;var D=B[Symbol.toPrimitive];if(D!==void 0){var x=D.call(B,U);if(typeof x!="object")return x;throw new TypeError("@@toPrimitive must return a primitive value.")}return(U==="string"?String:Number)(B)}(I,"string");return typeof P=="symbol"?P:String(P)}(N))in A?Object.defineProperty(A,N,{value:L,enumerable:!0,configurable:!0,writable:!0}):A[N]=L,A}var r=s("./end-of-stream"),t=Symbol("lastResolve"),e=Symbol("lastReject"),l=Symbol("error"),n=Symbol("ended"),i=Symbol("lastPromise"),f=Symbol("handlePromise"),c=Symbol("stream");function u(A,N){return{value:A,done:N}}function d(A){var N=A[t];if(N!==null){var L=A[c].read();L!==null&&(A[i]=null,A[t]=null,A[e]=null,N(u(L,!1)))}}function h(A){m.nextTick(d,A)}var w=Object.getPrototypeOf(function(){}),_=Object.setPrototypeOf((o(a={get stream(){return this[c]},next:function(){var A=this,N=this[l];if(N!==null)return Promise.reject(N);if(this[n])return Promise.resolve(u(void 0,!0));if(this[c].destroyed)return new Promise(function(B,U){m.nextTick(function(){A[l]?U(A[l]):B(u(void 0,!0))})});var L,I=this[i];if(I)L=new Promise(function(B,U){return function(D,x){B.then(function(){U[n]?D(u(void 0,!0)):U[f](D,x)},x)}}(I,this));else{var P=this[c].read();if(P!==null)return Promise.resolve(u(P,!1));L=new Promise(this[f])}return this[i]=L,L}},Symbol.asyncIterator,function(){return this}),o(a,"return",function(){var A=this;return new Promise(function(N,L){A[c].destroy(null,function(I){I?L(I):N(u(void 0,!0))})})}),a),w);T.exports=function(A){var N,L=Object.create(_,(o(N={},c,{value:A,writable:!0}),o(N,t,{value:null,writable:!0}),o(N,e,{value:null,writable:!0}),o(N,l,{value:null,writable:!0}),o(N,n,{value:A._readableState.endEmitted,writable:!0}),o(N,f,{value:function(I,P){var B=L[c].read();B?(L[i]=null,L[t]=null,L[e]=null,I(u(B,!1))):(L[t]=I,L[e]=P)},writable:!0}),N));return L[i]=null,r(A,function(I){if(I&&I.code!=="ERR_STREAM_PREMATURE_CLOSE"){var P=L[e];return P!==null&&(L[i]=null,L[t]=null,L[e]=null,P(I)),void(L[l]=I)}var B=L[t];B!==null&&(L[i]=null,L[t]=null,L[e]=null,B(u(void 0,!0))),L[n]=!0}),A.on("readable",h.bind(null,L)),L}}).call(this)}).call(this,s("_process"))},{"./end-of-stream":486,_process:467}],484:[function(s,T,S){function m(i,f){var c=Object.keys(i);if(Object.getOwnPropertySymbols){var u=Object.getOwnPropertySymbols(i);f&&(u=u.filter(function(d){return Object.getOwnPropertyDescriptor(i,d).enumerable})),c.push.apply(c,u)}return c}function a(i){for(var f=1;f<arguments.length;f++){var c=arguments[f]!=null?arguments[f]:{};f%2?m(Object(c),!0).forEach(function(u){o(i,u,c[u])}):Object.getOwnPropertyDescriptors?Object.defineProperties(i,Object.getOwnPropertyDescriptors(c)):m(Object(c)).forEach(function(u){Object.defineProperty(i,u,Object.getOwnPropertyDescriptor(c,u))})}return i}function o(i,f,c){return(f=t(f))in i?Object.defineProperty(i,f,{value:c,enumerable:!0,configurable:!0,writable:!0}):i[f]=c,i}function r(i,f){for(var c=0;c<f.length;c++){var u=f[c];u.enumerable=u.enumerable||!1,u.configurable=!0,"value"in u&&(u.writable=!0),Object.defineProperty(i,t(u.key),u)}}function t(i){var f=function(c,u){if(typeof c!="object"||c===null)return c;var d=c[Symbol.toPrimitive];if(d!==void 0){var h=d.call(c,u);if(typeof h!="object")return h;throw new TypeError("@@toPrimitive must return a primitive value.")}return(u==="string"?String:Number)(c)}(i,"string");return typeof f=="symbol"?f:String(f)}var e=s("buffer").Buffer,l=s("util").inspect,n=l&&l.custom||"inspect";T.exports=function(){function i(){(function(u,d){if(!(u instanceof d))throw new TypeError("Cannot call a class as a function")})(this,i),this.head=null,this.tail=null,this.length=0}var f,c;return f=i,(c=[{key:"push",value:function(u){var d={data:u,next:null};this.length>0?this.tail.next=d:this.head=d,this.tail=d,++this.length}},{key:"unshift",value:function(u){var d={data:u,next:this.head};this.length===0&&(this.tail=d),this.head=d,++this.length}},{key:"shift",value:function(){if(this.length!==0){var u=this.head.data;return this.length===1?this.head=this.tail=null:this.head=this.head.next,--this.length,u}}},{key:"clear",value:function(){this.head=this.tail=null,this.length=0}},{key:"join",value:function(u){if(this.length===0)return"";for(var d=this.head,h=""+d.data;d=d.next;)h+=u+d.data;return h}},{key:"concat",value:function(u){if(this.length===0)return e.alloc(0);for(var d,h,w,_=e.allocUnsafe(u>>>0),A=this.head,N=0;A;)d=A.data,h=_,w=N,e.prototype.copy.call(d,h,w),N+=A.data.length,A=A.next;return _}},{key:"consume",value:function(u,d){var h;return u<this.head.data.length?(h=this.head.data.slice(0,u),this.head.data=this.head.data.slice(u)):h=u===this.head.data.length?this.shift():d?this._getString(u):this._getBuffer(u),h}},{key:"first",value:function(){return this.head.data}},{key:"_getString",value:function(u){var d=this.head,h=1,w=d.data;for(u-=w.length;d=d.next;){var _=d.data,A=u>_.length?_.length:u;if(A===_.length?w+=_:w+=_.slice(0,u),(u-=A)==0){A===_.length?(++h,d.next?this.head=d.next:this.head=this.tail=null):(this.head=d,d.data=_.slice(A));break}++h}return this.length-=h,w}},{key:"_getBuffer",value:function(u){var d=e.allocUnsafe(u),h=this.head,w=1;for(h.data.copy(d),u-=h.data.length;h=h.next;){var _=h.data,A=u>_.length?_.length:u;if(_.copy(d,d.length-u,0,A),(u-=A)==0){A===_.length?(++w,h.next?this.head=h.next:this.head=this.tail=null):(this.head=h,h.data=_.slice(A));break}++w}return this.length-=w,d}},{key:n,value:function(u,d){return l(this,a(a({},d),{},{depth:0,customInspect:!1}))}}])&&r(f.prototype,c),Object.defineProperty(f,"prototype",{writable:!1}),i}()},{buffer:220,util:188}],485:[function(s,T,S){(function(m){(function(){function a(t,e){r(t,e),o(t)}function o(t){t._writableState&&!t._writableState.emitClose||t._readableState&&!t._readableState.emitClose||t.emit("close")}function r(t,e){t.emit("error",e)}T.exports={destroy:function(t,e){var l=this,n=this._readableState&&this._readableState.destroyed,i=this._writableState&&this._writableState.destroyed;return n||i?(e?e(t):t&&(this._writableState?this._writableState.errorEmitted||(this._writableState.errorEmitted=!0,m.nextTick(r,this,t)):m.nextTick(r,this,t)),this):(this._readableState&&(this._readableState.destroyed=!0),this._writableState&&(this._writableState.destroyed=!0),this._destroy(t||null,function(f){!e&&f?l._writableState?l._writableState.errorEmitted?m.nextTick(o,l):(l._writableState.errorEmitted=!0,m.nextTick(a,l,f)):m.nextTick(a,l,f):e?(m.nextTick(o,l),e(f)):m.nextTick(o,l)}),this)},undestroy:function(){this._readableState&&(this._readableState.destroyed=!1,this._readableState.reading=!1,this._readableState.ended=!1,this._readableState.endEmitted=!1),this._writableState&&(this._writableState.destroyed=!1,this._writableState.ended=!1,this._writableState.ending=!1,this._writableState.finalCalled=!1,this._writableState.prefinished=!1,this._writableState.finished=!1,this._writableState.errorEmitted=!1)},errorOrDestroy:function(t,e){var l=t._readableState,n=t._writableState;l&&l.autoDestroy||n&&n.autoDestroy?t.destroy(e):t.emit("error",e)}}}).call(this)}).call(this,s("_process"))},{_process:467}],486:[function(s,T,S){var m=s("../../../errors").codes.ERR_STREAM_PREMATURE_CLOSE;function a(){}T.exports=function o(r,t,e){if(typeof t=="function")return o(r,null,t);t||(t={}),e=function(A){var N=!1;return function(){if(!N){N=!0;for(var L=arguments.length,I=new Array(L),P=0;P<L;P++)I[P]=arguments[P];A.apply(this,I)}}}(e||a);var l=t.readable||t.readable!==!1&&r.readable,n=t.writable||t.writable!==!1&&r.writable,i=function(){r.writable||c()},f=r._writableState&&r._writableState.finished,c=function(){n=!1,f=!0,l||e.call(r)},u=r._readableState&&r._readableState.endEmitted,d=function(){l=!1,u=!0,n||e.call(r)},h=function(A){e.call(r,A)},w=function(){var A;return l&&!u?(r._readableState&&r._readableState.ended||(A=new m),e.call(r,A)):n&&!f?(r._writableState&&r._writableState.ended||(A=new m),e.call(r,A)):void 0},_=function(){r.req.on("finish",c)};return function(A){return A.setHeader&&typeof A.abort=="function"}(r)?(r.on("complete",c),r.on("abort",w),r.req?_():r.on("request",_)):n&&!r._writableState&&(r.on("end",i),r.on("close",i)),r.on("end",d),r.on("finish",c),t.error!==!1&&r.on("error",h),r.on("close",w),function(){r.removeListener("complete",c),r.removeListener("abort",w),r.removeListener("request",_),r.req&&r.req.removeListener("finish",c),r.removeListener("end",i),r.removeListener("close",i),r.removeListener("finish",c),r.removeListener("end",d),r.removeListener("error",h),r.removeListener("close",w)}}},{"../../../errors":477}],487:[function(s,T,S){T.exports=function(){throw new Error("Readable.from is not available in the browser")}},{}],488:[function(s,T,S){var m,a=s("../../../errors").codes,o=a.ERR_MISSING_ARGS,r=a.ERR_STREAM_DESTROYED;function t(f){if(f)throw f}function e(f,c,u,d){d=function(_){var A=!1;return function(){A||(A=!0,_.apply(void 0,arguments))}}(d);var h=!1;f.on("close",function(){h=!0}),m===void 0&&(m=s("./end-of-stream")),m(f,{readable:c,writable:u},function(_){if(_)return d(_);h=!0,d()});var w=!1;return function(_){if(!h&&!w)return w=!0,function(A){return A.setHeader&&typeof A.abort=="function"}(f)?f.abort():typeof f.destroy=="function"?f.destroy():void d(_||new r("pipe"))}}function l(f){f()}function n(f,c){return f.pipe(c)}function i(f){return f.length?typeof f[f.length-1]!="function"?t:f.pop():t}T.exports=function(){for(var f=arguments.length,c=new Array(f),u=0;u<f;u++)c[u]=arguments[u];var d,h=i(c);if(Array.isArray(c[0])&&(c=c[0]),c.length<2)throw new o("streams");var w=c.map(function(_,A){var N=A<c.length-1;return e(_,N,A>0,function(L){d||(d=L),L&&w.forEach(l),N||(w.forEach(l),h(d))})});return c.reduce(n)}},{"../../../errors":477,"./end-of-stream":486}],489:[function(s,T,S){var m=s("../../../errors").codes.ERR_INVALID_OPT_VALUE;T.exports={getHighWaterMark:function(a,o,r,t){var e=function(l,n,i){return l.highWaterMark!=null?l.highWaterMark:n?l[i]:null}(o,t,r);if(e!=null){if(!isFinite(e)||Math.floor(e)!==e||e<0)throw new m(t?r:"highWaterMark",e);return Math.floor(e)}return a.objectMode?16:16384}}},{"../../../errors":477}],490:[function(s,T,S){T.exports=s("events").EventEmitter},{events:422}],491:[function(s,T,S){(S=T.exports=s("./lib/_stream_readable.js")).Stream=S,S.Readable=S,S.Writable=s("./lib/_stream_writable.js"),S.Duplex=s("./lib/_stream_duplex.js"),S.Transform=s("./lib/_stream_transform.js"),S.PassThrough=s("./lib/_stream_passthrough.js"),S.finished=s("./lib/internal/streams/end-of-stream.js"),S.pipeline=s("./lib/internal/streams/pipeline.js")},{"./lib/_stream_duplex.js":478,"./lib/_stream_passthrough.js":479,"./lib/_stream_readable.js":480,"./lib/_stream_transform.js":481,"./lib/_stream_writable.js":482,"./lib/internal/streams/end-of-stream.js":486,"./lib/internal/streams/pipeline.js":488}],492:[function(s,T,S){var m=function(a){var o=Object.prototype,r=o.hasOwnProperty,t=Object.defineProperty||function(g,y,k){g[y]=k.value},e=typeof Symbol=="function"?Symbol:{},l=e.iterator||"@@iterator",n=e.asyncIterator||"@@asyncIterator",i=e.toStringTag||"@@toStringTag";function f(g,y,k){return Object.defineProperty(g,y,{value:k,enumerable:!0,configurable:!0,writable:!0}),g[y]}try{f({},"")}catch{f=function(y,k,R){return y[k]=R}}function c(g,y,k,R){var O=y&&y.prototype instanceof h?y:h,z=Object.create(O.prototype),$=new v(R||[]);return t(z,"_invoke",{value:U(g,k,$)}),z}function u(g,y,k){try{return{type:"normal",arg:g.call(y,k)}}catch(R){return{type:"throw",arg:R}}}a.wrap=c;var d={};function h(){}function w(){}function _(){}var A={};f(A,l,function(){return this});var N=Object.getPrototypeOf,L=N&&N(N(p([])));L&&L!==o&&r.call(L,l)&&(A=L);var I=_.prototype=h.prototype=Object.create(A);function P(g){["next","throw","return"].forEach(function(y){f(g,y,function(k){return this._invoke(y,k)})})}function B(g,y){var k;t(this,"_invoke",{value:function(R,O){function z(){return new y(function($,W){(function j(H,E,C,F){var V=u(g[H],g,E);if(V.type!=="throw"){var Z=V.arg,q=Z.value;return q&&typeof q=="object"&&r.call(q,"__await")?y.resolve(q.__await).then(function(K){j("next",K,C,F)},function(K){j("throw",K,C,F)}):y.resolve(q).then(function(K){Z.value=K,C(Z)},function(K){return j("throw",K,C,F)})}F(V.arg)})(R,O,$,W)})}return k=k?k.then(z,z):z()}})}function U(g,y,k){var R="suspendedStart";return function(O,z){if(R==="executing")throw new Error("Generator is already running");if(R==="completed"){if(O==="throw")throw z;return b()}for(k.method=O,k.arg=z;;){var $=k.delegate;if($){var W=D($,k);if(W){if(W===d)continue;return W}}if(k.method==="next")k.sent=k._sent=k.arg;else if(k.method==="throw"){if(R==="suspendedStart")throw R="completed",k.arg;k.dispatchException(k.arg)}else k.method==="return"&&k.abrupt("return",k.arg);R="executing";var j=u(g,y,k);if(j.type==="normal"){if(R=k.done?"completed":"suspendedYield",j.arg===d)continue;return{value:j.arg,done:k.done}}j.type==="throw"&&(R="completed",k.method="throw",k.arg=j.arg)}}}function D(g,y){var k=y.method,R=g.iterator[k];if(R===void 0)return y.delegate=null,k==="throw"&&g.iterator.return&&(y.method="return",y.arg=void 0,D(g,y),y.method==="throw")||k!=="return"&&(y.method="throw",y.arg=new TypeError("The iterator does not provide a '"+k+"' method")),d;var O=u(R,g.iterator,y.arg);if(O.type==="throw")return y.method="throw",y.arg=O.arg,y.delegate=null,d;var z=O.arg;return z?z.done?(y[g.resultName]=z.value,y.next=g.nextLoc,y.method!=="return"&&(y.method="next",y.arg=void 0),y.delegate=null,d):z:(y.method="throw",y.arg=new TypeError("iterator result is not an object"),y.delegate=null,d)}function x(g){var y={tryLoc:g[0]};1 in g&&(y.catchLoc=g[1]),2 in g&&(y.finallyLoc=g[2],y.afterLoc=g[3]),this.tryEntries.push(y)}function M(g){var y=g.completion||{};y.type="normal",delete y.arg,g.completion=y}function v(g){this.tryEntries=[{tryLoc:"root"}],g.forEach(x,this),this.reset(!0)}function p(g){if(g){var y=g[l];if(y)return y.call(g);if(typeof g.next=="function")return g;if(!isNaN(g.length)){var k=-1,R=function O(){for(;++k<g.length;)if(r.call(g,k))return O.value=g[k],O.done=!1,O;return O.value=void 0,O.done=!0,O};return R.next=R}}return{next:b}}function b(){return{value:void 0,done:!0}}return w.prototype=_,t(I,"constructor",{value:_,configurable:!0}),t(_,"constructor",{value:w,configurable:!0}),w.displayName=f(_,i,"GeneratorFunction"),a.isGeneratorFunction=function(g){var y=typeof g=="function"&&g.constructor;return!!y&&(y===w||(y.displayName||y.name)==="GeneratorFunction")},a.mark=function(g){return Object.setPrototypeOf?Object.setPrototypeOf(g,_):(g.__proto__=_,f(g,i,"GeneratorFunction")),g.prototype=Object.create(I),g},a.awrap=function(g){return{__await:g}},P(B.prototype),f(B.prototype,n,function(){return this}),a.AsyncIterator=B,a.async=function(g,y,k,R,O){O===void 0&&(O=Promise);var z=new B(c(g,y,k,R),O);return a.isGeneratorFunction(y)?z:z.next().then(function($){return $.done?$.value:z.next()})},P(I),f(I,i,"Generator"),f(I,l,function(){return this}),f(I,"toString",function(){return"[object Generator]"}),a.keys=function(g){var y=Object(g),k=[];for(var R in y)k.push(R);return k.reverse(),function O(){for(;k.length;){var z=k.pop();if(z in y)return O.value=z,O.done=!1,O}return O.done=!0,O}},a.values=p,v.prototype={constructor:v,reset:function(g){if(this.prev=0,this.next=0,this.sent=this._sent=void 0,this.done=!1,this.delegate=null,this.method="next",this.arg=void 0,this.tryEntries.forEach(M),!g)for(var y in this)y.charAt(0)==="t"&&r.call(this,y)&&!isNaN(+y.slice(1))&&(this[y]=void 0)},stop:function(){this.done=!0;var g=this.tryEntries[0].completion;if(g.type==="throw")throw g.arg;return this.rval},dispatchException:function(g){if(this.done)throw g;var y=this;function k(j,H){return z.type="throw",z.arg=g,y.next=j,H&&(y.method="next",y.arg=void 0),!!H}for(var R=this.tryEntries.length-1;R>=0;--R){var O=this.tryEntries[R],z=O.completion;if(O.tryLoc==="root")return k("end");if(O.tryLoc<=this.prev){var $=r.call(O,"catchLoc"),W=r.call(O,"finallyLoc");if($&&W){if(this.prev<O.catchLoc)return k(O.catchLoc,!0);if(this.prev<O.finallyLoc)return k(O.finallyLoc)}else if($){if(this.prev<O.catchLoc)return k(O.catchLoc,!0)}else{if(!W)throw new Error("try statement without catch or finally");if(this.prev<O.finallyLoc)return k(O.finallyLoc)}}}},abrupt:function(g,y){for(var k=this.tryEntries.length-1;k>=0;--k){var R=this.tryEntries[k];if(R.tryLoc<=this.prev&&r.call(R,"finallyLoc")&&this.prev<R.finallyLoc){var O=R;break}}O&&(g==="break"||g==="continue")&&O.tryLoc<=y&&y<=O.finallyLoc&&(O=null);var z=O?O.completion:{};return z.type=g,z.arg=y,O?(this.method="next",this.next=O.finallyLoc,d):this.complete(z)},complete:function(g,y){if(g.type==="throw")throw g.arg;return g.type==="break"||g.type==="continue"?this.next=g.arg:g.type==="return"?(this.rval=this.arg=g.arg,this.method="return",this.next="end"):g.type==="normal"&&y&&(this.next=y),d},finish:function(g){for(var y=this.tryEntries.length-1;y>=0;--y){var k=this.tryEntries[y];if(k.finallyLoc===g)return this.complete(k.completion,k.afterLoc),M(k),d}},catch:function(g){for(var y=this.tryEntries.length-1;y>=0;--y){var k=this.tryEntries[y];if(k.tryLoc===g){var R=k.completion;if(R.type==="throw"){var O=R.arg;M(k)}return O}}throw new Error("illegal catch attempt")},delegateYield:function(g,y,k){return this.delegate={iterator:p(g),resultName:y,nextLoc:k},this.method==="next"&&(this.arg=void 0),d}},a}(typeof T=="object"?T.exports:{});try{regeneratorRuntime=m}catch{typeof globalThis=="object"?globalThis.regeneratorRuntime=m:Function("r","regeneratorRuntime = r")(m)}},{}],493:[function(s,T,S){var m=s("buffer").Buffer,a=s("inherits"),o=s("hash-base"),r=new Array(16),t=[0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,7,4,13,1,10,6,15,3,12,0,9,5,2,14,11,8,3,10,14,4,9,15,8,1,2,7,0,6,13,11,5,12,1,9,11,10,0,8,12,4,13,3,7,15,14,5,6,2,4,0,5,9,7,12,2,10,14,1,3,8,11,6,15,13],e=[5,14,7,0,9,2,11,4,13,6,15,8,1,10,3,12,6,11,3,7,0,13,5,10,14,15,8,12,4,9,1,2,15,5,1,3,7,14,6,9,11,8,12,2,10,0,4,13,8,6,4,1,3,11,15,0,5,12,2,13,9,7,10,14,12,15,10,4,1,5,8,7,6,2,13,14,0,3,9,11],l=[11,14,15,12,5,8,7,9,11,13,14,15,6,7,9,8,7,6,8,13,11,9,7,15,7,12,15,9,11,7,13,12,11,13,6,7,14,9,13,15,14,8,13,6,5,12,7,5,11,12,14,15,14,15,9,8,9,14,5,6,8,6,5,12,9,15,5,11,6,8,13,12,5,12,13,14,11,8,5,6],n=[8,9,9,11,13,15,15,5,7,7,8,11,14,14,12,6,9,13,15,7,12,8,9,11,7,7,12,7,6,15,13,11,9,7,15,11,8,6,6,14,12,13,5,14,13,13,7,5,15,5,8,11,14,14,6,14,6,9,12,9,12,5,15,8,8,5,12,9,12,5,14,6,8,13,6,5,15,13,11,11],i=[0,1518500249,1859775393,2400959708,2840853838],f=[1352829926,1548603684,1836072691,2053994217,0];function c(){o.call(this,64),this._a=1732584193,this._b=4023233417,this._c=2562383102,this._d=271733878,this._e=3285377520}function u(N,L){return N<<L|N>>>32-L}function d(N,L,I,P,B,U,D,x){return u(N+(L^I^P)+U+D|0,x)+B|0}function h(N,L,I,P,B,U,D,x){return u(N+(L&I|~L&P)+U+D|0,x)+B|0}function w(N,L,I,P,B,U,D,x){return u(N+((L|~I)^P)+U+D|0,x)+B|0}function _(N,L,I,P,B,U,D,x){return u(N+(L&P|I&~P)+U+D|0,x)+B|0}function A(N,L,I,P,B,U,D,x){return u(N+(L^(I|~P))+U+D|0,x)+B|0}a(c,o),c.prototype._update=function(){for(var N=r,L=0;L<16;++L)N[L]=this._block.readInt32LE(4*L);for(var I=0|this._a,P=0|this._b,B=0|this._c,U=0|this._d,D=0|this._e,x=0|this._a,M=0|this._b,v=0|this._c,p=0|this._d,b=0|this._e,g=0;g<80;g+=1){var y,k;g<16?(y=d(I,P,B,U,D,N[t[g]],i[0],l[g]),k=A(x,M,v,p,b,N[e[g]],f[0],n[g])):g<32?(y=h(I,P,B,U,D,N[t[g]],i[1],l[g]),k=_(x,M,v,p,b,N[e[g]],f[1],n[g])):g<48?(y=w(I,P,B,U,D,N[t[g]],i[2],l[g]),k=w(x,M,v,p,b,N[e[g]],f[2],n[g])):g<64?(y=_(I,P,B,U,D,N[t[g]],i[3],l[g]),k=h(x,M,v,p,b,N[e[g]],f[3],n[g])):(y=A(I,P,B,U,D,N[t[g]],i[4],l[g]),k=d(x,M,v,p,b,N[e[g]],f[4],n[g])),I=D,D=U,U=u(B,10),B=P,P=y,x=b,b=p,p=u(v,10),v=M,M=k}var R=this._b+B+p|0;this._b=this._c+U+b|0,this._c=this._d+D+x|0,this._d=this._e+I+M|0,this._e=this._a+P+v|0,this._a=R},c.prototype._digest=function(){this._block[this._blockOffset++]=128,this._blockOffset>56&&(this._block.fill(0,this._blockOffset,64),this._update(),this._blockOffset=0),this._block.fill(0,this._blockOffset,56),this._block.writeUInt32LE(this._length[0],56),this._block.writeUInt32LE(this._length[1],60),this._update();var N=m.alloc?m.alloc(20):new m(20);return N.writeInt32LE(this._a,0),N.writeInt32LE(this._b,4),N.writeInt32LE(this._c,8),N.writeInt32LE(this._d,12),N.writeInt32LE(this._e,16),N},T.exports=c},{buffer:220,"hash-base":425,inherits:440}],494:[function(s,T,S){/*! safe-buffer. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> */var m=s("buffer"),a=m.Buffer;function o(t,e){for(var l in t)e[l]=t[l]}function r(t,e,l){return a(t,e,l)}a.from&&a.alloc&&a.allocUnsafe&&a.allocUnsafeSlow?T.exports=m:(o(m,S),S.Buffer=r),r.prototype=Object.create(a.prototype),o(a,r),r.from=function(t,e,l){if(typeof t=="number")throw new TypeError("Argument must not be a number");return a(t,e,l)},r.alloc=function(t,e,l){if(typeof t!="number")throw new TypeError("Argument must be a number");var n=a(t);return e!==void 0?typeof l=="string"?n.fill(e,l):n.fill(e):n.fill(0),n},r.allocUnsafe=function(t){if(typeof t!="number")throw new TypeError("Argument must be a number");return a(t)},r.allocUnsafeSlow=function(t){if(typeof t!="number")throw new TypeError("Argument must be a number");return m.SlowBuffer(t)}},{buffer:220}],495:[function(s,T,S){(function(m){(function(){var a,o=s("buffer"),r=o.Buffer,t={};for(a in o)o.hasOwnProperty(a)&&a!=="SlowBuffer"&&a!=="Buffer"&&(t[a]=o[a]);var e=t.Buffer={};for(a in r)r.hasOwnProperty(a)&&a!=="allocUnsafe"&&a!=="allocUnsafeSlow"&&(e[a]=r[a]);if(t.Buffer.prototype=r.prototype,e.from&&e.from!==Uint8Array.from||(e.from=function(l,n,i){if(typeof l=="number")throw new TypeError('The "value" argument must not be of type number. Received type '+typeof l);if(l&&l.length===void 0)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof l);return r(l,n,i)}),e.alloc||(e.alloc=function(l,n,i){if(typeof l!="number")throw new TypeError('The "size" argument must be of type number. Received type '+typeof l);if(l<0||l>=2*(1<<30))throw new RangeError('The value "'+l+'" is invalid for option "size"');var f=r(l);return n&&n.length!==0?typeof i=="string"?f.fill(n,i):f.fill(n):f.fill(0),f}),!t.kStringMaxLength)try{t.kStringMaxLength=m.binding("buffer").kStringMaxLength}catch{}t.constants||(t.constants={MAX_LENGTH:t.kMaxLength},t.kStringMaxLength&&(t.constants.MAX_STRING_LENGTH=t.kStringMaxLength)),T.exports=t}).call(this)}).call(this,s("_process"))},{_process:467,buffer:220}],496:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0});const m=s("xmlchars/xml/1.0/ed5"),a=s("xmlchars/xml/1.1/ed2"),o=s("xmlchars/xmlns/1.0/ed3");var r=m.isS,t=m.isChar,e=m.isNameStartChar,l=m.isNameChar,n=m.S_LIST,i=m.NAME_RE,f=a.isChar,c=o.isNCNameStartChar,u=o.isNCNameChar,d=o.NC_NAME_RE;const h="http://www.w3.org/XML/1998/namespace",w="http://www.w3.org/2000/xmlns/",_={__proto__:null,xml:h,xmlns:w},A={__proto__:null,amp:"&",gt:">",lt:"<",quot:'"',apos:"'"},N=p=>p===34||p===39,L=[34,39],I=[...L,91,62],P=[...L,60,93],B=[61,63,...n],U=[...n,62,38,60];function D(p,b,g){switch(b){case"xml":g!==h&&p.fail(`xml prefix must be bound to ${h}.`);break;case"xmlns":g!==w&&p.fail(`xmlns prefix must be bound to ${w}.`)}switch(g){case w:p.fail(b===""?`the default namespace may not be set to ${g}.`:`may not assign a prefix (even "xmlns") to the URI ${w}.`);break;case h:switch(b){case"xml":break;case"":p.fail(`the default namespace may not be set to ${g}.`);break;default:p.fail("may not assign the xml namespace to another prefix.")}}}const x=p=>d.test(p),M=p=>i.test(p);S.EVENTS=["xmldecl","text","processinginstruction","doctype","comment","opentagstart","attribute","opentag","closetag","cdata","error","end","ready"];const v={xmldecl:"xmldeclHandler",text:"textHandler",processinginstruction:"piHandler",doctype:"doctypeHandler",comment:"commentHandler",opentagstart:"openTagStartHandler",attribute:"attributeHandler",opentag:"openTagHandler",closetag:"closeTagHandler",cdata:"cdataHandler",error:"errorHandler",end:"endHandler",ready:"readyHandler"};S.SaxesParser=class{constructor(p){this.opt=p??{},this.fragmentOpt=!!this.opt.fragment;const b=this.xmlnsOpt=!!this.opt.xmlns;if(this.trackPosition=this.opt.position!==!1,this.fileName=this.opt.fileName,b){this.nameStartCheck=c,this.nameCheck=u,this.isName=x,this.processAttribs=this.processAttribsNS,this.pushAttrib=this.pushAttribNS,this.ns=Object.assign({__proto__:null},_);const g=this.opt.additionalNamespaces;g!=null&&(function(y,k){for(const R of Object.keys(k))D(y,R,k[R])}(this,g),Object.assign(this.ns,g))}else this.nameStartCheck=e,this.nameCheck=l,this.isName=M,this.processAttribs=this.processAttribsPlain,this.pushAttrib=this.pushAttribPlain;this.stateTable=[this.sBegin,this.sBeginWhitespace,this.sDoctype,this.sDoctypeQuote,this.sDTD,this.sDTDQuoted,this.sDTDOpenWaka,this.sDTDOpenWakaBang,this.sDTDComment,this.sDTDCommentEnding,this.sDTDCommentEnded,this.sDTDPI,this.sDTDPIEnding,this.sText,this.sEntity,this.sOpenWaka,this.sOpenWakaBang,this.sComment,this.sCommentEnding,this.sCommentEnded,this.sCData,this.sCDataEnding,this.sCDataEnding2,this.sPIFirstChar,this.sPIRest,this.sPIBody,this.sPIEnding,this.sXMLDeclNameStart,this.sXMLDeclName,this.sXMLDeclEq,this.sXMLDeclValueStart,this.sXMLDeclValue,this.sXMLDeclSeparator,this.sXMLDeclEnding,this.sOpenTag,this.sOpenTagSlash,this.sAttrib,this.sAttribName,this.sAttribNameSawWhite,this.sAttribValue,this.sAttribValueQuoted,this.sAttribValueClosed,this.sAttribValueUnquoted,this.sCloseTag,this.sCloseTagSawWhite],this._init()}get closed(){return this._closed}_init(){var p;this.openWakaBang="",this.text="",this.name="",this.piTarget="",this.entity="",this.q=null,this.tags=[],this.tag=null,this.topNS=null,this.chunk="",this.chunkPosition=0,this.i=0,this.prevI=0,this.carriedFromPrevious=void 0,this.forbiddenState=0,this.attribList=[];const{fragmentOpt:b}=this;this.state=b?13:0,this.reportedTextBeforeRoot=this.reportedTextAfterRoot=this.closedRoot=this.sawRoot=b,this.xmlDeclPossible=!b,this.xmlDeclExpects=["version"],this.entityReturnState=void 0;let{defaultXMLVersion:g}=this.opt;if(g===void 0){if(this.opt.forceXMLVersion===!0)throw new Error("forceXMLVersion set but defaultXMLVersion is not set");g="1.0"}this.setXMLVersion(g),this.positionAtNewLine=0,this.doctype=!1,this._closed=!1,this.xmlDecl={version:void 0,encoding:void 0,standalone:void 0},this.line=1,this.column=0,this.ENTITIES=Object.create(A),(p=this.readyHandler)===null||p===void 0||p.call(this)}get position(){return this.chunkPosition+this.i}get columnIndex(){return this.position-this.positionAtNewLine}on(p,b){this[v[p]]=b}off(p){this[v[p]]=void 0}makeError(p){var b;let g=(b=this.fileName)!==null&&b!==void 0?b:"";return this.trackPosition&&(g.length>0&&(g+=":"),g+=`${this.line}:${this.column}`),g.length>0&&(g+=": "),new Error(g+p)}fail(p){const b=this.makeError(p),g=this.errorHandler;if(g===void 0)throw b;return g(b),this}write(p){if(this.closed)return this.fail("cannot write after close; assign an onready handler.");let b=!1;p===null?(b=!0,p=""):typeof p=="object"&&(p=p.toString()),this.carriedFromPrevious!==void 0&&(p=`${this.carriedFromPrevious}${p}`,this.carriedFromPrevious=void 0);let g=p.length;const y=p.charCodeAt(g-1);!b&&(y===13||y>=55296&&y<=56319)&&(this.carriedFromPrevious=p[g-1],g--,p=p.slice(0,g));const{stateTable:k}=this;for(this.chunk=p,this.i=0;this.i<g;)k[this.state].call(this);return this.chunkPosition+=g,b?this.end():this}close(){return this.write(null)}getCode10(){const{chunk:p,i:b}=this;if(this.prevI=b,this.i=b+1,b>=p.length)return-1;const g=p.charCodeAt(b);if(this.column++,g<55296){if(g>=32||g===9)return g;switch(g){case 10:return this.line++,this.column=0,this.positionAtNewLine=this.position,10;case 13:return p.charCodeAt(b+1)===10&&(this.i=b+2),this.line++,this.column=0,this.positionAtNewLine=this.position,-2;default:return this.fail("disallowed character."),g}}if(g>56319)return g>=57344&&g<=65533||this.fail("disallowed character."),g;const y=65536+1024*(g-55296)+(p.charCodeAt(b+1)-56320);return this.i=b+2,y>1114111&&this.fail("disallowed character."),y}getCode11(){const{chunk:p,i:b}=this;if(this.prevI=b,this.i=b+1,b>=p.length)return-1;const g=p.charCodeAt(b);if(this.column++,g<55296){if(g>31&&g<127||g>159&&g!==8232||g===9)return g;switch(g){case 10:return this.line++,this.column=0,this.positionAtNewLine=this.position,10;case 13:{const k=p.charCodeAt(b+1);k!==10&&k!==133||(this.i=b+2)}case 133:case 8232:return this.line++,this.column=0,this.positionAtNewLine=this.position,-2;default:return this.fail("disallowed character."),g}}if(g>56319)return g>=57344&&g<=65533||this.fail("disallowed character."),g;const y=65536+1024*(g-55296)+(p.charCodeAt(b+1)-56320);return this.i=b+2,y>1114111&&this.fail("disallowed character."),y}getCodeNorm(){const p=this.getCode();return p===-2?10:p}unget(){this.i=this.prevI,this.column--}captureTo(p){let{i:b}=this;const{chunk:g}=this;for(;;){const y=this.getCode(),k=y===-2,R=k?10:y;if(R===-1||p.includes(R))return this.text+=g.slice(b,this.prevI),R;k&&(this.text+=g.slice(b,this.prevI)+`
`,b=this.i)}}captureToChar(p){let{i:b}=this;const{chunk:g}=this;for(;;){let y=this.getCode();switch(y){case-2:this.text+=g.slice(b,this.prevI)+`
`,b=this.i,y=10;break;case-1:return this.text+=g.slice(b),!1}if(y===p)return this.text+=g.slice(b,this.prevI),!0}}captureNameChars(){const{chunk:p,i:b}=this;for(;;){const g=this.getCode();if(g===-1)return this.name+=p.slice(b),-1;if(!l(g))return this.name+=p.slice(b,this.prevI),g===-2?10:g}}skipSpaces(){for(;;){const p=this.getCodeNorm();if(p===-1||!r(p))return p}}setXMLVersion(p){this.currentXMLVersion=p,p==="1.0"?(this.isChar=t,this.getCode=this.getCode10):(this.isChar=f,this.getCode=this.getCode11)}sBegin(){this.chunk.charCodeAt(0)===65279&&(this.i++,this.column++),this.state=1}sBeginWhitespace(){const p=this.i,b=this.skipSpaces();switch(this.prevI!==p&&(this.xmlDeclPossible=!1),b){case 60:if(this.state=15,this.text.length!==0)throw new Error("no-empty text at start");break;case-1:break;default:this.unget(),this.state=13,this.xmlDeclPossible=!1}}sDoctype(){var p;const b=this.captureTo(I);switch(b){case 62:(p=this.doctypeHandler)===null||p===void 0||p.call(this,this.text),this.text="",this.state=13,this.doctype=!0;break;case-1:break;default:this.text+=String.fromCodePoint(b),b===91?this.state=4:N(b)&&(this.state=3,this.q=b)}}sDoctypeQuote(){const p=this.q;this.captureToChar(p)&&(this.text+=String.fromCodePoint(p),this.q=null,this.state=2)}sDTD(){const p=this.captureTo(P);p!==-1&&(this.text+=String.fromCodePoint(p),p===93?this.state=2:p===60?this.state=6:N(p)&&(this.state=5,this.q=p))}sDTDQuoted(){const p=this.q;this.captureToChar(p)&&(this.text+=String.fromCodePoint(p),this.state=4,this.q=null)}sDTDOpenWaka(){const p=this.getCodeNorm();switch(this.text+=String.fromCodePoint(p),p){case 33:this.state=7,this.openWakaBang="";break;case 63:this.state=11;break;default:this.state=4}}sDTDOpenWakaBang(){const p=String.fromCodePoint(this.getCodeNorm()),b=this.openWakaBang+=p;this.text+=p,b!=="-"&&(this.state=b==="--"?8:4,this.openWakaBang="")}sDTDComment(){this.captureToChar(45)&&(this.text+="-",this.state=9)}sDTDCommentEnding(){const p=this.getCodeNorm();this.text+=String.fromCodePoint(p),this.state=p===45?10:8}sDTDCommentEnded(){const p=this.getCodeNorm();this.text+=String.fromCodePoint(p),p===62?this.state=4:(this.fail("malformed comment."),this.state=8)}sDTDPI(){this.captureToChar(63)&&(this.text+="?",this.state=12)}sDTDPIEnding(){const p=this.getCodeNorm();this.text+=String.fromCodePoint(p),p===62&&(this.state=4)}sText(){this.tags.length!==0?this.handleTextInRoot():this.handleTextOutsideRoot()}sEntity(){let{i:p}=this;const{chunk:b}=this;t:for(;;)switch(this.getCode()){case-2:this.entity+=b.slice(p,this.prevI)+`
`,p=this.i;break;case 59:{const{entityReturnState:g}=this,y=this.entity+b.slice(p,this.prevI);let k;this.state=g,y===""?(this.fail("empty entity name."),k="&;"):(k=this.parseEntity(y),this.entity=""),g===13&&this.textHandler===void 0||(this.text+=k);break t}case-1:this.entity+=b.slice(p);break t}}sOpenWaka(){const p=this.getCode();if(e(p))this.state=34,this.unget(),this.xmlDeclPossible=!1;else switch(p){case 47:this.state=43,this.xmlDeclPossible=!1;break;case 33:this.state=16,this.openWakaBang="",this.xmlDeclPossible=!1;break;case 63:this.state=23;break;default:this.fail("disallowed character in tag name"),this.state=13,this.xmlDeclPossible=!1}}sOpenWakaBang(){switch(this.openWakaBang+=String.fromCodePoint(this.getCodeNorm()),this.openWakaBang){case"[CDATA[":this.sawRoot||this.reportedTextBeforeRoot||(this.fail("text data outside of root node."),this.reportedTextBeforeRoot=!0),this.closedRoot&&!this.reportedTextAfterRoot&&(this.fail("text data outside of root node."),this.reportedTextAfterRoot=!0),this.state=20,this.openWakaBang="";break;case"--":this.state=17,this.openWakaBang="";break;case"DOCTYPE":this.state=2,(this.doctype||this.sawRoot)&&this.fail("inappropriately located doctype declaration."),this.openWakaBang="";break;default:this.openWakaBang.length>=7&&this.fail("incorrect syntax.")}}sComment(){this.captureToChar(45)&&(this.state=18)}sCommentEnding(){var p;const b=this.getCodeNorm();b===45?(this.state=19,(p=this.commentHandler)===null||p===void 0||p.call(this,this.text),this.text=""):(this.text+="-"+String.fromCodePoint(b),this.state=17)}sCommentEnded(){const p=this.getCodeNorm();p!==62?(this.fail("malformed comment."),this.text+="--"+String.fromCodePoint(p),this.state=17):this.state=13}sCData(){this.captureToChar(93)&&(this.state=21)}sCDataEnding(){const p=this.getCodeNorm();p===93?this.state=22:(this.text+="]"+String.fromCodePoint(p),this.state=20)}sCDataEnding2(){var p;const b=this.getCodeNorm();switch(b){case 62:(p=this.cdataHandler)===null||p===void 0||p.call(this,this.text),this.text="",this.state=13;break;case 93:this.text+="]";break;default:this.text+="]]"+String.fromCodePoint(b),this.state=20}}sPIFirstChar(){const p=this.getCodeNorm();this.nameStartCheck(p)?(this.piTarget+=String.fromCodePoint(p),this.state=24):p===63||r(p)?(this.fail("processing instruction without a target."),this.state=p===63?26:25):(this.fail("disallowed character in processing instruction name."),this.piTarget+=String.fromCodePoint(p),this.state=24)}sPIRest(){const{chunk:p,i:b}=this;for(;;){const g=this.getCodeNorm();if(g===-1)return void(this.piTarget+=p.slice(b));if(!this.nameCheck(g)){this.piTarget+=p.slice(b,this.prevI);const y=g===63;y||r(g)?this.piTarget==="xml"?(this.xmlDeclPossible||this.fail("an XML declaration must be at the start of the document."),this.state=y?33:27):this.state=y?26:25:(this.fail("disallowed character in processing instruction name."),this.piTarget+=String.fromCodePoint(g));break}}}sPIBody(){if(this.text.length===0){const p=this.getCodeNorm();p===63?this.state=26:r(p)||(this.text=String.fromCodePoint(p))}else this.captureToChar(63)&&(this.state=26)}sPIEnding(){var p;const b=this.getCodeNorm();if(b===62){const{piTarget:g}=this;g.toLowerCase()==="xml"&&this.fail("the XML declaration must appear at the start of the document."),(p=this.piHandler)===null||p===void 0||p.call(this,{target:g,body:this.text}),this.piTarget=this.text="",this.state=13}else b===63?this.text+="?":(this.text+="?"+String.fromCodePoint(b),this.state=25);this.xmlDeclPossible=!1}sXMLDeclNameStart(){const p=this.skipSpaces();p!==63?p!==-1&&(this.state=28,this.name=String.fromCodePoint(p)):this.state=33}sXMLDeclName(){const p=this.captureTo(B);if(p===63)return this.state=33,this.name+=this.text,this.text="",void this.fail("XML declaration is incomplete.");if(r(p)||p===61){if(this.name+=this.text,this.text="",!this.xmlDeclExpects.includes(this.name))switch(this.name.length){case 0:this.fail("did not expect any more name/value pairs.");break;case 1:this.fail(`expected the name ${this.xmlDeclExpects[0]}.`);break;default:this.fail("expected one of "+this.xmlDeclExpects.join(", "))}this.state=p===61?30:29}}sXMLDeclEq(){const p=this.getCodeNorm();if(p===63)return this.state=33,void this.fail("XML declaration is incomplete.");r(p)||(p!==61&&this.fail("value required."),this.state=30)}sXMLDeclValueStart(){const p=this.getCodeNorm();if(p===63)return this.state=33,void this.fail("XML declaration is incomplete.");r(p)||(N(p)?this.q=p:(this.fail("value must be quoted."),this.q=32),this.state=31)}sXMLDeclValue(){const p=this.captureTo([this.q,63]);if(p===63)return this.state=33,this.text="",void this.fail("XML declaration is incomplete.");if(p===-1)return;const b=this.text;switch(this.text="",this.name){case"version":{this.xmlDeclExpects=["encoding","standalone"];const g=b;this.xmlDecl.version=g,/^1\.[0-9]+$/.test(g)?this.opt.forceXMLVersion||this.setXMLVersion(g):this.fail("version number must match /^1\\.[0-9]+$/.");break}case"encoding":/^[A-Za-z][A-Za-z0-9._-]*$/.test(b)||this.fail("encoding value must match /^[A-Za-z0-9][A-Za-z0-9._-]*$/."),this.xmlDeclExpects=["standalone"],this.xmlDecl.encoding=b;break;case"standalone":b!=="yes"&&b!=="no"&&this.fail('standalone value must match "yes" or "no".'),this.xmlDeclExpects=[],this.xmlDecl.standalone=b}this.name="",this.state=32}sXMLDeclSeparator(){const p=this.getCodeNorm();p!==63?(r(p)||(this.fail("whitespace required."),this.unget()),this.state=27):this.state=33}sXMLDeclEnding(){var p;this.getCodeNorm()===62?(this.piTarget!=="xml"?this.fail("processing instructions are not allowed before root."):this.name!=="version"&&this.xmlDeclExpects.includes("version")&&this.fail("XML declaration must contain a version."),(p=this.xmldeclHandler)===null||p===void 0||p.call(this,this.xmlDecl),this.name="",this.piTarget=this.text="",this.state=13):this.fail("The character ? is disallowed anywhere in XML declarations."),this.xmlDeclPossible=!1}sOpenTag(){var p;const b=this.captureNameChars();if(b===-1)return;const g=this.tag={name:this.name,attributes:Object.create(null)};switch(this.name="",this.xmlnsOpt&&(this.topNS=g.ns=Object.create(null)),(p=this.openTagStartHandler)===null||p===void 0||p.call(this,g),this.sawRoot=!0,!this.fragmentOpt&&this.closedRoot&&this.fail("documents may contain only one root."),b){case 62:this.openTag();break;case 47:this.state=35;break;default:r(b)||this.fail("disallowed character in tag name."),this.state=36}}sOpenTagSlash(){this.getCode()===62?this.openSelfClosingTag():(this.fail("forward-slash in opening tag not followed by >."),this.state=36)}sAttrib(){const p=this.skipSpaces();p!==-1&&(e(p)?(this.unget(),this.state=37):p===62?this.openTag():p===47?this.state=35:this.fail("disallowed character in attribute name."))}sAttribName(){const p=this.captureNameChars();p===61?this.state=39:r(p)?this.state=38:p===62?(this.fail("attribute without value."),this.pushAttrib(this.name,this.name),this.name=this.text="",this.openTag()):p!==-1&&this.fail("disallowed character in attribute name.")}sAttribNameSawWhite(){const p=this.skipSpaces();switch(p){case-1:return;case 61:this.state=39;break;default:this.fail("attribute without value."),this.text="",this.name="",p===62?this.openTag():e(p)?(this.unget(),this.state=37):(this.fail("disallowed character in attribute name."),this.state=36)}}sAttribValue(){const p=this.getCodeNorm();N(p)?(this.q=p,this.state=40):r(p)||(this.fail("unquoted attribute value."),this.state=42,this.unget())}sAttribValueQuoted(){const{q:p,chunk:b}=this;let{i:g}=this;for(;;)switch(this.getCode()){case p:return this.pushAttrib(this.name,this.text+b.slice(g,this.prevI)),this.name=this.text="",this.q=null,void(this.state=41);case 38:return this.text+=b.slice(g,this.prevI),this.state=14,void(this.entityReturnState=40);case 10:case-2:case 9:this.text+=b.slice(g,this.prevI)+" ",g=this.i;break;case 60:return this.text+=b.slice(g,this.prevI),void this.fail("disallowed character.");case-1:return void(this.text+=b.slice(g))}}sAttribValueClosed(){const p=this.getCodeNorm();r(p)?this.state=36:p===62?this.openTag():p===47?this.state=35:e(p)?(this.fail("no whitespace between attributes."),this.unget(),this.state=37):this.fail("disallowed character in attribute name.")}sAttribValueUnquoted(){const p=this.captureTo(U);switch(p){case 38:this.state=14,this.entityReturnState=42;break;case 60:this.fail("disallowed character.");break;case-1:break;default:this.text.includes("]]>")&&this.fail('the string "]]>" is disallowed in char data.'),this.pushAttrib(this.name,this.text),this.name=this.text="",p===62?this.openTag():this.state=36}}sCloseTag(){const p=this.captureNameChars();p===62?this.closeTag():r(p)?this.state=44:p!==-1&&this.fail("disallowed character in closing tag.")}sCloseTagSawWhite(){switch(this.skipSpaces()){case 62:this.closeTag();break;case-1:break;default:this.fail("disallowed character in closing tag.")}}handleTextInRoot(){let{i:p,forbiddenState:b}=this;const{chunk:g,textHandler:y}=this;t:for(;;)switch(this.getCode()){case 60:if(this.state=15,y!==void 0){const{text:k}=this,R=g.slice(p,this.prevI);k.length!==0?(y(k+R),this.text=""):R.length!==0&&y(R)}b=0;break t;case 38:this.state=14,this.entityReturnState=13,y!==void 0&&(this.text+=g.slice(p,this.prevI)),b=0;break t;case 93:switch(b){case 0:b=1;break;case 1:b=2;break;case 2:break;default:throw new Error("impossible state")}break;case 62:b===2&&this.fail('the string "]]>" is disallowed in char data.'),b=0;break;case-2:y!==void 0&&(this.text+=g.slice(p,this.prevI)+`
`),p=this.i,b=0;break;case-1:y!==void 0&&(this.text+=g.slice(p));break t;default:b=0}this.forbiddenState=b}handleTextOutsideRoot(){let{i:p}=this;const{chunk:b,textHandler:g}=this;let y=!1;t:for(;;){const k=this.getCode();switch(k){case 60:if(this.state=15,g!==void 0){const{text:R}=this,O=b.slice(p,this.prevI);R.length!==0?(g(R+O),this.text=""):O.length!==0&&g(O)}break t;case 38:this.state=14,this.entityReturnState=13,g!==void 0&&(this.text+=b.slice(p,this.prevI)),y=!0;break t;case-2:g!==void 0&&(this.text+=b.slice(p,this.prevI)+`
`),p=this.i;break;case-1:g!==void 0&&(this.text+=b.slice(p));break t;default:r(k)||(y=!0)}}y&&(this.sawRoot||this.reportedTextBeforeRoot||(this.fail("text data outside of root node."),this.reportedTextBeforeRoot=!0),this.closedRoot&&!this.reportedTextAfterRoot&&(this.fail("text data outside of root node."),this.reportedTextAfterRoot=!0))}pushAttribNS(p,b){var g;const{prefix:y,local:k}=this.qname(p),R={name:p,prefix:y,local:k,value:b};if(this.attribList.push(R),(g=this.attributeHandler)===null||g===void 0||g.call(this,R),y==="xmlns"){const O=b.trim();this.currentXMLVersion==="1.0"&&O===""&&this.fail("invalid attempt to undefine prefix in XML 1.0"),this.topNS[k]=O,D(this,k,O)}else if(p==="xmlns"){const O=b.trim();this.topNS[""]=O,D(this,"",O)}}pushAttribPlain(p,b){var g;const y={name:p,value:b};this.attribList.push(y),(g=this.attributeHandler)===null||g===void 0||g.call(this,y)}end(){var p,b;this.sawRoot||this.fail("document must contain a root element.");const{tags:g}=this;for(;g.length>0;){const k=g.pop();this.fail("unclosed tag: "+k.name)}this.state!==0&&this.state!==13&&this.fail("unexpected end.");const{text:y}=this;return y.length!==0&&((p=this.textHandler)===null||p===void 0||p.call(this,y),this.text=""),this._closed=!0,(b=this.endHandler)===null||b===void 0||b.call(this),this._init(),this}resolve(p){var b,g;let y=this.topNS[p];if(y!==void 0)return y;const{tags:k}=this;for(let R=k.length-1;R>=0;R--)if(y=k[R].ns[p],y!==void 0)return y;return y=this.ns[p],y!==void 0?y:(g=(b=this.opt).resolvePrefix)===null||g===void 0?void 0:g.call(b,p)}qname(p){const b=p.indexOf(":");if(b===-1)return{prefix:"",local:p};const g=p.slice(b+1),y=p.slice(0,b);return(y===""||g===""||g.includes(":"))&&this.fail(`malformed name: ${p}.`),{prefix:y,local:g}}processAttribsNS(){var p;const{attribList:b}=this,g=this.tag;{const{prefix:R,local:O}=this.qname(g.name);g.prefix=R,g.local=O;const z=g.uri=(p=this.resolve(R))!==null&&p!==void 0?p:"";R!==""&&(R==="xmlns"&&this.fail('tags may not have "xmlns" as prefix.'),z===""&&(this.fail(`unbound namespace prefix: ${JSON.stringify(R)}.`),g.uri=R))}if(b.length===0)return;const{attributes:y}=g,k=new Set;for(const R of b){const{name:O,prefix:z,local:$}=R;let W,j;z===""?(W=O==="xmlns"?w:"",j=O):(W=this.resolve(z),W===void 0&&(this.fail(`unbound namespace prefix: ${JSON.stringify(z)}.`),W=z),j=`{${W}}${$}`),k.has(j)&&this.fail(`duplicate attribute: ${j}.`),k.add(j),R.uri=W,y[O]=R}this.attribList=[]}processAttribsPlain(){const{attribList:p}=this,b=this.tag.attributes;for(const{name:g,value:y}of p)b[g]!==void 0&&this.fail(`duplicate attribute: ${g}.`),b[g]=y;this.attribList=[]}openTag(){var p;this.processAttribs();const{tags:b}=this,g=this.tag;g.isSelfClosing=!1,(p=this.openTagHandler)===null||p===void 0||p.call(this,g),b.push(g),this.state=13,this.name=""}openSelfClosingTag(){var p,b,g;this.processAttribs();const{tags:y}=this,k=this.tag;k.isSelfClosing=!0,(p=this.openTagHandler)===null||p===void 0||p.call(this,k),(b=this.closeTagHandler)===null||b===void 0||b.call(this,k),(this.tag=(g=y[y.length-1])!==null&&g!==void 0?g:null)===null&&(this.closedRoot=!0),this.state=13,this.name=""}closeTag(){const{tags:p,name:b}=this;if(this.state=13,this.name="",b==="")return this.fail("weird empty close tag."),void(this.text+="</>");const g=this.closeTagHandler;let y=p.length;for(;y-- >0;){const k=this.tag=p.pop();if(this.topNS=k.ns,g?.(k),k.name===b)break;this.fail("unexpected close tag.")}y===0?this.closedRoot=!0:y<0&&(this.fail(`unmatched closing tag: ${b}.`),this.text+=`</${b}>`)}parseEntity(p){if(p[0]!=="#"){const g=this.ENTITIES[p];return g!==void 0?g:(this.fail(this.isName(p)?"undefined entity.":"disallowed character in entity name."),`&${p};`)}let b=NaN;return p[1]==="x"&&/^#x[0-9a-f]+$/i.test(p)?b=parseInt(p.slice(2),16):/^#[0-9]+$/.test(p)&&(b=parseInt(p.slice(1),10)),this.isChar(b)?String.fromCodePoint(b):(this.fail("malformed character entity."),`&${p};`)}}},{"xmlchars/xml/1.0/ed5":543,"xmlchars/xml/1.1/ed2":544,"xmlchars/xmlns/1.0/ed3":545}],497:[function(s,T,S){var m=s("safe-buffer").Buffer;function a(o,r){this._block=m.alloc(o),this._finalSize=r,this._blockSize=o,this._len=0}a.prototype.update=function(o,r){typeof o=="string"&&(r=r||"utf8",o=m.from(o,r));for(var t=this._block,e=this._blockSize,l=o.length,n=this._len,i=0;i<l;){for(var f=n%e,c=Math.min(l-i,e-f),u=0;u<c;u++)t[f+u]=o[i+u];i+=c,(n+=c)%e==0&&this._update(t)}return this._len+=l,this},a.prototype.digest=function(o){var r=this._len%this._blockSize;this._block[r]=128,this._block.fill(0,r+1),r>=this._finalSize&&(this._update(this._block),this._block.fill(0));var t=8*this._len;if(t<=4294967295)this._block.writeUInt32BE(t,this._blockSize-4);else{var e=(4294967295&t)>>>0,l=(t-e)/4294967296;this._block.writeUInt32BE(l,this._blockSize-8),this._block.writeUInt32BE(e,this._blockSize-4)}this._update(this._block);var n=this._hash();return o?n.toString(o):n},a.prototype._update=function(){throw new Error("_update must be implemented by subclass")},T.exports=a},{"safe-buffer":494}],498:[function(s,T,S){var m=T.exports=function(a){a=a.toLowerCase();var o=m[a];if(!o)throw new Error(a+" is not supported (we accept pull requests)");return new o};m.sha=s("./sha"),m.sha1=s("./sha1"),m.sha224=s("./sha224"),m.sha256=s("./sha256"),m.sha384=s("./sha384"),m.sha512=s("./sha512")},{"./sha":499,"./sha1":500,"./sha224":501,"./sha256":502,"./sha384":503,"./sha512":504}],499:[function(s,T,S){var m=s("inherits"),a=s("./hash"),o=s("safe-buffer").Buffer,r=[1518500249,1859775393,-1894007588,-899497514],t=new Array(80);function e(){this.init(),this._w=t,a.call(this,64,56)}function l(i){return i<<30|i>>>2}function n(i,f,c,u){return i===0?f&c|~f&u:i===2?f&c|f&u|c&u:f^c^u}m(e,a),e.prototype.init=function(){return this._a=1732584193,this._b=4023233417,this._c=2562383102,this._d=271733878,this._e=3285377520,this},e.prototype._update=function(i){for(var f,c=this._w,u=0|this._a,d=0|this._b,h=0|this._c,w=0|this._d,_=0|this._e,A=0;A<16;++A)c[A]=i.readInt32BE(4*A);for(;A<80;++A)c[A]=c[A-3]^c[A-8]^c[A-14]^c[A-16];for(var N=0;N<80;++N){var L=~~(N/20),I=0|((f=u)<<5|f>>>27)+n(L,d,h,w)+_+c[N]+r[L];_=w,w=h,h=l(d),d=u,u=I}this._a=u+this._a|0,this._b=d+this._b|0,this._c=h+this._c|0,this._d=w+this._d|0,this._e=_+this._e|0},e.prototype._hash=function(){var i=o.allocUnsafe(20);return i.writeInt32BE(0|this._a,0),i.writeInt32BE(0|this._b,4),i.writeInt32BE(0|this._c,8),i.writeInt32BE(0|this._d,12),i.writeInt32BE(0|this._e,16),i},T.exports=e},{"./hash":497,inherits:440,"safe-buffer":494}],500:[function(s,T,S){var m=s("inherits"),a=s("./hash"),o=s("safe-buffer").Buffer,r=[1518500249,1859775393,-1894007588,-899497514],t=new Array(80);function e(){this.init(),this._w=t,a.call(this,64,56)}function l(f){return f<<5|f>>>27}function n(f){return f<<30|f>>>2}function i(f,c,u,d){return f===0?c&u|~c&d:f===2?c&u|c&d|u&d:c^u^d}m(e,a),e.prototype.init=function(){return this._a=1732584193,this._b=4023233417,this._c=2562383102,this._d=271733878,this._e=3285377520,this},e.prototype._update=function(f){for(var c,u=this._w,d=0|this._a,h=0|this._b,w=0|this._c,_=0|this._d,A=0|this._e,N=0;N<16;++N)u[N]=f.readInt32BE(4*N);for(;N<80;++N)u[N]=(c=u[N-3]^u[N-8]^u[N-14]^u[N-16])<<1|c>>>31;for(var L=0;L<80;++L){var I=~~(L/20),P=l(d)+i(I,h,w,_)+A+u[L]+r[I]|0;A=_,_=w,w=n(h),h=d,d=P}this._a=d+this._a|0,this._b=h+this._b|0,this._c=w+this._c|0,this._d=_+this._d|0,this._e=A+this._e|0},e.prototype._hash=function(){var f=o.allocUnsafe(20);return f.writeInt32BE(0|this._a,0),f.writeInt32BE(0|this._b,4),f.writeInt32BE(0|this._c,8),f.writeInt32BE(0|this._d,12),f.writeInt32BE(0|this._e,16),f},T.exports=e},{"./hash":497,inherits:440,"safe-buffer":494}],501:[function(s,T,S){var m=s("inherits"),a=s("./sha256"),o=s("./hash"),r=s("safe-buffer").Buffer,t=new Array(64);function e(){this.init(),this._w=t,o.call(this,64,56)}m(e,a),e.prototype.init=function(){return this._a=3238371032,this._b=914150663,this._c=812702999,this._d=4144912697,this._e=4290775857,this._f=1750603025,this._g=1694076839,this._h=3204075428,this},e.prototype._hash=function(){var l=r.allocUnsafe(28);return l.writeInt32BE(this._a,0),l.writeInt32BE(this._b,4),l.writeInt32BE(this._c,8),l.writeInt32BE(this._d,12),l.writeInt32BE(this._e,16),l.writeInt32BE(this._f,20),l.writeInt32BE(this._g,24),l},T.exports=e},{"./hash":497,"./sha256":502,inherits:440,"safe-buffer":494}],502:[function(s,T,S){var m=s("inherits"),a=s("./hash"),o=s("safe-buffer").Buffer,r=[1116352408,1899447441,3049323471,3921009573,961987163,1508970993,2453635748,2870763221,3624381080,310598401,607225278,1426881987,1925078388,2162078206,2614888103,3248222580,3835390401,4022224774,264347078,604807628,770255983,1249150122,1555081692,1996064986,2554220882,2821834349,2952996808,3210313671,3336571891,3584528711,113926993,338241895,666307205,773529912,1294757372,1396182291,1695183700,1986661051,2177026350,2456956037,2730485921,2820302411,3259730800,3345764771,3516065817,3600352804,4094571909,275423344,430227734,506948616,659060556,883997877,958139571,1322822218,1537002063,1747873779,1955562222,2024104815,2227730452,2361852424,2428436474,2756734187,3204031479,3329325298],t=new Array(64);function e(){this.init(),this._w=t,a.call(this,64,56)}function l(u,d,h){return h^u&(d^h)}function n(u,d,h){return u&d|h&(u|d)}function i(u){return(u>>>2|u<<30)^(u>>>13|u<<19)^(u>>>22|u<<10)}function f(u){return(u>>>6|u<<26)^(u>>>11|u<<21)^(u>>>25|u<<7)}function c(u){return(u>>>7|u<<25)^(u>>>18|u<<14)^u>>>3}m(e,a),e.prototype.init=function(){return this._a=1779033703,this._b=3144134277,this._c=1013904242,this._d=2773480762,this._e=1359893119,this._f=2600822924,this._g=528734635,this._h=1541459225,this},e.prototype._update=function(u){for(var d,h=this._w,w=0|this._a,_=0|this._b,A=0|this._c,N=0|this._d,L=0|this._e,I=0|this._f,P=0|this._g,B=0|this._h,U=0;U<16;++U)h[U]=u.readInt32BE(4*U);for(;U<64;++U)h[U]=0|(((d=h[U-2])>>>17|d<<15)^(d>>>19|d<<13)^d>>>10)+h[U-7]+c(h[U-15])+h[U-16];for(var D=0;D<64;++D){var x=B+f(L)+l(L,I,P)+r[D]+h[D]|0,M=i(w)+n(w,_,A)|0;B=P,P=I,I=L,L=N+x|0,N=A,A=_,_=w,w=x+M|0}this._a=w+this._a|0,this._b=_+this._b|0,this._c=A+this._c|0,this._d=N+this._d|0,this._e=L+this._e|0,this._f=I+this._f|0,this._g=P+this._g|0,this._h=B+this._h|0},e.prototype._hash=function(){var u=o.allocUnsafe(32);return u.writeInt32BE(this._a,0),u.writeInt32BE(this._b,4),u.writeInt32BE(this._c,8),u.writeInt32BE(this._d,12),u.writeInt32BE(this._e,16),u.writeInt32BE(this._f,20),u.writeInt32BE(this._g,24),u.writeInt32BE(this._h,28),u},T.exports=e},{"./hash":497,inherits:440,"safe-buffer":494}],503:[function(s,T,S){var m=s("inherits"),a=s("./sha512"),o=s("./hash"),r=s("safe-buffer").Buffer,t=new Array(160);function e(){this.init(),this._w=t,o.call(this,128,112)}m(e,a),e.prototype.init=function(){return this._ah=3418070365,this._bh=1654270250,this._ch=2438529370,this._dh=355462360,this._eh=1731405415,this._fh=2394180231,this._gh=3675008525,this._hh=1203062813,this._al=3238371032,this._bl=914150663,this._cl=812702999,this._dl=4144912697,this._el=4290775857,this._fl=1750603025,this._gl=1694076839,this._hl=3204075428,this},e.prototype._hash=function(){var l=r.allocUnsafe(48);function n(i,f,c){l.writeInt32BE(i,c),l.writeInt32BE(f,c+4)}return n(this._ah,this._al,0),n(this._bh,this._bl,8),n(this._ch,this._cl,16),n(this._dh,this._dl,24),n(this._eh,this._el,32),n(this._fh,this._fl,40),l},T.exports=e},{"./hash":497,"./sha512":504,inherits:440,"safe-buffer":494}],504:[function(s,T,S){var m=s("inherits"),a=s("./hash"),o=s("safe-buffer").Buffer,r=[1116352408,3609767458,1899447441,602891725,3049323471,3964484399,3921009573,2173295548,961987163,4081628472,1508970993,3053834265,2453635748,2937671579,2870763221,3664609560,3624381080,2734883394,310598401,1164996542,607225278,1323610764,1426881987,3590304994,1925078388,4068182383,2162078206,991336113,2614888103,633803317,3248222580,3479774868,3835390401,2666613458,4022224774,944711139,264347078,2341262773,604807628,2007800933,770255983,1495990901,1249150122,1856431235,1555081692,3175218132,1996064986,2198950837,2554220882,3999719339,2821834349,766784016,2952996808,2566594879,3210313671,3203337956,3336571891,1034457026,3584528711,2466948901,113926993,3758326383,338241895,168717936,666307205,1188179964,773529912,1546045734,1294757372,1522805485,1396182291,2643833823,1695183700,2343527390,1986661051,1014477480,2177026350,1206759142,2456956037,344077627,2730485921,1290863460,2820302411,3158454273,3259730800,3505952657,3345764771,106217008,3516065817,3606008344,3600352804,1432725776,4094571909,1467031594,275423344,851169720,430227734,3100823752,506948616,1363258195,659060556,3750685593,883997877,3785050280,958139571,3318307427,1322822218,3812723403,1537002063,2003034995,1747873779,3602036899,1955562222,1575990012,2024104815,1125592928,2227730452,2716904306,2361852424,442776044,2428436474,593698344,2756734187,3733110249,3204031479,2999351573,3329325298,3815920427,3391569614,3928383900,3515267271,566280711,3940187606,3454069534,4118630271,4000239992,116418474,1914138554,174292421,2731055270,289380356,3203993006,460393269,320620315,685471733,587496836,852142971,1086792851,1017036298,365543100,1126000580,2618297676,1288033470,3409855158,1501505948,4234509866,1607167915,987167468,1816402316,1246189591],t=new Array(160);function e(){this.init(),this._w=t,a.call(this,128,112)}function l(_,A,N){return N^_&(A^N)}function n(_,A,N){return _&A|N&(_|A)}function i(_,A){return(_>>>28|A<<4)^(A>>>2|_<<30)^(A>>>7|_<<25)}function f(_,A){return(_>>>14|A<<18)^(_>>>18|A<<14)^(A>>>9|_<<23)}function c(_,A){return(_>>>1|A<<31)^(_>>>8|A<<24)^_>>>7}function u(_,A){return(_>>>1|A<<31)^(_>>>8|A<<24)^(_>>>7|A<<25)}function d(_,A){return(_>>>19|A<<13)^(A>>>29|_<<3)^_>>>6}function h(_,A){return(_>>>19|A<<13)^(A>>>29|_<<3)^(_>>>6|A<<26)}function w(_,A){return _>>>0<A>>>0?1:0}m(e,a),e.prototype.init=function(){return this._ah=1779033703,this._bh=3144134277,this._ch=1013904242,this._dh=2773480762,this._eh=1359893119,this._fh=2600822924,this._gh=528734635,this._hh=1541459225,this._al=4089235720,this._bl=2227873595,this._cl=4271175723,this._dl=1595750129,this._el=2917565137,this._fl=725511199,this._gl=4215389547,this._hl=327033209,this},e.prototype._update=function(_){for(var A=this._w,N=0|this._ah,L=0|this._bh,I=0|this._ch,P=0|this._dh,B=0|this._eh,U=0|this._fh,D=0|this._gh,x=0|this._hh,M=0|this._al,v=0|this._bl,p=0|this._cl,b=0|this._dl,g=0|this._el,y=0|this._fl,k=0|this._gl,R=0|this._hl,O=0;O<32;O+=2)A[O]=_.readInt32BE(4*O),A[O+1]=_.readInt32BE(4*O+4);for(;O<160;O+=2){var z=A[O-30],$=A[O-30+1],W=c(z,$),j=u($,z),H=d(z=A[O-4],$=A[O-4+1]),E=h($,z),C=A[O-14],F=A[O-14+1],V=A[O-32],Z=A[O-32+1],q=j+F|0,K=W+C+w(q,j)|0;K=(K=K+H+w(q=q+E|0,E)|0)+V+w(q=q+Z|0,Z)|0,A[O]=K,A[O+1]=q}for(var et=0;et<160;et+=2){K=A[et],q=A[et+1];var tt=n(N,L,I),X=n(M,v,p),J=i(N,M),G=i(M,N),nt=f(B,g),rt=f(g,B),st=r[et],ot=r[et+1],lt=l(B,U,D),ct=l(g,y,k),wt=R+rt|0,vt=x+nt+w(wt,R)|0;vt=(vt=(vt=vt+lt+w(wt=wt+ct|0,ct)|0)+st+w(wt=wt+ot|0,ot)|0)+K+w(wt=wt+q|0,q)|0;var mt=G+X|0,Rt=J+tt+w(mt,G)|0;x=D,R=k,D=U,k=y,U=B,y=g,B=P+vt+w(g=b+wt|0,b)|0,P=I,b=p,I=L,p=v,L=N,v=M,N=vt+Rt+w(M=wt+mt|0,wt)|0}this._al=this._al+M|0,this._bl=this._bl+v|0,this._cl=this._cl+p|0,this._dl=this._dl+b|0,this._el=this._el+g|0,this._fl=this._fl+y|0,this._gl=this._gl+k|0,this._hl=this._hl+R|0,this._ah=this._ah+N+w(this._al,M)|0,this._bh=this._bh+L+w(this._bl,v)|0,this._ch=this._ch+I+w(this._cl,p)|0,this._dh=this._dh+P+w(this._dl,b)|0,this._eh=this._eh+B+w(this._el,g)|0,this._fh=this._fh+U+w(this._fl,y)|0,this._gh=this._gh+D+w(this._gl,k)|0,this._hh=this._hh+x+w(this._hl,R)|0},e.prototype._hash=function(){var _=o.allocUnsafe(64);function A(N,L,I){_.writeInt32BE(N,I),_.writeInt32BE(L,I+4)}return A(this._ah,this._al,0),A(this._bh,this._bl,8),A(this._ch,this._cl,16),A(this._dh,this._dl,24),A(this._eh,this._el,32),A(this._fh,this._fl,40),A(this._gh,this._gl,48),A(this._hh,this._hl,56),_},T.exports=e},{"./hash":497,inherits:440,"safe-buffer":494}],505:[function(s,T,S){T.exports=a;var m=s("events").EventEmitter;function a(){m.call(this)}s("inherits")(a,m),a.Readable=s("readable-stream/readable.js"),a.Writable=s("readable-stream/writable.js"),a.Duplex=s("readable-stream/duplex.js"),a.Transform=s("readable-stream/transform.js"),a.PassThrough=s("readable-stream/passthrough.js"),a.Stream=a,a.prototype.pipe=function(o,r){var t=this;function e(d){o.writable&&o.write(d)===!1&&t.pause&&t.pause()}function l(){t.readable&&t.resume&&t.resume()}t.on("data",e),o.on("drain",l),o._isStdio||r&&r.end===!1||(t.on("end",i),t.on("close",f));var n=!1;function i(){n||(n=!0,o.end())}function f(){n||(n=!0,typeof o.destroy=="function"&&o.destroy())}function c(d){if(u(),m.listenerCount(this,"error")===0)throw d}function u(){t.removeListener("data",e),o.removeListener("drain",l),t.removeListener("end",i),t.removeListener("close",f),t.removeListener("error",c),o.removeListener("error",c),t.removeListener("end",u),t.removeListener("close",u),o.removeListener("close",u)}return t.on("error",c),o.on("error",c),t.on("end",u),t.on("close",u),o.on("close",u),o.emit("pipe",t),o}},{events:422,inherits:440,"readable-stream/duplex.js":507,"readable-stream/passthrough.js":516,"readable-stream/readable.js":517,"readable-stream/transform.js":518,"readable-stream/writable.js":519}],506:[function(s,T,S){var m={}.toString;T.exports=Array.isArray||function(a){return m.call(a)=="[object Array]"}},{}],507:[function(s,T,S){T.exports=s("./lib/_stream_duplex.js")},{"./lib/_stream_duplex.js":508}],508:[function(s,T,S){var m=s("process-nextick-args"),a=Object.keys||function(u){var d=[];for(var h in u)d.push(h);return d};T.exports=i;var o=Object.create(s("core-util-is"));o.inherits=s("inherits");var r=s("./_stream_readable"),t=s("./_stream_writable");o.inherits(i,r);for(var e=a(t.prototype),l=0;l<e.length;l++){var n=e[l];i.prototype[n]||(i.prototype[n]=t.prototype[n])}function i(u){if(!(this instanceof i))return new i(u);r.call(this,u),t.call(this,u),u&&u.readable===!1&&(this.readable=!1),u&&u.writable===!1&&(this.writable=!1),this.allowHalfOpen=!0,u&&u.allowHalfOpen===!1&&(this.allowHalfOpen=!1),this.once("end",f)}function f(){this.allowHalfOpen||this._writableState.ended||m.nextTick(c,this)}function c(u){u.end()}Object.defineProperty(i.prototype,"writableHighWaterMark",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),Object.defineProperty(i.prototype,"destroyed",{get:function(){return this._readableState!==void 0&&this._writableState!==void 0&&this._readableState.destroyed&&this._writableState.destroyed},set:function(u){this._readableState!==void 0&&this._writableState!==void 0&&(this._readableState.destroyed=u,this._writableState.destroyed=u)}}),i.prototype._destroy=function(u,d){this.push(null),this.end(),m.nextTick(d,u)}},{"./_stream_readable":510,"./_stream_writable":512,"core-util-is":383,inherits:440,"process-nextick-args":466}],509:[function(s,T,S){T.exports=o;var m=s("./_stream_transform"),a=Object.create(s("core-util-is"));function o(r){if(!(this instanceof o))return new o(r);m.call(this,r)}a.inherits=s("inherits"),a.inherits(o,m),o.prototype._transform=function(r,t,e){e(null,r)}},{"./_stream_transform":511,"core-util-is":383,inherits:440}],510:[function(s,T,S){(function(m,a){(function(){var o=s("process-nextick-args");T.exports=N;var r,t=s("isarray");N.ReadableState=A,s("events").EventEmitter;var e=function(R,O){return R.listeners(O).length},l=s("./internal/streams/stream"),n=s("safe-buffer").Buffer,i=(a!==void 0?a:typeof window<"u"?window:typeof self<"u"?self:{}).Uint8Array||function(){},f=Object.create(s("core-util-is"));f.inherits=s("inherits");var c=s("util"),u=void 0;u=c&&c.debuglog?c.debuglog("stream"):function(){};var d,h=s("./internal/streams/BufferList"),w=s("./internal/streams/destroy");f.inherits(N,l);var _=["error","close","destroy","pause","resume"];function A(R,O){R=R||{};var z=O instanceof(r=r||s("./_stream_duplex"));this.objectMode=!!R.objectMode,z&&(this.objectMode=this.objectMode||!!R.readableObjectMode);var $=R.highWaterMark,W=R.readableHighWaterMark,j=this.objectMode?16:16384;this.highWaterMark=$||$===0?$:z&&(W||W===0)?W:j,this.highWaterMark=Math.floor(this.highWaterMark),this.buffer=new h,this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.resumeScheduled=!1,this.destroyed=!1,this.defaultEncoding=R.defaultEncoding||"utf8",this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,R.encoding&&(d||(d=s("string_decoder/").StringDecoder),this.decoder=new d(R.encoding),this.encoding=R.encoding)}function N(R){if(r=r||s("./_stream_duplex"),!(this instanceof N))return new N(R);this._readableState=new A(R,this),this.readable=!0,R&&(typeof R.read=="function"&&(this._read=R.read),typeof R.destroy=="function"&&(this._destroy=R.destroy)),l.call(this)}function L(R,O,z,$,W){var j,H=R._readableState;return O===null?(H.reading=!1,function(E,C){if(!C.ended){if(C.decoder){var F=C.decoder.end();F&&F.length&&(C.buffer.push(F),C.length+=C.objectMode?1:F.length)}C.ended=!0,B(E)}}(R,H)):(W||(j=function(E,C){var F;V=C,n.isBuffer(V)||V instanceof i||typeof C=="string"||C===void 0||E.objectMode||(F=new TypeError("Invalid non-string/buffer chunk"));var V;return F}(H,O)),j?R.emit("error",j):H.objectMode||O&&O.length>0?(typeof O=="string"||H.objectMode||Object.getPrototypeOf(O)===n.prototype||(O=function(E){return n.from(E)}(O)),$?H.endEmitted?R.emit("error",new Error("stream.unshift() after end event")):I(R,H,O,!0):H.ended?R.emit("error",new Error("stream.push() after EOF")):(H.reading=!1,H.decoder&&!z?(O=H.decoder.write(O),H.objectMode||O.length!==0?I(R,H,O,!1):D(R,H)):I(R,H,O,!1))):$||(H.reading=!1)),function(E){return!E.ended&&(E.needReadable||E.length<E.highWaterMark||E.length===0)}(H)}function I(R,O,z,$){O.flowing&&O.length===0&&!O.sync?(R.emit("data",z),R.read(0)):(O.length+=O.objectMode?1:z.length,$?O.buffer.unshift(z):O.buffer.push(z),O.needReadable&&B(R)),D(R,O)}Object.defineProperty(N.prototype,"destroyed",{get:function(){return this._readableState!==void 0&&this._readableState.destroyed},set:function(R){this._readableState&&(this._readableState.destroyed=R)}}),N.prototype.destroy=w.destroy,N.prototype._undestroy=w.undestroy,N.prototype._destroy=function(R,O){this.push(null),O(R)},N.prototype.push=function(R,O){var z,$=this._readableState;return $.objectMode?z=!0:typeof R=="string"&&((O=O||$.defaultEncoding)!==$.encoding&&(R=n.from(R,O),O=""),z=!0),L(this,R,O,!1,z)},N.prototype.unshift=function(R){return L(this,R,null,!0,!1)},N.prototype.isPaused=function(){return this._readableState.flowing===!1},N.prototype.setEncoding=function(R){return d||(d=s("string_decoder/").StringDecoder),this._readableState.decoder=new d(R),this._readableState.encoding=R,this};function P(R,O){return R<=0||O.length===0&&O.ended?0:O.objectMode?1:R!=R?O.flowing&&O.length?O.buffer.head.data.length:O.length:(R>O.highWaterMark&&(O.highWaterMark=function(z){return z>=8388608?z=8388608:(z--,z|=z>>>1,z|=z>>>2,z|=z>>>4,z|=z>>>8,z|=z>>>16,z++),z}(R)),R<=O.length?R:O.ended?O.length:(O.needReadable=!0,0))}function B(R){var O=R._readableState;O.needReadable=!1,O.emittedReadable||(u("emitReadable",O.flowing),O.emittedReadable=!0,O.sync?o.nextTick(U,R):U(R))}function U(R){u("emit readable"),R.emit("readable"),p(R)}function D(R,O){O.readingMore||(O.readingMore=!0,o.nextTick(x,R,O))}function x(R,O){for(var z=O.length;!O.reading&&!O.flowing&&!O.ended&&O.length<O.highWaterMark&&(u("maybeReadMore read 0"),R.read(0),z!==O.length);)z=O.length;O.readingMore=!1}function M(R){u("readable nexttick read 0"),R.read(0)}function v(R,O){O.reading||(u("resume read 0"),R.read(0)),O.resumeScheduled=!1,O.awaitDrain=0,R.emit("resume"),p(R),O.flowing&&!O.reading&&R.read(0)}function p(R){var O=R._readableState;for(u("flow",O.flowing);O.flowing&&R.read()!==null;);}function b(R,O){return O.length===0?null:(O.objectMode?z=O.buffer.shift():!R||R>=O.length?(z=O.decoder?O.buffer.join(""):O.buffer.length===1?O.buffer.head.data:O.buffer.concat(O.length),O.buffer.clear()):z=function($,W,j){var H;return $<W.head.data.length?(H=W.head.data.slice(0,$),W.head.data=W.head.data.slice($)):H=$===W.head.data.length?W.shift():j?function(E,C){var F=C.head,V=1,Z=F.data;for(E-=Z.length;F=F.next;){var q=F.data,K=E>q.length?q.length:E;if(K===q.length?Z+=q:Z+=q.slice(0,E),(E-=K)===0){K===q.length?(++V,F.next?C.head=F.next:C.head=C.tail=null):(C.head=F,F.data=q.slice(K));break}++V}return C.length-=V,Z}($,W):function(E,C){var F=n.allocUnsafe(E),V=C.head,Z=1;for(V.data.copy(F),E-=V.data.length;V=V.next;){var q=V.data,K=E>q.length?q.length:E;if(q.copy(F,F.length-E,0,K),(E-=K)===0){K===q.length?(++Z,V.next?C.head=V.next:C.head=C.tail=null):(C.head=V,V.data=q.slice(K));break}++Z}return C.length-=Z,F}($,W),H}(R,O.buffer,O.decoder),z);var z}function g(R){var O=R._readableState;if(O.length>0)throw new Error('"endReadable()" called on non-empty stream');O.endEmitted||(O.ended=!0,o.nextTick(y,O,R))}function y(R,O){R.endEmitted||R.length!==0||(R.endEmitted=!0,O.readable=!1,O.emit("end"))}function k(R,O){for(var z=0,$=R.length;z<$;z++)if(R[z]===O)return z;return-1}N.prototype.read=function(R){u("read",R),R=parseInt(R,10);var O=this._readableState,z=R;if(R!==0&&(O.emittedReadable=!1),R===0&&O.needReadable&&(O.length>=O.highWaterMark||O.ended))return u("read: emitReadable",O.length,O.ended),O.length===0&&O.ended?g(this):B(this),null;if((R=P(R,O))===0&&O.ended)return O.length===0&&g(this),null;var $,W=O.needReadable;return u("need readable",W),(O.length===0||O.length-R<O.highWaterMark)&&u("length less than watermark",W=!0),O.ended||O.reading?u("reading or ended",W=!1):W&&(u("do read"),O.reading=!0,O.sync=!0,O.length===0&&(O.needReadable=!0),this._read(O.highWaterMark),O.sync=!1,O.reading||(R=P(z,O))),($=R>0?b(R,O):null)===null?(O.needReadable=!0,R=0):O.length-=R,O.length===0&&(O.ended||(O.needReadable=!0),z!==R&&O.ended&&g(this)),$!==null&&this.emit("data",$),$},N.prototype._read=function(R){this.emit("error",new Error("_read() is not implemented"))},N.prototype.pipe=function(R,O){var z=this,$=this._readableState;switch($.pipesCount){case 0:$.pipes=R;break;case 1:$.pipes=[$.pipes,R];break;default:$.pipes.push(R)}$.pipesCount+=1,u("pipe count=%d opts=%j",$.pipesCount,O);var W=(!O||O.end!==!1)&&R!==m.stdout&&R!==m.stderr?H:et;function j(tt,X){u("onunpipe"),tt===z&&X&&X.hasUnpiped===!1&&(X.hasUnpiped=!0,u("cleanup"),R.removeListener("close",q),R.removeListener("finish",K),R.removeListener("drain",E),R.removeListener("error",Z),R.removeListener("unpipe",j),z.removeListener("end",H),z.removeListener("end",et),z.removeListener("data",V),C=!0,!$.awaitDrain||R._writableState&&!R._writableState.needDrain||E())}function H(){u("onend"),R.end()}$.endEmitted?o.nextTick(W):z.once("end",W),R.on("unpipe",j);var E=function(tt){return function(){var X=tt._readableState;u("pipeOnDrain",X.awaitDrain),X.awaitDrain&&X.awaitDrain--,X.awaitDrain===0&&e(tt,"data")&&(X.flowing=!0,p(tt))}}(z);R.on("drain",E);var C=!1,F=!1;function V(tt){u("ondata"),F=!1,R.write(tt)!==!1||F||(($.pipesCount===1&&$.pipes===R||$.pipesCount>1&&k($.pipes,R)!==-1)&&!C&&(u("false write response, pause",$.awaitDrain),$.awaitDrain++,F=!0),z.pause())}function Z(tt){u("onerror",tt),et(),R.removeListener("error",Z),e(R,"error")===0&&R.emit("error",tt)}function q(){R.removeListener("finish",K),et()}function K(){u("onfinish"),R.removeListener("close",q),et()}function et(){u("unpipe"),z.unpipe(R)}return z.on("data",V),function(tt,X,J){if(typeof tt.prependListener=="function")return tt.prependListener(X,J);tt._events&&tt._events[X]?t(tt._events[X])?tt._events[X].unshift(J):tt._events[X]=[J,tt._events[X]]:tt.on(X,J)}(R,"error",Z),R.once("close",q),R.once("finish",K),R.emit("pipe",z),$.flowing||(u("pipe resume"),z.resume()),R},N.prototype.unpipe=function(R){var O=this._readableState,z={hasUnpiped:!1};if(O.pipesCount===0)return this;if(O.pipesCount===1)return R&&R!==O.pipes||(R||(R=O.pipes),O.pipes=null,O.pipesCount=0,O.flowing=!1,R&&R.emit("unpipe",this,z)),this;if(!R){var $=O.pipes,W=O.pipesCount;O.pipes=null,O.pipesCount=0,O.flowing=!1;for(var j=0;j<W;j++)$[j].emit("unpipe",this,{hasUnpiped:!1});return this}var H=k(O.pipes,R);return H===-1||(O.pipes.splice(H,1),O.pipesCount-=1,O.pipesCount===1&&(O.pipes=O.pipes[0]),R.emit("unpipe",this,z)),this},N.prototype.on=function(R,O){var z=l.prototype.on.call(this,R,O);if(R==="data")this._readableState.flowing!==!1&&this.resume();else if(R==="readable"){var $=this._readableState;$.endEmitted||$.readableListening||($.readableListening=$.needReadable=!0,$.emittedReadable=!1,$.reading?$.length&&B(this):o.nextTick(M,this))}return z},N.prototype.addListener=N.prototype.on,N.prototype.resume=function(){var R=this._readableState;return R.flowing||(u("resume"),R.flowing=!0,function(O,z){z.resumeScheduled||(z.resumeScheduled=!0,o.nextTick(v,O,z))}(this,R)),this},N.prototype.pause=function(){return u("call pause flowing=%j",this._readableState.flowing),this._readableState.flowing!==!1&&(u("pause"),this._readableState.flowing=!1,this.emit("pause")),this},N.prototype.wrap=function(R){var O=this,z=this._readableState,$=!1;for(var W in R.on("end",function(){if(u("wrapped end"),z.decoder&&!z.ended){var H=z.decoder.end();H&&H.length&&O.push(H)}O.push(null)}),R.on("data",function(H){u("wrapped data"),z.decoder&&(H=z.decoder.write(H)),z.objectMode&&H==null||(z.objectMode||H&&H.length)&&(O.push(H)||($=!0,R.pause()))}),R)this[W]===void 0&&typeof R[W]=="function"&&(this[W]=function(H){return function(){return R[H].apply(R,arguments)}}(W));for(var j=0;j<_.length;j++)R.on(_[j],this.emit.bind(this,_[j]));return this._read=function(H){u("wrapped _read",H),$&&($=!1,R.resume())},this},Object.defineProperty(N.prototype,"readableHighWaterMark",{enumerable:!1,get:function(){return this._readableState.highWaterMark}}),N._fromList=b}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{"./_stream_duplex":508,"./internal/streams/BufferList":513,"./internal/streams/destroy":514,"./internal/streams/stream":515,_process:467,"core-util-is":383,events:422,inherits:440,isarray:506,"process-nextick-args":466,"safe-buffer":520,"string_decoder/":521,util:188}],511:[function(s,T,S){T.exports=r;var m=s("./_stream_duplex"),a=Object.create(s("core-util-is"));function o(l,n){var i=this._transformState;i.transforming=!1;var f=i.writecb;if(!f)return this.emit("error",new Error("write callback called multiple times"));i.writechunk=null,i.writecb=null,n!=null&&this.push(n),f(l);var c=this._readableState;c.reading=!1,(c.needReadable||c.length<c.highWaterMark)&&this._read(c.highWaterMark)}function r(l){if(!(this instanceof r))return new r(l);m.call(this,l),this._transformState={afterTransform:o.bind(this),needTransform:!1,transforming:!1,writecb:null,writechunk:null,writeencoding:null},this._readableState.needReadable=!0,this._readableState.sync=!1,l&&(typeof l.transform=="function"&&(this._transform=l.transform),typeof l.flush=="function"&&(this._flush=l.flush)),this.on("prefinish",t)}function t(){var l=this;typeof this._flush=="function"?this._flush(function(n,i){e(l,n,i)}):e(this,null,null)}function e(l,n,i){if(n)return l.emit("error",n);if(i!=null&&l.push(i),l._writableState.length)throw new Error("Calling transform done when ws.length != 0");if(l._transformState.transforming)throw new Error("Calling transform done when still transforming");return l.push(null)}a.inherits=s("inherits"),a.inherits(r,m),r.prototype.push=function(l,n){return this._transformState.needTransform=!1,m.prototype.push.call(this,l,n)},r.prototype._transform=function(l,n,i){throw new Error("_transform() is not implemented")},r.prototype._write=function(l,n,i){var f=this._transformState;if(f.writecb=i,f.writechunk=l,f.writeencoding=n,!f.transforming){var c=this._readableState;(f.needTransform||c.needReadable||c.length<c.highWaterMark)&&this._read(c.highWaterMark)}},r.prototype._read=function(l){var n=this._transformState;n.writechunk!==null&&n.writecb&&!n.transforming?(n.transforming=!0,this._transform(n.writechunk,n.writeencoding,n.afterTransform)):n.needTransform=!0},r.prototype._destroy=function(l,n){var i=this;m.prototype._destroy.call(this,l,function(f){n(f),i.emit("close")})}},{"./_stream_duplex":508,"core-util-is":383,inherits:440}],512:[function(s,T,S){(function(m,a,o){(function(){var r=s("process-nextick-args");function t(D){var x=this;this.next=null,this.entry=null,this.finish=function(){(function(M,v,p){var b=M.entry;for(M.entry=null;b;){var g=b.callback;v.pendingcb--,g(p),b=b.next}v.corkedRequestsFree.next=M})(x,D)}}T.exports=A;var e,l=!m.browser&&["v0.10","v0.9."].indexOf(m.version.slice(0,5))>-1?o:r.nextTick;A.WritableState=_;var n=Object.create(s("core-util-is"));n.inherits=s("inherits");var i={deprecate:s("util-deprecate")},f=s("./internal/streams/stream"),c=s("safe-buffer").Buffer,u=(a!==void 0?a:typeof window<"u"?window:typeof self<"u"?self:{}).Uint8Array||function(){},d,h=s("./internal/streams/destroy");function w(){}function _(D,x){e=e||s("./_stream_duplex"),D=D||{};var M=x instanceof e;this.objectMode=!!D.objectMode,M&&(this.objectMode=this.objectMode||!!D.writableObjectMode);var v=D.highWaterMark,p=D.writableHighWaterMark,b=this.objectMode?16:16384;this.highWaterMark=v||v===0?v:M&&(p||p===0)?p:b,this.highWaterMark=Math.floor(this.highWaterMark),this.finalCalled=!1,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1,this.destroyed=!1;var g=D.decodeStrings===!1;this.decodeStrings=!g,this.defaultEncoding=D.defaultEncoding||"utf8",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(y){(function(k,R){var O=k._writableState,z=O.sync,$=O.writecb;if(function(j){j.writing=!1,j.writecb=null,j.length-=j.writelen,j.writelen=0}(O),R)(function(j,H,E,C,F){--H.pendingcb,E?(r.nextTick(F,C),r.nextTick(U,j,H),j._writableState.errorEmitted=!0,j.emit("error",C)):(F(C),j._writableState.errorEmitted=!0,j.emit("error",C),U(j,H))})(k,O,z,R,$);else{var W=P(O);W||O.corked||O.bufferProcessing||!O.bufferedRequest||I(k,O),z?l(L,k,O,W,$):L(k,O,W,$)}})(x,y)},this.writecb=null,this.writelen=0,this.bufferedRequest=null,this.lastBufferedRequest=null,this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1,this.bufferedRequestCount=0,this.corkedRequestsFree=new t(this)}function A(D){if(e=e||s("./_stream_duplex"),!(d.call(A,this)||this instanceof e))return new A(D);this._writableState=new _(D,this),this.writable=!0,D&&(typeof D.write=="function"&&(this._write=D.write),typeof D.writev=="function"&&(this._writev=D.writev),typeof D.destroy=="function"&&(this._destroy=D.destroy),typeof D.final=="function"&&(this._final=D.final)),f.call(this)}function N(D,x,M,v,p,b,g){x.writelen=v,x.writecb=g,x.writing=!0,x.sync=!0,M?D._writev(p,x.onwrite):D._write(p,b,x.onwrite),x.sync=!1}function L(D,x,M,v){M||function(p,b){b.length===0&&b.needDrain&&(b.needDrain=!1,p.emit("drain"))}(D,x),x.pendingcb--,v(),U(D,x)}function I(D,x){x.bufferProcessing=!0;var M=x.bufferedRequest;if(D._writev&&M&&M.next){var v=x.bufferedRequestCount,p=new Array(v),b=x.corkedRequestsFree;b.entry=M;for(var g=0,y=!0;M;)p[g]=M,M.isBuf||(y=!1),M=M.next,g+=1;p.allBuffers=y,N(D,x,!0,x.length,p,"",b.finish),x.pendingcb++,x.lastBufferedRequest=null,b.next?(x.corkedRequestsFree=b.next,b.next=null):x.corkedRequestsFree=new t(x),x.bufferedRequestCount=0}else{for(;M;){var k=M.chunk,R=M.encoding,O=M.callback;if(N(D,x,!1,x.objectMode?1:k.length,k,R,O),M=M.next,x.bufferedRequestCount--,x.writing)break}M===null&&(x.lastBufferedRequest=null)}x.bufferedRequest=M,x.bufferProcessing=!1}function P(D){return D.ending&&D.length===0&&D.bufferedRequest===null&&!D.finished&&!D.writing}function B(D,x){D._final(function(M){x.pendingcb--,M&&D.emit("error",M),x.prefinished=!0,D.emit("prefinish"),U(D,x)})}function U(D,x){var M=P(x);return M&&(function(v,p){p.prefinished||p.finalCalled||(typeof v._final=="function"?(p.pendingcb++,p.finalCalled=!0,r.nextTick(B,v,p)):(p.prefinished=!0,v.emit("prefinish")))}(D,x),x.pendingcb===0&&(x.finished=!0,D.emit("finish"))),M}n.inherits(A,f),_.prototype.getBuffer=function(){for(var D=this.bufferedRequest,x=[];D;)x.push(D),D=D.next;return x},function(){try{Object.defineProperty(_.prototype,"buffer",{get:i.deprecate(function(){return this.getBuffer()},"_writableState.buffer is deprecated. Use _writableState.getBuffer instead.","DEP0003")})}catch{}}(),typeof Symbol=="function"&&Symbol.hasInstance&&typeof Function.prototype[Symbol.hasInstance]=="function"?(d=Function.prototype[Symbol.hasInstance],Object.defineProperty(A,Symbol.hasInstance,{value:function(D){return!!d.call(this,D)||this===A&&D&&D._writableState instanceof _}})):d=function(D){return D instanceof this},A.prototype.pipe=function(){this.emit("error",new Error("Cannot pipe, not readable"))},A.prototype.write=function(D,x,M){var v,p=this._writableState,b=!1,g=!p.objectMode&&(v=D,c.isBuffer(v)||v instanceof u);return g&&!c.isBuffer(D)&&(D=function(y){return c.from(y)}(D)),typeof x=="function"&&(M=x,x=null),g?x="buffer":x||(x=p.defaultEncoding),typeof M!="function"&&(M=w),p.ended?function(y,k){var R=new Error("write after end");y.emit("error",R),r.nextTick(k,R)}(this,M):(g||function(y,k,R,O){var z=!0,$=!1;return R===null?$=new TypeError("May not write null values to stream"):typeof R=="string"||R===void 0||k.objectMode||($=new TypeError("Invalid non-string/buffer chunk")),$&&(y.emit("error",$),r.nextTick(O,$),z=!1),z}(this,p,D,M))&&(p.pendingcb++,b=function(y,k,R,O,z,$){if(!R){var W=function(C,F,V){return C.objectMode||C.decodeStrings===!1||typeof F!="string"||(F=c.from(F,V)),F}(k,O,z);O!==W&&(R=!0,z="buffer",O=W)}var j=k.objectMode?1:O.length;k.length+=j;var H=k.length<k.highWaterMark;if(H||(k.needDrain=!0),k.writing||k.corked){var E=k.lastBufferedRequest;k.lastBufferedRequest={chunk:O,encoding:z,isBuf:R,callback:$,next:null},E?E.next=k.lastBufferedRequest:k.bufferedRequest=k.lastBufferedRequest,k.bufferedRequestCount+=1}else N(y,k,!1,j,O,z,$);return H}(this,p,g,D,x,M)),b},A.prototype.cork=function(){this._writableState.corked++},A.prototype.uncork=function(){var D=this._writableState;D.corked&&(D.corked--,D.writing||D.corked||D.bufferProcessing||!D.bufferedRequest||I(this,D))},A.prototype.setDefaultEncoding=function(D){if(typeof D=="string"&&(D=D.toLowerCase()),!(["hex","utf8","utf-8","ascii","binary","base64","ucs2","ucs-2","utf16le","utf-16le","raw"].indexOf((D+"").toLowerCase())>-1))throw new TypeError("Unknown encoding: "+D);return this._writableState.defaultEncoding=D,this},Object.defineProperty(A.prototype,"writableHighWaterMark",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),A.prototype._write=function(D,x,M){M(new Error("_write() is not implemented"))},A.prototype._writev=null,A.prototype.end=function(D,x,M){var v=this._writableState;typeof D=="function"?(M=D,D=null,x=null):typeof x=="function"&&(M=x,x=null),D!=null&&this.write(D,x),v.corked&&(v.corked=1,this.uncork()),v.ending||function(p,b,g){b.ending=!0,U(p,b),g&&(b.finished?r.nextTick(g):p.once("finish",g)),b.ended=!0,p.writable=!1}(this,v,M)},Object.defineProperty(A.prototype,"destroyed",{get:function(){return this._writableState!==void 0&&this._writableState.destroyed},set:function(D){this._writableState&&(this._writableState.destroyed=D)}}),A.prototype.destroy=h.destroy,A.prototype._undestroy=h.undestroy,A.prototype._destroy=function(D,x){this.end(),x(D)}}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{},s("timers").setImmediate)},{"./_stream_duplex":508,"./internal/streams/destroy":514,"./internal/streams/stream":515,_process:467,"core-util-is":383,inherits:440,"process-nextick-args":466,"safe-buffer":520,timers:523,"util-deprecate":524}],513:[function(s,T,S){var m=s("safe-buffer").Buffer,a=s("util");T.exports=function(){function o(){(function(r,t){if(!(r instanceof t))throw new TypeError("Cannot call a class as a function")})(this,o),this.head=null,this.tail=null,this.length=0}return o.prototype.push=function(r){var t={data:r,next:null};this.length>0?this.tail.next=t:this.head=t,this.tail=t,++this.length},o.prototype.unshift=function(r){var t={data:r,next:this.head};this.length===0&&(this.tail=t),this.head=t,++this.length},o.prototype.shift=function(){if(this.length!==0){var r=this.head.data;return this.length===1?this.head=this.tail=null:this.head=this.head.next,--this.length,r}},o.prototype.clear=function(){this.head=this.tail=null,this.length=0},o.prototype.join=function(r){if(this.length===0)return"";for(var t=this.head,e=""+t.data;t=t.next;)e+=r+t.data;return e},o.prototype.concat=function(r){if(this.length===0)return m.alloc(0);for(var t,e,l,n=m.allocUnsafe(r>>>0),i=this.head,f=0;i;)t=i.data,e=n,l=f,t.copy(e,l),f+=i.data.length,i=i.next;return n},o}(),a&&a.inspect&&a.inspect.custom&&(T.exports.prototype[a.inspect.custom]=function(){var o=a.inspect({length:this.length});return this.constructor.name+" "+o})},{"safe-buffer":520,util:188}],514:[function(s,T,S){var m=s("process-nextick-args");function a(o,r){o.emit("error",r)}T.exports={destroy:function(o,r){var t=this,e=this._readableState&&this._readableState.destroyed,l=this._writableState&&this._writableState.destroyed;return e||l?(r?r(o):o&&(this._writableState?this._writableState.errorEmitted||(this._writableState.errorEmitted=!0,m.nextTick(a,this,o)):m.nextTick(a,this,o)),this):(this._readableState&&(this._readableState.destroyed=!0),this._writableState&&(this._writableState.destroyed=!0),this._destroy(o||null,function(n){!r&&n?t._writableState?t._writableState.errorEmitted||(t._writableState.errorEmitted=!0,m.nextTick(a,t,n)):m.nextTick(a,t,n):r&&r(n)}),this)},undestroy:function(){this._readableState&&(this._readableState.destroyed=!1,this._readableState.reading=!1,this._readableState.ended=!1,this._readableState.endEmitted=!1),this._writableState&&(this._writableState.destroyed=!1,this._writableState.ended=!1,this._writableState.ending=!1,this._writableState.finalCalled=!1,this._writableState.prefinished=!1,this._writableState.finished=!1,this._writableState.errorEmitted=!1)}}},{"process-nextick-args":466}],515:[function(s,T,S){arguments[4][490][0].apply(S,arguments)},{dup:490,events:422}],516:[function(s,T,S){T.exports=s("./readable").PassThrough},{"./readable":517}],517:[function(s,T,S){(S=T.exports=s("./lib/_stream_readable.js")).Stream=S,S.Readable=S,S.Writable=s("./lib/_stream_writable.js"),S.Duplex=s("./lib/_stream_duplex.js"),S.Transform=s("./lib/_stream_transform.js"),S.PassThrough=s("./lib/_stream_passthrough.js")},{"./lib/_stream_duplex.js":508,"./lib/_stream_passthrough.js":509,"./lib/_stream_readable.js":510,"./lib/_stream_transform.js":511,"./lib/_stream_writable.js":512}],518:[function(s,T,S){T.exports=s("./readable").Transform},{"./readable":517}],519:[function(s,T,S){T.exports=s("./lib/_stream_writable.js")},{"./lib/_stream_writable.js":512}],520:[function(s,T,S){arguments[4][217][0].apply(S,arguments)},{buffer:220,dup:217}],521:[function(s,T,S){arguments[4][218][0].apply(S,arguments)},{dup:218,"safe-buffer":520}],522:[function(s,T,S){arguments[4][218][0].apply(S,arguments)},{dup:218,"safe-buffer":494}],523:[function(s,T,S){(function(m,a){(function(){var o=s("process/browser.js").nextTick,r=Function.prototype.apply,t=Array.prototype.slice,e={},l=0;function n(i,f){this._id=i,this._clearFn=f}S.setTimeout=function(){return new n(r.call(setTimeout,window,arguments),clearTimeout)},S.setInterval=function(){return new n(r.call(setInterval,window,arguments),clearInterval)},S.clearTimeout=S.clearInterval=function(i){i.close()},n.prototype.unref=n.prototype.ref=function(){},n.prototype.close=function(){this._clearFn.call(window,this._id)},S.enroll=function(i,f){clearTimeout(i._idleTimeoutId),i._idleTimeout=f},S.unenroll=function(i){clearTimeout(i._idleTimeoutId),i._idleTimeout=-1},S._unrefActive=S.active=function(i){clearTimeout(i._idleTimeoutId);var f=i._idleTimeout;f>=0&&(i._idleTimeoutId=setTimeout(function(){i._onTimeout&&i._onTimeout()},f))},S.setImmediate=typeof m=="function"?m:function(i){var f=l++,c=!(arguments.length<2)&&t.call(arguments,1);return e[f]=!0,o(function(){e[f]&&(c?i.apply(null,c):i.call(null),S.clearImmediate(f))}),f},S.clearImmediate=typeof a=="function"?a:function(i){delete e[i]}}).call(this)}).call(this,s("timers").setImmediate,s("timers").clearImmediate)},{"process/browser.js":467,timers:523}],524:[function(s,T,S){(function(m){(function(){function a(o){try{if(!m.localStorage)return!1}catch{return!1}var r=m.localStorage[o];return r!=null&&String(r).toLowerCase()==="true"}T.exports=function(o,r){if(a("noDeprecation"))return o;var t=!1;return function(){if(!t){if(a("throwDeprecation"))throw new Error(r);a("traceDeprecation")?console.trace(r):console.warn(r),t=!0}return o.apply(this,arguments)}}}).call(this)}).call(this,typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{}],525:[function(s,T,S){typeof Object.create=="function"?T.exports=function(m,a){m.super_=a,m.prototype=Object.create(a.prototype,{constructor:{value:m,enumerable:!1,writable:!0,configurable:!0}})}:T.exports=function(m,a){m.super_=a;var o=function(){};o.prototype=a.prototype,m.prototype=new o,m.prototype.constructor=m}},{}],526:[function(s,T,S){T.exports=function(m){return m&&typeof m=="object"&&typeof m.copy=="function"&&typeof m.fill=="function"&&typeof m.readUInt8=="function"}},{}],527:[function(s,T,S){(function(m,a){(function(){var o=/%[sdj%]/g;S.format=function(p){if(!_(p)){for(var b=[],g=0;g<arguments.length;g++)b.push(e(arguments[g]));return b.join(" ")}g=1;for(var y=arguments,k=y.length,R=String(p).replace(o,function(z){if(z==="%%")return"%";if(g>=k)return z;switch(z){case"%s":return String(y[g++]);case"%d":return Number(y[g++]);case"%j":try{return JSON.stringify(y[g++])}catch{return"[Circular]"}default:return z}}),O=y[g];g<k;O=y[++g])h(O)||!L(O)?R+=" "+O:R+=" "+e(O);return R},S.deprecate=function(p,b){if(A(a.process))return function(){return S.deprecate(p,b).apply(this,arguments)};if(m.noDeprecation===!0)return p;var g=!1;return function(){if(!g){if(m.throwDeprecation)throw new Error(b);m.traceDeprecation?console.trace(b):console.error(b),g=!0}return p.apply(this,arguments)}};var r,t={};function e(p,b){var g={seen:[],stylize:n};return arguments.length>=3&&(g.depth=arguments[2]),arguments.length>=4&&(g.colors=arguments[3]),d(b)?g.showHidden=b:b&&S._extend(g,b),A(g.showHidden)&&(g.showHidden=!1),A(g.depth)&&(g.depth=2),A(g.colors)&&(g.colors=!1),A(g.customInspect)&&(g.customInspect=!0),g.colors&&(g.stylize=l),i(g,p,g.depth)}function l(p,b){var g=e.styles[b];return g?"\x1B["+e.colors[g][0]+"m"+p+"\x1B["+e.colors[g][1]+"m":p}function n(p,b){return p}function i(p,b,g){if(p.customInspect&&b&&B(b.inspect)&&b.inspect!==S.inspect&&(!b.constructor||b.constructor.prototype!==b)){var y=b.inspect(g,p);return _(y)||(y=i(p,y,g)),y}var k=function(E,C){if(A(C))return E.stylize("undefined","undefined");if(_(C)){var F="'"+JSON.stringify(C).replace(/^"|"$/g,"").replace(/'/g,"\\'").replace(/\\"/g,'"')+"'";return E.stylize(F,"string")}if(w(C))return E.stylize(""+C,"number");if(d(C))return E.stylize(""+C,"boolean");if(h(C))return E.stylize("null","null")}(p,b);if(k)return k;var R=Object.keys(b),O=function(E){var C={};return E.forEach(function(F,V){C[F]=!0}),C}(R);if(p.showHidden&&(R=Object.getOwnPropertyNames(b)),P(b)&&(R.indexOf("message")>=0||R.indexOf("description")>=0))return f(b);if(R.length===0){if(B(b)){var z=b.name?": "+b.name:"";return p.stylize("[Function"+z+"]","special")}if(N(b))return p.stylize(RegExp.prototype.toString.call(b),"regexp");if(I(b))return p.stylize(Date.prototype.toString.call(b),"date");if(P(b))return f(b)}var $,W="",j=!1,H=["{","}"];return u(b)&&(j=!0,H=["[","]"]),B(b)&&(W=" [Function"+(b.name?": "+b.name:"")+"]"),N(b)&&(W=" "+RegExp.prototype.toString.call(b)),I(b)&&(W=" "+Date.prototype.toUTCString.call(b)),P(b)&&(W=" "+f(b)),R.length!==0||j&&b.length!=0?g<0?N(b)?p.stylize(RegExp.prototype.toString.call(b),"regexp"):p.stylize("[Object]","special"):(p.seen.push(b),$=j?function(E,C,F,V,Z){for(var q=[],K=0,et=C.length;K<et;++K)v(C,String(K))?q.push(c(E,C,F,V,String(K),!0)):q.push("");return Z.forEach(function(tt){tt.match(/^\d+$/)||q.push(c(E,C,F,V,tt,!0))}),q}(p,b,g,O,R):R.map(function(E){return c(p,b,g,O,E,j)}),p.seen.pop(),function(E,C,F){return E.reduce(function(V,Z){return Z.indexOf(`
`)>=0,V+Z.replace(/\u001b\[\d\d?m/g,"").length+1},0)>60?F[0]+(C===""?"":C+`
 `)+" "+E.join(`,
  `)+" "+F[1]:F[0]+C+" "+E.join(", ")+" "+F[1]}($,W,H)):H[0]+W+H[1]}function f(p){return"["+Error.prototype.toString.call(p)+"]"}function c(p,b,g,y,k,R){var O,z,$;if(($=Object.getOwnPropertyDescriptor(b,k)||{value:b[k]}).get?z=$.set?p.stylize("[Getter/Setter]","special"):p.stylize("[Getter]","special"):$.set&&(z=p.stylize("[Setter]","special")),v(y,k)||(O="["+k+"]"),z||(p.seen.indexOf($.value)<0?(z=h(g)?i(p,$.value,null):i(p,$.value,g-1)).indexOf(`
`)>-1&&(z=R?z.split(`
`).map(function(W){return"  "+W}).join(`
`).substr(2):`
`+z.split(`
`).map(function(W){return"   "+W}).join(`
`)):z=p.stylize("[Circular]","special")),A(O)){if(R&&k.match(/^\d+$/))return z;(O=JSON.stringify(""+k)).match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)?(O=O.substr(1,O.length-2),O=p.stylize(O,"name")):(O=O.replace(/'/g,"\\'").replace(/\\"/g,'"').replace(/(^"|"$)/g,"'"),O=p.stylize(O,"string"))}return O+": "+z}function u(p){return Array.isArray(p)}function d(p){return typeof p=="boolean"}function h(p){return p===null}function w(p){return typeof p=="number"}function _(p){return typeof p=="string"}function A(p){return p===void 0}function N(p){return L(p)&&U(p)==="[object RegExp]"}function L(p){return typeof p=="object"&&p!==null}function I(p){return L(p)&&U(p)==="[object Date]"}function P(p){return L(p)&&(U(p)==="[object Error]"||p instanceof Error)}function B(p){return typeof p=="function"}function U(p){return Object.prototype.toString.call(p)}function D(p){return p<10?"0"+p.toString(10):p.toString(10)}S.debuglog=function(p){if(A(r)&&(r=m.env.NODE_DEBUG||""),p=p.toUpperCase(),!t[p])if(new RegExp("\\b"+p+"\\b","i").test(r)){var b=m.pid;t[p]=function(){var g=S.format.apply(S,arguments);console.error("%s %d: %s",p,b,g)}}else t[p]=function(){};return t[p]},S.inspect=e,e.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},e.styles={special:"cyan",number:"yellow",boolean:"yellow",undefined:"grey",null:"bold",string:"green",date:"magenta",regexp:"red"},S.isArray=u,S.isBoolean=d,S.isNull=h,S.isNullOrUndefined=function(p){return p==null},S.isNumber=w,S.isString=_,S.isSymbol=function(p){return typeof p=="symbol"},S.isUndefined=A,S.isRegExp=N,S.isObject=L,S.isDate=I,S.isError=P,S.isFunction=B,S.isPrimitive=function(p){return p===null||typeof p=="boolean"||typeof p=="number"||typeof p=="string"||typeof p=="symbol"||p===void 0},S.isBuffer=s("./support/isBuffer");var x=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];function M(){var p=new Date,b=[D(p.getHours()),D(p.getMinutes()),D(p.getSeconds())].join(":");return[p.getDate(),x[p.getMonth()],b].join(" ")}function v(p,b){return Object.prototype.hasOwnProperty.call(p,b)}S.log=function(){console.log("%s - %s",M(),S.format.apply(S,arguments))},S.inherits=s("inherits"),S._extend=function(p,b){if(!b||!L(b))return p;for(var g=Object.keys(b),y=g.length;y--;)p[g[y]]=b[g[y]];return p}}).call(this)}).call(this,s("_process"),typeof Yt<"u"?Yt:typeof self<"u"?self:typeof window<"u"?window:{})},{"./support/isBuffer":526,_process:467,inherits:525}],528:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),Object.defineProperty(S,"v1",{enumerable:!0,get:function(){return m.default}}),Object.defineProperty(S,"v3",{enumerable:!0,get:function(){return a.default}}),Object.defineProperty(S,"v4",{enumerable:!0,get:function(){return o.default}}),Object.defineProperty(S,"v5",{enumerable:!0,get:function(){return r.default}}),Object.defineProperty(S,"NIL",{enumerable:!0,get:function(){return t.default}}),Object.defineProperty(S,"version",{enumerable:!0,get:function(){return e.default}}),Object.defineProperty(S,"validate",{enumerable:!0,get:function(){return l.default}}),Object.defineProperty(S,"stringify",{enumerable:!0,get:function(){return n.default}}),Object.defineProperty(S,"parse",{enumerable:!0,get:function(){return i.default}});var m=f(s("./v1.js")),a=f(s("./v3.js")),o=f(s("./v4.js")),r=f(s("./v5.js")),t=f(s("./nil.js")),e=f(s("./version.js")),l=f(s("./validate.js")),n=f(s("./stringify.js")),i=f(s("./parse.js"));function f(c){return c&&c.__esModule?c:{default:c}}},{"./nil.js":530,"./parse.js":531,"./stringify.js":535,"./v1.js":536,"./v3.js":537,"./v4.js":539,"./v5.js":540,"./validate.js":541,"./version.js":542}],529:[function(s,T,S){function m(i){return 14+(i+64>>>9<<4)+1}function a(i,f){const c=(65535&i)+(65535&f);return(i>>16)+(f>>16)+(c>>16)<<16|65535&c}function o(i,f,c,u,d,h){return a((w=a(a(f,i),a(u,h)))<<(_=d)|w>>>32-_,c);var w,_}function r(i,f,c,u,d,h,w){return o(f&c|~f&u,i,f,d,h,w)}function t(i,f,c,u,d,h,w){return o(f&u|c&~u,i,f,d,h,w)}function e(i,f,c,u,d,h,w){return o(f^c^u,i,f,d,h,w)}function l(i,f,c,u,d,h,w){return o(c^(f|~u),i,f,d,h,w)}Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var n=function(i){if(typeof i=="string"){const f=unescape(encodeURIComponent(i));i=new Uint8Array(f.length);for(let c=0;c<f.length;++c)i[c]=f.charCodeAt(c)}return function(f){const c=[],u=32*f.length;for(let d=0;d<u;d+=8){const h=f[d>>5]>>>d%32&255,w=parseInt("0123456789abcdef".charAt(h>>>4&15)+"0123456789abcdef".charAt(15&h),16);c.push(w)}return c}(function(f,c){f[c>>5]|=128<<c%32,f[m(c)-1]=c;let u=1732584193,d=-271733879,h=-1732584194,w=271733878;for(let _=0;_<f.length;_+=16){const A=u,N=d,L=h,I=w;u=r(u,d,h,w,f[_],7,-680876936),w=r(w,u,d,h,f[_+1],12,-389564586),h=r(h,w,u,d,f[_+2],17,606105819),d=r(d,h,w,u,f[_+3],22,-1044525330),u=r(u,d,h,w,f[_+4],7,-176418897),w=r(w,u,d,h,f[_+5],12,1200080426),h=r(h,w,u,d,f[_+6],17,-1473231341),d=r(d,h,w,u,f[_+7],22,-45705983),u=r(u,d,h,w,f[_+8],7,1770035416),w=r(w,u,d,h,f[_+9],12,-1958414417),h=r(h,w,u,d,f[_+10],17,-42063),d=r(d,h,w,u,f[_+11],22,-1990404162),u=r(u,d,h,w,f[_+12],7,1804603682),w=r(w,u,d,h,f[_+13],12,-40341101),h=r(h,w,u,d,f[_+14],17,-1502002290),d=r(d,h,w,u,f[_+15],22,1236535329),u=t(u,d,h,w,f[_+1],5,-165796510),w=t(w,u,d,h,f[_+6],9,-1069501632),h=t(h,w,u,d,f[_+11],14,643717713),d=t(d,h,w,u,f[_],20,-373897302),u=t(u,d,h,w,f[_+5],5,-701558691),w=t(w,u,d,h,f[_+10],9,38016083),h=t(h,w,u,d,f[_+15],14,-660478335),d=t(d,h,w,u,f[_+4],20,-405537848),u=t(u,d,h,w,f[_+9],5,568446438),w=t(w,u,d,h,f[_+14],9,-1019803690),h=t(h,w,u,d,f[_+3],14,-187363961),d=t(d,h,w,u,f[_+8],20,1163531501),u=t(u,d,h,w,f[_+13],5,-1444681467),w=t(w,u,d,h,f[_+2],9,-51403784),h=t(h,w,u,d,f[_+7],14,1735328473),d=t(d,h,w,u,f[_+12],20,-1926607734),u=e(u,d,h,w,f[_+5],4,-378558),w=e(w,u,d,h,f[_+8],11,-2022574463),h=e(h,w,u,d,f[_+11],16,1839030562),d=e(d,h,w,u,f[_+14],23,-35309556),u=e(u,d,h,w,f[_+1],4,-1530992060),w=e(w,u,d,h,f[_+4],11,1272893353),h=e(h,w,u,d,f[_+7],16,-155497632),d=e(d,h,w,u,f[_+10],23,-1094730640),u=e(u,d,h,w,f[_+13],4,681279174),w=e(w,u,d,h,f[_],11,-358537222),h=e(h,w,u,d,f[_+3],16,-722521979),d=e(d,h,w,u,f[_+6],23,76029189),u=e(u,d,h,w,f[_+9],4,-640364487),w=e(w,u,d,h,f[_+12],11,-421815835),h=e(h,w,u,d,f[_+15],16,530742520),d=e(d,h,w,u,f[_+2],23,-995338651),u=l(u,d,h,w,f[_],6,-198630844),w=l(w,u,d,h,f[_+7],10,1126891415),h=l(h,w,u,d,f[_+14],15,-1416354905),d=l(d,h,w,u,f[_+5],21,-57434055),u=l(u,d,h,w,f[_+12],6,1700485571),w=l(w,u,d,h,f[_+3],10,-1894986606),h=l(h,w,u,d,f[_+10],15,-1051523),d=l(d,h,w,u,f[_+1],21,-2054922799),u=l(u,d,h,w,f[_+8],6,1873313359),w=l(w,u,d,h,f[_+15],10,-30611744),h=l(h,w,u,d,f[_+6],15,-1560198380),d=l(d,h,w,u,f[_+13],21,1309151649),u=l(u,d,h,w,f[_+4],6,-145523070),w=l(w,u,d,h,f[_+11],10,-1120210379),h=l(h,w,u,d,f[_+2],15,718787259),d=l(d,h,w,u,f[_+9],21,-343485551),u=a(u,A),d=a(d,N),h=a(h,L),w=a(w,I)}return[u,d,h,w]}(function(f){if(f.length===0)return[];const c=8*f.length,u=new Uint32Array(m(c));for(let d=0;d<c;d+=8)u[d>>5]|=(255&f[d/8])<<d%32;return u}(i),8*i.length))};S.default=n},{}],530:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0,S.default="00000000-0000-0000-0000-000000000000"},{}],531:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var m,a=(m=s("./validate.js"))&&m.__esModule?m:{default:m},o=function(r){if(!(0,a.default)(r))throw TypeError("Invalid UUID");let t;const e=new Uint8Array(16);return e[0]=(t=parseInt(r.slice(0,8),16))>>>24,e[1]=t>>>16&255,e[2]=t>>>8&255,e[3]=255&t,e[4]=(t=parseInt(r.slice(9,13),16))>>>8,e[5]=255&t,e[6]=(t=parseInt(r.slice(14,18),16))>>>8,e[7]=255&t,e[8]=(t=parseInt(r.slice(19,23),16))>>>8,e[9]=255&t,e[10]=(t=parseInt(r.slice(24,36),16))/1099511627776&255,e[11]=t/4294967296&255,e[12]=t>>>24&255,e[13]=t>>>16&255,e[14]=t>>>8&255,e[15]=255&t,e};S.default=o},{"./validate.js":541}],532:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0,S.default=/^(?:[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}|00000000-0000-0000-0000-000000000000)$/i},{}],533:[function(s,T,S){let m;Object.defineProperty(S,"__esModule",{value:!0}),S.default=function(){if(!m&&(m=typeof crypto<"u"&&crypto.getRandomValues&&crypto.getRandomValues.bind(crypto)||typeof msCrypto<"u"&&typeof msCrypto.getRandomValues=="function"&&msCrypto.getRandomValues.bind(msCrypto),!m))throw new Error("crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported");return m(a)};const a=new Uint8Array(16)},{}],534:[function(s,T,S){function m(r,t,e,l){switch(r){case 0:return t&e^~t&l;case 1:return t^e^l;case 2:return t&e^t&l^e&l;case 3:return t^e^l}}function a(r,t){return r<<t|r>>>32-t}Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var o=function(r){const t=[1518500249,1859775393,2400959708,3395469782],e=[1732584193,4023233417,2562383102,271733878,3285377520];if(typeof r=="string"){const f=unescape(encodeURIComponent(r));r=[];for(let c=0;c<f.length;++c)r.push(f.charCodeAt(c))}else Array.isArray(r)||(r=Array.prototype.slice.call(r));r.push(128);const l=r.length/4+2,n=Math.ceil(l/16),i=new Array(n);for(let f=0;f<n;++f){const c=new Uint32Array(16);for(let u=0;u<16;++u)c[u]=r[64*f+4*u]<<24|r[64*f+4*u+1]<<16|r[64*f+4*u+2]<<8|r[64*f+4*u+3];i[f]=c}i[n-1][14]=8*(r.length-1)/Math.pow(2,32),i[n-1][14]=Math.floor(i[n-1][14]),i[n-1][15]=8*(r.length-1)&4294967295;for(let f=0;f<n;++f){const c=new Uint32Array(80);for(let A=0;A<16;++A)c[A]=i[f][A];for(let A=16;A<80;++A)c[A]=a(c[A-3]^c[A-8]^c[A-14]^c[A-16],1);let u=e[0],d=e[1],h=e[2],w=e[3],_=e[4];for(let A=0;A<80;++A){const N=Math.floor(A/20),L=a(u,5)+m(N,d,h,w)+_+t[N]+c[A]>>>0;_=w,w=h,h=a(d,30)>>>0,d=u,u=L}e[0]=e[0]+u>>>0,e[1]=e[1]+d>>>0,e[2]=e[2]+h>>>0,e[3]=e[3]+w>>>0,e[4]=e[4]+_>>>0}return[e[0]>>24&255,e[0]>>16&255,e[0]>>8&255,255&e[0],e[1]>>24&255,e[1]>>16&255,e[1]>>8&255,255&e[1],e[2]>>24&255,e[2]>>16&255,e[2]>>8&255,255&e[2],e[3]>>24&255,e[3]>>16&255,e[3]>>8&255,255&e[3],e[4]>>24&255,e[4]>>16&255,e[4]>>8&255,255&e[4]]};S.default=o},{}],535:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var m,a=(m=s("./validate.js"))&&m.__esModule?m:{default:m};const o=[];for(let t=0;t<256;++t)o.push((t+256).toString(16).substr(1));var r=function(t){let e=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0;const l=(o[t[e+0]]+o[t[e+1]]+o[t[e+2]]+o[t[e+3]]+"-"+o[t[e+4]]+o[t[e+5]]+"-"+o[t[e+6]]+o[t[e+7]]+"-"+o[t[e+8]]+o[t[e+9]]+"-"+o[t[e+10]]+o[t[e+11]]+o[t[e+12]]+o[t[e+13]]+o[t[e+14]]+o[t[e+15]]).toLowerCase();if(!(0,a.default)(l))throw TypeError("Stringified UUID is invalid");return l};S.default=r},{"./validate.js":541}],536:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var m=o(s("./rng.js")),a=o(s("./stringify.js"));function o(i){return i&&i.__esModule?i:{default:i}}let r,t,e=0,l=0;var n=function(i,f,c){let u=f&&c||0;const d=f||new Array(16);let h=(i=i||{}).node||r,w=i.clockseq!==void 0?i.clockseq:t;if(h==null||w==null){const P=i.random||(i.rng||m.default)();h==null&&(h=r=[1|P[0],P[1],P[2],P[3],P[4],P[5]]),w==null&&(w=t=16383&(P[6]<<8|P[7]))}let _=i.msecs!==void 0?i.msecs:Date.now(),A=i.nsecs!==void 0?i.nsecs:l+1;const N=_-e+(A-l)/1e4;if(N<0&&i.clockseq===void 0&&(w=w+1&16383),(N<0||_>e)&&i.nsecs===void 0&&(A=0),A>=1e4)throw new Error("uuid.v1(): Can't create more than 10M uuids/sec");e=_,l=A,t=w,_+=122192928e5;const L=(1e4*(268435455&_)+A)%4294967296;d[u++]=L>>>24&255,d[u++]=L>>>16&255,d[u++]=L>>>8&255,d[u++]=255&L;const I=_/4294967296*1e4&268435455;d[u++]=I>>>8&255,d[u++]=255&I,d[u++]=I>>>24&15|16,d[u++]=I>>>16&255,d[u++]=w>>>8|128,d[u++]=255&w;for(let P=0;P<6;++P)d[u+P]=h[P];return f||(0,a.default)(d)};S.default=n},{"./rng.js":533,"./stringify.js":535}],537:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var m=o(s("./v35.js")),a=o(s("./md5.js"));function o(t){return t&&t.__esModule?t:{default:t}}var r=(0,m.default)("v3",48,a.default);S.default=r},{"./md5.js":529,"./v35.js":538}],538:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=function(e,l,n){function i(f,c,u,d){if(typeof f=="string"&&(f=function(w){w=unescape(encodeURIComponent(w));const _=[];for(let A=0;A<w.length;++A)_.push(w.charCodeAt(A));return _}(f)),typeof c=="string"&&(c=(0,a.default)(c)),c.length!==16)throw TypeError("Namespace must be array-like (16 iterable integer values, 0-255)");let h=new Uint8Array(16+f.length);if(h.set(c),h.set(f,c.length),h=n(h),h[6]=15&h[6]|l,h[8]=63&h[8]|128,u){d=d||0;for(let w=0;w<16;++w)u[d+w]=h[w];return u}return(0,m.default)(h)}try{i.name=e}catch{}return i.DNS=r,i.URL=t,i},S.URL=S.DNS=void 0;var m=o(s("./stringify.js")),a=o(s("./parse.js"));function o(e){return e&&e.__esModule?e:{default:e}}const r="6ba7b810-9dad-11d1-80b4-00c04fd430c8";S.DNS=r;const t="6ba7b811-9dad-11d1-80b4-00c04fd430c8";S.URL=t},{"./parse.js":531,"./stringify.js":535}],539:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var m=o(s("./rng.js")),a=o(s("./stringify.js"));function o(t){return t&&t.__esModule?t:{default:t}}var r=function(t,e,l){const n=(t=t||{}).random||(t.rng||m.default)();if(n[6]=15&n[6]|64,n[8]=63&n[8]|128,e){l=l||0;for(let i=0;i<16;++i)e[l+i]=n[i];return e}return(0,a.default)(n)};S.default=r},{"./rng.js":533,"./stringify.js":535}],540:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var m=o(s("./v35.js")),a=o(s("./sha1.js"));function o(t){return t&&t.__esModule?t:{default:t}}var r=(0,m.default)("v5",80,a.default);S.default=r},{"./sha1.js":534,"./v35.js":538}],541:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var m,a=(m=s("./regex.js"))&&m.__esModule?m:{default:m},o=function(r){return typeof r=="string"&&a.default.test(r)};S.default=o},{"./regex.js":532}],542:[function(s,T,S){Object.defineProperty(S,"__esModule",{value:!0}),S.default=void 0;var m,a=(m=s("./validate.js"))&&m.__esModule?m:{default:m},o=function(r){if(!(0,a.default)(r))throw TypeError("Invalid UUID");return parseInt(r.substr(14,1),16)};S.default=o},{"./validate.js":541}],543:[function(s,T,S){/**
* Character classes and associated utilities for the 5th edition of XML 1.0.
*
* @author Louis-Dominique Dubeau
* @license MIT
* @copyright Louis-Dominique Dubeau
*/Object.defineProperty(S,"__esModule",{value:!0}),S.CHAR=`	
\r -퟿-�𐀀-􏿿`,S.S=` 	\r
`,S.NAME_START_CHAR=":A-Z_a-zÀ-ÖØ-öø-˿Ͱ-ͽͿ-῿‌‍⁰-↏Ⰰ-⿯、-퟿豈-﷏ﷰ-�𐀀-󯿿",S.NAME_CHAR="-"+S.NAME_START_CHAR+".0-9·̀-ͯ‿-⁀",S.CHAR_RE=new RegExp("^["+S.CHAR+"]$","u"),S.S_RE=new RegExp("^["+S.S+"]+$","u"),S.NAME_START_CHAR_RE=new RegExp("^["+S.NAME_START_CHAR+"]$","u"),S.NAME_CHAR_RE=new RegExp("^["+S.NAME_CHAR+"]$","u"),S.NAME_RE=new RegExp("^["+S.NAME_START_CHAR+"]["+S.NAME_CHAR+"]*$","u"),S.NMTOKEN_RE=new RegExp("^["+S.NAME_CHAR+"]+$","u");function m(a){return a>=65&&a<=90||a>=97&&a<=122||a===58||a===95||a===8204||a===8205||a>=192&&a<=214||a>=216&&a<=246||a>=248&&a<=767||a>=880&&a<=893||a>=895&&a<=8191||a>=8304&&a<=8591||a>=11264&&a<=12271||a>=12289&&a<=55295||a>=63744&&a<=64975||a>=65008&&a<=65533||a>=65536&&a<=983039}S.S_LIST=[32,10,13,9],S.isChar=function(a){return a>=32&&a<=55295||a===10||a===13||a===9||a>=57344&&a<=65533||a>=65536&&a<=1114111},S.isS=function(a){return a===32||a===10||a===13||a===9},S.isNameStartChar=m,S.isNameChar=function(a){return m(a)||a>=48&&a<=57||a===45||a===46||a===183||a>=768&&a<=879||a>=8255&&a<=8256}},{}],544:[function(s,T,S){/**
* Character classes and associated utilities for the 2nd edition of XML 1.1.
*
* @author Louis-Dominique Dubeau
* @license MIT
* @copyright Louis-Dominique Dubeau
*/Object.defineProperty(S,"__esModule",{value:!0}),S.CHAR="-퟿-�𐀀-􏿿",S.RESTRICTED_CHAR="-\b\v\f---",S.S=` 	\r
`,S.NAME_START_CHAR=":A-Z_a-zÀ-ÖØ-öø-˿Ͱ-ͽͿ-῿‌‍⁰-↏Ⰰ-⿯、-퟿豈-﷏ﷰ-�𐀀-󯿿",S.NAME_CHAR="-"+S.NAME_START_CHAR+".0-9·̀-ͯ‿-⁀",S.CHAR_RE=new RegExp("^["+S.CHAR+"]$","u"),S.RESTRICTED_CHAR_RE=new RegExp("^["+S.RESTRICTED_CHAR+"]$","u"),S.S_RE=new RegExp("^["+S.S+"]+$","u"),S.NAME_START_CHAR_RE=new RegExp("^["+S.NAME_START_CHAR+"]$","u"),S.NAME_CHAR_RE=new RegExp("^["+S.NAME_CHAR+"]$","u"),S.NAME_RE=new RegExp("^["+S.NAME_START_CHAR+"]["+S.NAME_CHAR+"]*$","u"),S.NMTOKEN_RE=new RegExp("^["+S.NAME_CHAR+"]+$","u");function m(a){return a>=65&&a<=90||a>=97&&a<=122||a===58||a===95||a===8204||a===8205||a>=192&&a<=214||a>=216&&a<=246||a>=248&&a<=767||a>=880&&a<=893||a>=895&&a<=8191||a>=8304&&a<=8591||a>=11264&&a<=12271||a>=12289&&a<=55295||a>=63744&&a<=64975||a>=65008&&a<=65533||a>=65536&&a<=983039}S.S_LIST=[32,10,13,9],S.isChar=function(a){return a>=1&&a<=55295||a>=57344&&a<=65533||a>=65536&&a<=1114111},S.isRestrictedChar=function(a){return a>=1&&a<=8||a===11||a===12||a>=14&&a<=31||a>=127&&a<=132||a>=134&&a<=159},S.isCharAndNotRestricted=function(a){return a===9||a===10||a===13||a>31&&a<127||a===133||a>159&&a<=55295||a>=57344&&a<=65533||a>=65536&&a<=1114111},S.isS=function(a){return a===32||a===10||a===13||a===9},S.isNameStartChar=m,S.isNameChar=function(a){return m(a)||a>=48&&a<=57||a===45||a===46||a===183||a>=768&&a<=879||a>=8255&&a<=8256}},{}],545:[function(s,T,S){/**
* Character class utilities for XML NS 1.0 edition 3.
*
* @author Louis-Dominique Dubeau
* @license MIT
* @copyright Louis-Dominique Dubeau
*/function m(a){return a>=65&&a<=90||a===95||a>=97&&a<=122||a>=192&&a<=214||a>=216&&a<=246||a>=248&&a<=767||a>=880&&a<=893||a>=895&&a<=8191||a>=8204&&a<=8205||a>=8304&&a<=8591||a>=11264&&a<=12271||a>=12289&&a<=55295||a>=63744&&a<=64975||a>=65008&&a<=65533||a>=65536&&a<=983039}Object.defineProperty(S,"__esModule",{value:!0}),S.NC_NAME_START_CHAR="A-Z_a-zÀ-ÖØ-öø-˿Ͱ-ͽͿ-῿‌-‍⁰-↏Ⰰ-⿯、-퟿豈-﷏ﷰ-�𐀀-󯿿",S.NC_NAME_CHAR="-"+S.NC_NAME_START_CHAR+".0-9·̀-ͯ‿-⁀",S.NC_NAME_START_CHAR_RE=new RegExp("^["+S.NC_NAME_START_CHAR+"]$","u"),S.NC_NAME_CHAR_RE=new RegExp("^["+S.NC_NAME_CHAR+"]$","u"),S.NC_NAME_RE=new RegExp("^["+S.NC_NAME_START_CHAR+"]["+S.NC_NAME_CHAR+"]*$","u"),S.isNCNameStartChar=m,S.isNCNameChar=function(a){return m(a)||a===45||a===46||a>=48&&a<=57||a===183||a>=768&&a<=879||a>=8255&&a<=8256}},{}]},{},[15])(15)})})(qe);var Ze=qe.exports;const Ye=Ke(Ze),We="FILE_BASE64_PLACEHOLDER",Ge=1;let Ue=globalThis.fileBase64||We,Je=globalThis.pageNumber||Ge;function Qe(Ct){let Mt="";for(;Ct>0;){const s=(Ct-1)%26;Mt=String.fromCharCode(65+s)+Mt,Ct=Math.floor((Ct-1)/26)}return Mt}function ze(Ct){if(Ct){if(Ct.argb){const Mt=Ct.argb;if(Mt.length===8){const s=parseInt(Mt.substring(2,4),16),T=parseInt(Mt.substring(4,6),16),S=parseInt(Mt.substring(6,8),16);return`rgb(${s}, ${T}, ${S})`}}if(Ct.theme!==void 0)return{0:"#000000",1:"#FFFFFF",2:"#44546A",3:"#E7E6E6",4:"#4472C4",5:"#ED7D31",6:"#A5A5A5",7:"#FFC000",8:"#5B9BD5",9:"#70AD47"}[Ct.theme]||void 0}}function tr(Ct){const Mt=Ct.value;if(Mt==null)return"";if(typeof Mt=="object"&&"formula"in Mt){const s=Mt;return s.result!==void 0?typeof s.result=="object"&&s.result!==null&&"error"in s.result?String(s.result.error):String(s.result):`=${s.formula}`}return typeof Mt=="object"&&"richText"in Mt?Mt.richText.map(s=>s.text).join(""):typeof Mt=="object"&&"hyperlink"in Mt?Mt.text||"":Mt instanceof Date?Mt.toLocaleDateString():typeof Mt=="object"&&"error"in Mt?String(Mt.error):String(Mt)}function er(Ct){const Mt=[];if(Ct.font){Ct.font.bold&&Mt.push("font-weight: bold"),Ct.font.italic&&Mt.push("font-style: italic"),Ct.font.underline&&Mt.push("text-decoration: underline"),Ct.font.strike&&Mt.push("text-decoration: line-through"),Ct.font.size&&Mt.push(`font-size: ${Ct.font.size}pt`),Ct.font.name&&Mt.push(`font-family: "${Ct.font.name}", sans-serif`);const T=ze(Ct.font.color);T&&Mt.push(`color: ${T}`)}if(Ct.fill&&Ct.fill.type==="pattern"){const T=Ct.fill;if(T.fgColor){const S=ze(T.fgColor);S&&Mt.push(`background-color: ${S}`)}}if(Ct.alignment){if(Ct.alignment.horizontal&&Mt.push(`text-align: ${Ct.alignment.horizontal}`),Ct.alignment.vertical){const T=Ct.alignment.vertical==="middle"?"middle":Ct.alignment.vertical;Mt.push(`vertical-align: ${T}`)}Ct.alignment.wrapText&&(Mt.push("white-space: normal"),Mt.push("word-wrap: break-word"))}const s=(T,S)=>{if(!T||!T.style)return;const m=ze(T.color)||"#000000";let a="1px",o="solid";switch(T.style){case"thin":a="1px";break;case"medium":a="2px";break;case"thick":a="3px";break;case"dotted":o="dotted";break;case"dashed":o="dashed";break;case"double":o="double",a="3px";break}Mt.push(`border-${S}: ${a} ${o} ${m}`)};return Ct.border&&(s(Ct.border.top,"top"),s(Ct.border.right,"right"),s(Ct.border.bottom,"bottom"),s(Ct.border.left,"left")),Mt.join("; ")}function rr(){if(!document.getElementById("container"))return;const Mt=document.createElement("div");Mt.style.cssText=`
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: white;
    display: flex;
    justify-content: center;
    align-items: center;
    z-index: 1000;
  `,Mt.innerHTML=`
    <div style="padding: 2rem; text-align: center;">
      <h2>Local Testing Mode</h2>
      <p>Select an XLSX file to render:</p>
      <input type="file" accept=".xlsx,.xls" id="file-input" style="margin: 1rem 0;">
    </div>
  `,document.body.appendChild(Mt),document.getElementById("file-input").addEventListener("change",async T=>{const S=T.target.files?.[0];if(!S)return;const m=new FileReader;m.onload=async a=>{Ue=(a.target?.result).split(",")[1],Mt.remove(),await Xe()},m.readAsDataURL(S)})}async function Xe(){try{const Ct=document.getElementById("xlsx-container");if(!Ct)throw new Error("XLSX container element not found");if(Ue===We)return rr(),{width:1280,height:960,pageCount:1,pageNumber:1,scale:1};const Mt=atob(Ue),s=new Uint8Array(Mt.length);for(let I=0;I<Mt.length;I++)s[I]=Mt.charCodeAt(I);const T=new Ye.Workbook;await T.xlsx.load(s.buffer);const S=T.worksheets,m=S.length,a=Math.max(1,Math.min(Je,m)),o=S[a-1];if(!o)throw new Error(`Worksheet ${a} not found`);const r=document.createElement("table");r.className="xlsx-table";let t=0,e=0;o.eachRow({includeEmpty:!1},(I,P)=>{P>t&&(t=P),I.eachCell({includeEmpty:!1},(B,U)=>{U>e&&(e=U)})});const l=t||o.rowCount||1,n=e||o.columnCount||1,i=document.createElement("thead"),f=document.createElement("tr"),c=document.createElement("th");c.className="corner",f.appendChild(c);for(let I=1;I<=n;I++){const P=document.createElement("th");P.textContent=Qe(I),f.appendChild(P)}i.appendChild(f),r.appendChild(i);const u=document.createElement("tbody"),d=new Map,h=new Set;o.model.merges?.forEach(I=>{const P=I.match(/([A-Z]+)(\d+):([A-Z]+)(\d+)/);if(P){const B=Ve(P[1]),U=parseInt(P[2]),D=Ve(P[3]),x=parseInt(P[4]),M=`${U},${B}`;d.set(M,{rowSpan:x-U+1,colSpan:D-B+1});for(let v=U;v<=x;v++)for(let p=B;p<=D;p++)(v!==U||p!==B)&&h.add(`${v},${p}`)}});for(let I=1;I<=l;I++){const P=o.getRow(I),B=document.createElement("tr"),U=document.createElement("td");U.className="row-header",U.textContent=String(I),P.height&&(B.style.height=`${P.height}px`),B.appendChild(U);for(let D=1;D<=n;D++){const x=`${I},${D}`;if(h.has(x))continue;const M=P.getCell(D),v=document.createElement("td"),p=d.get(x);p&&(p.rowSpan>1&&(v.rowSpan=p.rowSpan),p.colSpan>1&&(v.colSpan=p.colSpan)),v.textContent=tr(M);const b=er(M);b&&(v.style.cssText=b),B.appendChild(v)}u.appendChild(B)}r.appendChild(u),Ct.innerHTML="",Ct.appendChild(r),await new Promise(I=>setTimeout(I,100));const w=2,_=r.getBoundingClientRect(),A=Math.ceil(_.width*w),N=Math.ceil(_.height*w),L={width:A,height:N,pageCount:m,pageNumber:a,scale:w,tableRect:{width:_.width,height:_.height,top:_.top,left:_.left},viewport:{width:window.innerWidth,height:window.innerHeight}};return console.log("RenderMetadata:",L),L}catch(Ct){throw console.error("Error rendering XLSX:",Ct),Ct}}function Ve(Ct){let Mt=0;for(let s=0;s<Ct.length;s++)Mt=Mt*26+(Ct.charCodeAt(s)-64);return Mt}window.renderComplete=Xe();</script>
</head>
<body>
  <div id="container">
    <div id="xlsx-container"></div>
  </div>
</body>
</html>
