<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>LaTeX Renderer</title>
  <style>
    * {
      margin: 0;
      padding: 0;
      box-sizing: border-box;
    }
    body {
      background: white;
      overflow: hidden;
    }
    #container {
      width: 100%;
      min-height: 100vh;
      display: flex;
      justify-content: center;
      align-items: flex-start;
      padding: 40px;
    }
    #tex-container {
      max-width: 800px;
      width: 100%;
    }
  </style>
  <script type="module" crossorigin>(function(){const e=document.createElement("link").relList;if(e&&e.supports&&e.supports("modulepreload"))return;for(const t of document.querySelectorAll('link[rel="modulepreload"]'))i(t);new MutationObserver(t=>{for(const l of t)if(l.type==="childList")for(const h of l.addedNodes)h.tagName==="LINK"&&h.rel==="modulepreload"&&i(h)}).observe(document,{childList:!0,subtree:!0});function n(t){const l={};return t.integrity&&(l.integrity=t.integrity),t.referrerPolicy&&(l.referrerPolicy=t.referrerPolicy),t.crossOrigin==="use-credentials"?l.credentials="include":t.crossOrigin==="anonymous"?l.credentials="omit":l.credentials="same-origin",l}function i(t){if(t.ep)return;t.ep=!0;const l=n(t);fetch(t.href,l)}})();var Nr=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function Ir(r){return r&&r.__esModule&&Object.prototype.hasOwnProperty.call(r,"default")?r.default:r}function x5(r){if(r.__esModule)return r;var e=r.default;if(typeof e=="function"){var n=function i(){if(this instanceof i){var t=[null];return t.push.apply(t,arguments),new(Function.bind.apply(e,t))}return e.apply(this,arguments)};n.prototype=e.prototype}else n={};return Object.defineProperty(n,"__esModule",{value:!0}),Object.keys(r).forEach(function(i){var t=Object.getOwnPropertyDescriptor(r,i);Object.defineProperty(n,i,t.get?t:{enumerable:!0,get:function(){return r[i]}})}),n}var Ci,nc,Ca={exports:{}};/*! https://mths.be/he v1.2.0 by @mathias | MIT license */Ci=Ca,nc=Ca.exports,function(r){var e=nc,n=Ci&&Ci.exports==e&&Ci,i=typeof Nr=="object"&&Nr;i.global!==i&&i.window!==i||(r=i);var t=/[\uD800-\uDBFF][\uDC00-\uDFFF]/g,l=/[\x01-\x7F]/g,h=/[\x01-\t\x0B\f\x0E-\x1F\x7F\x81\x8D\x8F\x90\x9D\xA0-\uFFFF]/g,p=/<\u20D2|=\u20E5|>\u20D2|\u205F\u200A|\u219D\u0338|\u2202\u0338|\u2220\u20D2|\u2229\uFE00|\u222A\uFE00|\u223C\u20D2|\u223D\u0331|\u223E\u0333|\u2242\u0338|\u224B\u0338|\u224D\u20D2|\u224E\u0338|\u224F\u0338|\u2250\u0338|\u2261\u20E5|\u2264\u20D2|\u2265\u20D2|\u2266\u0338|\u2267\u0338|\u2268\uFE00|\u2269\uFE00|\u226A\u0338|\u226A\u20D2|\u226B\u0338|\u226B\u20D2|\u227F\u0338|\u2282\u20D2|\u2283\u20D2|\u228A\uFE00|\u228B\uFE00|\u228F\u0338|\u2290\u0338|\u2293\uFE00|\u2294\uFE00|\u22B4\u20D2|\u22B5\u20D2|\u22D8\u0338|\u22D9\u0338|\u22DA\uFE00|\u22DB\uFE00|\u22F5\u0338|\u22F9\u0338|\u2933\u0338|\u29CF\u0338|\u29D0\u0338|\u2A6D\u0338|\u2A70\u0338|\u2A7D\u0338|\u2A7E\u0338|\u2AA1\u0338|\u2AA2\u0338|\u2AAC\uFE00|\u2AAD\uFE00|\u2AAF\u0338|\u2AB0\u0338|\u2AC5\u0338|\u2AC6\u0338|\u2ACB\uFE00|\u2ACC\uFE00|\u2AFD\u20E5|[\xA0-\u0113\u0116-\u0122\u0124-\u012B\u012E-\u014D\u0150-\u017E\u0192\u01B5\u01F5\u0237\u02C6\u02C7\u02D8-\u02DD\u0311\u0391-\u03A1\u03A3-\u03A9\u03B1-\u03C9\u03D1\u03D2\u03D5\u03D6\u03DC\u03DD\u03F0\u03F1\u03F5\u03F6\u0401-\u040C\u040E-\u044F\u0451-\u045C\u045E\u045F\u2002-\u2005\u2007-\u2010\u2013-\u2016\u2018-\u201A\u201C-\u201E\u2020-\u2022\u2025\u2026\u2030-\u2035\u2039\u203A\u203E\u2041\u2043\u2044\u204F\u2057\u205F-\u2063\u20AC\u20DB\u20DC\u2102\u2105\u210A-\u2113\u2115-\u211E\u2122\u2124\u2127-\u2129\u212C\u212D\u212F-\u2131\u2133-\u2138\u2145-\u2148\u2153-\u215E\u2190-\u219B\u219D-\u21A7\u21A9-\u21AE\u21B0-\u21B3\u21B5-\u21B7\u21BA-\u21DB\u21DD\u21E4\u21E5\u21F5\u21FD-\u2205\u2207-\u2209\u220B\u220C\u220F-\u2214\u2216-\u2218\u221A\u221D-\u2238\u223A-\u2257\u2259\u225A\u225C\u225F-\u2262\u2264-\u228B\u228D-\u229B\u229D-\u22A5\u22A7-\u22B0\u22B2-\u22BB\u22BD-\u22DB\u22DE-\u22E3\u22E6-\u22F7\u22F9-\u22FE\u2305\u2306\u2308-\u2310\u2312\u2313\u2315\u2316\u231C-\u231F\u2322\u2323\u232D\u232E\u2336\u233D\u233F\u237C\u23B0\u23B1\u23B4-\u23B6\u23DC-\u23DF\u23E2\u23E7\u2423\u24C8\u2500\u2502\u250C\u2510\u2514\u2518\u251C\u2524\u252C\u2534\u253C\u2550-\u256C\u2580\u2584\u2588\u2591-\u2593\u25A1\u25AA\u25AB\u25AD\u25AE\u25B1\u25B3-\u25B5\u25B8\u25B9\u25BD-\u25BF\u25C2\u25C3\u25CA\u25CB\u25EC\u25EF\u25F8-\u25FC\u2605\u2606\u260E\u2640\u2642\u2660\u2663\u2665\u2666\u266A\u266D-\u266F\u2713\u2717\u2720\u2736\u2758\u2772\u2773\u27C8\u27C9\u27E6-\u27ED\u27F5-\u27FA\u27FC\u27FF\u2902-\u2905\u290C-\u2913\u2916\u2919-\u2920\u2923-\u292A\u2933\u2935-\u2939\u293C\u293D\u2945\u2948-\u294B\u294E-\u2976\u2978\u2979\u297B-\u297F\u2985\u2986\u298B-\u2996\u299A\u299C\u299D\u29A4-\u29B7\u29B9\u29BB\u29BC\u29BE-\u29C5\u29C9\u29CD-\u29D0\u29DC-\u29DE\u29E3-\u29E5\u29EB\u29F4\u29F6\u2A00-\u2A02\u2A04\u2A06\u2A0C\u2A0D\u2A10-\u2A17\u2A22-\u2A27\u2A29\u2A2A\u2A2D-\u2A31\u2A33-\u2A3C\u2A3F\u2A40\u2A42-\u2A4D\u2A50\u2A53-\u2A58\u2A5A-\u2A5D\u2A5F\u2A66\u2A6A\u2A6D-\u2A75\u2A77-\u2A9A\u2A9D-\u2AA2\u2AA4-\u2AB0\u2AB3-\u2AC8\u2ACB\u2ACC\u2ACF-\u2ADB\u2AE4\u2AE6-\u2AE9\u2AEB-\u2AF3\u2AFD\uFB00-\uFB04]|\uD835[\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDCCF\uDD04\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDD6B]/g,m={"­":"shy","‌":"zwnj","‍":"zwj","‎":"lrm","⁣":"ic","⁢":"it","⁡":"af","‏":"rlm","​":"ZeroWidthSpace","⁠":"NoBreak","̑":"DownBreve","⃛":"tdot","⃜":"DotDot","	":"Tab","\n":"NewLine"," ":"puncsp"," ":"MediumSpace"," ":"thinsp"," ":"hairsp"," ":"emsp13"," ":"ensp"," ":"emsp14"," ":"emsp"," ":"numsp"," ":"nbsp","  ":"ThickSpace","‾":"oline",_:"lowbar","‐":"dash","–":"ndash","—":"mdash","―":"horbar",",":"comma",";":"semi","⁏":"bsemi",":":"colon","⩴":"Colone","!":"excl","¡":"iexcl","?":"quest","¿":"iquest",".":"period","‥":"nldr","…":"mldr","·":"middot","'":"apos","‘":"lsquo","’":"rsquo","‚":"sbquo","‹":"lsaquo","›":"rsaquo",'"':"quot","“":"ldquo","”":"rdquo","„":"bdquo","«":"laquo","»":"raquo","(":"lpar",")":"rpar","[":"lsqb","]":"rsqb","{":"lcub","}":"rcub","⌈":"lceil","⌉":"rceil","⌊":"lfloor","⌋":"rfloor","⦅":"lopar","⦆":"ropar","⦋":"lbrke","⦌":"rbrke","⦍":"lbrkslu","⦎":"rbrksld","⦏":"lbrksld","⦐":"rbrkslu","⦑":"langd","⦒":"rangd","⦓":"lparlt","⦔":"rpargt","⦕":"gtlPar","⦖":"ltrPar","⟦":"lobrk","⟧":"robrk","⟨":"lang","⟩":"rang","⟪":"Lang","⟫":"Rang","⟬":"loang","⟭":"roang","❲":"lbbrk","❳":"rbbrk","‖":"Vert","§":"sect","¶":"para","@":"commat","*":"ast","/":"sol",undefined:null,"&":"amp","#":"num","%":"percnt","‰":"permil","‱":"pertenk","†":"dagger","‡":"Dagger","•":"bull","⁃":"hybull","′":"prime","″":"Prime","‴":"tprime","⁗":"qprime","‵":"bprime","⁁":"caret","`":"grave","´":"acute","˜":"tilde","^":"Hat","¯":"macr","˘":"breve","˙":"dot","¨":"die","˚":"ring","˝":"dblac","¸":"cedil","˛":"ogon","ˆ":"circ","ˇ":"caron","°":"deg","©":"copy","®":"reg","℗":"copysr","℘":"wp","℞":"rx","℧":"mho","℩":"iiota","←":"larr","↚":"nlarr","→":"rarr","↛":"nrarr","↑":"uarr","↓":"darr","↔":"harr","↮":"nharr","↕":"varr","↖":"nwarr","↗":"nearr","↘":"searr","↙":"swarr","↝":"rarrw","↝̸":"nrarrw","↞":"Larr","↟":"Uarr","↠":"Rarr","↡":"Darr","↢":"larrtl","↣":"rarrtl","↤":"mapstoleft","↥":"mapstoup","↦":"map","↧":"mapstodown","↩":"larrhk","↪":"rarrhk","↫":"larrlp","↬":"rarrlp","↭":"harrw","↰":"lsh","↱":"rsh","↲":"ldsh","↳":"rdsh","↵":"crarr","↶":"cularr","↷":"curarr","↺":"olarr","↻":"orarr","↼":"lharu","↽":"lhard","↾":"uharr","↿":"uharl","⇀":"rharu","⇁":"rhard","⇂":"dharr","⇃":"dharl","⇄":"rlarr","⇅":"udarr","⇆":"lrarr","⇇":"llarr","⇈":"uuarr","⇉":"rrarr","⇊":"ddarr","⇋":"lrhar","⇌":"rlhar","⇐":"lArr","⇍":"nlArr","⇑":"uArr","⇒":"rArr","⇏":"nrArr","⇓":"dArr","⇔":"iff","⇎":"nhArr","⇕":"vArr","⇖":"nwArr","⇗":"neArr","⇘":"seArr","⇙":"swArr","⇚":"lAarr","⇛":"rAarr","⇝":"zigrarr","⇤":"larrb","⇥":"rarrb","⇵":"duarr","⇽":"loarr","⇾":"roarr","⇿":"hoarr","∀":"forall","∁":"comp","∂":"part","∂̸":"npart","∃":"exist","∄":"nexist","∅":"empty","∇":"Del","∈":"in","∉":"notin","∋":"ni","∌":"notni","϶":"bepsi","∏":"prod","∐":"coprod","∑":"sum","+":"plus","±":"pm","÷":"div","×":"times","<":"lt","≮":"nlt","<⃒":"nvlt","=":"equals","≠":"ne","=⃥":"bne","⩵":"Equal",">":"gt","≯":"ngt",">⃒":"nvgt","¬":"not","|":"vert","¦":"brvbar","−":"minus","∓":"mp","∔":"plusdo","⁄":"frasl","∖":"setmn","∗":"lowast","∘":"compfn","√":"Sqrt","∝":"prop","∞":"infin","∟":"angrt","∠":"ang","∠⃒":"nang","∡":"angmsd","∢":"angsph","∣":"mid","∤":"nmid","∥":"par","∦":"npar","∧":"and","∨":"or","∩":"cap","∩︀":"caps","∪":"cup","∪︀":"cups","∫":"int","∬":"Int","∭":"tint","⨌":"qint","∮":"oint","∯":"Conint","∰":"Cconint","∱":"cwint","∲":"cwconint","∳":"awconint","∴":"there4","∵":"becaus","∶":"ratio","∷":"Colon","∸":"minusd","∺":"mDDot","∻":"homtht","∼":"sim","≁":"nsim","∼⃒":"nvsim","∽":"bsim","∽̱":"race","∾":"ac","∾̳":"acE","∿":"acd","≀":"wr","≂":"esim","≂̸":"nesim","≃":"sime","≄":"nsime","≅":"cong","≇":"ncong","≆":"simne","≈":"ap","≉":"nap","≊":"ape","≋":"apid","≋̸":"napid","≌":"bcong","≍":"CupCap","≭":"NotCupCap","≍⃒":"nvap","≎":"bump","≎̸":"nbump","≏":"bumpe","≏̸":"nbumpe","≐":"doteq","≐̸":"nedot","≑":"eDot","≒":"efDot","≓":"erDot","≔":"colone","≕":"ecolon","≖":"ecir","≗":"cire","≙":"wedgeq","≚":"veeeq","≜":"trie","≟":"equest","≡":"equiv","≢":"nequiv","≡⃥":"bnequiv","≤":"le","≰":"nle","≤⃒":"nvle","≥":"ge","≱":"nge","≥⃒":"nvge","≦":"lE","≦̸":"nlE","≧":"gE","≧̸":"ngE","≨︀":"lvnE","≨":"lnE","≩":"gnE","≩︀":"gvnE","≪":"ll","≪̸":"nLtv","≪⃒":"nLt","≫":"gg","≫̸":"nGtv","≫⃒":"nGt","≬":"twixt","≲":"lsim","≴":"nlsim","≳":"gsim","≵":"ngsim","≶":"lg","≸":"ntlg","≷":"gl","≹":"ntgl","≺":"pr","⊀":"npr","≻":"sc","⊁":"nsc","≼":"prcue","⋠":"nprcue","≽":"sccue","⋡":"nsccue","≾":"prsim","≿":"scsim","≿̸":"NotSucceedsTilde","⊂":"sub","⊄":"nsub","⊂⃒":"vnsub","⊃":"sup","⊅":"nsup","⊃⃒":"vnsup","⊆":"sube","⊈":"nsube","⊇":"supe","⊉":"nsupe","⊊︀":"vsubne","⊊":"subne","⊋︀":"vsupne","⊋":"supne","⊍":"cupdot","⊎":"uplus","⊏":"sqsub","⊏̸":"NotSquareSubset","⊐":"sqsup","⊐̸":"NotSquareSuperset","⊑":"sqsube","⋢":"nsqsube","⊒":"sqsupe","⋣":"nsqsupe","⊓":"sqcap","⊓︀":"sqcaps","⊔":"sqcup","⊔︀":"sqcups","⊕":"oplus","⊖":"ominus","⊗":"otimes","⊘":"osol","⊙":"odot","⊚":"ocir","⊛":"oast","⊝":"odash","⊞":"plusb","⊟":"minusb","⊠":"timesb","⊡":"sdotb","⊢":"vdash","⊬":"nvdash","⊣":"dashv","⊤":"top","⊥":"bot","⊧":"models","⊨":"vDash","⊭":"nvDash","⊩":"Vdash","⊮":"nVdash","⊪":"Vvdash","⊫":"VDash","⊯":"nVDash","⊰":"prurel","⊲":"vltri","⋪":"nltri","⊳":"vrtri","⋫":"nrtri","⊴":"ltrie","⋬":"nltrie","⊴⃒":"nvltrie","⊵":"rtrie","⋭":"nrtrie","⊵⃒":"nvrtrie","⊶":"origof","⊷":"imof","⊸":"mumap","⊹":"hercon","⊺":"intcal","⊻":"veebar","⊽":"barvee","⊾":"angrtvb","⊿":"lrtri","⋀":"Wedge","⋁":"Vee","⋂":"xcap","⋃":"xcup","⋄":"diam","⋅":"sdot","⋆":"Star","⋇":"divonx","⋈":"bowtie","⋉":"ltimes","⋊":"rtimes","⋋":"lthree","⋌":"rthree","⋍":"bsime","⋎":"cuvee","⋏":"cuwed","⋐":"Sub","⋑":"Sup","⋒":"Cap","⋓":"Cup","⋔":"fork","⋕":"epar","⋖":"ltdot","⋗":"gtdot","⋘":"Ll","⋘̸":"nLl","⋙":"Gg","⋙̸":"nGg","⋚︀":"lesg","⋚":"leg","⋛":"gel","⋛︀":"gesl","⋞":"cuepr","⋟":"cuesc","⋦":"lnsim","⋧":"gnsim","⋨":"prnsim","⋩":"scnsim","⋮":"vellip","⋯":"ctdot","⋰":"utdot","⋱":"dtdot","⋲":"disin","⋳":"isinsv","⋴":"isins","⋵":"isindot","⋵̸":"notindot","⋶":"notinvc","⋷":"notinvb","⋹":"isinE","⋹̸":"notinE","⋺":"nisd","⋻":"xnis","⋼":"nis","⋽":"notnivc","⋾":"notnivb","⌅":"barwed","⌆":"Barwed","⌌":"drcrop","⌍":"dlcrop","⌎":"urcrop","⌏":"ulcrop","⌐":"bnot","⌒":"profline","⌓":"profsurf","⌕":"telrec","⌖":"target","⌜":"ulcorn","⌝":"urcorn","⌞":"dlcorn","⌟":"drcorn","⌢":"frown","⌣":"smile","⌭":"cylcty","⌮":"profalar","⌶":"topbot","⌽":"ovbar","⌿":"solbar","⍼":"angzarr","⎰":"lmoust","⎱":"rmoust","⎴":"tbrk","⎵":"bbrk","⎶":"bbrktbrk","⏜":"OverParenthesis","⏝":"UnderParenthesis","⏞":"OverBrace","⏟":"UnderBrace","⏢":"trpezium","⏧":"elinters","␣":"blank","─":"boxh","│":"boxv","┌":"boxdr","┐":"boxdl","└":"boxur","┘":"boxul","├":"boxvr","┤":"boxvl","┬":"boxhd","┴":"boxhu","┼":"boxvh","═":"boxH","║":"boxV","╒":"boxdR","╓":"boxDr","╔":"boxDR","╕":"boxdL","╖":"boxDl","╗":"boxDL","╘":"boxuR","╙":"boxUr","╚":"boxUR","╛":"boxuL","╜":"boxUl","╝":"boxUL","╞":"boxvR","╟":"boxVr","╠":"boxVR","╡":"boxvL","╢":"boxVl","╣":"boxVL","╤":"boxHd","╥":"boxhD","╦":"boxHD","╧":"boxHu","╨":"boxhU","╩":"boxHU","╪":"boxvH","╫":"boxVh","╬":"boxVH","▀":"uhblk","▄":"lhblk","█":"block","░":"blk14","▒":"blk12","▓":"blk34","□":"squ","▪":"squf","▫":"EmptyVerySmallSquare","▭":"rect","▮":"marker","▱":"fltns","△":"xutri","▴":"utrif","▵":"utri","▸":"rtrif","▹":"rtri","▽":"xdtri","▾":"dtrif","▿":"dtri","◂":"ltrif","◃":"ltri","◊":"loz","○":"cir","◬":"tridot","◯":"xcirc","◸":"ultri","◹":"urtri","◺":"lltri","◻":"EmptySmallSquare","◼":"FilledSmallSquare","★":"starf","☆":"star","☎":"phone","♀":"female","♂":"male","♠":"spades","♣":"clubs","♥":"hearts","♦":"diams","♪":"sung","✓":"check","✗":"cross","✠":"malt","✶":"sext","❘":"VerticalSeparator","⟈":"bsolhsub","⟉":"suphsol","⟵":"xlarr","⟶":"xrarr","⟷":"xharr","⟸":"xlArr","⟹":"xrArr","⟺":"xhArr","⟼":"xmap","⟿":"dzigrarr","⤂":"nvlArr","⤃":"nvrArr","⤄":"nvHarr","⤅":"Map","⤌":"lbarr","⤍":"rbarr","⤎":"lBarr","⤏":"rBarr","⤐":"RBarr","⤑":"DDotrahd","⤒":"UpArrowBar","⤓":"DownArrowBar","⤖":"Rarrtl","⤙":"latail","⤚":"ratail","⤛":"lAtail","⤜":"rAtail","⤝":"larrfs","⤞":"rarrfs","⤟":"larrbfs","⤠":"rarrbfs","⤣":"nwarhk","⤤":"nearhk","⤥":"searhk","⤦":"swarhk","⤧":"nwnear","⤨":"toea","⤩":"tosa","⤪":"swnwar","⤳":"rarrc","⤳̸":"nrarrc","⤵":"cudarrr","⤶":"ldca","⤷":"rdca","⤸":"cudarrl","⤹":"larrpl","⤼":"curarrm","⤽":"cularrp","⥅":"rarrpl","⥈":"harrcir","⥉":"Uarrocir","⥊":"lurdshar","⥋":"ldrushar","⥎":"LeftRightVector","⥏":"RightUpDownVector","⥐":"DownLeftRightVector","⥑":"LeftUpDownVector","⥒":"LeftVectorBar","⥓":"RightVectorBar","⥔":"RightUpVectorBar","⥕":"RightDownVectorBar","⥖":"DownLeftVectorBar","⥗":"DownRightVectorBar","⥘":"LeftUpVectorBar","⥙":"LeftDownVectorBar","⥚":"LeftTeeVector","⥛":"RightTeeVector","⥜":"RightUpTeeVector","⥝":"RightDownTeeVector","⥞":"DownLeftTeeVector","⥟":"DownRightTeeVector","⥠":"LeftUpTeeVector","⥡":"LeftDownTeeVector","⥢":"lHar","⥣":"uHar","⥤":"rHar","⥥":"dHar","⥦":"luruhar","⥧":"ldrdhar","⥨":"ruluhar","⥩":"rdldhar","⥪":"lharul","⥫":"llhard","⥬":"rharul","⥭":"lrhard","⥮":"udhar","⥯":"duhar","⥰":"RoundImplies","⥱":"erarr","⥲":"simrarr","⥳":"larrsim","⥴":"rarrsim","⥵":"rarrap","⥶":"ltlarr","⥸":"gtrarr","⥹":"subrarr","⥻":"suplarr","⥼":"lfisht","⥽":"rfisht","⥾":"ufisht","⥿":"dfisht","⦚":"vzigzag","⦜":"vangrt","⦝":"angrtvbd","⦤":"ange","⦥":"range","⦦":"dwangle","⦧":"uwangle","⦨":"angmsdaa","⦩":"angmsdab","⦪":"angmsdac","⦫":"angmsdad","⦬":"angmsdae","⦭":"angmsdaf","⦮":"angmsdag","⦯":"angmsdah","⦰":"bemptyv","⦱":"demptyv","⦲":"cemptyv","⦳":"raemptyv","⦴":"laemptyv","⦵":"ohbar","⦶":"omid","⦷":"opar","⦹":"operp","⦻":"olcross","⦼":"odsold","⦾":"olcir","⦿":"ofcir","⧀":"olt","⧁":"ogt","⧂":"cirscir","⧃":"cirE","⧄":"solb","⧅":"bsolb","⧉":"boxbox","⧍":"trisb","⧎":"rtriltri","⧏":"LeftTriangleBar","⧏̸":"NotLeftTriangleBar","⧐":"RightTriangleBar","⧐̸":"NotRightTriangleBar","⧜":"iinfin","⧝":"infintie","⧞":"nvinfin","⧣":"eparsl","⧤":"smeparsl","⧥":"eqvparsl","⧫":"lozf","⧴":"RuleDelayed","⧶":"dsol","⨀":"xodot","⨁":"xoplus","⨂":"xotime","⨄":"xuplus","⨆":"xsqcup","⨍":"fpartint","⨐":"cirfnint","⨑":"awint","⨒":"rppolint","⨓":"scpolint","⨔":"npolint","⨕":"pointint","⨖":"quatint","⨗":"intlarhk","⨢":"pluscir","⨣":"plusacir","⨤":"simplus","⨥":"plusdu","⨦":"plussim","⨧":"plustwo","⨩":"mcomma","⨪":"minusdu","⨭":"loplus","⨮":"roplus","⨯":"Cross","⨰":"timesd","⨱":"timesbar","⨳":"smashp","⨴":"lotimes","⨵":"rotimes","⨶":"otimesas","⨷":"Otimes","⨸":"odiv","⨹":"triplus","⨺":"triminus","⨻":"tritime","⨼":"iprod","⨿":"amalg","⩀":"capdot","⩂":"ncup","⩃":"ncap","⩄":"capand","⩅":"cupor","⩆":"cupcap","⩇":"capcup","⩈":"cupbrcap","⩉":"capbrcup","⩊":"cupcup","⩋":"capcap","⩌":"ccups","⩍":"ccaps","⩐":"ccupssm","⩓":"And","⩔":"Or","⩕":"andand","⩖":"oror","⩗":"orslope","⩘":"andslope","⩚":"andv","⩛":"orv","⩜":"andd","⩝":"ord","⩟":"wedbar","⩦":"sdote","⩪":"simdot","⩭":"congdot","⩭̸":"ncongdot","⩮":"easter","⩯":"apacir","⩰":"apE","⩰̸":"napE","⩱":"eplus","⩲":"pluse","⩳":"Esim","⩷":"eDDot","⩸":"equivDD","⩹":"ltcir","⩺":"gtcir","⩻":"ltquest","⩼":"gtquest","⩽":"les","⩽̸":"nles","⩾":"ges","⩾̸":"nges","⩿":"lesdot","⪀":"gesdot","⪁":"lesdoto","⪂":"gesdoto","⪃":"lesdotor","⪄":"gesdotol","⪅":"lap","⪆":"gap","⪇":"lne","⪈":"gne","⪉":"lnap","⪊":"gnap","⪋":"lEg","⪌":"gEl","⪍":"lsime","⪎":"gsime","⪏":"lsimg","⪐":"gsiml","⪑":"lgE","⪒":"glE","⪓":"lesges","⪔":"gesles","⪕":"els","⪖":"egs","⪗":"elsdot","⪘":"egsdot","⪙":"el","⪚":"eg","⪝":"siml","⪞":"simg","⪟":"simlE","⪠":"simgE","⪡":"LessLess","⪡̸":"NotNestedLessLess","⪢":"GreaterGreater","⪢̸":"NotNestedGreaterGreater","⪤":"glj","⪥":"gla","⪦":"ltcc","⪧":"gtcc","⪨":"lescc","⪩":"gescc","⪪":"smt","⪫":"lat","⪬":"smte","⪬︀":"smtes","⪭":"late","⪭︀":"lates","⪮":"bumpE","⪯":"pre","⪯̸":"npre","⪰":"sce","⪰̸":"nsce","⪳":"prE","⪴":"scE","⪵":"prnE","⪶":"scnE","⪷":"prap","⪸":"scap","⪹":"prnap","⪺":"scnap","⪻":"Pr","⪼":"Sc","⪽":"subdot","⪾":"supdot","⪿":"subplus","⫀":"supplus","⫁":"submult","⫂":"supmult","⫃":"subedot","⫄":"supedot","⫅":"subE","⫅̸":"nsubE","⫆":"supE","⫆̸":"nsupE","⫇":"subsim","⫈":"supsim","⫋︀":"vsubnE","⫋":"subnE","⫌︀":"vsupnE","⫌":"supnE","⫏":"csub","⫐":"csup","⫑":"csube","⫒":"csupe","⫓":"subsup","⫔":"supsub","⫕":"subsub","⫖":"supsup","⫗":"suphsub","⫘":"supdsub","⫙":"forkv","⫚":"topfork","⫛":"mlcp","⫤":"Dashv","⫦":"Vdashl","⫧":"Barv","⫨":"vBar","⫩":"vBarv","⫫":"Vbar","⫬":"Not","⫭":"bNot","⫮":"rnmid","⫯":"cirmid","⫰":"midcir","⫱":"topcir","⫲":"nhpar","⫳":"parsim","⫽":"parsl","⫽⃥":"nparsl","♭":"flat","♮":"natur","♯":"sharp","¤":"curren","¢":"cent",$:"dollar","£":"pound","¥":"yen","€":"euro","¹":"sup1","½":"half","⅓":"frac13","¼":"frac14","⅕":"frac15","⅙":"frac16","⅛":"frac18","²":"sup2","⅔":"frac23","⅖":"frac25","³":"sup3","¾":"frac34","⅗":"frac35","⅜":"frac38","⅘":"frac45","⅚":"frac56","⅝":"frac58","⅞":"frac78","𝒶":"ascr","𝕒":"aopf","𝔞":"afr","𝔸":"Aopf","𝔄":"Afr","𝒜":"Ascr",ª:"ordf",á:"aacute",Á:"Aacute",à:"agrave",À:"Agrave",ă:"abreve",Ă:"Abreve",â:"acirc",Â:"Acirc",å:"aring",Å:"angst",ä:"auml",Ä:"Auml",ã:"atilde",Ã:"Atilde",ą:"aogon",Ą:"Aogon",ā:"amacr",Ā:"Amacr",æ:"aelig",Æ:"AElig","𝒷":"bscr","𝕓":"bopf","𝔟":"bfr","𝔹":"Bopf",ℬ:"Bscr","𝔅":"Bfr","𝔠":"cfr","𝒸":"cscr","𝕔":"copf",ℭ:"Cfr","𝒞":"Cscr",ℂ:"Copf",ć:"cacute",Ć:"Cacute",ĉ:"ccirc",Ĉ:"Ccirc",č:"ccaron",Č:"Ccaron",ċ:"cdot",Ċ:"Cdot",ç:"ccedil",Ç:"Ccedil","℅":"incare","𝔡":"dfr","ⅆ":"dd","𝕕":"dopf","𝒹":"dscr","𝒟":"Dscr","𝔇":"Dfr","ⅅ":"DD","𝔻":"Dopf",ď:"dcaron",Ď:"Dcaron",đ:"dstrok",Đ:"Dstrok",ð:"eth",Ð:"ETH","ⅇ":"ee",ℯ:"escr","𝔢":"efr","𝕖":"eopf",ℰ:"Escr","𝔈":"Efr","𝔼":"Eopf",é:"eacute",É:"Eacute",è:"egrave",È:"Egrave",ê:"ecirc",Ê:"Ecirc",ě:"ecaron",Ě:"Ecaron",ë:"euml",Ë:"Euml",ė:"edot",Ė:"Edot",ę:"eogon",Ę:"Eogon",ē:"emacr",Ē:"Emacr","𝔣":"ffr","𝕗":"fopf","𝒻":"fscr","𝔉":"Ffr","𝔽":"Fopf",ℱ:"Fscr",ﬀ:"fflig",ﬃ:"ffilig",ﬄ:"ffllig",ﬁ:"filig",fj:"fjlig",ﬂ:"fllig",ƒ:"fnof",ℊ:"gscr","𝕘":"gopf","𝔤":"gfr","𝒢":"Gscr","𝔾":"Gopf","𝔊":"Gfr",ǵ:"gacute",ğ:"gbreve",Ğ:"Gbreve",ĝ:"gcirc",Ĝ:"Gcirc",ġ:"gdot",Ġ:"Gdot",Ģ:"Gcedil","𝔥":"hfr",ℎ:"planckh","𝒽":"hscr","𝕙":"hopf",ℋ:"Hscr",ℌ:"Hfr",ℍ:"Hopf",ĥ:"hcirc",Ĥ:"Hcirc",ℏ:"hbar",ħ:"hstrok",Ħ:"Hstrok","𝕚":"iopf","𝔦":"ifr","𝒾":"iscr","ⅈ":"ii","𝕀":"Iopf",ℐ:"Iscr",ℑ:"Im",í:"iacute",Í:"Iacute",ì:"igrave",Ì:"Igrave",î:"icirc",Î:"Icirc",ï:"iuml",Ï:"Iuml",ĩ:"itilde",Ĩ:"Itilde",İ:"Idot",į:"iogon",Į:"Iogon",ī:"imacr",Ī:"Imacr",ĳ:"ijlig",Ĳ:"IJlig",ı:"imath","𝒿":"jscr","𝕛":"jopf","𝔧":"jfr","𝒥":"Jscr","𝔍":"Jfr","𝕁":"Jopf",ĵ:"jcirc",Ĵ:"Jcirc","ȷ":"jmath","𝕜":"kopf","𝓀":"kscr","𝔨":"kfr","𝒦":"Kscr","𝕂":"Kopf","𝔎":"Kfr",ķ:"kcedil",Ķ:"Kcedil","𝔩":"lfr","𝓁":"lscr",ℓ:"ell","𝕝":"lopf",ℒ:"Lscr","𝔏":"Lfr","𝕃":"Lopf",ĺ:"lacute",Ĺ:"Lacute",ľ:"lcaron",Ľ:"Lcaron",ļ:"lcedil",Ļ:"Lcedil",ł:"lstrok",Ł:"Lstrok",ŀ:"lmidot",Ŀ:"Lmidot","𝔪":"mfr","𝕞":"mopf","𝓂":"mscr","𝔐":"Mfr","𝕄":"Mopf",ℳ:"Mscr","𝔫":"nfr","𝕟":"nopf","𝓃":"nscr",ℕ:"Nopf","𝒩":"Nscr","𝔑":"Nfr",ń:"nacute",Ń:"Nacute",ň:"ncaron",Ň:"Ncaron",ñ:"ntilde",Ñ:"Ntilde",ņ:"ncedil",Ņ:"Ncedil","№":"numero",ŋ:"eng",Ŋ:"ENG","𝕠":"oopf","𝔬":"ofr",ℴ:"oscr","𝒪":"Oscr","𝔒":"Ofr","𝕆":"Oopf",º:"ordm",ó:"oacute",Ó:"Oacute",ò:"ograve",Ò:"Ograve",ô:"ocirc",Ô:"Ocirc",ö:"ouml",Ö:"Ouml",ő:"odblac",Ő:"Odblac",õ:"otilde",Õ:"Otilde",ø:"oslash",Ø:"Oslash",ō:"omacr",Ō:"Omacr",œ:"oelig",Œ:"OElig","𝔭":"pfr","𝓅":"pscr","𝕡":"popf",ℙ:"Popf","𝔓":"Pfr","𝒫":"Pscr","𝕢":"qopf","𝔮":"qfr","𝓆":"qscr","𝒬":"Qscr","𝔔":"Qfr",ℚ:"Qopf",ĸ:"kgreen","𝔯":"rfr","𝕣":"ropf","𝓇":"rscr",ℛ:"Rscr",ℜ:"Re",ℝ:"Ropf",ŕ:"racute",Ŕ:"Racute",ř:"rcaron",Ř:"Rcaron",ŗ:"rcedil",Ŗ:"Rcedil","𝕤":"sopf","𝓈":"sscr","𝔰":"sfr","𝕊":"Sopf","𝔖":"Sfr","𝒮":"Sscr","Ⓢ":"oS",ś:"sacute",Ś:"Sacute",ŝ:"scirc",Ŝ:"Scirc",š:"scaron",Š:"Scaron",ş:"scedil",Ş:"Scedil",ß:"szlig","𝔱":"tfr","𝓉":"tscr","𝕥":"topf","𝒯":"Tscr","𝔗":"Tfr","𝕋":"Topf",ť:"tcaron",Ť:"Tcaron",ţ:"tcedil",Ţ:"Tcedil","™":"trade",ŧ:"tstrok",Ŧ:"Tstrok","𝓊":"uscr","𝕦":"uopf","𝔲":"ufr","𝕌":"Uopf","𝔘":"Ufr","𝒰":"Uscr",ú:"uacute",Ú:"Uacute",ù:"ugrave",Ù:"Ugrave",ŭ:"ubreve",Ŭ:"Ubreve",û:"ucirc",Û:"Ucirc",ů:"uring",Ů:"Uring",ü:"uuml",Ü:"Uuml",ű:"udblac",Ű:"Udblac",ũ:"utilde",Ũ:"Utilde",ų:"uogon",Ų:"Uogon",ū:"umacr",Ū:"Umacr","𝔳":"vfr","𝕧":"vopf","𝓋":"vscr","𝔙":"Vfr","𝕍":"Vopf","𝒱":"Vscr","𝕨":"wopf","𝓌":"wscr","𝔴":"wfr","𝒲":"Wscr","𝕎":"Wopf","𝔚":"Wfr",ŵ:"wcirc",Ŵ:"Wcirc","𝔵":"xfr","𝓍":"xscr","𝕩":"xopf","𝕏":"Xopf","𝔛":"Xfr","𝒳":"Xscr","𝔶":"yfr","𝓎":"yscr","𝕪":"yopf","𝒴":"Yscr","𝔜":"Yfr","𝕐":"Yopf",ý:"yacute",Ý:"Yacute",ŷ:"ycirc",Ŷ:"Ycirc",ÿ:"yuml",Ÿ:"Yuml","𝓏":"zscr","𝔷":"zfr","𝕫":"zopf",ℨ:"Zfr",ℤ:"Zopf","𝒵":"Zscr",ź:"zacute",Ź:"Zacute",ž:"zcaron",Ž:"Zcaron",ż:"zdot",Ż:"Zdot",Ƶ:"imped",þ:"thorn",Þ:"THORN",ŉ:"napos",α:"alpha",Α:"Alpha",β:"beta",Β:"Beta",γ:"gamma",Γ:"Gamma",δ:"delta",Δ:"Delta",ε:"epsi","ϵ":"epsiv",Ε:"Epsilon",ϝ:"gammad",Ϝ:"Gammad",ζ:"zeta",Ζ:"Zeta",η:"eta",Η:"Eta",θ:"theta",ϑ:"thetav",Θ:"Theta",ι:"iota",Ι:"Iota",κ:"kappa",ϰ:"kappav",Κ:"Kappa",λ:"lambda",Λ:"Lambda",μ:"mu",µ:"micro",Μ:"Mu",ν:"nu",Ν:"Nu",ξ:"xi",Ξ:"Xi",ο:"omicron",Ο:"Omicron",π:"pi",ϖ:"piv",Π:"Pi",ρ:"rho",ϱ:"rhov",Ρ:"Rho",σ:"sigma",Σ:"Sigma",ς:"sigmaf",τ:"tau",Τ:"Tau",υ:"upsi",Υ:"Upsilon",ϒ:"Upsi",φ:"phi",ϕ:"phiv",Φ:"Phi",χ:"chi",Χ:"Chi",ψ:"psi",Ψ:"Psi",ω:"omega",Ω:"ohm",а:"acy",А:"Acy",б:"bcy",Б:"Bcy",в:"vcy",В:"Vcy",г:"gcy",Г:"Gcy",ѓ:"gjcy",Ѓ:"GJcy",д:"dcy",Д:"Dcy",ђ:"djcy",Ђ:"DJcy",е:"iecy",Е:"IEcy",ё:"iocy",Ё:"IOcy",є:"jukcy",Є:"Jukcy",ж:"zhcy",Ж:"ZHcy",з:"zcy",З:"Zcy",ѕ:"dscy",Ѕ:"DScy",и:"icy",И:"Icy",і:"iukcy",І:"Iukcy",ї:"yicy",Ї:"YIcy",й:"jcy",Й:"Jcy",ј:"jsercy",Ј:"Jsercy",к:"kcy",К:"Kcy",ќ:"kjcy",Ќ:"KJcy",л:"lcy",Л:"Lcy",љ:"ljcy",Љ:"LJcy",м:"mcy",М:"Mcy",н:"ncy",Н:"Ncy",њ:"njcy",Њ:"NJcy",о:"ocy",О:"Ocy",п:"pcy",П:"Pcy",р:"rcy",Р:"Rcy",с:"scy",С:"Scy",т:"tcy",Т:"Tcy",ћ:"tshcy",Ћ:"TSHcy",у:"ucy",У:"Ucy",ў:"ubrcy",Ў:"Ubrcy",ф:"fcy",Ф:"Fcy",х:"khcy",Х:"KHcy",ц:"tscy",Ц:"TScy",ч:"chcy",Ч:"CHcy",џ:"dzcy",Џ:"DZcy",ш:"shcy",Ш:"SHcy",щ:"shchcy",Щ:"SHCHcy",ъ:"hardcy",Ъ:"HARDcy",ы:"ycy",Ы:"Ycy",ь:"softcy",Ь:"SOFTcy",э:"ecy",Э:"Ecy",ю:"yucy",Ю:"YUcy",я:"yacy",Я:"YAcy",ℵ:"aleph",ℶ:"beth",ℷ:"gimel",ℸ:"daleth"},y=/["&'<>`]/g,_={'"':"&quot;","&":"&amp;","'":"&#x27;","<":"&lt;",">":"&gt;","`":"&#x60;"},S=/&#(?:[xX][^a-fA-F0-9]|[^0-9xX])/,E=/[\0-\x08\x0B\x0E-\x1F\x7F-\x9F\uFDD0-\uFDEF\uFFFE\uFFFF]|[\uD83F\uD87F\uD8BF\uD8FF\uD93F\uD97F\uD9BF\uD9FF\uDA3F\uDA7F\uDABF\uDAFF\uDB3F\uDB7F\uDBBF\uDBFF][\uDFFE\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/,R=/&(CounterClockwiseContourIntegral|DoubleLongLeftRightArrow|ClockwiseContourIntegral|NotNestedGreaterGreater|NotSquareSupersetEqual|DiacriticalDoubleAcute|NotRightTriangleEqual|NotSucceedsSlantEqual|NotPrecedesSlantEqual|CloseCurlyDoubleQuote|NegativeVeryThinSpace|DoubleContourIntegral|FilledVerySmallSquare|CapitalDifferentialD|OpenCurlyDoubleQuote|EmptyVerySmallSquare|NestedGreaterGreater|DoubleLongRightArrow|NotLeftTriangleEqual|NotGreaterSlantEqual|ReverseUpEquilibrium|DoubleLeftRightArrow|NotSquareSubsetEqual|NotDoubleVerticalBar|RightArrowLeftArrow|NotGreaterFullEqual|NotRightTriangleBar|SquareSupersetEqual|DownLeftRightVector|DoubleLongLeftArrow|leftrightsquigarrow|LeftArrowRightArrow|NegativeMediumSpace|blacktriangleright|RightDownVectorBar|PrecedesSlantEqual|RightDoubleBracket|SucceedsSlantEqual|NotLeftTriangleBar|RightTriangleEqual|SquareIntersection|RightDownTeeVector|ReverseEquilibrium|NegativeThickSpace|longleftrightarrow|Longleftrightarrow|LongLeftRightArrow|DownRightTeeVector|DownRightVectorBar|GreaterSlantEqual|SquareSubsetEqual|LeftDownVectorBar|LeftDoubleBracket|VerticalSeparator|rightleftharpoons|NotGreaterGreater|NotSquareSuperset|blacktriangleleft|blacktriangledown|NegativeThinSpace|LeftDownTeeVector|NotLessSlantEqual|leftrightharpoons|DoubleUpDownArrow|DoubleVerticalBar|LeftTriangleEqual|FilledSmallSquare|twoheadrightarrow|NotNestedLessLess|DownLeftTeeVector|DownLeftVectorBar|RightAngleBracket|NotTildeFullEqual|NotReverseElement|RightUpDownVector|DiacriticalTilde|NotSucceedsTilde|circlearrowright|NotPrecedesEqual|rightharpoondown|DoubleRightArrow|NotSucceedsEqual|NonBreakingSpace|NotRightTriangle|LessEqualGreater|RightUpTeeVector|LeftAngleBracket|GreaterFullEqual|DownArrowUpArrow|RightUpVectorBar|twoheadleftarrow|GreaterEqualLess|downharpoonright|RightTriangleBar|ntrianglerighteq|NotSupersetEqual|LeftUpDownVector|DiacriticalAcute|rightrightarrows|vartriangleright|UpArrowDownArrow|DiacriticalGrave|UnderParenthesis|EmptySmallSquare|LeftUpVectorBar|leftrightarrows|DownRightVector|downharpoonleft|trianglerighteq|ShortRightArrow|OverParenthesis|DoubleLeftArrow|DoubleDownArrow|NotSquareSubset|bigtriangledown|ntrianglelefteq|UpperRightArrow|curvearrowright|vartriangleleft|NotLeftTriangle|nleftrightarrow|LowerRightArrow|NotHumpDownHump|NotGreaterTilde|rightthreetimes|LeftUpTeeVector|NotGreaterEqual|straightepsilon|LeftTriangleBar|rightsquigarrow|ContourIntegral|rightleftarrows|CloseCurlyQuote|RightDownVector|LeftRightVector|nLeftrightarrow|leftharpoondown|circlearrowleft|SquareSuperset|OpenCurlyQuote|hookrightarrow|HorizontalLine|DiacriticalDot|NotLessGreater|ntriangleright|DoubleRightTee|InvisibleComma|InvisibleTimes|LowerLeftArrow|DownLeftVector|NotSubsetEqual|curvearrowleft|trianglelefteq|NotVerticalBar|TildeFullEqual|downdownarrows|NotGreaterLess|RightTeeVector|ZeroWidthSpace|looparrowright|LongRightArrow|doublebarwedge|ShortLeftArrow|ShortDownArrow|RightVectorBar|GreaterGreater|ReverseElement|rightharpoonup|LessSlantEqual|leftthreetimes|upharpoonright|rightarrowtail|LeftDownVector|Longrightarrow|NestedLessLess|UpperLeftArrow|nshortparallel|leftleftarrows|leftrightarrow|Leftrightarrow|LeftRightArrow|longrightarrow|upharpoonleft|RightArrowBar|ApplyFunction|LeftTeeVector|leftarrowtail|NotEqualTilde|varsubsetneqq|varsupsetneqq|RightTeeArrow|SucceedsEqual|SucceedsTilde|LeftVectorBar|SupersetEqual|hookleftarrow|DifferentialD|VerticalTilde|VeryThinSpace|blacktriangle|bigtriangleup|LessFullEqual|divideontimes|leftharpoonup|UpEquilibrium|ntriangleleft|RightTriangle|measuredangle|shortparallel|longleftarrow|Longleftarrow|LongLeftArrow|DoubleLeftTee|Poincareplane|PrecedesEqual|triangleright|DoubleUpArrow|RightUpVector|fallingdotseq|looparrowleft|PrecedesTilde|NotTildeEqual|NotTildeTilde|smallsetminus|Proportional|triangleleft|triangledown|UnderBracket|NotHumpEqual|exponentiale|ExponentialE|NotLessTilde|HilbertSpace|RightCeiling|blacklozenge|varsupsetneq|HumpDownHump|GreaterEqual|VerticalLine|LeftTeeArrow|NotLessEqual|DownTeeArrow|LeftTriangle|varsubsetneq|Intersection|NotCongruent|DownArrowBar|LeftUpVector|LeftArrowBar|risingdotseq|GreaterTilde|RoundImplies|SquareSubset|ShortUpArrow|NotSuperset|quaternions|precnapprox|backepsilon|preccurlyeq|OverBracket|blacksquare|MediumSpace|VerticalBar|circledcirc|circleddash|CircleMinus|CircleTimes|LessGreater|curlyeqprec|curlyeqsucc|diamondsuit|UpDownArrow|Updownarrow|RuleDelayed|Rrightarrow|updownarrow|RightVector|nRightarrow|nrightarrow|eqslantless|LeftCeiling|Equilibrium|SmallCircle|expectation|NotSucceeds|thickapprox|GreaterLess|SquareUnion|NotPrecedes|NotLessLess|straightphi|succnapprox|succcurlyeq|SubsetEqual|sqsupseteq|Proportion|Laplacetrf|ImaginaryI|supsetneqq|NotGreater|gtreqqless|NotElement|ThickSpace|TildeEqual|TildeTilde|Fouriertrf|rmoustache|EqualTilde|eqslantgtr|UnderBrace|LeftVector|UpArrowBar|nLeftarrow|nsubseteqq|subsetneqq|nsupseteqq|nleftarrow|succapprox|lessapprox|UpTeeArrow|upuparrows|curlywedge|lesseqqgtr|varepsilon|varnothing|RightFloor|complement|CirclePlus|sqsubseteq|Lleftarrow|circledast|RightArrow|Rightarrow|rightarrow|lmoustache|Bernoullis|precapprox|mapstoleft|mapstodown|longmapsto|dotsquare|downarrow|DoubleDot|nsubseteq|supsetneq|leftarrow|nsupseteq|subsetneq|ThinSpace|ngeqslant|subseteqq|HumpEqual|NotSubset|triangleq|NotCupCap|lesseqgtr|heartsuit|TripleDot|Leftarrow|Coproduct|Congruent|varpropto|complexes|gvertneqq|LeftArrow|LessTilde|supseteqq|MinusPlus|CircleDot|nleqslant|NotExists|gtreqless|nparallel|UnionPlus|LeftFloor|checkmark|CenterDot|centerdot|Mellintrf|gtrapprox|bigotimes|OverBrace|spadesuit|therefore|pitchfork|rationals|PlusMinus|Backslash|Therefore|DownBreve|backsimeq|backprime|DownArrow|nshortmid|Downarrow|lvertneqq|eqvparsl|imagline|imagpart|infintie|integers|Integral|intercal|LessLess|Uarrocir|intlarhk|sqsupset|angmsdaf|sqsubset|llcorner|vartheta|cupbrcap|lnapprox|Superset|SuchThat|succnsim|succneqq|angmsdag|biguplus|curlyvee|trpezium|Succeeds|NotTilde|bigwedge|angmsdah|angrtvbd|triminus|cwconint|fpartint|lrcorner|smeparsl|subseteq|urcorner|lurdshar|laemptyv|DDotrahd|approxeq|ldrushar|awconint|mapstoup|backcong|shortmid|triangle|geqslant|gesdotol|timesbar|circledR|circledS|setminus|multimap|naturals|scpolint|ncongdot|RightTee|boxminus|gnapprox|boxtimes|andslope|thicksim|angmsdaa|varsigma|cirfnint|rtriltri|angmsdab|rppolint|angmsdac|barwedge|drbkarow|clubsuit|thetasym|bsolhsub|capbrcup|dzigrarr|doteqdot|DotEqual|dotminus|UnderBar|NotEqual|realpart|otimesas|ulcorner|hksearow|hkswarow|parallel|PartialD|elinters|emptyset|plusacir|bbrktbrk|angmsdad|pointint|bigoplus|angmsdae|Precedes|bigsqcup|varkappa|notindot|supseteq|precneqq|precnsim|profalar|profline|profsurf|leqslant|lesdotor|raemptyv|subplus|notnivb|notnivc|subrarr|zigrarr|vzigzag|submult|subedot|Element|between|cirscir|larrbfs|larrsim|lotimes|lbrksld|lbrkslu|lozenge|ldrdhar|dbkarow|bigcirc|epsilon|simrarr|simplus|ltquest|Epsilon|luruhar|gtquest|maltese|npolint|eqcolon|npreceq|bigodot|ddagger|gtrless|bnequiv|harrcir|ddotseq|equivDD|backsim|demptyv|nsqsube|nsqsupe|Upsilon|nsubset|upsilon|minusdu|nsucceq|swarrow|nsupset|coloneq|searrow|boxplus|napprox|natural|asympeq|alefsym|congdot|nearrow|bigstar|diamond|supplus|tritime|LeftTee|nvinfin|triplus|NewLine|nvltrie|nvrtrie|nwarrow|nexists|Diamond|ruluhar|Implies|supmult|angzarr|suplarr|suphsub|questeq|because|digamma|Because|olcross|bemptyv|omicron|Omicron|rotimes|NoBreak|intprod|angrtvb|orderof|uwangle|suphsol|lesdoto|orslope|DownTee|realine|cudarrl|rdldhar|OverBar|supedot|lessdot|supdsub|topfork|succsim|rbrkslu|rbrksld|pertenk|cudarrr|isindot|planckh|lessgtr|pluscir|gesdoto|plussim|plustwo|lesssim|cularrp|rarrsim|Cayleys|notinva|notinvb|notinvc|UpArrow|Uparrow|uparrow|NotLess|dwangle|precsim|Product|curarrm|Cconint|dotplus|rarrbfs|ccupssm|Cedilla|cemptyv|notniva|quatint|frac35|frac38|frac45|frac56|frac58|frac78|tridot|xoplus|gacute|gammad|Gammad|lfisht|lfloor|bigcup|sqsupe|gbreve|Gbreve|lharul|sqsube|sqcups|Gcedil|apacir|llhard|lmidot|Lmidot|lmoust|andand|sqcaps|approx|Abreve|spades|circeq|tprime|divide|topcir|Assign|topbot|gesdot|divonx|xuplus|timesd|gesles|atilde|solbar|SOFTcy|loplus|timesb|lowast|lowbar|dlcorn|dlcrop|softcy|dollar|lparlt|thksim|lrhard|Atilde|lsaquo|smashp|bigvee|thinsp|wreath|bkarow|lsquor|lstrok|Lstrok|lthree|ltimes|ltlarr|DotDot|simdot|ltrPar|weierp|xsqcup|angmsd|sigmav|sigmaf|zeetrf|Zcaron|zcaron|mapsto|vsupne|thetav|cirmid|marker|mcomma|Zacute|vsubnE|there4|gtlPar|vsubne|bottom|gtrarr|SHCHcy|shchcy|midast|midcir|middot|minusb|minusd|gtrdot|bowtie|sfrown|mnplus|models|colone|seswar|Colone|mstpos|searhk|gtrsim|nacute|Nacute|boxbox|telrec|hairsp|Tcedil|nbumpe|scnsim|ncaron|Ncaron|ncedil|Ncedil|hamilt|Scedil|nearhk|hardcy|HARDcy|tcedil|Tcaron|commat|nequiv|nesear|tcaron|target|hearts|nexist|varrho|scedil|Scaron|scaron|hellip|Sacute|sacute|hercon|swnwar|compfn|rtimes|rthree|rsquor|rsaquo|zacute|wedgeq|homtht|barvee|barwed|Barwed|rpargt|horbar|conint|swarhk|roplus|nltrie|hslash|hstrok|Hstrok|rmoust|Conint|bprime|hybull|hyphen|iacute|Iacute|supsup|supsub|supsim|varphi|coprod|brvbar|agrave|Supset|supset|igrave|Igrave|notinE|Agrave|iiiint|iinfin|copysr|wedbar|Verbar|vangrt|becaus|incare|verbar|inodot|bullet|drcorn|intcal|drcrop|cularr|vellip|Utilde|bumpeq|cupcap|dstrok|Dstrok|CupCap|cupcup|cupdot|eacute|Eacute|supdot|iquest|easter|ecaron|Ecaron|ecolon|isinsv|utilde|itilde|Itilde|curarr|succeq|Bumpeq|cacute|ulcrop|nparsl|Cacute|nprcue|egrave|Egrave|nrarrc|nrarrw|subsup|subsub|nrtrie|jsercy|nsccue|Jsercy|kappav|kcedil|Kcedil|subsim|ulcorn|nsimeq|egsdot|veebar|kgreen|capand|elsdot|Subset|subset|curren|aacute|lacute|Lacute|emptyv|ntilde|Ntilde|lagran|lambda|Lambda|capcap|Ugrave|langle|subdot|emsp13|numero|emsp14|nvdash|nvDash|nVdash|nVDash|ugrave|ufisht|nvHarr|larrfs|nvlArr|larrhk|larrlp|larrpl|nvrArr|Udblac|nwarhk|larrtl|nwnear|oacute|Oacute|latail|lAtail|sstarf|lbrace|odblac|Odblac|lbrack|udblac|odsold|eparsl|lcaron|Lcaron|ograve|Ograve|lcedil|Lcedil|Aacute|ssmile|ssetmn|squarf|ldquor|capcup|ominus|cylcty|rharul|eqcirc|dagger|rfloor|rfisht|Dagger|daleth|equals|origof|capdot|equest|dcaron|Dcaron|rdquor|oslash|Oslash|otilde|Otilde|otimes|Otimes|urcrop|Ubreve|ubreve|Yacute|Uacute|uacute|Rcedil|rcedil|urcorn|parsim|Rcaron|Vdashl|rcaron|Tstrok|percnt|period|permil|Exists|yacute|rbrack|rbrace|phmmat|ccaron|Ccaron|planck|ccedil|plankv|tstrok|female|plusdo|plusdu|ffilig|plusmn|ffllig|Ccedil|rAtail|dfisht|bernou|ratail|Rarrtl|rarrtl|angsph|rarrpl|rarrlp|rarrhk|xwedge|xotime|forall|ForAll|Vvdash|vsupnE|preceq|bigcap|frac12|frac13|frac14|primes|rarrfs|prnsim|frac15|Square|frac16|square|lesdot|frac18|frac23|propto|prurel|rarrap|rangle|puncsp|frac25|Racute|qprime|racute|lesges|frac34|abreve|AElig|eqsim|utdot|setmn|urtri|Equal|Uring|seArr|uring|searr|dashv|Dashv|mumap|nabla|iogon|Iogon|sdote|sdotb|scsim|napid|napos|equiv|natur|Acirc|dblac|erarr|nbump|iprod|erDot|ucirc|awint|esdot|angrt|ncong|isinE|scnap|Scirc|scirc|ndash|isins|Ubrcy|nearr|neArr|isinv|nedot|ubrcy|acute|Ycirc|iukcy|Iukcy|xutri|nesim|caret|jcirc|Jcirc|caron|twixt|ddarr|sccue|exist|jmath|sbquo|ngeqq|angst|ccaps|lceil|ngsim|UpTee|delta|Delta|rtrif|nharr|nhArr|nhpar|rtrie|jukcy|Jukcy|kappa|rsquo|Kappa|nlarr|nlArr|TSHcy|rrarr|aogon|Aogon|fflig|xrarr|tshcy|ccirc|nleqq|filig|upsih|nless|dharl|nlsim|fjlig|ropar|nltri|dharr|robrk|roarr|fllig|fltns|roang|rnmid|subnE|subne|lAarr|trisb|Ccirc|acirc|ccups|blank|VDash|forkv|Vdash|langd|cedil|blk12|blk14|laquo|strns|diams|notin|vDash|larrb|blk34|block|disin|uplus|vdash|vBarv|aelig|starf|Wedge|check|xrArr|lates|lbarr|lBarr|notni|lbbrk|bcong|frasl|lbrke|frown|vrtri|vprop|vnsup|gamma|Gamma|wedge|xodot|bdquo|srarr|doteq|ldquo|boxdl|boxdL|gcirc|Gcirc|boxDl|boxDL|boxdr|boxdR|boxDr|TRADE|trade|rlhar|boxDR|vnsub|npart|vltri|rlarr|boxhd|boxhD|nprec|gescc|nrarr|nrArr|boxHd|boxHD|boxhu|boxhU|nrtri|boxHu|clubs|boxHU|times|colon|Colon|gimel|xlArr|Tilde|nsime|tilde|nsmid|nspar|THORN|thorn|xlarr|nsube|nsubE|thkap|xhArr|comma|nsucc|boxul|boxuL|nsupe|nsupE|gneqq|gnsim|boxUl|boxUL|grave|boxur|boxuR|boxUr|boxUR|lescc|angle|bepsi|boxvh|varpi|boxvH|numsp|Theta|gsime|gsiml|theta|boxVh|boxVH|boxvl|gtcir|gtdot|boxvL|boxVl|boxVL|crarr|cross|Cross|nvsim|boxvr|nwarr|nwArr|sqsup|dtdot|Uogon|lhard|lharu|dtrif|ocirc|Ocirc|lhblk|duarr|odash|sqsub|Hacek|sqcup|llarr|duhar|oelig|OElig|ofcir|boxvR|uogon|lltri|boxVr|csube|uuarr|ohbar|csupe|ctdot|olarr|olcir|harrw|oline|sqcap|omacr|Omacr|omega|Omega|boxVR|aleph|lneqq|lnsim|loang|loarr|rharu|lobrk|hcirc|operp|oplus|rhard|Hcirc|orarr|Union|order|ecirc|Ecirc|cuepr|szlig|cuesc|breve|reals|eDDot|Breve|hoarr|lopar|utrif|rdquo|Umacr|umacr|efDot|swArr|ultri|alpha|rceil|ovbar|swarr|Wcirc|wcirc|smtes|smile|bsemi|lrarr|aring|parsl|lrhar|bsime|uhblk|lrtri|cupor|Aring|uharr|uharl|slarr|rbrke|bsolb|lsime|rbbrk|RBarr|lsimg|phone|rBarr|rbarr|icirc|lsquo|Icirc|emacr|Emacr|ratio|simne|plusb|simlE|simgE|simeq|pluse|ltcir|ltdot|empty|xharr|xdtri|iexcl|Alpha|ltrie|rarrw|pound|ltrif|xcirc|bumpe|prcue|bumpE|asymp|amacr|cuvee|Sigma|sigma|iiint|udhar|iiota|ijlig|IJlig|supnE|imacr|Imacr|prime|Prime|image|prnap|eogon|Eogon|rarrc|mdash|mDDot|cuwed|imath|supne|imped|Amacr|udarr|prsim|micro|rarrb|cwint|raquo|infin|eplus|range|rangd|Ucirc|radic|minus|amalg|veeeq|rAarr|epsiv|ycirc|quest|sharp|quot|zwnj|Qscr|race|qscr|Qopf|qopf|qint|rang|Rang|Zscr|zscr|Zopf|zopf|rarr|rArr|Rarr|Pscr|pscr|prop|prod|prnE|prec|ZHcy|zhcy|prap|Zeta|zeta|Popf|popf|Zdot|plus|zdot|Yuml|yuml|phiv|YUcy|yucy|Yscr|yscr|perp|Yopf|yopf|part|para|YIcy|Ouml|rcub|yicy|YAcy|rdca|ouml|osol|Oscr|rdsh|yacy|real|oscr|xvee|andd|rect|andv|Xscr|oror|ordm|ordf|xscr|ange|aopf|Aopf|rHar|Xopf|opar|Oopf|xopf|xnis|rhov|oopf|omid|xmap|oint|apid|apos|ogon|ascr|Ascr|odot|odiv|xcup|xcap|ocir|oast|nvlt|nvle|nvgt|nvge|nvap|Wscr|wscr|auml|ntlg|ntgl|nsup|nsub|nsim|Nscr|nscr|nsce|Wopf|ring|npre|wopf|npar|Auml|Barv|bbrk|Nopf|nopf|nmid|nLtv|beta|ropf|Ropf|Beta|beth|nles|rpar|nleq|bnot|bNot|nldr|NJcy|rscr|Rscr|Vscr|vscr|rsqb|njcy|bopf|nisd|Bopf|rtri|Vopf|nGtv|ngtr|vopf|boxh|boxH|boxv|nges|ngeq|boxV|bscr|scap|Bscr|bsim|Vert|vert|bsol|bull|bump|caps|cdot|ncup|scnE|ncap|nbsp|napE|Cdot|cent|sdot|Vbar|nang|vBar|chcy|Mscr|mscr|sect|semi|CHcy|Mopf|mopf|sext|circ|cire|mldr|mlcp|cirE|comp|shcy|SHcy|vArr|varr|cong|copf|Copf|copy|COPY|malt|male|macr|lvnE|cscr|ltri|sime|ltcc|simg|Cscr|siml|csub|Uuml|lsqb|lsim|uuml|csup|Lscr|lscr|utri|smid|lpar|cups|smte|lozf|darr|Lopf|Uscr|solb|lopf|sopf|Sopf|lneq|uscr|spar|dArr|lnap|Darr|dash|Sqrt|LJcy|ljcy|lHar|dHar|Upsi|upsi|diam|lesg|djcy|DJcy|leqq|dopf|Dopf|dscr|Dscr|dscy|ldsh|ldca|squf|DScy|sscr|Sscr|dsol|lcub|late|star|Star|Uopf|Larr|lArr|larr|uopf|dtri|dzcy|sube|subE|Lang|lang|Kscr|kscr|Kopf|kopf|KJcy|kjcy|KHcy|khcy|DZcy|ecir|edot|eDot|Jscr|jscr|succ|Jopf|jopf|Edot|uHar|emsp|ensp|Iuml|iuml|eopf|isin|Iscr|iscr|Eopf|epar|sung|epsi|escr|sup1|sup2|sup3|Iota|iota|supe|supE|Iopf|iopf|IOcy|iocy|Escr|esim|Esim|imof|Uarr|QUOT|uArr|uarr|euml|IEcy|iecy|Idot|Euml|euro|excl|Hscr|hscr|Hopf|hopf|TScy|tscy|Tscr|hbar|tscr|flat|tbrk|fnof|hArr|harr|half|fopf|Fopf|tdot|gvnE|fork|trie|gtcc|fscr|Fscr|gdot|gsim|Gscr|gscr|Gopf|gopf|gneq|Gdot|tosa|gnap|Topf|topf|geqq|toea|GJcy|gjcy|tint|gesl|mid|Sfr|ggg|top|ges|gla|glE|glj|geq|gne|gEl|gel|gnE|Gcy|gcy|gap|Tfr|tfr|Tcy|tcy|Hat|Tau|Ffr|tau|Tab|hfr|Hfr|ffr|Fcy|fcy|icy|Icy|iff|ETH|eth|ifr|Ifr|Eta|eta|int|Int|Sup|sup|ucy|Ucy|Sum|sum|jcy|ENG|ufr|Ufr|eng|Jcy|jfr|els|ell|egs|Efr|efr|Jfr|uml|kcy|Kcy|Ecy|ecy|kfr|Kfr|lap|Sub|sub|lat|lcy|Lcy|leg|Dot|dot|lEg|leq|les|squ|div|die|lfr|Lfr|lgE|Dfr|dfr|Del|deg|Dcy|dcy|lne|lnE|sol|loz|smt|Cup|lrm|cup|lsh|Lsh|sim|shy|map|Map|mcy|Mcy|mfr|Mfr|mho|gfr|Gfr|sfr|cir|Chi|chi|nap|Cfr|vcy|Vcy|cfr|Scy|scy|ncy|Ncy|vee|Vee|Cap|cap|nfr|scE|sce|Nfr|nge|ngE|nGg|vfr|Vfr|ngt|bot|nGt|nis|niv|Rsh|rsh|nle|nlE|bne|Bfr|bfr|nLl|nlt|nLt|Bcy|bcy|not|Not|rlm|wfr|Wfr|npr|nsc|num|ocy|ast|Ocy|ofr|xfr|Xfr|Ofr|ogt|ohm|apE|olt|Rho|ape|rho|Rfr|rfr|ord|REG|ang|reg|orv|And|and|AMP|Rcy|amp|Afr|ycy|Ycy|yen|yfr|Yfr|rcy|par|pcy|Pcy|pfr|Pfr|phi|Phi|afr|Acy|acy|zcy|Zcy|piv|acE|acd|zfr|Zfr|pre|prE|psi|Psi|qfr|Qfr|zwj|Or|ge|Gg|gt|gg|el|oS|lt|Lt|LT|Re|lg|gl|eg|ne|Im|it|le|DD|wp|wr|nu|Nu|dd|lE|Sc|sc|pi|Pi|ee|af|ll|Ll|rx|gE|xi|pm|Xi|ic|pr|Pr|in|ni|mp|mu|ac|Mu|or|ap|Gt|GT|ii);|&(Aacute|Agrave|Atilde|Ccedil|Eacute|Egrave|Iacute|Igrave|Ntilde|Oacute|Ograve|Oslash|Otilde|Uacute|Ugrave|Yacute|aacute|agrave|atilde|brvbar|ccedil|curren|divide|eacute|egrave|frac12|frac14|frac34|iacute|igrave|iquest|middot|ntilde|oacute|ograve|oslash|otilde|plusmn|uacute|ugrave|yacute|AElig|Acirc|Aring|Ecirc|Icirc|Ocirc|THORN|Ucirc|acirc|acute|aelig|aring|cedil|ecirc|icirc|iexcl|laquo|micro|ocirc|pound|raquo|szlig|thorn|times|ucirc|Auml|COPY|Euml|Iuml|Ouml|QUOT|Uuml|auml|cent|copy|euml|iuml|macr|nbsp|ordf|ordm|ouml|para|quot|sect|sup1|sup2|sup3|uuml|yuml|AMP|ETH|REG|amp|deg|eth|not|reg|shy|uml|yen|GT|LT|gt|lt)(?!;)([=a-zA-Z0-9]?)|&#([0-9]+)(;?)|&#[xX]([a-fA-F0-9]+)(;?)|&([0-9a-zA-Z]+)/g,I={aacute:"á",Aacute:"Á",abreve:"ă",Abreve:"Ă",ac:"∾",acd:"∿",acE:"∾̳",acirc:"â",Acirc:"Â",acute:"´",acy:"а",Acy:"А",aelig:"æ",AElig:"Æ",af:"⁡",afr:"𝔞",Afr:"𝔄",agrave:"à",Agrave:"À",alefsym:"ℵ",aleph:"ℵ",alpha:"α",Alpha:"Α",amacr:"ā",Amacr:"Ā",amalg:"⨿",amp:"&",AMP:"&",and:"∧",And:"⩓",andand:"⩕",andd:"⩜",andslope:"⩘",andv:"⩚",ang:"∠",ange:"⦤",angle:"∠",angmsd:"∡",angmsdaa:"⦨",angmsdab:"⦩",angmsdac:"⦪",angmsdad:"⦫",angmsdae:"⦬",angmsdaf:"⦭",angmsdag:"⦮",angmsdah:"⦯",angrt:"∟",angrtvb:"⊾",angrtvbd:"⦝",angsph:"∢",angst:"Å",angzarr:"⍼",aogon:"ą",Aogon:"Ą",aopf:"𝕒",Aopf:"𝔸",ap:"≈",apacir:"⩯",ape:"≊",apE:"⩰",apid:"≋",apos:"'",ApplyFunction:"⁡",approx:"≈",approxeq:"≊",aring:"å",Aring:"Å",ascr:"𝒶",Ascr:"𝒜",Assign:"≔",ast:"*",asymp:"≈",asympeq:"≍",atilde:"ã",Atilde:"Ã",auml:"ä",Auml:"Ä",awconint:"∳",awint:"⨑",backcong:"≌",backepsilon:"϶",backprime:"‵",backsim:"∽",backsimeq:"⋍",Backslash:"∖",Barv:"⫧",barvee:"⊽",barwed:"⌅",Barwed:"⌆",barwedge:"⌅",bbrk:"⎵",bbrktbrk:"⎶",bcong:"≌",bcy:"б",Bcy:"Б",bdquo:"„",becaus:"∵",because:"∵",Because:"∵",bemptyv:"⦰",bepsi:"϶",bernou:"ℬ",Bernoullis:"ℬ",beta:"β",Beta:"Β",beth:"ℶ",between:"≬",bfr:"𝔟",Bfr:"𝔅",bigcap:"⋂",bigcirc:"◯",bigcup:"⋃",bigodot:"⨀",bigoplus:"⨁",bigotimes:"⨂",bigsqcup:"⨆",bigstar:"★",bigtriangledown:"▽",bigtriangleup:"△",biguplus:"⨄",bigvee:"⋁",bigwedge:"⋀",bkarow:"⤍",blacklozenge:"⧫",blacksquare:"▪",blacktriangle:"▴",blacktriangledown:"▾",blacktriangleleft:"◂",blacktriangleright:"▸",blank:"␣",blk12:"▒",blk14:"░",blk34:"▓",block:"█",bne:"=⃥",bnequiv:"≡⃥",bnot:"⌐",bNot:"⫭",bopf:"𝕓",Bopf:"𝔹",bot:"⊥",bottom:"⊥",bowtie:"⋈",boxbox:"⧉",boxdl:"┐",boxdL:"╕",boxDl:"╖",boxDL:"╗",boxdr:"┌",boxdR:"╒",boxDr:"╓",boxDR:"╔",boxh:"─",boxH:"═",boxhd:"┬",boxhD:"╥",boxHd:"╤",boxHD:"╦",boxhu:"┴",boxhU:"╨",boxHu:"╧",boxHU:"╩",boxminus:"⊟",boxplus:"⊞",boxtimes:"⊠",boxul:"┘",boxuL:"╛",boxUl:"╜",boxUL:"╝",boxur:"└",boxuR:"╘",boxUr:"╙",boxUR:"╚",boxv:"│",boxV:"║",boxvh:"┼",boxvH:"╪",boxVh:"╫",boxVH:"╬",boxvl:"┤",boxvL:"╡",boxVl:"╢",boxVL:"╣",boxvr:"├",boxvR:"╞",boxVr:"╟",boxVR:"╠",bprime:"‵",breve:"˘",Breve:"˘",brvbar:"¦",bscr:"𝒷",Bscr:"ℬ",bsemi:"⁏",bsim:"∽",bsime:"⋍",bsol:"\\",bsolb:"⧅",bsolhsub:"⟈",bull:"•",bullet:"•",bump:"≎",bumpe:"≏",bumpE:"⪮",bumpeq:"≏",Bumpeq:"≎",cacute:"ć",Cacute:"Ć",cap:"∩",Cap:"⋒",capand:"⩄",capbrcup:"⩉",capcap:"⩋",capcup:"⩇",capdot:"⩀",CapitalDifferentialD:"ⅅ",caps:"∩︀",caret:"⁁",caron:"ˇ",Cayleys:"ℭ",ccaps:"⩍",ccaron:"č",Ccaron:"Č",ccedil:"ç",Ccedil:"Ç",ccirc:"ĉ",Ccirc:"Ĉ",Cconint:"∰",ccups:"⩌",ccupssm:"⩐",cdot:"ċ",Cdot:"Ċ",cedil:"¸",Cedilla:"¸",cemptyv:"⦲",cent:"¢",centerdot:"·",CenterDot:"·",cfr:"𝔠",Cfr:"ℭ",chcy:"ч",CHcy:"Ч",check:"✓",checkmark:"✓",chi:"χ",Chi:"Χ",cir:"○",circ:"ˆ",circeq:"≗",circlearrowleft:"↺",circlearrowright:"↻",circledast:"⊛",circledcirc:"⊚",circleddash:"⊝",CircleDot:"⊙",circledR:"®",circledS:"Ⓢ",CircleMinus:"⊖",CirclePlus:"⊕",CircleTimes:"⊗",cire:"≗",cirE:"⧃",cirfnint:"⨐",cirmid:"⫯",cirscir:"⧂",ClockwiseContourIntegral:"∲",CloseCurlyDoubleQuote:"”",CloseCurlyQuote:"’",clubs:"♣",clubsuit:"♣",colon:":",Colon:"∷",colone:"≔",Colone:"⩴",coloneq:"≔",comma:",",commat:"@",comp:"∁",compfn:"∘",complement:"∁",complexes:"ℂ",cong:"≅",congdot:"⩭",Congruent:"≡",conint:"∮",Conint:"∯",ContourIntegral:"∮",copf:"𝕔",Copf:"ℂ",coprod:"∐",Coproduct:"∐",copy:"©",COPY:"©",copysr:"℗",CounterClockwiseContourIntegral:"∳",crarr:"↵",cross:"✗",Cross:"⨯",cscr:"𝒸",Cscr:"𝒞",csub:"⫏",csube:"⫑",csup:"⫐",csupe:"⫒",ctdot:"⋯",cudarrl:"⤸",cudarrr:"⤵",cuepr:"⋞",cuesc:"⋟",cularr:"↶",cularrp:"⤽",cup:"∪",Cup:"⋓",cupbrcap:"⩈",cupcap:"⩆",CupCap:"≍",cupcup:"⩊",cupdot:"⊍",cupor:"⩅",cups:"∪︀",curarr:"↷",curarrm:"⤼",curlyeqprec:"⋞",curlyeqsucc:"⋟",curlyvee:"⋎",curlywedge:"⋏",curren:"¤",curvearrowleft:"↶",curvearrowright:"↷",cuvee:"⋎",cuwed:"⋏",cwconint:"∲",cwint:"∱",cylcty:"⌭",dagger:"†",Dagger:"‡",daleth:"ℸ",darr:"↓",dArr:"⇓",Darr:"↡",dash:"‐",dashv:"⊣",Dashv:"⫤",dbkarow:"⤏",dblac:"˝",dcaron:"ď",Dcaron:"Ď",dcy:"д",Dcy:"Д",dd:"ⅆ",DD:"ⅅ",ddagger:"‡",ddarr:"⇊",DDotrahd:"⤑",ddotseq:"⩷",deg:"°",Del:"∇",delta:"δ",Delta:"Δ",demptyv:"⦱",dfisht:"⥿",dfr:"𝔡",Dfr:"𝔇",dHar:"⥥",dharl:"⇃",dharr:"⇂",DiacriticalAcute:"´",DiacriticalDot:"˙",DiacriticalDoubleAcute:"˝",DiacriticalGrave:"`",DiacriticalTilde:"˜",diam:"⋄",diamond:"⋄",Diamond:"⋄",diamondsuit:"♦",diams:"♦",die:"¨",DifferentialD:"ⅆ",digamma:"ϝ",disin:"⋲",div:"÷",divide:"÷",divideontimes:"⋇",divonx:"⋇",djcy:"ђ",DJcy:"Ђ",dlcorn:"⌞",dlcrop:"⌍",dollar:"$",dopf:"𝕕",Dopf:"𝔻",dot:"˙",Dot:"¨",DotDot:"⃜",doteq:"≐",doteqdot:"≑",DotEqual:"≐",dotminus:"∸",dotplus:"∔",dotsquare:"⊡",doublebarwedge:"⌆",DoubleContourIntegral:"∯",DoubleDot:"¨",DoubleDownArrow:"⇓",DoubleLeftArrow:"⇐",DoubleLeftRightArrow:"⇔",DoubleLeftTee:"⫤",DoubleLongLeftArrow:"⟸",DoubleLongLeftRightArrow:"⟺",DoubleLongRightArrow:"⟹",DoubleRightArrow:"⇒",DoubleRightTee:"⊨",DoubleUpArrow:"⇑",DoubleUpDownArrow:"⇕",DoubleVerticalBar:"∥",downarrow:"↓",Downarrow:"⇓",DownArrow:"↓",DownArrowBar:"⤓",DownArrowUpArrow:"⇵",DownBreve:"̑",downdownarrows:"⇊",downharpoonleft:"⇃",downharpoonright:"⇂",DownLeftRightVector:"⥐",DownLeftTeeVector:"⥞",DownLeftVector:"↽",DownLeftVectorBar:"⥖",DownRightTeeVector:"⥟",DownRightVector:"⇁",DownRightVectorBar:"⥗",DownTee:"⊤",DownTeeArrow:"↧",drbkarow:"⤐",drcorn:"⌟",drcrop:"⌌",dscr:"𝒹",Dscr:"𝒟",dscy:"ѕ",DScy:"Ѕ",dsol:"⧶",dstrok:"đ",Dstrok:"Đ",dtdot:"⋱",dtri:"▿",dtrif:"▾",duarr:"⇵",duhar:"⥯",dwangle:"⦦",dzcy:"џ",DZcy:"Џ",dzigrarr:"⟿",eacute:"é",Eacute:"É",easter:"⩮",ecaron:"ě",Ecaron:"Ě",ecir:"≖",ecirc:"ê",Ecirc:"Ê",ecolon:"≕",ecy:"э",Ecy:"Э",eDDot:"⩷",edot:"ė",eDot:"≑",Edot:"Ė",ee:"ⅇ",efDot:"≒",efr:"𝔢",Efr:"𝔈",eg:"⪚",egrave:"è",Egrave:"È",egs:"⪖",egsdot:"⪘",el:"⪙",Element:"∈",elinters:"⏧",ell:"ℓ",els:"⪕",elsdot:"⪗",emacr:"ē",Emacr:"Ē",empty:"∅",emptyset:"∅",EmptySmallSquare:"◻",emptyv:"∅",EmptyVerySmallSquare:"▫",emsp:" ",emsp13:" ",emsp14:" ",eng:"ŋ",ENG:"Ŋ",ensp:" ",eogon:"ę",Eogon:"Ę",eopf:"𝕖",Eopf:"𝔼",epar:"⋕",eparsl:"⧣",eplus:"⩱",epsi:"ε",epsilon:"ε",Epsilon:"Ε",epsiv:"ϵ",eqcirc:"≖",eqcolon:"≕",eqsim:"≂",eqslantgtr:"⪖",eqslantless:"⪕",Equal:"⩵",equals:"=",EqualTilde:"≂",equest:"≟",Equilibrium:"⇌",equiv:"≡",equivDD:"⩸",eqvparsl:"⧥",erarr:"⥱",erDot:"≓",escr:"ℯ",Escr:"ℰ",esdot:"≐",esim:"≂",Esim:"⩳",eta:"η",Eta:"Η",eth:"ð",ETH:"Ð",euml:"ë",Euml:"Ë",euro:"€",excl:"!",exist:"∃",Exists:"∃",expectation:"ℰ",exponentiale:"ⅇ",ExponentialE:"ⅇ",fallingdotseq:"≒",fcy:"ф",Fcy:"Ф",female:"♀",ffilig:"ﬃ",fflig:"ﬀ",ffllig:"ﬄ",ffr:"𝔣",Ffr:"𝔉",filig:"ﬁ",FilledSmallSquare:"◼",FilledVerySmallSquare:"▪",fjlig:"fj",flat:"♭",fllig:"ﬂ",fltns:"▱",fnof:"ƒ",fopf:"𝕗",Fopf:"𝔽",forall:"∀",ForAll:"∀",fork:"⋔",forkv:"⫙",Fouriertrf:"ℱ",fpartint:"⨍",frac12:"½",frac13:"⅓",frac14:"¼",frac15:"⅕",frac16:"⅙",frac18:"⅛",frac23:"⅔",frac25:"⅖",frac34:"¾",frac35:"⅗",frac38:"⅜",frac45:"⅘",frac56:"⅚",frac58:"⅝",frac78:"⅞",frasl:"⁄",frown:"⌢",fscr:"𝒻",Fscr:"ℱ",gacute:"ǵ",gamma:"γ",Gamma:"Γ",gammad:"ϝ",Gammad:"Ϝ",gap:"⪆",gbreve:"ğ",Gbreve:"Ğ",Gcedil:"Ģ",gcirc:"ĝ",Gcirc:"Ĝ",gcy:"г",Gcy:"Г",gdot:"ġ",Gdot:"Ġ",ge:"≥",gE:"≧",gel:"⋛",gEl:"⪌",geq:"≥",geqq:"≧",geqslant:"⩾",ges:"⩾",gescc:"⪩",gesdot:"⪀",gesdoto:"⪂",gesdotol:"⪄",gesl:"⋛︀",gesles:"⪔",gfr:"𝔤",Gfr:"𝔊",gg:"≫",Gg:"⋙",ggg:"⋙",gimel:"ℷ",gjcy:"ѓ",GJcy:"Ѓ",gl:"≷",gla:"⪥",glE:"⪒",glj:"⪤",gnap:"⪊",gnapprox:"⪊",gne:"⪈",gnE:"≩",gneq:"⪈",gneqq:"≩",gnsim:"⋧",gopf:"𝕘",Gopf:"𝔾",grave:"`",GreaterEqual:"≥",GreaterEqualLess:"⋛",GreaterFullEqual:"≧",GreaterGreater:"⪢",GreaterLess:"≷",GreaterSlantEqual:"⩾",GreaterTilde:"≳",gscr:"ℊ",Gscr:"𝒢",gsim:"≳",gsime:"⪎",gsiml:"⪐",gt:">",Gt:"≫",GT:">",gtcc:"⪧",gtcir:"⩺",gtdot:"⋗",gtlPar:"⦕",gtquest:"⩼",gtrapprox:"⪆",gtrarr:"⥸",gtrdot:"⋗",gtreqless:"⋛",gtreqqless:"⪌",gtrless:"≷",gtrsim:"≳",gvertneqq:"≩︀",gvnE:"≩︀",Hacek:"ˇ",hairsp:" ",half:"½",hamilt:"ℋ",hardcy:"ъ",HARDcy:"Ъ",harr:"↔",hArr:"⇔",harrcir:"⥈",harrw:"↭",Hat:"^",hbar:"ℏ",hcirc:"ĥ",Hcirc:"Ĥ",hearts:"♥",heartsuit:"♥",hellip:"…",hercon:"⊹",hfr:"𝔥",Hfr:"ℌ",HilbertSpace:"ℋ",hksearow:"⤥",hkswarow:"⤦",hoarr:"⇿",homtht:"∻",hookleftarrow:"↩",hookrightarrow:"↪",hopf:"𝕙",Hopf:"ℍ",horbar:"―",HorizontalLine:"─",hscr:"𝒽",Hscr:"ℋ",hslash:"ℏ",hstrok:"ħ",Hstrok:"Ħ",HumpDownHump:"≎",HumpEqual:"≏",hybull:"⁃",hyphen:"‐",iacute:"í",Iacute:"Í",ic:"⁣",icirc:"î",Icirc:"Î",icy:"и",Icy:"И",Idot:"İ",iecy:"е",IEcy:"Е",iexcl:"¡",iff:"⇔",ifr:"𝔦",Ifr:"ℑ",igrave:"ì",Igrave:"Ì",ii:"ⅈ",iiiint:"⨌",iiint:"∭",iinfin:"⧜",iiota:"℩",ijlig:"ĳ",IJlig:"Ĳ",Im:"ℑ",imacr:"ī",Imacr:"Ī",image:"ℑ",ImaginaryI:"ⅈ",imagline:"ℐ",imagpart:"ℑ",imath:"ı",imof:"⊷",imped:"Ƶ",Implies:"⇒",in:"∈",incare:"℅",infin:"∞",infintie:"⧝",inodot:"ı",int:"∫",Int:"∬",intcal:"⊺",integers:"ℤ",Integral:"∫",intercal:"⊺",Intersection:"⋂",intlarhk:"⨗",intprod:"⨼",InvisibleComma:"⁣",InvisibleTimes:"⁢",iocy:"ё",IOcy:"Ё",iogon:"į",Iogon:"Į",iopf:"𝕚",Iopf:"𝕀",iota:"ι",Iota:"Ι",iprod:"⨼",iquest:"¿",iscr:"𝒾",Iscr:"ℐ",isin:"∈",isindot:"⋵",isinE:"⋹",isins:"⋴",isinsv:"⋳",isinv:"∈",it:"⁢",itilde:"ĩ",Itilde:"Ĩ",iukcy:"і",Iukcy:"І",iuml:"ï",Iuml:"Ï",jcirc:"ĵ",Jcirc:"Ĵ",jcy:"й",Jcy:"Й",jfr:"𝔧",Jfr:"𝔍",jmath:"ȷ",jopf:"𝕛",Jopf:"𝕁",jscr:"𝒿",Jscr:"𝒥",jsercy:"ј",Jsercy:"Ј",jukcy:"є",Jukcy:"Є",kappa:"κ",Kappa:"Κ",kappav:"ϰ",kcedil:"ķ",Kcedil:"Ķ",kcy:"к",Kcy:"К",kfr:"𝔨",Kfr:"𝔎",kgreen:"ĸ",khcy:"х",KHcy:"Х",kjcy:"ќ",KJcy:"Ќ",kopf:"𝕜",Kopf:"𝕂",kscr:"𝓀",Kscr:"𝒦",lAarr:"⇚",lacute:"ĺ",Lacute:"Ĺ",laemptyv:"⦴",lagran:"ℒ",lambda:"λ",Lambda:"Λ",lang:"⟨",Lang:"⟪",langd:"⦑",langle:"⟨",lap:"⪅",Laplacetrf:"ℒ",laquo:"«",larr:"←",lArr:"⇐",Larr:"↞",larrb:"⇤",larrbfs:"⤟",larrfs:"⤝",larrhk:"↩",larrlp:"↫",larrpl:"⤹",larrsim:"⥳",larrtl:"↢",lat:"⪫",latail:"⤙",lAtail:"⤛",late:"⪭",lates:"⪭︀",lbarr:"⤌",lBarr:"⤎",lbbrk:"❲",lbrace:"{",lbrack:"[",lbrke:"⦋",lbrksld:"⦏",lbrkslu:"⦍",lcaron:"ľ",Lcaron:"Ľ",lcedil:"ļ",Lcedil:"Ļ",lceil:"⌈",lcub:"{",lcy:"л",Lcy:"Л",ldca:"⤶",ldquo:"“",ldquor:"„",ldrdhar:"⥧",ldrushar:"⥋",ldsh:"↲",le:"≤",lE:"≦",LeftAngleBracket:"⟨",leftarrow:"←",Leftarrow:"⇐",LeftArrow:"←",LeftArrowBar:"⇤",LeftArrowRightArrow:"⇆",leftarrowtail:"↢",LeftCeiling:"⌈",LeftDoubleBracket:"⟦",LeftDownTeeVector:"⥡",LeftDownVector:"⇃",LeftDownVectorBar:"⥙",LeftFloor:"⌊",leftharpoondown:"↽",leftharpoonup:"↼",leftleftarrows:"⇇",leftrightarrow:"↔",Leftrightarrow:"⇔",LeftRightArrow:"↔",leftrightarrows:"⇆",leftrightharpoons:"⇋",leftrightsquigarrow:"↭",LeftRightVector:"⥎",LeftTee:"⊣",LeftTeeArrow:"↤",LeftTeeVector:"⥚",leftthreetimes:"⋋",LeftTriangle:"⊲",LeftTriangleBar:"⧏",LeftTriangleEqual:"⊴",LeftUpDownVector:"⥑",LeftUpTeeVector:"⥠",LeftUpVector:"↿",LeftUpVectorBar:"⥘",LeftVector:"↼",LeftVectorBar:"⥒",leg:"⋚",lEg:"⪋",leq:"≤",leqq:"≦",leqslant:"⩽",les:"⩽",lescc:"⪨",lesdot:"⩿",lesdoto:"⪁",lesdotor:"⪃",lesg:"⋚︀",lesges:"⪓",lessapprox:"⪅",lessdot:"⋖",lesseqgtr:"⋚",lesseqqgtr:"⪋",LessEqualGreater:"⋚",LessFullEqual:"≦",LessGreater:"≶",lessgtr:"≶",LessLess:"⪡",lesssim:"≲",LessSlantEqual:"⩽",LessTilde:"≲",lfisht:"⥼",lfloor:"⌊",lfr:"𝔩",Lfr:"𝔏",lg:"≶",lgE:"⪑",lHar:"⥢",lhard:"↽",lharu:"↼",lharul:"⥪",lhblk:"▄",ljcy:"љ",LJcy:"Љ",ll:"≪",Ll:"⋘",llarr:"⇇",llcorner:"⌞",Lleftarrow:"⇚",llhard:"⥫",lltri:"◺",lmidot:"ŀ",Lmidot:"Ŀ",lmoust:"⎰",lmoustache:"⎰",lnap:"⪉",lnapprox:"⪉",lne:"⪇",lnE:"≨",lneq:"⪇",lneqq:"≨",lnsim:"⋦",loang:"⟬",loarr:"⇽",lobrk:"⟦",longleftarrow:"⟵",Longleftarrow:"⟸",LongLeftArrow:"⟵",longleftrightarrow:"⟷",Longleftrightarrow:"⟺",LongLeftRightArrow:"⟷",longmapsto:"⟼",longrightarrow:"⟶",Longrightarrow:"⟹",LongRightArrow:"⟶",looparrowleft:"↫",looparrowright:"↬",lopar:"⦅",lopf:"𝕝",Lopf:"𝕃",loplus:"⨭",lotimes:"⨴",lowast:"∗",lowbar:"_",LowerLeftArrow:"↙",LowerRightArrow:"↘",loz:"◊",lozenge:"◊",lozf:"⧫",lpar:"(",lparlt:"⦓",lrarr:"⇆",lrcorner:"⌟",lrhar:"⇋",lrhard:"⥭",lrm:"‎",lrtri:"⊿",lsaquo:"‹",lscr:"𝓁",Lscr:"ℒ",lsh:"↰",Lsh:"↰",lsim:"≲",lsime:"⪍",lsimg:"⪏",lsqb:"[",lsquo:"‘",lsquor:"‚",lstrok:"ł",Lstrok:"Ł",lt:"<",Lt:"≪",LT:"<",ltcc:"⪦",ltcir:"⩹",ltdot:"⋖",lthree:"⋋",ltimes:"⋉",ltlarr:"⥶",ltquest:"⩻",ltri:"◃",ltrie:"⊴",ltrif:"◂",ltrPar:"⦖",lurdshar:"⥊",luruhar:"⥦",lvertneqq:"≨︀",lvnE:"≨︀",macr:"¯",male:"♂",malt:"✠",maltese:"✠",map:"↦",Map:"⤅",mapsto:"↦",mapstodown:"↧",mapstoleft:"↤",mapstoup:"↥",marker:"▮",mcomma:"⨩",mcy:"м",Mcy:"М",mdash:"—",mDDot:"∺",measuredangle:"∡",MediumSpace:" ",Mellintrf:"ℳ",mfr:"𝔪",Mfr:"𝔐",mho:"℧",micro:"µ",mid:"∣",midast:"*",midcir:"⫰",middot:"·",minus:"−",minusb:"⊟",minusd:"∸",minusdu:"⨪",MinusPlus:"∓",mlcp:"⫛",mldr:"…",mnplus:"∓",models:"⊧",mopf:"𝕞",Mopf:"𝕄",mp:"∓",mscr:"𝓂",Mscr:"ℳ",mstpos:"∾",mu:"μ",Mu:"Μ",multimap:"⊸",mumap:"⊸",nabla:"∇",nacute:"ń",Nacute:"Ń",nang:"∠⃒",nap:"≉",napE:"⩰̸",napid:"≋̸",napos:"ŉ",napprox:"≉",natur:"♮",natural:"♮",naturals:"ℕ",nbsp:" ",nbump:"≎̸",nbumpe:"≏̸",ncap:"⩃",ncaron:"ň",Ncaron:"Ň",ncedil:"ņ",Ncedil:"Ņ",ncong:"≇",ncongdot:"⩭̸",ncup:"⩂",ncy:"н",Ncy:"Н",ndash:"–",ne:"≠",nearhk:"⤤",nearr:"↗",neArr:"⇗",nearrow:"↗",nedot:"≐̸",NegativeMediumSpace:"​",NegativeThickSpace:"​",NegativeThinSpace:"​",NegativeVeryThinSpace:"​",nequiv:"≢",nesear:"⤨",nesim:"≂̸",NestedGreaterGreater:"≫",NestedLessLess:"≪",NewLine:`
`,nexist:"∄",nexists:"∄",nfr:"𝔫",Nfr:"𝔑",nge:"≱",ngE:"≧̸",ngeq:"≱",ngeqq:"≧̸",ngeqslant:"⩾̸",nges:"⩾̸",nGg:"⋙̸",ngsim:"≵",ngt:"≯",nGt:"≫⃒",ngtr:"≯",nGtv:"≫̸",nharr:"↮",nhArr:"⇎",nhpar:"⫲",ni:"∋",nis:"⋼",nisd:"⋺",niv:"∋",njcy:"њ",NJcy:"Њ",nlarr:"↚",nlArr:"⇍",nldr:"‥",nle:"≰",nlE:"≦̸",nleftarrow:"↚",nLeftarrow:"⇍",nleftrightarrow:"↮",nLeftrightarrow:"⇎",nleq:"≰",nleqq:"≦̸",nleqslant:"⩽̸",nles:"⩽̸",nless:"≮",nLl:"⋘̸",nlsim:"≴",nlt:"≮",nLt:"≪⃒",nltri:"⋪",nltrie:"⋬",nLtv:"≪̸",nmid:"∤",NoBreak:"⁠",NonBreakingSpace:" ",nopf:"𝕟",Nopf:"ℕ",not:"¬",Not:"⫬",NotCongruent:"≢",NotCupCap:"≭",NotDoubleVerticalBar:"∦",NotElement:"∉",NotEqual:"≠",NotEqualTilde:"≂̸",NotExists:"∄",NotGreater:"≯",NotGreaterEqual:"≱",NotGreaterFullEqual:"≧̸",NotGreaterGreater:"≫̸",NotGreaterLess:"≹",NotGreaterSlantEqual:"⩾̸",NotGreaterTilde:"≵",NotHumpDownHump:"≎̸",NotHumpEqual:"≏̸",notin:"∉",notindot:"⋵̸",notinE:"⋹̸",notinva:"∉",notinvb:"⋷",notinvc:"⋶",NotLeftTriangle:"⋪",NotLeftTriangleBar:"⧏̸",NotLeftTriangleEqual:"⋬",NotLess:"≮",NotLessEqual:"≰",NotLessGreater:"≸",NotLessLess:"≪̸",NotLessSlantEqual:"⩽̸",NotLessTilde:"≴",NotNestedGreaterGreater:"⪢̸",NotNestedLessLess:"⪡̸",notni:"∌",notniva:"∌",notnivb:"⋾",notnivc:"⋽",NotPrecedes:"⊀",NotPrecedesEqual:"⪯̸",NotPrecedesSlantEqual:"⋠",NotReverseElement:"∌",NotRightTriangle:"⋫",NotRightTriangleBar:"⧐̸",NotRightTriangleEqual:"⋭",NotSquareSubset:"⊏̸",NotSquareSubsetEqual:"⋢",NotSquareSuperset:"⊐̸",NotSquareSupersetEqual:"⋣",NotSubset:"⊂⃒",NotSubsetEqual:"⊈",NotSucceeds:"⊁",NotSucceedsEqual:"⪰̸",NotSucceedsSlantEqual:"⋡",NotSucceedsTilde:"≿̸",NotSuperset:"⊃⃒",NotSupersetEqual:"⊉",NotTilde:"≁",NotTildeEqual:"≄",NotTildeFullEqual:"≇",NotTildeTilde:"≉",NotVerticalBar:"∤",npar:"∦",nparallel:"∦",nparsl:"⫽⃥",npart:"∂̸",npolint:"⨔",npr:"⊀",nprcue:"⋠",npre:"⪯̸",nprec:"⊀",npreceq:"⪯̸",nrarr:"↛",nrArr:"⇏",nrarrc:"⤳̸",nrarrw:"↝̸",nrightarrow:"↛",nRightarrow:"⇏",nrtri:"⋫",nrtrie:"⋭",nsc:"⊁",nsccue:"⋡",nsce:"⪰̸",nscr:"𝓃",Nscr:"𝒩",nshortmid:"∤",nshortparallel:"∦",nsim:"≁",nsime:"≄",nsimeq:"≄",nsmid:"∤",nspar:"∦",nsqsube:"⋢",nsqsupe:"⋣",nsub:"⊄",nsube:"⊈",nsubE:"⫅̸",nsubset:"⊂⃒",nsubseteq:"⊈",nsubseteqq:"⫅̸",nsucc:"⊁",nsucceq:"⪰̸",nsup:"⊅",nsupe:"⊉",nsupE:"⫆̸",nsupset:"⊃⃒",nsupseteq:"⊉",nsupseteqq:"⫆̸",ntgl:"≹",ntilde:"ñ",Ntilde:"Ñ",ntlg:"≸",ntriangleleft:"⋪",ntrianglelefteq:"⋬",ntriangleright:"⋫",ntrianglerighteq:"⋭",nu:"ν",Nu:"Ν",num:"#",numero:"№",numsp:" ",nvap:"≍⃒",nvdash:"⊬",nvDash:"⊭",nVdash:"⊮",nVDash:"⊯",nvge:"≥⃒",nvgt:">⃒",nvHarr:"⤄",nvinfin:"⧞",nvlArr:"⤂",nvle:"≤⃒",nvlt:"<⃒",nvltrie:"⊴⃒",nvrArr:"⤃",nvrtrie:"⊵⃒",nvsim:"∼⃒",nwarhk:"⤣",nwarr:"↖",nwArr:"⇖",nwarrow:"↖",nwnear:"⤧",oacute:"ó",Oacute:"Ó",oast:"⊛",ocir:"⊚",ocirc:"ô",Ocirc:"Ô",ocy:"о",Ocy:"О",odash:"⊝",odblac:"ő",Odblac:"Ő",odiv:"⨸",odot:"⊙",odsold:"⦼",oelig:"œ",OElig:"Œ",ofcir:"⦿",ofr:"𝔬",Ofr:"𝔒",ogon:"˛",ograve:"ò",Ograve:"Ò",ogt:"⧁",ohbar:"⦵",ohm:"Ω",oint:"∮",olarr:"↺",olcir:"⦾",olcross:"⦻",oline:"‾",olt:"⧀",omacr:"ō",Omacr:"Ō",omega:"ω",Omega:"Ω",omicron:"ο",Omicron:"Ο",omid:"⦶",ominus:"⊖",oopf:"𝕠",Oopf:"𝕆",opar:"⦷",OpenCurlyDoubleQuote:"“",OpenCurlyQuote:"‘",operp:"⦹",oplus:"⊕",or:"∨",Or:"⩔",orarr:"↻",ord:"⩝",order:"ℴ",orderof:"ℴ",ordf:"ª",ordm:"º",origof:"⊶",oror:"⩖",orslope:"⩗",orv:"⩛",oS:"Ⓢ",oscr:"ℴ",Oscr:"𝒪",oslash:"ø",Oslash:"Ø",osol:"⊘",otilde:"õ",Otilde:"Õ",otimes:"⊗",Otimes:"⨷",otimesas:"⨶",ouml:"ö",Ouml:"Ö",ovbar:"⌽",OverBar:"‾",OverBrace:"⏞",OverBracket:"⎴",OverParenthesis:"⏜",par:"∥",para:"¶",parallel:"∥",parsim:"⫳",parsl:"⫽",part:"∂",PartialD:"∂",pcy:"п",Pcy:"П",percnt:"%",period:".",permil:"‰",perp:"⊥",pertenk:"‱",pfr:"𝔭",Pfr:"𝔓",phi:"φ",Phi:"Φ",phiv:"ϕ",phmmat:"ℳ",phone:"☎",pi:"π",Pi:"Π",pitchfork:"⋔",piv:"ϖ",planck:"ℏ",planckh:"ℎ",plankv:"ℏ",plus:"+",plusacir:"⨣",plusb:"⊞",pluscir:"⨢",plusdo:"∔",plusdu:"⨥",pluse:"⩲",PlusMinus:"±",plusmn:"±",plussim:"⨦",plustwo:"⨧",pm:"±",Poincareplane:"ℌ",pointint:"⨕",popf:"𝕡",Popf:"ℙ",pound:"£",pr:"≺",Pr:"⪻",prap:"⪷",prcue:"≼",pre:"⪯",prE:"⪳",prec:"≺",precapprox:"⪷",preccurlyeq:"≼",Precedes:"≺",PrecedesEqual:"⪯",PrecedesSlantEqual:"≼",PrecedesTilde:"≾",preceq:"⪯",precnapprox:"⪹",precneqq:"⪵",precnsim:"⋨",precsim:"≾",prime:"′",Prime:"″",primes:"ℙ",prnap:"⪹",prnE:"⪵",prnsim:"⋨",prod:"∏",Product:"∏",profalar:"⌮",profline:"⌒",profsurf:"⌓",prop:"∝",Proportion:"∷",Proportional:"∝",propto:"∝",prsim:"≾",prurel:"⊰",pscr:"𝓅",Pscr:"𝒫",psi:"ψ",Psi:"Ψ",puncsp:" ",qfr:"𝔮",Qfr:"𝔔",qint:"⨌",qopf:"𝕢",Qopf:"ℚ",qprime:"⁗",qscr:"𝓆",Qscr:"𝒬",quaternions:"ℍ",quatint:"⨖",quest:"?",questeq:"≟",quot:'"',QUOT:'"',rAarr:"⇛",race:"∽̱",racute:"ŕ",Racute:"Ŕ",radic:"√",raemptyv:"⦳",rang:"⟩",Rang:"⟫",rangd:"⦒",range:"⦥",rangle:"⟩",raquo:"»",rarr:"→",rArr:"⇒",Rarr:"↠",rarrap:"⥵",rarrb:"⇥",rarrbfs:"⤠",rarrc:"⤳",rarrfs:"⤞",rarrhk:"↪",rarrlp:"↬",rarrpl:"⥅",rarrsim:"⥴",rarrtl:"↣",Rarrtl:"⤖",rarrw:"↝",ratail:"⤚",rAtail:"⤜",ratio:"∶",rationals:"ℚ",rbarr:"⤍",rBarr:"⤏",RBarr:"⤐",rbbrk:"❳",rbrace:"}",rbrack:"]",rbrke:"⦌",rbrksld:"⦎",rbrkslu:"⦐",rcaron:"ř",Rcaron:"Ř",rcedil:"ŗ",Rcedil:"Ŗ",rceil:"⌉",rcub:"}",rcy:"р",Rcy:"Р",rdca:"⤷",rdldhar:"⥩",rdquo:"”",rdquor:"”",rdsh:"↳",Re:"ℜ",real:"ℜ",realine:"ℛ",realpart:"ℜ",reals:"ℝ",rect:"▭",reg:"®",REG:"®",ReverseElement:"∋",ReverseEquilibrium:"⇋",ReverseUpEquilibrium:"⥯",rfisht:"⥽",rfloor:"⌋",rfr:"𝔯",Rfr:"ℜ",rHar:"⥤",rhard:"⇁",rharu:"⇀",rharul:"⥬",rho:"ρ",Rho:"Ρ",rhov:"ϱ",RightAngleBracket:"⟩",rightarrow:"→",Rightarrow:"⇒",RightArrow:"→",RightArrowBar:"⇥",RightArrowLeftArrow:"⇄",rightarrowtail:"↣",RightCeiling:"⌉",RightDoubleBracket:"⟧",RightDownTeeVector:"⥝",RightDownVector:"⇂",RightDownVectorBar:"⥕",RightFloor:"⌋",rightharpoondown:"⇁",rightharpoonup:"⇀",rightleftarrows:"⇄",rightleftharpoons:"⇌",rightrightarrows:"⇉",rightsquigarrow:"↝",RightTee:"⊢",RightTeeArrow:"↦",RightTeeVector:"⥛",rightthreetimes:"⋌",RightTriangle:"⊳",RightTriangleBar:"⧐",RightTriangleEqual:"⊵",RightUpDownVector:"⥏",RightUpTeeVector:"⥜",RightUpVector:"↾",RightUpVectorBar:"⥔",RightVector:"⇀",RightVectorBar:"⥓",ring:"˚",risingdotseq:"≓",rlarr:"⇄",rlhar:"⇌",rlm:"‏",rmoust:"⎱",rmoustache:"⎱",rnmid:"⫮",roang:"⟭",roarr:"⇾",robrk:"⟧",ropar:"⦆",ropf:"𝕣",Ropf:"ℝ",roplus:"⨮",rotimes:"⨵",RoundImplies:"⥰",rpar:")",rpargt:"⦔",rppolint:"⨒",rrarr:"⇉",Rrightarrow:"⇛",rsaquo:"›",rscr:"𝓇",Rscr:"ℛ",rsh:"↱",Rsh:"↱",rsqb:"]",rsquo:"’",rsquor:"’",rthree:"⋌",rtimes:"⋊",rtri:"▹",rtrie:"⊵",rtrif:"▸",rtriltri:"⧎",RuleDelayed:"⧴",ruluhar:"⥨",rx:"℞",sacute:"ś",Sacute:"Ś",sbquo:"‚",sc:"≻",Sc:"⪼",scap:"⪸",scaron:"š",Scaron:"Š",sccue:"≽",sce:"⪰",scE:"⪴",scedil:"ş",Scedil:"Ş",scirc:"ŝ",Scirc:"Ŝ",scnap:"⪺",scnE:"⪶",scnsim:"⋩",scpolint:"⨓",scsim:"≿",scy:"с",Scy:"С",sdot:"⋅",sdotb:"⊡",sdote:"⩦",searhk:"⤥",searr:"↘",seArr:"⇘",searrow:"↘",sect:"§",semi:";",seswar:"⤩",setminus:"∖",setmn:"∖",sext:"✶",sfr:"𝔰",Sfr:"𝔖",sfrown:"⌢",sharp:"♯",shchcy:"щ",SHCHcy:"Щ",shcy:"ш",SHcy:"Ш",ShortDownArrow:"↓",ShortLeftArrow:"←",shortmid:"∣",shortparallel:"∥",ShortRightArrow:"→",ShortUpArrow:"↑",shy:"­",sigma:"σ",Sigma:"Σ",sigmaf:"ς",sigmav:"ς",sim:"∼",simdot:"⩪",sime:"≃",simeq:"≃",simg:"⪞",simgE:"⪠",siml:"⪝",simlE:"⪟",simne:"≆",simplus:"⨤",simrarr:"⥲",slarr:"←",SmallCircle:"∘",smallsetminus:"∖",smashp:"⨳",smeparsl:"⧤",smid:"∣",smile:"⌣",smt:"⪪",smte:"⪬",smtes:"⪬︀",softcy:"ь",SOFTcy:"Ь",sol:"/",solb:"⧄",solbar:"⌿",sopf:"𝕤",Sopf:"𝕊",spades:"♠",spadesuit:"♠",spar:"∥",sqcap:"⊓",sqcaps:"⊓︀",sqcup:"⊔",sqcups:"⊔︀",Sqrt:"√",sqsub:"⊏",sqsube:"⊑",sqsubset:"⊏",sqsubseteq:"⊑",sqsup:"⊐",sqsupe:"⊒",sqsupset:"⊐",sqsupseteq:"⊒",squ:"□",square:"□",Square:"□",SquareIntersection:"⊓",SquareSubset:"⊏",SquareSubsetEqual:"⊑",SquareSuperset:"⊐",SquareSupersetEqual:"⊒",SquareUnion:"⊔",squarf:"▪",squf:"▪",srarr:"→",sscr:"𝓈",Sscr:"𝒮",ssetmn:"∖",ssmile:"⌣",sstarf:"⋆",star:"☆",Star:"⋆",starf:"★",straightepsilon:"ϵ",straightphi:"ϕ",strns:"¯",sub:"⊂",Sub:"⋐",subdot:"⪽",sube:"⊆",subE:"⫅",subedot:"⫃",submult:"⫁",subne:"⊊",subnE:"⫋",subplus:"⪿",subrarr:"⥹",subset:"⊂",Subset:"⋐",subseteq:"⊆",subseteqq:"⫅",SubsetEqual:"⊆",subsetneq:"⊊",subsetneqq:"⫋",subsim:"⫇",subsub:"⫕",subsup:"⫓",succ:"≻",succapprox:"⪸",succcurlyeq:"≽",Succeeds:"≻",SucceedsEqual:"⪰",SucceedsSlantEqual:"≽",SucceedsTilde:"≿",succeq:"⪰",succnapprox:"⪺",succneqq:"⪶",succnsim:"⋩",succsim:"≿",SuchThat:"∋",sum:"∑",Sum:"∑",sung:"♪",sup:"⊃",Sup:"⋑",sup1:"¹",sup2:"²",sup3:"³",supdot:"⪾",supdsub:"⫘",supe:"⊇",supE:"⫆",supedot:"⫄",Superset:"⊃",SupersetEqual:"⊇",suphsol:"⟉",suphsub:"⫗",suplarr:"⥻",supmult:"⫂",supne:"⊋",supnE:"⫌",supplus:"⫀",supset:"⊃",Supset:"⋑",supseteq:"⊇",supseteqq:"⫆",supsetneq:"⊋",supsetneqq:"⫌",supsim:"⫈",supsub:"⫔",supsup:"⫖",swarhk:"⤦",swarr:"↙",swArr:"⇙",swarrow:"↙",swnwar:"⤪",szlig:"ß",Tab:"	",target:"⌖",tau:"τ",Tau:"Τ",tbrk:"⎴",tcaron:"ť",Tcaron:"Ť",tcedil:"ţ",Tcedil:"Ţ",tcy:"т",Tcy:"Т",tdot:"⃛",telrec:"⌕",tfr:"𝔱",Tfr:"𝔗",there4:"∴",therefore:"∴",Therefore:"∴",theta:"θ",Theta:"Θ",thetasym:"ϑ",thetav:"ϑ",thickapprox:"≈",thicksim:"∼",ThickSpace:"  ",thinsp:" ",ThinSpace:" ",thkap:"≈",thksim:"∼",thorn:"þ",THORN:"Þ",tilde:"˜",Tilde:"∼",TildeEqual:"≃",TildeFullEqual:"≅",TildeTilde:"≈",times:"×",timesb:"⊠",timesbar:"⨱",timesd:"⨰",tint:"∭",toea:"⤨",top:"⊤",topbot:"⌶",topcir:"⫱",topf:"𝕥",Topf:"𝕋",topfork:"⫚",tosa:"⤩",tprime:"‴",trade:"™",TRADE:"™",triangle:"▵",triangledown:"▿",triangleleft:"◃",trianglelefteq:"⊴",triangleq:"≜",triangleright:"▹",trianglerighteq:"⊵",tridot:"◬",trie:"≜",triminus:"⨺",TripleDot:"⃛",triplus:"⨹",trisb:"⧍",tritime:"⨻",trpezium:"⏢",tscr:"𝓉",Tscr:"𝒯",tscy:"ц",TScy:"Ц",tshcy:"ћ",TSHcy:"Ћ",tstrok:"ŧ",Tstrok:"Ŧ",twixt:"≬",twoheadleftarrow:"↞",twoheadrightarrow:"↠",uacute:"ú",Uacute:"Ú",uarr:"↑",uArr:"⇑",Uarr:"↟",Uarrocir:"⥉",ubrcy:"ў",Ubrcy:"Ў",ubreve:"ŭ",Ubreve:"Ŭ",ucirc:"û",Ucirc:"Û",ucy:"у",Ucy:"У",udarr:"⇅",udblac:"ű",Udblac:"Ű",udhar:"⥮",ufisht:"⥾",ufr:"𝔲",Ufr:"𝔘",ugrave:"ù",Ugrave:"Ù",uHar:"⥣",uharl:"↿",uharr:"↾",uhblk:"▀",ulcorn:"⌜",ulcorner:"⌜",ulcrop:"⌏",ultri:"◸",umacr:"ū",Umacr:"Ū",uml:"¨",UnderBar:"_",UnderBrace:"⏟",UnderBracket:"⎵",UnderParenthesis:"⏝",Union:"⋃",UnionPlus:"⊎",uogon:"ų",Uogon:"Ų",uopf:"𝕦",Uopf:"𝕌",uparrow:"↑",Uparrow:"⇑",UpArrow:"↑",UpArrowBar:"⤒",UpArrowDownArrow:"⇅",updownarrow:"↕",Updownarrow:"⇕",UpDownArrow:"↕",UpEquilibrium:"⥮",upharpoonleft:"↿",upharpoonright:"↾",uplus:"⊎",UpperLeftArrow:"↖",UpperRightArrow:"↗",upsi:"υ",Upsi:"ϒ",upsih:"ϒ",upsilon:"υ",Upsilon:"Υ",UpTee:"⊥",UpTeeArrow:"↥",upuparrows:"⇈",urcorn:"⌝",urcorner:"⌝",urcrop:"⌎",uring:"ů",Uring:"Ů",urtri:"◹",uscr:"𝓊",Uscr:"𝒰",utdot:"⋰",utilde:"ũ",Utilde:"Ũ",utri:"▵",utrif:"▴",uuarr:"⇈",uuml:"ü",Uuml:"Ü",uwangle:"⦧",vangrt:"⦜",varepsilon:"ϵ",varkappa:"ϰ",varnothing:"∅",varphi:"ϕ",varpi:"ϖ",varpropto:"∝",varr:"↕",vArr:"⇕",varrho:"ϱ",varsigma:"ς",varsubsetneq:"⊊︀",varsubsetneqq:"⫋︀",varsupsetneq:"⊋︀",varsupsetneqq:"⫌︀",vartheta:"ϑ",vartriangleleft:"⊲",vartriangleright:"⊳",vBar:"⫨",Vbar:"⫫",vBarv:"⫩",vcy:"в",Vcy:"В",vdash:"⊢",vDash:"⊨",Vdash:"⊩",VDash:"⊫",Vdashl:"⫦",vee:"∨",Vee:"⋁",veebar:"⊻",veeeq:"≚",vellip:"⋮",verbar:"|",Verbar:"‖",vert:"|",Vert:"‖",VerticalBar:"∣",VerticalLine:"|",VerticalSeparator:"❘",VerticalTilde:"≀",VeryThinSpace:" ",vfr:"𝔳",Vfr:"𝔙",vltri:"⊲",vnsub:"⊂⃒",vnsup:"⊃⃒",vopf:"𝕧",Vopf:"𝕍",vprop:"∝",vrtri:"⊳",vscr:"𝓋",Vscr:"𝒱",vsubne:"⊊︀",vsubnE:"⫋︀",vsupne:"⊋︀",vsupnE:"⫌︀",Vvdash:"⊪",vzigzag:"⦚",wcirc:"ŵ",Wcirc:"Ŵ",wedbar:"⩟",wedge:"∧",Wedge:"⋀",wedgeq:"≙",weierp:"℘",wfr:"𝔴",Wfr:"𝔚",wopf:"𝕨",Wopf:"𝕎",wp:"℘",wr:"≀",wreath:"≀",wscr:"𝓌",Wscr:"𝒲",xcap:"⋂",xcirc:"◯",xcup:"⋃",xdtri:"▽",xfr:"𝔵",Xfr:"𝔛",xharr:"⟷",xhArr:"⟺",xi:"ξ",Xi:"Ξ",xlarr:"⟵",xlArr:"⟸",xmap:"⟼",xnis:"⋻",xodot:"⨀",xopf:"𝕩",Xopf:"𝕏",xoplus:"⨁",xotime:"⨂",xrarr:"⟶",xrArr:"⟹",xscr:"𝓍",Xscr:"𝒳",xsqcup:"⨆",xuplus:"⨄",xutri:"△",xvee:"⋁",xwedge:"⋀",yacute:"ý",Yacute:"Ý",yacy:"я",YAcy:"Я",ycirc:"ŷ",Ycirc:"Ŷ",ycy:"ы",Ycy:"Ы",yen:"¥",yfr:"𝔶",Yfr:"𝔜",yicy:"ї",YIcy:"Ї",yopf:"𝕪",Yopf:"𝕐",yscr:"𝓎",Yscr:"𝒴",yucy:"ю",YUcy:"Ю",yuml:"ÿ",Yuml:"Ÿ",zacute:"ź",Zacute:"Ź",zcaron:"ž",Zcaron:"Ž",zcy:"з",Zcy:"З",zdot:"ż",Zdot:"Ż",zeetrf:"ℨ",ZeroWidthSpace:"​",zeta:"ζ",Zeta:"Ζ",zfr:"𝔷",Zfr:"ℨ",zhcy:"ж",ZHcy:"Ж",zigrarr:"⇝",zopf:"𝕫",Zopf:"ℤ",zscr:"𝓏",Zscr:"𝒵",zwj:"‍",zwnj:"‌"},U={aacute:"á",Aacute:"Á",acirc:"â",Acirc:"Â",acute:"´",aelig:"æ",AElig:"Æ",agrave:"à",Agrave:"À",amp:"&",AMP:"&",aring:"å",Aring:"Å",atilde:"ã",Atilde:"Ã",auml:"ä",Auml:"Ä",brvbar:"¦",ccedil:"ç",Ccedil:"Ç",cedil:"¸",cent:"¢",copy:"©",COPY:"©",curren:"¤",deg:"°",divide:"÷",eacute:"é",Eacute:"É",ecirc:"ê",Ecirc:"Ê",egrave:"è",Egrave:"È",eth:"ð",ETH:"Ð",euml:"ë",Euml:"Ë",frac12:"½",frac14:"¼",frac34:"¾",gt:">",GT:">",iacute:"í",Iacute:"Í",icirc:"î",Icirc:"Î",iexcl:"¡",igrave:"ì",Igrave:"Ì",iquest:"¿",iuml:"ï",Iuml:"Ï",laquo:"«",lt:"<",LT:"<",macr:"¯",micro:"µ",middot:"·",nbsp:" ",not:"¬",ntilde:"ñ",Ntilde:"Ñ",oacute:"ó",Oacute:"Ó",ocirc:"ô",Ocirc:"Ô",ograve:"ò",Ograve:"Ò",ordf:"ª",ordm:"º",oslash:"ø",Oslash:"Ø",otilde:"õ",Otilde:"Õ",ouml:"ö",Ouml:"Ö",para:"¶",plusmn:"±",pound:"£",quot:'"',QUOT:'"',raquo:"»",reg:"®",REG:"®",sect:"§",shy:"­",sup1:"¹",sup2:"²",sup3:"³",szlig:"ß",thorn:"þ",THORN:"Þ",times:"×",uacute:"ú",Uacute:"Ú",ucirc:"û",Ucirc:"Û",ugrave:"ù",Ugrave:"Ù",uml:"¨",uuml:"ü",Uuml:"Ü",yacute:"ý",Yacute:"Ý",yen:"¥",yuml:"ÿ"},Y={0:"�",128:"€",130:"‚",131:"ƒ",132:"„",133:"…",134:"†",135:"‡",136:"ˆ",137:"‰",138:"Š",139:"‹",140:"Œ",142:"Ž",145:"‘",146:"’",147:"“",148:"”",149:"•",150:"–",151:"—",152:"˜",153:"™",154:"š",155:"›",156:"œ",158:"ž",159:"Ÿ"},it=[1,2,3,4,5,6,7,8,11,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,64976,64977,64978,64979,64980,64981,64982,64983,64984,64985,64986,64987,64988,64989,64990,64991,64992,64993,64994,64995,64996,64997,64998,64999,65e3,65001,65002,65003,65004,65005,65006,65007,65534,65535,131070,131071,196606,196607,262142,262143,327678,327679,393214,393215,458750,458751,524286,524287,589822,589823,655358,655359,720894,720895,786430,786431,851966,851967,917502,917503,983038,983039,1048574,1048575,1114110,1114111],nt=String.fromCharCode,pt={}.hasOwnProperty,dt=function(Q,ut){return pt.call(Q,ut)},yt=function(Q,ut){if(!Q)return ut;var at,Ct={};for(at in ut)Ct[at]=dt(Q,at)?Q[at]:ut[at];return Ct},D=function(Q,ut){var at="";return Q>=55296&&Q<=57343||Q>1114111?(ut&&L("character reference outside the permissible Unicode range"),"�"):dt(Y,Q)?(ut&&L("disallowed character reference"),Y[Q]):(ut&&function(Ct,kt){for(var Mt=-1,Wt=Ct.length;++Mt<Wt;)if(Ct[Mt]==kt)return!0;return!1}(it,Q)&&L("disallowed character reference"),Q>65535&&(at+=nt((Q-=65536)>>>10&1023|55296),Q=56320|1023&Q),at+=nt(Q))},At=function(Q){return"&#x"+Q.toString(16).toUpperCase()+";"},q=function(Q){return"&#"+Q+";"},L=function(Q){throw Error("Parse error: "+Q)},G=function(Q,ut){(ut=yt(ut,G.options)).strict&&E.test(Q)&&L("forbidden code point");var at=ut.encodeEverything,Ct=ut.useNamedReferences,kt=ut.allowUnsafeSymbols,Mt=ut.decimal?q:At,Wt=function(Rt){return Mt(Rt.charCodeAt(0))};return at?(Q=Q.replace(l,function(Rt){return Ct&&dt(m,Rt)?"&"+m[Rt]+";":Wt(Rt)}),Ct&&(Q=Q.replace(/&gt;\u20D2/g,"&nvgt;").replace(/&lt;\u20D2/g,"&nvlt;").replace(/&#x66;&#x6A;/g,"&fjlig;")),Ct&&(Q=Q.replace(p,function(Rt){return"&"+m[Rt]+";"}))):Ct?(kt||(Q=Q.replace(y,function(Rt){return"&"+m[Rt]+";"})),Q=(Q=Q.replace(/&gt;\u20D2/g,"&nvgt;").replace(/&lt;\u20D2/g,"&nvlt;")).replace(p,function(Rt){return"&"+m[Rt]+";"})):kt||(Q=Q.replace(y,Wt)),Q.replace(t,function(Rt){var Ce=Rt.charCodeAt(0),Fe=Rt.charCodeAt(1);return Mt(1024*(Ce-55296)+Fe-56320+65536)}).replace(h,Wt)};G.options={allowUnsafeSymbols:!1,encodeEverything:!1,strict:!1,useNamedReferences:!1,decimal:!1};var j=function(Q,ut){var at=(ut=yt(ut,j.options)).strict;return at&&S.test(Q)&&L("malformed character reference"),Q.replace(R,function(Ct,kt,Mt,Wt,Rt,Ce,Fe,Pe,qr){var ze,er,Cr,zr,rr,pr;return kt?I[rr=kt]:Mt?(rr=Mt,(pr=Wt)&&ut.isAttributeValue?(at&&pr=="="&&L("`&` did not start a character reference"),Ct):(at&&L("named character reference was not terminated by a semicolon"),U[rr]+(pr||""))):Rt?(Cr=Rt,er=Ce,at&&!er&&L("character reference was not terminated by a semicolon"),ze=parseInt(Cr,10),D(ze,at)):Fe?(zr=Fe,er=Pe,at&&!er&&L("character reference was not terminated by a semicolon"),ze=parseInt(zr,16),D(ze,at)):(at&&L("named character reference was not terminated by a semicolon"),Ct)})};j.options={isAttributeValue:!1,strict:!1};var Z={version:"1.2.0",encode:G,decode:j,escape:function(Q){return Q.replace(y,function(ut){return _[ut]})},unescape:j};if(e&&!e.nodeType)if(n)n.exports=Z;else for(var et in Z)dt(Z,et)&&(e[et]=Z[et]);else r.he=Z}(Nr);var is,Ln,F=Ir(Ca.exports);is=function(r){return function(){var e,n;function i(t,l){this._value=t,this._unit=l,n.has(l)&&(this._value=t*n.get(l),this._unit="sp")}return i.prototype,e=r,i.prototype._value=0,i.prototype._unit="",n=new Map([["sp",1],["pt",65536],["bp",65781.76],["pc",786432],["dd",81133568/1157],["cc",81133568/1157*12],["in",473628672e-2],["px",49336.32],["mm",473628672/2540],["cm",473628672/254]]),i.zero=new i(0,"sp"),Object.defineProperty(i.prototype,"value",{get:function(){return this._unit==="sp"?e.round(this._value/n.get("px"))+"px":e.round(this._value)+this._unit},configurable:!0,enumerable:!0}),Object.defineProperty(i.prototype,"px",{get:function(){return this._unit==="sp"?e.round(this._value/n.get("px")):e.error("Length.px() called on relative length!")},configurable:!0,enumerable:!0}),Object.defineProperty(i.prototype,"pxpct",{get:function(){return this._unit==="sp"?e.round(this._value/n.get("px")):e.round(this._value)+this._unit},configurable:!0,enumerable:!0}),Object.defineProperty(i.prototype,"unit",{get:function(){return this._unit},configurable:!0,enumerable:!0}),i.prototype.cmp=function(t){return this._unit!==t._unit&&e.error("Length.cmp(): incompatible lengths! ("+this._unit+" and "+t._unit+")"),this._value<t._value?-1:this._value===t._value?0:1},i.prototype.add=function(t){return this._unit!==t._unit&&e.error("Length.add(): incompatible lengths! ("+this._unit+" and "+t._unit+")"),new e.Length(this._value+t._value,this._unit)},i.prototype.sub=function(t){return this._unit!==t._unit&&e.error("Length.sub: incompatible lengths! ("+this._unit+" and "+t._unit+")"),new e.Length(this._value-t._value,this._unit)},i.prototype.mul=function(t){return new e.Length(this._value*t,this._unit)},i.prototype.div=function(t){return new e.Length(this._value/t,this._unit)},i.prototype.abs=function(){return new e.Length(Math.abs(this._value),this._unit)},i.prototype.ratio=function(t){return this._unit!==t._unit&&e.error("Length.ratio: incompatible lengths! ("+this._unit+" and "+t._unit+")"),this._value/t._value},i.prototype.norm=function(t){return this._unit!==t._unit&&e.error("Length.norm: incompatible lengths! ("+this._unit+" and "+t._unit+")"),new e.Length(Math.sqrt(Math.pow(this._value,2)+Math.pow(t._value,2)),this._unit)},i.min=function(){return Array.from(arguments).reduce(function(t,l){return t.cmp(l)<0?t:l})},i.max=function(){return Array.from(arguments).reduce(function(t,l){return t.cmp(l)>0?t:l})},i}()},Ln=function(){function r(e,n){this._x=e,this._y=n}return r.displayName="Vector",r.prototype,r.prototype._x=null,r.prototype._y=null,Object.defineProperty(r.prototype,"x",{get:function(){return this._x},configurable:!0,enumerable:!0}),Object.defineProperty(r.prototype,"y",{get:function(){return this._y},configurable:!0,enumerable:!0}),r.prototype.add=function(e){return new r(this._x.add(e.x),this._y.add(e.y))},r.prototype.sub=function(e){return new r(this._x.sub(e.x),this._y.sub(e.y))},r.prototype.mul=function(e){return new r(this._x.mul(e),this._y.mul(e))},r.prototype.shift_start=function(e){var n,i,t,l,h,p,m,y;if(this._x.unit!==this._y.unit)throw new Error("Vector.shift_start: incompatible lengths! ("+this._x.unit+" and "+this._y.unit+")");return n=this._x._value,i=this._y._value,t=Math.sqrt(1+i*i/(n*n)),l=Math.sqrt(1+n*n/(i*i)),h=n<0?-1:1,p=i<0?-1:1,n!==0&&i!==0?(m=e.div(t).mul(-h),y=e.div(l).mul(-p)):i===0?(m=e.mul(-h),y=this._y.mul(0)):(m=this._x.mul(0),y=e.mul(-p)),new r(m,y)},r.prototype.shift_end=function(e){var n,i,t,l,h,p,m,y;if(this._x.unit!==this._y.unit)throw new Error("Vector.shift_end: incompatible lengths! ("+this._x.unit+" and "+this._y.unit+")");return n=this._x._value,i=this._y._value,t=Math.sqrt(1+i*i/(n*n)),l=Math.sqrt(1+n*n/(i*i)),h=n<0?-1:1,p=i<0?-1:1,n!==0&&i!==0?(m=this._x.add(e.div(t).mul(h)),y=this._y.add(e.div(l).mul(p))):i===0?(m=this._x.add(e.mul(h)),y=this._y):(m=this._x,y=this._y.add(e.mul(p))),new r(m,y)},r.prototype.norm=function(){return this._x.norm(this._y)},r}();var _h,Pi,pn,Sn,Sh,ji,qh,w5=x5(Object.freeze({__proto__:null,get Vector(){return Ln},get makeLengthClass(){return is}})),k5=function(){function r(e,n,i,t){this.message=e,this.expected=n,this.found=i,this.location=t,this.name="SyntaxError",typeof Error.captureStackTrace=="function"&&Error.captureStackTrace(this,r)}return function(e,n){function i(){this.constructor=e}i.prototype=n.prototype,e.prototype=new i}(r,Error),r.buildMessage=function(e,n){var i={literal:function(p){return'"'+l(p.text)+'"'},class:function(p){var m,y="";for(m=0;m<p.parts.length;m++)y+=p.parts[m]instanceof Array?h(p.parts[m][0])+"-"+h(p.parts[m][1]):h(p.parts[m]);return"["+(p.inverted?"^":"")+y+"]"},any:function(p){return"any character"},end:function(p){return"end of input"},other:function(p){return p.description}};function t(p){return p.charCodeAt(0).toString(16).toUpperCase()}function l(p){return p.replace(/\\/g,"\\\\").replace(/"/g,'\\"').replace(/\0/g,"\\0").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/[\x00-\x0F]/g,function(m){return"\\x0"+t(m)}).replace(/[\x10-\x1F\x7F-\x9F]/g,function(m){return"\\x"+t(m)})}function h(p){return p.replace(/\\/g,"\\\\").replace(/\]/g,"\\]").replace(/\^/g,"\\^").replace(/-/g,"\\-").replace(/\0/g,"\\0").replace(/\t/g,"\\t").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/[\x00-\x0F]/g,function(m){return"\\x0"+t(m)}).replace(/[\x10-\x1F\x7F-\x9F]/g,function(m){return"\\x"+t(m)})}return"Expected "+function(p){var m,y,_,S=new Array(p.length);for(m=0;m<p.length;m++)S[m]=(_=p[m],i[_.type](_));if(S.sort(),S.length>0){for(m=1,y=1;m<S.length;m++)S[m-1]!==S[m]&&(S[y]=S[m],y++);S.length=y}switch(S.length){case 1:return S[0];case 2:return S[0]+" or "+S[1];default:return S.slice(0,-1).join(", ")+", or "+S[S.length-1]}}(e)+" but "+function(p){return p?'"'+l(p)+'"':"end of input"}(n)+" found."},{SyntaxError:r,parse:function(e,n){n=n!==void 0?n:{};var i,t={},l={latex:m0},h=m0,p=function(){we("expected \\begin{document}")},m=function(){we("\\end{document} missing")},y={type:"any"},_=function(){return N},S=function(){return N.macro("documentclass",[null,N.documentClass,null]),!0},E="document",R=W("document",!1),I=function(){return N.startBalanced(),N.enterGroup(),!0},U=function(s){N.exitGroup(),N.isBalanced()||we("groups need to be balanced!");var a=N.endBalanced();return a==1&&N.isBalanced()||we("grammar error: "+a+" levels of balancing are remaining, or the last level is unbalanced!"),N.createDocument(s),N.logUndefinedRefs(),N},Y=function(s,a,c,u){s.length>0&&N.break();var f=N.create(N.par,c,a?"noindent":"");return u&&N.break(),f},it=function(){return N.create(N.linebreak)},nt=function(){},pt=function(){return N.createText(N.sp)},dt=qt("text"),yt=function(s){return N.createText(s.join(""))},D=function(s){return s},At=function(){return N.enterGroup(!0),!0},q=function(s){return N.createText(s)},L=function(){if(!N.isBalanced())return N.exitGroup(),!0},G=qt("primitive"),j=function(){return N.sp},Z=function(s){return!N.isBalanced()},et=function(s){return s},Q=function(s){return s},ut=function(s){return N.break(),s},at=function(s){return N.isPreamble(s)},Ct=function(s){return N.isVmode(s)},kt=function(s){return N.isHmode(s)},Mt=function(s){return N.isHVmode(s)},Wt=function(s){return N.isHmode(s)||N.isHVmode(s)},Rt=function(s){if(N.hasMacro(s))return N.beginArgs(s),!0},Ce=function(s){var a=N.parsedArgs();return N.endArgs(),N.createFragment(N.macro(s,a))},Fe=function(s){we("macro only allowed in preamble: "+s)},Pe=function(s){we("unknown macro: \\"+s)},qr=qt("identifier"),ze=/^[\-$&_\/@]/,er=Te(["-","$","&","_","/","@"],!1,!1),Cr=/^[=,]/,zr=Te(["=",","],!1,!1),rr=qt("key=value"),pr="=",Wn=W("=",!1),yn=function(s){we("value expected")},$n=function(s,a){return a.trim()},Pr=function(s,a){return[s.trim(),a==null||a]},Ss=function(){return N.nextArg("X")},qs=function(){N.preExecMacro()},Cs=function(){return N.nextArg("g")},Zn=function(){N.argError("group argument expected")},Jn=function(s){N.addParsedArg(s)},zs=function(){return N.nextArg("hg")},Ts=function(){return N.nextArg("h")},Ms=function(){N.argError("horizontal material expected")},Es=function(s){N.addParsedArg(s)},Ds=function(){return N.nextArg("o?")},Ls=function(s){N.addParsedArg(s)},Bs=function(){return N.nextArg("i")},Ns=function(){N.argError("id group argument expected")},je=function(s){N.addParsedArg(s)},Os=function(){return N.nextArg("ie")},Fs=function(){N.argError("id or empty group arg expected")},Rs=function(){return N.nextArg("i?")},Hs=function(){return N.nextArg("k")},Vs=function(){N.argError("key group argument expected")},jr=function(s){N.addParsedArg(s)},Is=function(){return N.nextArg("k?")},Ps=function(){return N.nextArg("kv?")},js=function(){return N.nextArg("csv")},Gs=function(){N.argError("comma-sep. values group expected")},Gr=function(s){N.addParsedArg(s)},Us=function(){return N.nextArg("n")},Xs=function(){N.argError("num group argument expected")},Qn=function(s){N.addParsedArg(s)},Ys=function(){return N.nextArg("n?")},Ws=function(){return N.nextArg("l")},$s=function(){N.argError("length group argument expected")},Ur=function(s){N.addParsedArg(s)},Zs=function(){return N.nextArg("lg?")},Js=function(){return N.nextArg("l?")},Qs=function(){return N.nextArg("m")},Ks=function(){N.argError("macro group argument expected")},tl=function(s){N.addParsedArg(s)},el=function(){return N.nextArg("u")},rl=function(){N.argError("url group argument expected")},nl=function(s){N.addParsedArg(s)},il=function(){return N.nextArg("c")},ol=function(){N.argError("color group expected")},se=function(s){N.addParsedArg(s)},al=function(){return N.nextArg("c-ml")},sl=function(){N.argError("color model list expected")},ll=function(){return N.nextArg("c-ml?")},ul=function(){return N.nextArg("c-ssp")},cl=function(){N.argError("color set spec expected")},hl=function(){return N.nextArg("c-spl")},pl=function(){N.argError("color spec list expected")},dl=function(){return N.nextArg("cl")},ml=function(){N.argError("coordinate/length group expected")},fl=function(){return N.nextArg("cl?")},gl=function(){return N.nextArg("v")},bl=function(){N.argError("coordinate pair expected")},yl=function(){return N.nextArg("v?")},vl=function(){return N.nextArg("cols")},xl=function(){N.argError("column specification missing")},wl=function(){return N.nextArg("is")},kl=function(){return N.nextArg("items")},Al=function(){return N.nextArg("enumitems")},_l=function(){return N.selectArgsBranch("[")},Sl=function(){return N.selectArgsBranch("{")},i1=function(){return N.nextArg("s")},nr="*",ir=W("*",!1),o1=function(s){return N.addParsedArg(!!s),!!s},Kn=function(s){return s},ql=function(s){return s},le=",",ue=W(",",!1),ti=function(){return null},Cl=function(s){return s},a1=function(s){return new Map(s.filter(a=>a!=null))},zl=function(s){return s.trim()},s1=function(s){return s.filter(a=>a!=null)},Tl="sp",l1=W("sp",!1),Ml="pt",u1=W("pt",!1),El="px",c1=W("px",!1),Dl="dd",h1=W("dd",!1),Ll="mm",p1=W("mm",!1),Bl="pc",d1=W("pc",!1),Nl="cc",m1=W("cc",!1),Ol="cm",f1=W("cm",!1),Fl="in",g1=W("in",!1),Rl="ex",b1=W("ex",!1),Hl="em",y1=W("em",!1),v1=function(s){return s},x1=function(s,a){return new N.Length(s,a)},uo=function(s){return s},Vl=function(s){return s},w1=function(s){return N.length("unitlength").mul(s)},vn=function(s){return s},co="(",ho=W("(",!1),po=")",mo=W(")",!1),k1=function(s,a){return new v5(s,a)},Il="%",Pl=W("%",!1),A1=function(s){return s},_1=/^[\-._~:\/?#[\]@!$&()*+,;=]/,S1=Te(["-",".","_","~",":","/","?","#","[","]","@","!","$","&","(",")","*","+",",",";","="],!1,!1),jl="'",Gl=W("'",!1),q1=function(){we("illegal char in url given")},Ul=function(s){return s},C1=function(s){return s.join("")},fo=function(){return N.enterGroup(),N.startBalanced(),!0},z1=function(s,a){return N.isBalanced()||we("groups inside an argument need to be balanced!"),N.endBalanced(),N.exitGroup(),s!=null&&a.unshift(N.createText(s)),N.createFragment(a)},T1=function(s){return N.createFragment(s)},M1=function(s,a){return N.isBalanced()||we("groups inside an argument need to be balanced!"),N.endBalanced(),N.exitGroup(),N.createFragment(N.createText(s),a)},E1=function(s){return N.isBalanced()},D1=function(s){return N.isBalanced()||we("groups inside an optional argument need to be balanced!"),N.endBalanced(),N.exitGroup(),N.createFragment(s)},Xl="value",L1=W("value",!1),Yl="real",B1=W("real",!1),N1=function(s){return s},O1=function(s){return s},F1=function(s){return N.counter(s)},xn="+",wn=W("+",!1),Xr="-",Yr=W("-",!1),R1=function(s,a){return s=="-"?-a:a},Wr="/",$r=W("/",!1),H1=function(s,a){var c,u=s;for(c=0;c<a.length;c++)a[c][1]==="*"&&(u=Math.trunc(u*a[c][3])),a[c][1]==="/"&&(u=Math.trunc(u/a[c][3]));return Math.trunc(u)},V1=function(s,a){var c,u=s;for(c=0;c<a.length;c++)a[c][1]==="+"&&(u+=a[c][3]),a[c][1]==="-"&&(u-=a[c][3]);return u},Wl=function(s){return s},I1=function(s){return s},P1=function(s){return s},$l=":",Zl=W(":",!1),ei=";",ri=W(";",!1),Zr="!",Jr=W("!",!1),j1=">",G1=W(">",!1),Jl="wheel",U1=W("wheel",!1),Ql="twheel",X1=W("twheel",!1),Y1=function(s){return s.length%2==0},go=".",bo=W(".",!1),Kl="!!",W1=W("!!",!1),yo="[",vo=W("[",!1),xo="]",wo=W("]",!1),tu="rgb",$1=W("rgb",!1),eu="cmyk",Z1=W("cmyk",!1),ru="cmy",J1=W("cmy",!1),nu="hsb",Q1=W("hsb",!1),iu="gray",K1=W("gray",!1),ou="RBG",t4=W("RBG",!1),au="HTML",e4=W("HTML",!1),su="HSB",r4=W("HSB",!1),lu="Gray",n4=W("Gray",!1),uu="Hsb",i4=W("Hsb",!1),cu="tHsb",o4=W("tHsb",!1),hu="wave",a4=W("wave",!1),pu="named",s4=W("named",!1),l4=function(s,a,c){s&&(s=s[0]);var u=[a];return c.forEach(f=>u.push(f[1])),{core:s,models:u}},u4=function(s,a){var c=[s];return a.forEach(u=>c.push(u[1])),c},c4=function(s,a){var c=[s];return a.forEach(u=>c.push(u[1])),c},h4=function(s,a,c){var u=[{name:s,speclist:a}];return c.forEach(f=>u.push({name:f[2],speclist:f[4]})),u},du=function(s,a,c){return Array.isArray(a)?a.concat(c):[a].concat(c)},p4=function(s,a){return a.reduce(function(c,u){return c.concat(u)},s)},d4="l",m4=W("l",!1),f4="c",g4=W("c",!1),b4="r",y4=W("r",!1),v4="p",x4=W("p",!1),w4=function(s){return s},k4=function(s,a){for(var c=[],u=0;u<s;u++)c=c.concat(a.slice());return c},A4="|",_4=W("|",!1),S4="@",q4=W("@",!1),C4=function(s){return s},z4=function(s){return{type:"separator",content:s}},ni="vspace",mu=W("vspace",!1),T4=function(s){return N.createVSpaceInline(s)},M4=function(s){return N.createVSpace(s)},ii="small",fu=W("small",!1),oi="med",gu=W("med",!1),ai="big",bu=W("big",!1),si="skip",yu=W("skip",!1),E4=function(s){return N.createVSpaceSkipInline(s+"skip")},D4=function(s){return N.createVSpaceSkip(s+"skip")},vu="verb",L4=W("verb",!1),xu=function(s,a,c){return a==c},B4=function(s,a,c,u){return a==u||we("\\verb is missing its end delimiter: "+a),s&&(c=c.replace(/ /g,N.visp)),N.create(N.verb,N.createVerbatim(c,!0))},N4=qt("\\begin"),O4=function(s){return N.begin(s),s},F4=function(s,a){return{id:s,end:s+(a?"*":"")}},R4=qt("\\end"),H4=function(s,a){return s+(a?"*":"")},wu=function(s){return N.macro(s.id,N.endArgs())},V4=function(s,a,c){return N.createText(c)},I4=function(s,a,c,u,f,v){return N.createText(v)},P4=function(s,a,c,u,f,v){var w=N.end(s.end,f),C=N.createFragment(u);return C&&a&&a.length>0&&a[a.length-1].nodeType===1?(a[a.length-1].appendChild(c),a[a.length-1].appendChild(C),N.createFragment(a,w,v)):N.createFragment(a,c,C,w,v)},j4=function(s){N.break()},G4=function(s,a,c,u){var f=N.end(s.end,u),v=N.createFragment(c);return v&&a&&a.length>0&&a[a.length-1].nodeType===1?(a[a.length-1].appendChild(v),N.createFragment(a,f)):N.createFragment(a,v,f)},ku="item",U4=W("item",!1),X4=function(){N.break()},Y4=function(s){return s},dr=function(s,a){return a},li=function(s,a){return{label:s,text:N.createFragment(a)}},Au=function(s){if(s===null){var a="enum"+N.roman(N.counter("@enumdepth")),c="item-"+N.nextId();return N.stepCounter(a),N.refCounter(a,c),{id:c,node:N.macro("label"+a)}}return{id:void 0,node:s}},W4=qt("comment environment"),_u="\\begin",$4=W("\\begin",!1),ui="{comment}",Su=W("{comment}",!1),Z4=function(){N.break()},qu="\\end",J4=W("\\end",!1),Cu=function(s){return N.parseMath(s,!1)},zu=function(s){return N.parseMath(s,!0)},Tu="begin",Q4=W("begin",!1),Qr=function(){},Mu="end",K4=W("end",!1),Eu="par",td=W("par",!1),Du="noindent",ed=W("noindent",!1),Lu="plus",rd=W("plus",!1),Bu="minus",nd=W("minus",!1),Nu="endinput",id=W("endinput",!1),Ou="\\",Fu=W("\\",!1),od="{",ad=W("{",!1),sd="}",ld=W("}",!1),ud=qt("math"),cd="$",hd=W("$",!1),pd="&",dd=W("&",!1),md=qt("parameter"),fd="#",gd=W("#",!1),bd="^",yd=W("^",!1),vd="_",xd=W("_",!1),wd="\0",kd=W("\0",!1),Ad=qt("EOF"),_d=qt("newline"),Sd=`
`,qd=W(`
`,!1),Ru=`\r
`,Cd=W(`\r
`,!1),zd="\r",Td=W("\r",!1),Md="\u2028",Ed=W("\u2028",!1),Dd="\u2029",Ld=W("\u2029",!1),Bd=qt("whitespace"),Nd=/^[ \t]/,Od=Te([" ","	"],!1,!1),Fd=qt("comment"),ko=qt("spaces"),Hu=function(){return N.brsp},Rd=qt("control space"),Hd=qt("non-brk space"),Vd="~",Id=W("~",!1),Pd=function(){return N.nbsp},jd=qt("paragraph break"),Gd=function(){return!0},Ud=qt("linebreak"),Xd=function(s){return s},Yd=function(s){return s?N.createBreakSpace(s):N.create(N.linebreak)},Vu="put",Wd=W("put",!1),Iu="newline",$d=W("newline",!1),Zd=qt("letter"),Jd=/^[a-z]/i,Qd=Te([["a","z"]],!1,!0),Kd=function(s){return N.character(s)},tm=qt("digit"),Ao=/^[0-9]/,_o=Te([["0","9"]],!1,!1),em=function(s){return N.character(s)},rm=qt("punctuation"),nm=/^[.,;:*\/()!?=+<>]/,im=Te([".",",",";",":","*","/","(",")","!","?","=","+","<",">"],!1,!1),om=function(s){return N.character(s)},am=qt("quotes"),sm=/^[`']/,lm=Te(["`","'"],!1,!1),um=function(s){return N.textquote(s)},cm=qt("left bracket"),Pu=function(s){return N.character(s)},hm=qt("right bracket"),pm=qt("utf8 char"),dm=function(s){return N.character(s)},mm=qt("hyphen"),fm=function(){return N.hyphen()},gm=qt("ligature"),ju="ffi",bm=W("ffi",!1),Gu="ffl",ym=W("ffl",!1),Uu="ff",vm=W("ff",!1),Xu="fi",xm=W("fi",!1),Yu="fl",wm=W("fl",!1),Wu="---",km=W("---",!1),$u="--",Am=W("--",!1),Zu="``",_m=W("``",!1),Ju="''",Sm=W("''",!1),Qu="!´",qm=W("!´",!1),Ku="?´",Cm=W("?´",!1),t0="<<",zm=W("<<",!1),e0=">>",Tm=W(">>",!1),Mm=function(s){return N.ligature(s)},Em=qt("control symbol"),Dm=/^[$%#&{}_\-,\/@]/,Lm=Te(["$","%","#","&","{","}","_","-",",","/","@"],!1,!1),Bm=function(s){return N.controlSymbol(s)},Nm=qt("symbol macro"),Om=function(s){return N.hasSymbol(s)},Fm=function(s){return N.symbol(s)},Rm=qt("diacritic macro"),Hm=function(s){return N.hasDiacritic(s)},Vm=function(s,a,c){return N.diacritic(s,a)+(c||"")},Im=function(s,a){return N.diacritic(s,a)},Pm=function(s,a){return a},r0="symbol",jm=W("symbol",!1),ci=function(s){return String.fromCharCode(s)},n0="char",Gm=W("char",!1),i0="^^^^",Um=W("^^^^",!1),hi="^^",o0=W("^^",!1),Xm=function(s){return s=s.charCodeAt(0),String.fromCharCode(s<64?s+64:s-64)},Ym=function(s){return parseInt(s,10)},Wm=function(s){return parseInt(s,8)},$m='"',Zm=W('"',!1),Jm=function(s){return s},Qm=qt("8bit hex value"),a0=function(s){return parseInt(s,16)},Km=qt("16bit hex value"),t5=qt("integer value"),e5=qt("octal value"),s0=/^[0-7]/,l0=Te([["0","7"]],!1,!1),r5=qt("hex digit"),n5=/^[a-f0-9]/i,i5=Te([["a","f"],["0","9"]],!1,!0),o5=qt("float value"),a5=/^[+\-]/,s5=Te(["+","-"],!1,!1),l5=function(s){return parseFloat(s)},u0="the",u5=W("the",!1),c0=function(s){return N.hasCounter(s)},c5=function(s){return N.createText(""+N.counter(s))},h5=function(s){return N.theLength(s)},p5=function(s){return s},h0="showthe",d5=W("showthe",!1),m5=function(s){console.log(N.counter(s))},f5=function(s){console.log(N.length(s))},p0="message",g5=W("message",!1),b5=function(s){console.log(s.textContent)},o=0,k=0,pi=[{line:1,column:1}],Ge=0,So=[],b=0;if("startRule"in n){if(!(n.startRule in l))throw new Error(`Can't start parsing from rule "`+n.startRule+'".');h=l[n.startRule]}function we(s,a){throw function(c,u){return new r(c,null,null,u)}(s,a=a!==void 0?a:di(k,o))}function W(s,a){return{type:"literal",text:s,ignoreCase:a}}function Te(s,a,c){return{type:"class",parts:s,inverted:a,ignoreCase:c}}function qt(s){return{type:"other",description:s}}function d0(s){var a,c=pi[s];if(c)return c;for(a=s-1;!pi[a];)a--;for(c={line:(c=pi[a]).line,column:c.column};a<s;)e.charCodeAt(a)===10?(c.line++,c.column=1):c.column++,a++;return pi[s]=c,c}function di(s,a){var c=d0(s),u=d0(a);return{start:{offset:s,line:c.line,column:c.column},end:{offset:a,line:u.line,column:u.column}}}function z(s){o<Ge||(o>Ge&&(Ge=o,So=[]),So.push(s))}function m0(){var s,a,c,u,f,v,w,C,O;if(s=o,a=o,b++,c=f0(),b--,c!==t?(o=a,a=void 0):a=t,a!==t){for(c=[],u=o,(f=Xt())!==t&&(v=_t())!==t?(w=o,b++,C=Co(),b--,C!==t?(o=w,w=void 0):w=t,w===t&&(w=o,b++,C=fi(),b--,C!==t?(o=w,w=void 0):w=t),w!==t&&(C=An())!==t?u=f=[f,v,w,C]:(o=u,u=t)):(o=u,u=t);u!==t;)c.push(u),u=o,(f=Xt())!==t&&(v=_t())!==t?(w=o,b++,C=Co(),b--,C!==t?(o=w,w=void 0):w=t,w===t&&(w=o,b++,C=fi(),b--,C!==t?(o=w,w=void 0):w=t),w!==t&&(C=An())!==t?u=f=[f,v,w,C]:(o=u,u=t)):(o=u,u=t);if(c!==t)if((u=Xt())!==t)if(f=function(){var P,K,V,tt,ot,mt,ct;return P=o,K=_t(),K!==t&&(V=_n())!==t&&(tt=X())!==t&&(ot=Dt())!==t?(e.substr(o,8)===E?(mt=E,o+=8):(mt=t,b===0&&z(R)),mt!==t&&(ct=Ot())!==t?P=K=[K,V,tt,ot,mt,ct]:(o=P,P=t)):(o=P,P=t),P}(),f===t&&(k=o,f=(f=p())?void 0:t),f!==t)if((v=b0())!==t)if((w=g0())===t&&(k=o,w=(w=m())?void 0:t),w!==t){for(C=[],e.length>o?(O=e.charAt(o),o++):(O=t,b===0&&z(y));O!==t;)C.push(O),e.length>o?(O=e.charAt(o),o++):(O=t,b===0&&z(y));C!==t&&(O=Si())!==t?(k=s,s=a=_()):(o=s,s=t)}else o=s,s=t;else o=s,s=t;else o=s,s=t;else o=s,s=t;else o=s,s=t}else o=s,s=t;return s===t&&(s=o,a=o,b++,c=f0(),b--,c===t?a=void 0:(o=a,a=t),a!==t?(k=o,(c=(c=S())?void 0:t)!==t&&(u=b0())!==t&&(f=Si())!==t?(k=s,s=a=_()):(o=s,s=t)):(o=s,s=t)),s}function f0(){var s,a,c,u,f;return s=o,(a=Xt())!==t&&(c=_t())!==t?(u=o,b++,f=fi(),b--,f!==t?(o=u,u=void 0):u=t,u!==t?s=a=[a,c,u]:(o=s,s=t)):(o=s,s=t),s}function g0(){var s,a,c,u,f,v,w;return s=o,(a=_t())!==t&&(c=Ai())!==t&&(u=X())!==t&&(f=Dt())!==t?(e.substr(o,8)===E?(v=E,o+=8):(v=t,b===0&&z(R)),v!==t&&(w=Ot())!==t?s=a=[a,c,u,f,v,w]:(o=s,s=t)):(o=s,s=t),s}function b0(){var s,a,c;if(s=o,k=o,(I()?void 0:t)!==t)if(Xt()!==t){for(a=[],c=Me();c!==t;)a.push(c),c=Me();a!==t&&(c=Xt())!==t?(k=s,s=U(a)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;return s}function Me(){var s,a,c,u,f,v;if((s=v0())===t){for(s=o,a=[],c=o,u=o,(f=_t())!==t&&(v=_i())!==t?u=f=[f,v]:(o=u,u=t),u===t&&(u=null),u!==t&&(f=Re())!==t?c=u=[u,f]:(o=c,c=t);c!==t;)a.push(c),c=o,u=o,(f=_t())!==t&&(v=_i())!==t?u=f=[f,v]:(o=u,u=t),u===t&&(u=null),u!==t&&(f=Re())!==t?c=u=[u,f]:(o=c,c=t);if(a!==t)if((c=X())!==t)if(u=o,(f=_t())!==t&&(v=_i())!==t?u=f=[f,v]:(o=u,u=t),u===t&&(u=null),u!==t){if(f=[],(v=mi())!==t)for(;v!==t;)f.push(v),v=mi();else f=t;f!==t?((v=Re())===t&&(v=null),v!==t?(k=s,s=a=Y(a,u,f,v)):(o=s,s=t)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;else o=s,s=t}return s}function Kr(){var s,a;return(s=mi())===t&&(s=v0())===t&&(s=o,(a=Re())!==t&&(k=s,a=it()),s=a),s}function y0(){var s,a;return s=o,(a=qi())!==t&&(k=s,a=nt()),(s=a)===t&&(s=o,(a=Re())!==t&&(k=s,a=pt()),(s=a)===t&&(s=mi())),s}function mi(){var s,a,c,u,f;if(b++,s=o,a=[],(c=tc())===t&&(c=kn())===t&&(c=o,u=o,b++,f=Re(),b--,f===t?u=void 0:(o=u,u=t),u!==t&&(f=me())!==t?(k=c,c=u=nt()):(o=c,c=t)),c!==t)for(;c!==t;)a.push(c),(c=tc())===t&&(c=kn())===t&&(c=o,u=o,b++,f=Re(),b--,f===t?u=void 0:(o=u,u=t),u!==t&&(f=me())!==t?(k=c,c=u=nt()):(o=c,c=t));else a=t;return a!==t&&(k=s,a=yt(a)),(s=a)===t&&(s=qi())===t&&(s=o,a=o,c=o,b++,u=J0(),b--,u!==t?(o=c,c=void 0):c=t,c!==t&&(u=X())!==t?a=c=[c,u]:(o=a,a=t),a===t&&(a=null),a!==t?(c=function(){var v,w,C,O,P,K;return v=Ue(),v===t&&(v=o,_t()!==t?(w=o,C=o,b++,O=function(){var V,tt,ot;return V=o,tt=oe(),tt!==t?(k=o,(ot=(ot=kt(tt))?void 0:t)!==t?V=tt=[tt,ot]:(o=V,V=t)):(o=V,V=t),V}(),b--,O!==t?(o=C,C=void 0):C=t,C!==t&&(O=An())!==t?(k=w,w=C=D(O)):(o=w,w=t),w===t&&(w=o,C=o,b++,O=function(){var V,tt,ot,mt,ct;return V=o,tt=_n(),tt!==t&&(ot=Dt())!==t&&(mt=oe())!==t?(k=o,(ct=(ct=Wt(mt))?void 0:t)!==t?V=tt=[tt,ot,mt,ct]:(o=V,V=t)):(o=V,V=t),V}(),b--,O!==t?(o=C,C=void 0):C=t,C!==t?(O=function(){var V,tt,ot,mt,ct,Yt,Ht,Lt;if(V=o,tt=G0(),tt!==t)if(zo()!==t)if(ot=o,mt=o,b++,e.length>o?(ct=e.charAt(o),o++):(ct=t,b===0&&z(y)),b--,ct!==t?(o=mt,mt=void 0):mt=t,mt!==t&&(k=ot,mt=wu(tt)),(ot=mt)!==t)if(mt=o,(ct=mr())===t&&(ct=null),ct!==t&&(k=mt,ct=V4(tt,ot,ct)),(mt=ct)!==t){for(ct=[],Yt=Kr();Yt!==t;)ct.push(Yt),Yt=Kr();ct!==t&&(Yt=Xe())!==t?(Ht=o,(Lt=mr())===t&&(Lt=null),Lt!==t&&(k=Ht,Lt=I4(tt,ot,mt,ct,Yt,Lt)),(Ht=Lt)!==t?(k=V,V=tt=P4(tt,ot,mt,ct,Yt,Ht)):(o=V,V=t)):(o=V,V=t)}else o=V,V=t;else o=V,V=t;else o=V,V=t;else o=V,V=t;return V}(),O!==t?(k=w,w=C=Q(O)):(o=w,w=t)):(o=w,w=t),w===t&&(w=_i())===t&&(w=function(){var V,tt,ot,mt,ct;return V=o,tt=o,e.substr(o,5)===ii?(ot=ii,o+=5):(ot=t,b===0&&z(fu)),ot===t&&(e.substr(o,3)===oi?(ot=oi,o+=3):(ot=t,b===0&&z(gu)),ot===t&&(e.substr(o,3)===ai?(ot=ai,o+=3):(ot=t,b===0&&z(bu)))),tt=ot!==t?e.substring(tt,o):ot,tt!==t?(e.substr(o,4)===si?(ot=si,o+=4):(ot=t,b===0&&z(yu)),ot!==t?(mt=o,b++,ct=It(),b--,ct===t?mt=void 0:(o=mt,mt=t),mt!==t&&(ct=X())!==t?(k=V,V=tt=E4(tt)):(o=V,V=t)):(o=V,V=t)):(o=V,V=t),V}(),w===t&&(w=function(){var V,tt,ot,mt;return V=o,e.substr(o,6)===ni?(tt=ni,o+=6):(tt=t,b===0&&z(mu)),tt!==t?(e.charCodeAt(o)===42?(ot=nr,o++):(ot=t,b===0&&z(ir)),ot===t&&(ot=null),ot!==t&&(mt=Tr())!==t?(k=V,V=tt=T4(mt)):(o=V,V=t)):(o=V,V=t),V}(),w===t&&(w=function(){var V,tt,ot,mt,ct,Yt,Ht;return V=o,e.substr(o,3)===u0?(tt=u0,o+=3):(tt=t,b===0&&z(u5)),tt!==t?(ot=o,b++,mt=It(),b--,mt===t?ot=void 0:(o=ot,ot=t),ot!==t&&(mt=X())!==t?(ct=o,(Yt=No())!==t?(k=o,(Ht=(Ht=c0(Yt))?void 0:t)!==t?(k=ct,ct=Yt=c5(Yt)):(o=ct,ct=t)):(o=ct,ct=t),ct===t&&(ct=o,(Yt=_t())!==t&&(Ht=oe())!==t&&X()!==t?(k=ct,ct=Yt=h5(Ht)):(o=ct,ct=t)),ct!==t?(k=V,V=tt=p5(ct)):(o=V,V=t)):(o=V,V=t)):(o=V,V=t),V}(),w===t&&(w=function(){var V,tt,ot,mt,ct,Yt,Ht,Lt,fe,ge,on;if(V=o,e.substr(o,4)===vu?(tt=vu,o+=4):(tt=t,b===0&&z(L4)),tt!==t)if(e.charCodeAt(o)===42?(ot=nr,o++):(ot=t,b===0&&z(ir)),ot===t&&(ot=null),ot!==t)if(X()!==t)if(mt=o,b++,ct=It(),b--,ct===t?mt=void 0:(o=mt,mt=t),mt!==t)if(e.length>o?(ct=e.charAt(o),o++):(ct=t,b===0&&z(y)),ct!==t){for(Yt=o,Ht=[],Lt=o,fe=o,b++,ge=te(),b--,ge===t?fe=void 0:(o=fe,fe=t),fe!==t?(e.length>o?(ge=e.charAt(o),o++):(ge=t,b===0&&z(y)),ge!==t?(k=o,(on=(on=xu(ot,ct,ge))?t:void 0)!==t?Lt=fe=[fe,ge,on]:(o=Lt,Lt=t)):(o=Lt,Lt=t)):(o=Lt,Lt=t);Lt!==t;)Ht.push(Lt),Lt=o,fe=o,b++,ge=te(),b--,ge===t?fe=void 0:(o=fe,fe=t),fe!==t?(e.length>o?(ge=e.charAt(o),o++):(ge=t,b===0&&z(y)),ge!==t?(k=o,(on=(on=xu(ot,ct,ge))?t:void 0)!==t?Lt=fe=[fe,ge,on]:(o=Lt,Lt=t)):(o=Lt,Lt=t)):(o=Lt,Lt=t);(Yt=Ht!==t?e.substring(Yt,o):Ht)!==t?(e.length>o?(Ht=e.charAt(o),o++):(Ht=t,b===0&&z(y)),Ht!==t?(k=V,V=tt=B4(ot,ct,Yt,Ht)):(o=V,V=t)):(o=V,V=t)}else o=V,V=t;else o=V,V=t;else o=V,V=t;else o=V,V=t;else o=V,V=t;return V}(),w===t&&(w=o,C=o,b++,O=fi(),b--,O!==t?(o=C,C=void 0):C=t,C!==t?(O=function(){var V,tt;return V=o,tt=oe(),tt!==t&&(k=V,tt=Fe(tt)),V=tt,V}(),O!==t?w=C=[C,O]:(o=w,w=t)):(o=w,w=t),w===t&&(w=o,C=o,b++,O=_n(),b--,O===t?C=void 0:(o=C,C=t),C!==t?(O=o,b++,P=Ai(),b--,P===t?O=void 0:(o=O,O=t),O!==t?(P=o,b++,K=qo(),b--,K===t?P=void 0:(o=P,P=t),P!==t?(K=function(){var V,tt;return V=o,tt=oe(),tt!==t&&(k=V,tt=Pe(tt)),V=tt,V}(),K!==t?w=C=[C,O,P,K]:(o=w,w=t)):(o=w,w=t)):(o=w,w=t)):(o=w,w=t)))))))),w!==t?(k=v,v=D(w)):(o=v,v=t)):(o=v,v=t)),v}(),c!==t?(k=s,s=a=D(c)):(o=s,s=t)):(o=s,s=t),s===t&&(s=function(){var v;return v=function(){var w,C,O,P,K,V;if(w=o,C=Mr(),C!==t){if(O=o,P=[],(K=Ye())!==t)for(;K!==t;)P.push(K),K=Ye();else P=t;(O=P!==t?e.substring(O,o):P)!==t&&(P=Mr())!==t?(k=w,w=C=Cu(O)):(o=w,w=t)}else o=w,w=t;if(w===t)if(w=o,(C=_t())!==t)if(e.charCodeAt(o)===40?(O=co,o++):(O=t,b===0&&z(ho)),O!==t){if(P=o,K=[],(V=Ye())!==t)for(;V!==t;)K.push(V),V=Ye();else K=t;(P=K!==t?e.substring(P,o):K)!==t&&(K=_t())!==t?(e.charCodeAt(o)===41?(V=po,o++):(V=t,b===0&&z(mo)),V!==t?(k=w,w=C=Cu(P)):(o=w,w=t)):(o=w,w=t)}else o=w,w=t;else o=w,w=t;return w}(),v===t&&(v=function(){var w,C,O,P,K;if(w=o,C=Mr(),C!==t)if(Mr()!==t){if(O=o,P=[],(K=Ye())!==t)for(;K!==t;)P.push(K),K=Ye();else P=t;(O=P!==t?e.substring(O,o):P)!==t&&(P=Mr())!==t&&(K=Mr())!==t?(k=w,w=C=zu(O)):(o=w,w=t)}else o=w,w=t;else o=w,w=t;if(w===t)if(w=o,(C=_t())!==t)if(Q0()!==t){if(O=o,P=[],(K=Ye())!==t)for(;K!==t;)P.push(K),K=Ye();else P=t;(O=P!==t?e.substring(O,o):P)!==t&&(P=_t())!==t&&(K=K0())!==t?(k=w,w=C=zu(O)):(o=w,w=t)}else o=w,w=t;else o=w,w=t;return w}()),v}(),s===t&&(s=o,(a=Dt())!==t?(k=o,(c=(c=At())?void 0:t)!==t?((u=mr())===t&&(u=null),u!==t?(k=s,s=a=q(u)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t),s===t&&(s=o,(a=Ot())!==t?(k=o,(c=(c=L())?void 0:t)!==t?((u=mr())===t&&(u=null),u!==t?(k=s,s=a=q(u)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t))))),b--,s===t&&(a=t,b===0&&z(dt)),s}function kn(){var s,a,c,u;return b++,(s=It())===t&&(s=o,(a=mr())!==t?(c=o,b++,u=J0(),b--,u===t?c=void 0:(o=c,c=t),c!==t?(k=s,s=a=j()):(o=s,s=t)):(o=s,s=t),s===t&&(s=function(){var f,v;return b++,f=o,e.charCodeAt(o)===45?(v=Xr,o++):(v=t,b===0&&z(Yr)),v!==t&&(k=f,v=fm()),f=v,b--,f===t&&(v=t,b===0&&z(mm)),f}(),s===t&&(s=rn())===t&&(s=function(){var f,v;return b++,f=o,nm.test(e.charAt(o))?(v=e.charAt(o),o++):(v=t,b===0&&z(im)),v!==t&&(k=f,v=om(v)),f=v,b--,f===t&&(v=t,b===0&&z(rm)),f}(),s===t&&(s=function(){var f,v;return b++,f=o,sm.test(e.charAt(o))?(v=e.charAt(o),o++):(v=t,b===0&&z(lm)),v!==t&&(k=f,v=um(v)),f=v,b--,f===t&&(v=t,b===0&&z(am)),f}(),s===t&&(s=Q0())===t&&(s=o,(a=K0())!==t?(k=o,(c=(c=Z())?void 0:t)!==t?(k=s,s=a=et(a)):(o=s,s=t)):(o=s,s=t),s===t&&(s=function(){var f,v;return b++,f=o,e.charCodeAt(o)===126?(v=Vd,o++):(v=t,b===0&&z(Id)),v!==t&&(k=f,v=Pd()),f=v,b--,f===t&&(v=t,b===0&&z(Hd)),f}(),s===t&&(s=function(){var f,v,w,C,O,P;return b++,f=o,v=_t(),v!==t?(w=o,C=o,b++,O=te(),b--,O!==t?(o=C,C=void 0):C=t,C!==t?(O=o,b++,P=Re(),b--,P!==t?(o=O,O=void 0):O=t,O!==t?w=C=[C,O]:(o=w,w=t)):(o=w,w=t),w===t&&(w=te())===t&&(w=$t()),w!==t?(k=f,f=v=Hu()):(o=f,f=t)):(o=f,f=t),b--,f===t&&(v=t,b===0&&z(Rd)),f}(),s===t&&(s=function(){var f,v,w,C,O,P,K,V,tt;return b++,f=o,v=_t(),v!==t?(w=o,C=o,(O=It())!==t?(P=o,b++,K=It(),b--,K===t?P=void 0:(o=P,P=t),P!==t?C=O=[O,P]:(o=C,C=t)):(o=C,C=t),C===t&&(C=o,O=o,b++,P=It(),b--,P===t?O=void 0:(o=O,O=t),O!==t?(e.length>o?(P=e.charAt(o),o++):(P=t,b===0&&z(y)),P!==t?C=O=[O,P]:(o=C,C=t)):(o=C,C=t)),(w=C!==t?e.substring(w,o):C)!==t?(k=o,(C=(C=Hm(w))?void 0:t)!==t&&(O=X())!==t?(P=o,(K=Dt())!==t?((V=kn())===t&&(V=null),V!==t&&Ot()!==t?((tt=mr())===t&&(tt=null),tt!==t?(k=P,P=K=Vm(w,V,tt)):(o=P,P=t)):(o=P,P=t)):(o=P,P=t),P===t&&(P=o,(K=kn())!==t&&(k=P,K=Im(w,K)),P=K),P!==t?(k=f,f=v=Pm(w,P)):(o=f,f=t)):(o=f,f=t)):(o=f,f=t)):(o=f,f=t),b--,f===t&&(v=t,b===0&&z(Rm)),f}(),s===t&&(s=function(){var f,v,w;return b++,f=o,v=_t(),v!==t?(Dm.test(e.charAt(o))?(w=e.charAt(o),o++):(w=t,b===0&&z(Lm)),w!==t?(k=f,f=v=Bm(w)):(o=f,f=t)):(o=f,f=t),b--,f===t&&(v=t,b===0&&z(Em)),f}(),s===t&&(s=function(){var f,v,w;return b++,f=o,v=_t(),v!==t&&(w=oe())!==t?(k=o,(Om(w)?void 0:t)!==t&&X()!==t?(k=f,f=v=Fm(w)):(o=f,f=t)):(o=f,f=t),b--,f===t&&(v=t,b===0&&z(Nm)),f}(),s===t&&(s=function(){var f,v,w,C,O;return f=o,v=_t(),v!==t?(e.substr(o,6)===r0?(w=r0,o+=6):(w=t,b===0&&z(jm)),w!==t&&(C=Dt())!==t&&X()!==t&&(O=Go())!==t&&X()!==t&&Ot()!==t?(k=f,f=v=ci(O)):(o=f,f=t)):(o=f,f=t),f===t&&(f=o,(v=_t())!==t?(e.substr(o,4)===n0?(w=n0,o+=4):(w=t,b===0&&z(Gm)),w!==t&&(C=Go())!==t?(k=f,f=v=ci(C)):(o=f,f=t)):(o=f,f=t),f===t&&(f=o,e.substr(o,4)===i0?(v=i0,o+=4):(v=t,b===0&&z(Um)),v!==t&&(w=rc())!==t?(k=f,f=v=ci(w)):(o=f,f=t),f===t&&(f=o,e.substr(o,2)===hi?(v=hi,o+=2):(v=t,b===0&&z(o0)),v!==t&&(w=ec())!==t?(k=f,f=v=ci(w)):(o=f,f=t),f===t&&(f=o,e.substr(o,2)===hi?(v=hi,o+=2):(v=t,b===0&&z(o0)),v!==t?(e.length>o?(w=e.charAt(o),o++):(w=t,b===0&&z(y)),w!==t?(k=f,f=v=Xm(w)):(o=f,f=t)):(o=f,f=t))))),f}(),s===t&&(s=jo())))))))))))),b--,s===t&&(a=t,b===0&&z(G)),s}function Ue(){var s,a,c,u;return s=o,_t()!==t?(a=o,c=o,b++,u=Co(),b--,u!==t?(o=c,c=void 0):c=t,c!==t&&(u=An())!==t?a=c=[c,u]:(o=a,a=t),a===t&&(a=function(){var f,v,w,C,O,P,K;return f=o,e.substr(o,7)===h0?(v=h0,o+=7):(v=t,b===0&&z(d5)),v!==t?(w=o,b++,C=It(),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=X())!==t?(O=o,(P=No())!==t?(k=o,(K=(K=c0(P))?void 0:t)!==t?(k=O,O=P=m5(P)):(o=O,O=t)):(o=O,O=t),O===t&&(O=o,(P=_t())!==t&&(K=oe())!==t&&X()!==t?(k=O,O=P=f5(K)):(o=O,O=t)),O!==t?f=v=[v,w,C,O]:(o=f,f=t)):(o=f,f=t)):(o=f,f=t),f===t&&(f=o,e.substr(o,7)===p0?(v=p0,o+=7):(v=t,b===0&&z(g5)),v!==t&&(w=vi())!==t?(k=f,f=v=b5(w)):(o=f,f=t)),f}()),a!==t?(k=s,s=nt()):(o=s,s=t)):(o=s,s=t),s}function v0(){var s,a,c,u;return s=o,Xt()!==t&&Ue()!==t?(k=s,s=nt()):(o=s,s=t),s===t&&(s=o,Xt()!==t&&_t()!==t?(a=o,c=o,b++,u=qo(),b--,u!==t?(o=c,c=void 0):c=t,c!==t&&(u=An())!==t?(k=a,a=c=ut(u)):(o=a,a=t),a===t&&(a=o,c=o,b++,u=x0(),b--,u!==t?(o=c,c=void 0):c=t,c!==t?(u=function(){var f,v,w,C,O;if(f=o,v=G0(),v!==t)if(k=o,(j4()?t:void 0)!==t)if(zo()!==t)if(w=o,C=o,b++,e.length>o?(O=e.charAt(o),o++):(O=t,b===0&&z(y)),b--,O!==t?(o=C,C=void 0):C=t,C!==t&&(k=w,C=wu(v)),(w=C)!==t){for(C=[],O=Me();O!==t;)C.push(O),O=Me();C!==t&&(O=Xe())!==t?(k=f,f=v=G4(v,w,C,O)):(o=f,f=t)}else o=f,f=t;else o=f,f=t;else o=f,f=t;else o=f,f=t;return f}(),u!==t?(k=a,a=c=Q(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=function(){var f,v,w,C;return f=o,e.substr(o,6)===ni?(v=ni,o+=6):(v=t,b===0&&z(mu)),v!==t?(e.charCodeAt(o)===42?(w=nr,o++):(w=t,b===0&&z(ir)),w===t&&(w=null),w!==t&&(C=Tr())!==t?(k=f,f=v=M4(C)):(o=f,f=t)):(o=f,f=t),f}(),a===t&&(a=function(){var f,v,w,C,O;return f=o,v=o,e.substr(o,5)===ii?(w=ii,o+=5):(w=t,b===0&&z(fu)),w===t&&(e.substr(o,3)===oi?(w=oi,o+=3):(w=t,b===0&&z(gu)),w===t&&(e.substr(o,3)===ai?(w=ai,o+=3):(w=t,b===0&&z(bu)))),v=w!==t?e.substring(v,o):w,v!==t?(e.substr(o,4)===si?(w=si,o+=4):(w=t,b===0&&z(yu)),w!==t?(C=o,b++,O=It(),b--,O===t?C=void 0:(o=C,C=t),C!==t&&(O=X())!==t?(k=f,f=v=D4(v)):(o=f,f=t)):(o=f,f=t)):(o=f,f=t),f}()))),a!==t?(k=s,s=D(a)):(o=s,s=t)):(o=s,s=t)),s}function fi(){var s,a,c;return s=o,(a=oe())!==t?(k=o,(c=(c=at(a))?void 0:t)!==t?s=a=[a,c]:(o=s,s=t)):(o=s,s=t),s}function qo(){var s,a,c;return s=o,(a=oe())!==t?(k=o,(c=(c=Ct(a))?void 0:t)!==t?s=a=[a,c]:(o=s,s=t)):(o=s,s=t),s}function Co(){var s,a,c;return s=o,(a=oe())!==t?(k=o,(c=(c=Mt(a))?void 0:t)!==t?s=a=[a,c]:(o=s,s=t)):(o=s,s=t),s}function x0(){var s,a,c,u,f;return s=o,(a=_n())===t&&(a=Ai()),a!==t&&(c=Dt())!==t&&(u=oe())!==t?(k=o,(f=(f=Ct(u))?void 0:t)!==t?s=a=[a,c,u,f]:(o=s,s=t)):(o=s,s=t),s}function An(){var s,a;return s=o,(a=oe())!==t&&X()!==t?(k=o,(Rt(a)?void 0:t)!==t&&zo()!==t?(k=s,s=a=Ce(a)):(o=s,s=t)):(o=s,s=t),s}function oe(){var s,a,c;if(b++,s=o,a=[],(c=It())!==t)for(;c!==t;)a.push(c),c=It();else a=t;return s=a!==t?e.substring(s,o):a,b--,s===t&&(a=t,b===0&&z(qr)),s}function tn(){var s,a,c,u,f;if(s=o,a=[],(c=It())===t&&(c=rn())===t&&(c=$t())===t&&(ze.test(e.charAt(o))?(c=e.charAt(o),o++):(c=t,b===0&&z(er)),c===t&&(c=o,u=o,b++,Cr.test(e.charAt(o))?(f=e.charAt(o),o++):(f=t,b===0&&z(zr)),b--,f===t?u=void 0:(o=u,u=t),u!==t&&(f=jo())!==t?c=u=[u,f]:(o=c,c=t))),c!==t)for(;c!==t;)a.push(c),(c=It())===t&&(c=rn())===t&&(c=$t())===t&&(ze.test(e.charAt(o))?(c=e.charAt(o),o++):(c=t,b===0&&z(er)),c===t&&(c=o,u=o,b++,Cr.test(e.charAt(o))?(f=e.charAt(o),o++):(f=t,b===0&&z(zr)),b--,f===t?u=void 0:(o=u,u=t),u!==t&&(f=jo())!==t?c=u=[u,f]:(o=c,c=t)));else a=t;return s=a!==t?e.substring(s,o):a}function w0(){var s,a,c,u,f;return b++,s=o,(a=tn())!==t?(c=o,X()!==t?(e.charCodeAt(o)===61?(u=pr,o++):(u=t,b===0&&z(Wn)),u!==t&&X()!==t?((f=tn())===t&&(k=o,f=(f=yn())?void 0:t),f!==t?(k=c,c=$n(a,f)):(o=c,c=t)):(o=c,c=t)):(o=c,c=t),c===t&&(c=null),c!==t?(k=s,s=a=Pr(a,c)):(o=s,s=t)):(o=s,s=t),b--,s===t&&(a=t,b===0&&z(rr)),s}function zo(){var s,a,c,u,f,v;for(s=[],a=o,k=o,(c=(c=Ss())?void 0:t)!==t&&(k=a,c=qs()),(a=c)===t&&(a=To())===t&&(a=o,k=o,(c=(c=Cs())?void 0:t)!==t?((u=vi())===t&&(k=o,u=(u=Zn())?void 0:t),u!==t?(k=a,a=c=Jn(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=zs())?void 0:t)!==t?((u=N0())===t&&(k=o,u=(u=Zn())?void 0:t),u!==t?(k=a,a=c=Jn(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ts())?void 0:t)!==t?((u=Lo())===t&&(k=o,u=(u=Ms())?void 0:t),u!==t?(k=a,a=c=Es(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ds())?void 0:t)!==t?((u=Bo())===t&&(u=null),u!==t?(k=a,a=c=Ls(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Bs())?void 0:t)!==t?((u=Mo())===t&&(k=o,u=(u=Ns())?void 0:t),u!==t?(k=a,a=c=je(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Os())?void 0:t)!==t?((u=k0())===t&&(k=o,u=(u=Fs())?void 0:t),u!==t?(k=a,a=c=je(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Rs())?void 0:t)!==t?((u=_0())===t&&(u=null),u!==t?(k=a,a=c=je(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Hs())?void 0:t)!==t?((u=S0())===t&&(k=o,u=(u=Vs())?void 0:t),u!==t?(k=a,a=c=jr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Is())?void 0:t)!==t?((u=q0())===t&&(u=null),u!==t?(k=a,a=c=jr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ps())?void 0:t)!==t?((u=C0())===t&&(u=null),u!==t?(k=a,a=c=jr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=js())?void 0:t)!==t?((u=z0())===t&&(k=o,u=(u=Gs())?void 0:t),u!==t?(k=a,a=c=Gr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Us())?void 0:t)!==t?((u=Do())===t&&(k=o,u=(u=Xs())?void 0:t),u!==t?(k=a,a=c=Qn(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ys())?void 0:t)!==t?((u=M0())===t&&(u=null),u!==t?(k=a,a=c=Qn(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ws())?void 0:t)!==t?((u=Tr())===t&&(k=o,u=(u=$s())?void 0:t),u!==t?(k=a,a=c=Ur(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Zs())?void 0:t)!==t?((u=Tr())===t&&(u=null),u!==t?(k=a,a=c=Ur(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Js())?void 0:t)!==t?((u=T0())===t&&(u=null),u!==t?(k=a,a=c=Ur(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Qs())?void 0:t)!==t?((u=A0())===t&&(k=o,u=(u=Ks())?void 0:t),u!==t?(k=a,a=c=tl(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=el())?void 0:t)!==t?((u=B0())===t&&(k=o,u=(u=rl())?void 0:t),u!==t?(k=a,a=c=nl(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=il())?void 0:t)!==t?((u=O0())===t&&(k=o,u=(u=ol())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=al())?void 0:t)!==t?((u=F0())===t&&(k=o,u=(u=sl())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=ll())?void 0:t)!==t?((u=R0())===t&&(u=null),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=ul())?void 0:t)!==t?((u=H0())===t&&(k=o,u=(u=cl())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=hl())?void 0:t)!==t?((u=V0())===t&&(k=o,u=(u=pl())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=dl())?void 0:t)!==t?((u=E0())===t&&(k=o,u=(u=ml())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=fl())?void 0:t)!==t?((u=D0())===t&&(u=null),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=gl())?void 0:t)!==t?((u=yi())===t&&(k=o,u=(u=bl())?void 0:t),u!==t?(k=a,a=c=Gr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=yl())?void 0:t)!==t?((u=yi())===t&&(u=null),u!==t?(k=a,a=c=Gr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=vl())?void 0:t)!==t?((u=Io())===t&&(k=o,u=(u=xl())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=wl())?void 0:t)!==t&&(u=X())!==t?a=c=[c,u]:(o=a,a=t),a===t&&(a=o,k=o,(c=(c=kl())?void 0:t)!==t&&(u=U0())!==t?(k=a,a=c=je(u)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Al())?void 0:t)!==t&&(u=X0())!==t?(k=a,a=c=je(u)):(o=a,a=t),a===t&&(a=o,c=o,b++,u=o,(f=X())!==t&&(v=De())!==t?u=f=[f,v]:(o=u,u=t),b--,u!==t?(o=c,c=void 0):c=t,c!==t?(k=o,(u=(u=_l())?void 0:t)!==t?a=c=[c,u]:(o=a,a=t)):(o=a,a=t),a===t&&(a=o,c=o,b++,u=o,(f=X())!==t&&(v=Dt())!==t?u=f=[f,v]:(o=u,u=t),b--,u!==t?(o=c,c=void 0):c=t,c!==t?(k=o,(u=(u=Sl())?void 0:t)!==t?a=c=[c,u]:(o=a,a=t)):(o=a,a=t))))))))))))))))))))))))))))))))));a!==t;)s.push(a),a=o,k=o,(c=(c=Ss())?void 0:t)!==t&&(k=a,c=qs()),(a=c)===t&&(a=To())===t&&(a=o,k=o,(c=(c=Cs())?void 0:t)!==t?((u=vi())===t&&(k=o,u=(u=Zn())?void 0:t),u!==t?(k=a,a=c=Jn(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=zs())?void 0:t)!==t?((u=N0())===t&&(k=o,u=(u=Zn())?void 0:t),u!==t?(k=a,a=c=Jn(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ts())?void 0:t)!==t?((u=Lo())===t&&(k=o,u=(u=Ms())?void 0:t),u!==t?(k=a,a=c=Es(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ds())?void 0:t)!==t?((u=Bo())===t&&(u=null),u!==t?(k=a,a=c=Ls(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Bs())?void 0:t)!==t?((u=Mo())===t&&(k=o,u=(u=Ns())?void 0:t),u!==t?(k=a,a=c=je(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Os())?void 0:t)!==t?((u=k0())===t&&(k=o,u=(u=Fs())?void 0:t),u!==t?(k=a,a=c=je(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Rs())?void 0:t)!==t?((u=_0())===t&&(u=null),u!==t?(k=a,a=c=je(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Hs())?void 0:t)!==t?((u=S0())===t&&(k=o,u=(u=Vs())?void 0:t),u!==t?(k=a,a=c=jr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Is())?void 0:t)!==t?((u=q0())===t&&(u=null),u!==t?(k=a,a=c=jr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ps())?void 0:t)!==t?((u=C0())===t&&(u=null),u!==t?(k=a,a=c=jr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=js())?void 0:t)!==t?((u=z0())===t&&(k=o,u=(u=Gs())?void 0:t),u!==t?(k=a,a=c=Gr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Us())?void 0:t)!==t?((u=Do())===t&&(k=o,u=(u=Xs())?void 0:t),u!==t?(k=a,a=c=Qn(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ys())?void 0:t)!==t?((u=M0())===t&&(u=null),u!==t?(k=a,a=c=Qn(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Ws())?void 0:t)!==t?((u=Tr())===t&&(k=o,u=(u=$s())?void 0:t),u!==t?(k=a,a=c=Ur(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Zs())?void 0:t)!==t?((u=Tr())===t&&(u=null),u!==t?(k=a,a=c=Ur(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Js())?void 0:t)!==t?((u=T0())===t&&(u=null),u!==t?(k=a,a=c=Ur(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Qs())?void 0:t)!==t?((u=A0())===t&&(k=o,u=(u=Ks())?void 0:t),u!==t?(k=a,a=c=tl(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=el())?void 0:t)!==t?((u=B0())===t&&(k=o,u=(u=rl())?void 0:t),u!==t?(k=a,a=c=nl(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=il())?void 0:t)!==t?((u=O0())===t&&(k=o,u=(u=ol())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=al())?void 0:t)!==t?((u=F0())===t&&(k=o,u=(u=sl())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=ll())?void 0:t)!==t?((u=R0())===t&&(u=null),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=ul())?void 0:t)!==t?((u=H0())===t&&(k=o,u=(u=cl())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=hl())?void 0:t)!==t?((u=V0())===t&&(k=o,u=(u=pl())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=dl())?void 0:t)!==t?((u=E0())===t&&(k=o,u=(u=ml())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=fl())?void 0:t)!==t?((u=D0())===t&&(u=null),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=gl())?void 0:t)!==t?((u=yi())===t&&(k=o,u=(u=bl())?void 0:t),u!==t?(k=a,a=c=Gr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=yl())?void 0:t)!==t?((u=yi())===t&&(u=null),u!==t?(k=a,a=c=Gr(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=vl())?void 0:t)!==t?((u=Io())===t&&(k=o,u=(u=xl())?void 0:t),u!==t?(k=a,a=c=se(u)):(o=a,a=t)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=wl())?void 0:t)!==t&&(u=X())!==t?a=c=[c,u]:(o=a,a=t),a===t&&(a=o,k=o,(c=(c=kl())?void 0:t)!==t&&(u=U0())!==t?(k=a,a=c=je(u)):(o=a,a=t),a===t&&(a=o,k=o,(c=(c=Al())?void 0:t)!==t&&(u=X0())!==t?(k=a,a=c=je(u)):(o=a,a=t),a===t&&(a=o,c=o,b++,u=o,(f=X())!==t&&(v=De())!==t?u=f=[f,v]:(o=u,u=t),b--,u!==t?(o=c,c=void 0):c=t,c!==t?(k=o,(u=(u=_l())?void 0:t)!==t?a=c=[c,u]:(o=a,a=t)):(o=a,a=t),a===t&&(a=o,c=o,b++,u=o,(f=X())!==t&&(v=Dt())!==t?u=f=[f,v]:(o=u,u=t),b--,u!==t?(o=c,c=void 0):c=t,c!==t?(k=o,(u=(u=Sl())?void 0:t)!==t?a=c=[c,u]:(o=a,a=t)):(o=a,a=t))))))))))))))))))))))))))))))))));return s}function To(){var s,a;return s=o,k=o,(i1()?void 0:t)!==t&&X()!==t?(e.charCodeAt(o)===42?(a=nr,o++):(a=t,b===0&&z(ir)),a===t&&(a=null),a!==t?(k=s,s=o1(a)):(o=s,s=t)):(o=s,s=t),s}function Mo(){var s,a;return s=o,X()!==t&&Dt()!==t&&X()!==t&&(a=oe())!==t&&X()!==t&&Ot()!==t?(k=s,s=Kn(a)):(o=s,s=t),s}function k0(){var s,a;return s=o,X()!==t&&Dt()!==t&&X()!==t?((a=oe())===t&&(a=null),a!==t&&X()!==t&&Ot()!==t?(k=s,s=Kn(a)):(o=s,s=t)):(o=s,s=t),s}function A0(){var s,a;return s=o,X()!==t&&Dt()!==t&&X()!==t&&_t()!==t&&(a=oe())!==t&&X()!==t&&Ot()!==t?(k=s,s=Kn(a)):(o=s,s=t),s}function _0(){var s,a;return s=o,X()!==t&&De()!==t&&X()!==t&&(a=oe())!==t&&X()!==t&&We()!==t?(k=s,s=Kn(a)):(o=s,s=t),s}function S0(){var s,a;return s=o,X()!==t&&Dt()!==t&&X()!==t&&(a=tn())!==t&&X()!==t&&Ot()!==t?(k=s,s=ql(a)):(o=s,s=t),s}function q0(){var s,a;return s=o,X()!==t&&De()!==t&&X()!==t&&(a=tn())!==t&&X()!==t&&We()!==t?(k=s,s=ql(a)):(o=s,s=t),s}function C0(){var s,a,c,u;if(s=o,X()!==t)if(De()!==t){for(a=[],c=o,X()!==t?(e.charCodeAt(o)===44?(u=le,o++):(u=t,b===0&&z(ue)),u!==t?(k=c,c=ti()):(o=c,c=t)):(o=c,c=t),c===t&&(c=o,X()!==t&&(u=w0())!==t?(k=c,c=Cl(u)):(o=c,c=t));c!==t;)a.push(c),c=o,X()!==t?(e.charCodeAt(o)===44?(u=le,o++):(u=t,b===0&&z(ue)),u!==t?(k=c,c=ti()):(o=c,c=t)):(o=c,c=t),c===t&&(c=o,X()!==t&&(u=w0())!==t?(k=c,c=Cl(u)):(o=c,c=t));a!==t&&(c=X())!==t&&We()!==t?(k=s,s=a1(a)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;return s}function z0(){var s,a,c,u;if(s=o,X()!==t)if(Dt()!==t)if(X()!==t){for(a=[],c=o,X()!==t?(e.charCodeAt(o)===44?(u=le,o++):(u=t,b===0&&z(ue)),u!==t?(k=c,c=ti()):(o=c,c=t)):(o=c,c=t),c===t&&(c=o,X()!==t&&(u=tn())!==t?(k=c,c=zl(u)):(o=c,c=t));c!==t;)a.push(c),c=o,X()!==t?(e.charCodeAt(o)===44?(u=le,o++):(u=t,b===0&&z(ue)),u!==t?(k=c,c=ti()):(o=c,c=t)):(o=c,c=t),c===t&&(c=o,X()!==t&&(u=tn())!==t?(k=c,c=zl(u)):(o=c,c=t));a!==t&&(c=X())!==t&&Ot()!==t?(k=s,s=s1(a)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;else o=s,s=t;return s}function Eo(){var s,a,c,u;return s=o,X()!==t?(e.substr(o,2)===Tl?(a=Tl,o+=2):(a=t,b===0&&z(l1)),a===t&&(e.substr(o,2)===Ml?(a=Ml,o+=2):(a=t,b===0&&z(u1)),a===t&&(e.substr(o,2)===El?(a=El,o+=2):(a=t,b===0&&z(c1)),a===t&&(e.substr(o,2)===Dl?(a=Dl,o+=2):(a=t,b===0&&z(h1)),a===t&&(e.substr(o,2)===Ll?(a=Ll,o+=2):(a=t,b===0&&z(p1)),a===t&&(e.substr(o,2)===Bl?(a=Bl,o+=2):(a=t,b===0&&z(d1)),a===t&&(e.substr(o,2)===Nl?(a=Nl,o+=2):(a=t,b===0&&z(m1)),a===t&&(e.substr(o,2)===Ol?(a=Ol,o+=2):(a=t,b===0&&z(f1)),a===t&&(e.substr(o,2)===Fl?(a=Fl,o+=2):(a=t,b===0&&z(g1)),a===t&&(e.substr(o,2)===Rl?(a=Rl,o+=2):(a=t,b===0&&z(b1)),a===t&&(e.substr(o,2)===Hl?(a=Hl,o+=2):(a=t,b===0&&z(y1)))))))))))),a!==t?(c=o,b++,u=It(),b--,u===t?c=void 0:(o=c,c=t),c!==t&&(u=X())!==t?(k=s,s=v1(a)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t),s}function gi(){var s,a,c,u,f,v,w,C;return s=o,(a=ce())!==t&&(c=Eo())!==t?(u=o,f=function(){var O,P,K,V;return O=o,e.substr(o,4)===Lu?(P=Lu,o+=4):(P=t,b===0&&z(rd)),P!==t?(K=o,b++,V=It(),b--,V===t?K=void 0:(o=K,K=t),K!==t&&(V=X())!==t?(k=O,O=P=Qr()):(o=O,O=t)):(o=O,O=t),O}(),f!==t&&(v=ce())!==t&&(w=Eo())!==t?u=f=[f,v,w]:(o=u,u=t),u===t&&(u=null),u!==t?(f=o,v=function(){var O,P,K,V;return O=o,e.substr(o,5)===Bu?(P=Bu,o+=5):(P=t,b===0&&z(nd)),P!==t?(K=o,b++,V=It(),b--,V===t?K=void 0:(o=K,K=t),K!==t&&(V=X())!==t?(k=O,O=P=Qr()):(o=O,O=t)):(o=O,O=t),O}(),v!==t&&(w=ce())!==t&&(C=Eo())!==t?f=v=[v,w,C]:(o=f,f=t),f===t&&(f=null),f!==t?(k=s,s=a=x1(a,c)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t),s}function Tr(){var s,a;return s=o,X()!==t&&Dt()!==t&&X()!==t&&(a=gi())!==t&&Ot()!==t?(k=s,s=uo(a)):(o=s,s=t),s}function T0(){var s,a;return s=o,X()!==t&&De()!==t&&X()!==t&&(a=gi())!==t&&We()!==t?(k=s,s=uo(a)):(o=s,s=t),s}function Do(){var s,a;return s=o,X()!==t&&Dt()!==t&&(a=Fo())!==t&&Ot()!==t?(k=s,s=Vl(a)):(o=s,s=t),s}function M0(){var s,a;return s=o,X()!==t&&De()!==t&&(a=Fo())!==t&&We()!==t?(k=s,s=Vl(a)):(o=s,s=t),s}function bi(){var s,a,c;return s=o,X()!==t?((a=gi())===t&&(a=o,(c=ce())!==t&&(k=a,c=w1(c)),a=c),a!==t&&(c=X())!==t?(k=s,s=vn(a)):(o=s,s=t)):(o=s,s=t),s}function yi(){var s,a,c,u,f,v;return s=o,X()!==t?(e.charCodeAt(o)===40?(a=co,o++):(a=t,b===0&&z(ho)),a!==t&&(c=bi())!==t?(e.charCodeAt(o)===44?(u=le,o++):(u=t,b===0&&z(ue)),u!==t&&(f=bi())!==t?(e.charCodeAt(o)===41?(v=po,o++):(v=t,b===0&&z(mo)),v!==t&&X()!==t?(k=s,s=k1(c,f)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t),s}function E0(){var s,a;return s=o,X()!==t&&Dt()!==t&&(a=bi())!==t&&Ot()!==t?(k=s,s=vn(a)):(o=s,s=t),s}function D0(){var s,a;return s=o,X()!==t&&De()!==t&&(a=bi())!==t&&We()!==t?(k=s,s=vn(a)):(o=s,s=t),s}function L0(){var s;return(s=It())===t&&(s=rn())===t&&(_1.test(e.charAt(o))?(s=e.charAt(o),o++):(s=t,b===0&&z(S1)),s===t&&(e.charCodeAt(o)===39?(s=jl,o++):(s=t,b===0&&z(Gl)),s===t&&(s=function(){var a,c,u,f,v,w,C;return a=o,(c=_t())===t&&(c=null),c!==t?(u=o,f=o,e.charCodeAt(o)===37?(v=Il,o++):(v=t,b===0&&z(Pl)),v!==t&&(w=fr())!==t&&(C=fr())!==t?f=v=[v,w,C]:(o=f,f=t),(u=f!==t?e.substring(u,o):f)!==t?(k=a,a=c=A1(u)):(o=a,a=t)):(o=a,a=t),a}())===t&&(k=o,s=(s=q1())?void 0:t))),s}function B0(){var s,a,c,u,f,v,w;if(s=o,X()!==t)if(Dt()!==t)if(X()!==t){if(a=[],c=o,u=o,b++,f=o,(v=X())!==t&&(w=Ot())!==t?f=v=[v,w]:(o=f,f=t),b--,f===t?u=void 0:(o=u,u=t),u!==t&&(f=L0())!==t?(k=c,c=u=Ul(f)):(o=c,c=t),c!==t)for(;c!==t;)a.push(c),c=o,u=o,b++,f=o,(v=X())!==t&&(w=Ot())!==t?f=v=[v,w]:(o=f,f=t),b--,f===t?u=void 0:(o=u,u=t),u!==t&&(f=L0())!==t?(k=c,c=u=Ul(f)):(o=c,c=t);else a=t;a!==t&&(c=X())!==t&&(u=Ot())!==t?(k=s,s=C1(a)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;else o=s,s=t;return s}function vi(){var s,a,c,u;if(s=o,X()!==t)if(Dt()!==t)if(k=o,(fo()?void 0:t)!==t)if((a=mr())===t&&(a=null),a!==t){for(c=[],u=Kr();u!==t;)c.push(u),u=Kr();c!==t&&(u=Ot())!==t?(k=s,s=z1(a,c)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;else o=s,s=t;else o=s,s=t;return s}function Lo(){var s,a,c;for(s=o,a=[],c=y0();c!==t;)a.push(c),c=y0();return a!==t&&(k=s,a=T1(a)),s=a}function N0(){var s,a,c;return s=o,X()!==t&&Dt()!==t?(k=o,(fo()?void 0:t)!==t?((a=mr())===t&&(a=null),a!==t&&(c=Lo())!==t&&Ot()!==t?(k=s,s=M1(a,c)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t),s}function Bo(){var s,a,c;if(s=o,X()!==t)if(De()!==t)if(k=o,(fo()?void 0:t)!==t){for(a=[],c=Kr();c!==t;)a.push(c),c=Kr();a!==t&&(c=We())!==t?(k=o,(E1()?void 0:t)!==t?(k=s,s=D1(a)):(o=s,s=t)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;else o=s,s=t;return s}function No(){var s,a,c;return s=o,_t()!==t?(e.substr(o,5)===Xl?(a=Xl,o+=5):(a=t,b===0&&z(L1)),a!==t&&(c=Mo())!==t?(k=s,s=vn(c)):(o=s,s=t)):(o=s,s=t),s}function y5(){var s,a,c,u;return s=o,e.charCodeAt(o)===40?(a=co,o++):(a=t,b===0&&z(ho)),a!==t&&(c=Fo())!==t?(e.charCodeAt(o)===41?(u=po,o++):(u=t,b===0&&z(mo)),u!==t?(k=s,s=a=O1(c)):(o=s,s=t)):(o=s,s=t),s===t&&(s=Go())===t&&(s=function(){var f,v,w;return f=o,_t()!==t?(e.substr(o,4)===Yl?(v=Yl,o+=4):(v=t,b===0&&z(B1)),v!==t&&X()!==t&&Dt()!==t&&X()!==t&&(w=ce())!==t&&X()!==t&&Ot()!==t?(k=f,f=N1(w)):(o=f,f=t)):(o=f,f=t),f}(),s===t&&(s=o,(a=No())!==t&&(k=s,a=F1(a)),s=a)),s}function xi(){var s,a,c;return s=o,e.charCodeAt(o)===43?(a=xn,o++):(a=t,b===0&&z(wn)),a===t&&(e.charCodeAt(o)===45?(a=Xr,o++):(a=t,b===0&&z(Yr))),a!==t&&X()!==t&&(c=xi())!==t?(k=s,s=a=R1(a,c)):(o=s,s=t),s===t&&(s=y5()),s}function Oo(){var s,a,c,u,f,v,w,C;if(s=o,(a=xi())!==t){for(c=[],u=o,(f=X())!==t?(e.charCodeAt(o)===42?(v=nr,o++):(v=t,b===0&&z(ir)),v===t&&(e.charCodeAt(o)===47?(v=Wr,o++):(v=t,b===0&&z($r))),v!==t&&(w=X())!==t&&(C=xi())!==t?u=f=[f,v,w,C]:(o=u,u=t)):(o=u,u=t);u!==t;)c.push(u),u=o,(f=X())!==t?(e.charCodeAt(o)===42?(v=nr,o++):(v=t,b===0&&z(ir)),v===t&&(e.charCodeAt(o)===47?(v=Wr,o++):(v=t,b===0&&z($r))),v!==t&&(w=X())!==t&&(C=xi())!==t?u=f=[f,v,w,C]:(o=u,u=t)):(o=u,u=t);c!==t?(k=s,s=a=H1(a,c)):(o=s,s=t)}else o=s,s=t;return s}function Fo(){var s,a,c,u,f,v,w,C;if(s=o,X()!==t)if((a=Oo())!==t){for(c=[],u=o,(f=X())!==t?(e.charCodeAt(o)===43?(v=xn,o++):(v=t,b===0&&z(wn)),v===t&&(e.charCodeAt(o)===45?(v=Xr,o++):(v=t,b===0&&z(Yr))),v!==t&&(w=X())!==t&&(C=Oo())!==t?u=f=[f,v,w,C]:(o=u,u=t)):(o=u,u=t);u!==t;)c.push(u),u=o,(f=X())!==t?(e.charCodeAt(o)===43?(v=xn,o++):(v=t,b===0&&z(wn)),v===t&&(e.charCodeAt(o)===45?(v=Xr,o++):(v=t,b===0&&z(Yr))),v!==t&&(w=X())!==t&&(C=Oo())!==t?u=f=[f,v,w,C]:(o=u,u=t)):(o=u,u=t);c!==t&&(u=X())!==t?(k=s,s=V1(a,c)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;return s}function O0(){var s,a;return s=o,X()!==t&&Dt()!==t?(a=function(){var c,u,f,v;if(c=o,u=function(){var w,C,O,P,K,V,tt,ot,mt,ct,Yt,Ht,Lt;if(w=o,C=Ho(),C!==t)if(O=o,e.charCodeAt(o)===44?(P=le,o++):(P=t,b===0&&z(ue)),P!==t&&(K=nn())!==t?O=P=[P,K]:(o=O,O=t),O===t&&(O=null),O!==t)if(e.charCodeAt(o)===58?(P=$l,o++):(P=t,b===0&&z(Zl)),P!==t)if((K=wi())!==t)if(e.charCodeAt(o)===44?(V=le,o++):(V=t,b===0&&z(ue)),V!==t)if((tt=ce())!==t){for(ot=[],mt=o,e.charCodeAt(o)===59?(ct=ei,o++):(ct=t,b===0&&z(ri)),ct!==t&&(Yt=wi())!==t?(e.charCodeAt(o)===44?(Ht=le,o++):(Ht=t,b===0&&z(ue)),Ht!==t&&(Lt=ce())!==t?mt=ct=[ct,Yt,Ht,Lt]:(o=mt,mt=t)):(o=mt,mt=t);mt!==t;)ot.push(mt),mt=o,e.charCodeAt(o)===59?(ct=ei,o++):(ct=t,b===0&&z(ri)),ct!==t&&(Yt=wi())!==t?(e.charCodeAt(o)===44?(Ht=le,o++):(Ht=t,b===0&&z(ue)),Ht!==t&&(Lt=ce())!==t?mt=ct=[ct,Yt,Ht,Lt]:(o=mt,mt=t)):(o=mt,mt=t);ot!==t?w=C=[C,O,P,K,V,tt,ot]:(o=w,w=t)}else o=w,w=t;else o=w,w=t;else o=w,w=t;else o=w,w=t;else o=w,w=t;else o=w,w=t;return w}(),u===t&&(u=wi())===t&&(u=or()),u!==t){for(f=[],v=I0();v!==t;)f.push(v),v=I0();f!==t?c=u=[u,f]:(o=c,c=t)}else o=c,c=t;return c}(),a!==t&&Ot()!==t?(k=s,s=vn(a)):(o=s,s=t)):(o=s,s=t),s}function F0(){var s,a;return s=o,X()!==t&&Dt()!==t&&(a=P0())!==t&&Ot()!==t?(k=s,s=Wl(a)):(o=s,s=t),s}function R0(){var s,a;return s=o,X()!==t&&De()!==t&&(a=P0())!==t&&We()!==t?(k=s,s=Wl(a)):(o=s,s=t),s}function H0(){var s,a;return s=o,X()!==t&&Dt()!==t?(a=function(){var c,u,f,v,w,C,O,P,K,V,tt;if(c=o,u=or(),u!==t)if(e.charCodeAt(o)===44?(f=le,o++):(f=t,b===0&&z(ue)),f!==t)if((v=ki())!==t){for(w=[],C=o,e.charCodeAt(o)===59?(O=ei,o++):(O=t,b===0&&z(ri)),O!==t&&(P=X())!==t&&(K=or())!==t?(e.charCodeAt(o)===44?(V=le,o++):(V=t,b===0&&z(ue)),V!==t&&(tt=ki())!==t?C=O=[O,P,K,V,tt]:(o=C,C=t)):(o=C,C=t);C!==t;)w.push(C),C=o,e.charCodeAt(o)===59?(O=ei,o++):(O=t,b===0&&z(ri)),O!==t&&(P=X())!==t&&(K=or())!==t?(e.charCodeAt(o)===44?(V=le,o++):(V=t,b===0&&z(ue)),V!==t&&(tt=ki())!==t?C=O=[O,P,K,V,tt]:(o=C,C=t)):(o=C,C=t);w!==t?(k=c,c=u=h4(u,v,w)):(o=c,c=t)}else o=c,c=t;else o=c,c=t;else o=c,c=t;return c}(),a!==t&&Ot()!==t?(k=s,s=I1(a)):(o=s,s=t)):(o=s,s=t),s}function V0(){var s,a;return s=o,X()!==t&&Dt()!==t&&(a=ki())!==t&&Ot()!==t?(k=s,s=P1(a)):(o=s,s=t),s}function wi(){var s,a,c,u,f;return s=o,a=function(){var v,w,C;for(v=o,w=[],e.charCodeAt(o)===45?(C=Xr,o++):(C=t,b===0&&z(Yr));C!==t;)w.push(C),e.charCodeAt(o)===45?(C=Xr,o++):(C=t,b===0&&z(Yr));return w!==t&&(k=v,w=Y1(w)),v=w,v}(),a===t&&(a=null),a!==t&&(c=or())!==t?(u=function(){var v,w,C,O,P,K,V,tt,ot;if(v=o,e.charCodeAt(o)===33?(w=Zr,o++):(w=t,b===0&&z(Jr)),w!==t)if((C=ce())!==t){for(O=[],P=o,e.charCodeAt(o)===33?(K=Zr,o++):(K=t,b===0&&z(Jr)),K!==t&&(V=or())!==t?(e.charCodeAt(o)===33?(tt=Zr,o++):(tt=t,b===0&&z(Jr)),tt!==t&&(ot=ce())!==t?P=K=[K,V,tt,ot]:(o=P,P=t)):(o=P,P=t);P!==t;)O.push(P),P=o,e.charCodeAt(o)===33?(K=Zr,o++):(K=t,b===0&&z(Jr)),K!==t&&(V=or())!==t?(e.charCodeAt(o)===33?(tt=Zr,o++):(tt=t,b===0&&z(Jr)),tt!==t&&(ot=ce())!==t?P=K=[K,V,tt,ot]:(o=P,P=t)):(o=P,P=t);O!==t?(P=o,e.charCodeAt(o)===33?(K=Zr,o++):(K=t,b===0&&z(Jr)),K!==t&&(V=or())!==t?P=K=[K,V]:(o=P,P=t),P===t&&(P=null),P!==t?v=w=[w,C,O,P]:(o=v,v=t)):(o=v,v=t)}else o=v,v=t;else o=v,v=t;return v}(),u===t&&(u=null),u!==t?(f=function(){var v,w,C,O,P,K;if(v=o,e.substr(o,2)===Kl?(w=Kl,o+=2):(w=t,b===0&&z(W1)),w!==t){if(C=[],e.charCodeAt(o)===43?(O=xn,o++):(O=t,b===0&&z(wn)),O!==t)for(;O!==t;)C.push(O),e.charCodeAt(o)===43?(O=xn,o++):(O=t,b===0&&z(wn));else C=t;C===t&&(C=o,e.charCodeAt(o)===91?(O=yo,o++):(O=t,b===0&&z(vo)),O!==t&&(P=nn())!==t?(e.charCodeAt(o)===93?(K=xo,o++):(K=t,b===0&&z(wo)),K!==t?C=O=[O,P,K]:(o=C,C=t)):(o=C,C=t)),C!==t?v=w=[w,C]:(o=v,v=t)}else o=v,v=t;return v}(),f===t&&(f=null),f!==t?s=a=[a,c,u,f]:(o=s,s=t)):(o=s,s=t)):(o=s,s=t),s}function I0(){var s,a,c,u,f,v;if(s=o,a=function(){var w,C,O;return w=o,e.charCodeAt(o)===62?(C=j1,o++):(C=t,b===0&&z(G1)),C!==t?(e.substr(o,5)===Jl?(O=Jl,o+=5):(O=t,b===0&&z(U1)),O===t&&(e.substr(o,6)===Ql?(O=Ql,o+=6):(O=t,b===0&&z(X1))),O!==t?w=C=[C,O]:(o=w,w=t)):(o=w,w=t),w}(),a!==t){for(c=[],u=o,e.charCodeAt(o)===44?(f=le,o++):(f=t,b===0&&z(ue)),f!==t&&(v=ce())!==t?u=f=[f,v]:(o=u,u=t);u!==t;)c.push(u),u=o,e.charCodeAt(o)===44?(f=le,o++):(f=t,b===0&&z(ue)),f!==t&&(v=ce())!==t?u=f=[f,v]:(o=u,u=t);c!==t?s=a=[a,c]:(o=s,s=t)}else o=s,s=t;return s}function or(){var s,a,c;if(s=o,a=[],(c=It())===t&&(c=rn()),c!==t)for(;c!==t;)a.push(c),(c=It())===t&&(c=rn());else a=t;return(s=a!==t?e.substring(s,o):a)===t&&(s=o,e.charCodeAt(o)===46?(a=go,o++):(a=t,b===0&&z(bo)),s=a!==t?e.substring(s,o):a),s}function Ro(){var s;return(s=Ho())===t&&(s=function(){var a;return e.substr(o,3)===ou?(a=ou,o+=3):(a=t,b===0&&z(t4)),a===t&&(e.substr(o,4)===au?(a=au,o+=4):(a=t,b===0&&z(e4)),a===t&&(e.substr(o,3)===su?(a=su,o+=3):(a=t,b===0&&z(r4)),a===t&&(e.substr(o,4)===lu?(a=lu,o+=4):(a=t,b===0&&z(n4))))),a}())===t&&(s=function(){var a;return e.substr(o,3)===uu?(a=uu,o+=3):(a=t,b===0&&z(i4)),a===t&&(e.substr(o,4)===cu?(a=cu,o+=4):(a=t,b===0&&z(o4)),a===t&&(e.substr(o,4)===hu?(a=hu,o+=4):(a=t,b===0&&z(a4)))),a}())===t&&(s=function(){var a;return e.substr(o,5)===pu?(a=pu,o+=5):(a=t,b===0&&z(s4)),a}()),s}function Ho(){var s;return e.substr(o,3)===tu?(s=tu,o+=3):(s=t,b===0&&z($1)),s===t&&(e.substr(o,4)===eu?(s=eu,o+=4):(s=t,b===0&&z(Z1)),s===t&&(e.substr(o,3)===ru?(s=ru,o+=3):(s=t,b===0&&z(J1)),s===t&&(e.substr(o,3)===nu?(s=nu,o+=3):(s=t,b===0&&z(Q1)),s===t&&(e.substr(o,4)===iu?(s=iu,o+=4):(s=t,b===0&&z(K1)))))),s}function P0(){var s,a,c,u,f,v,w;if(s=o,a=o,(c=Ho())!==t?(e.charCodeAt(o)===58?(u=$l,o++):(u=t,b===0&&z(Zl)),u!==t?a=c=[c,u]:(o=a,a=t)):(o=a,a=t),a===t&&(a=null),a!==t)if((c=Ro())!==t){for(u=[],f=o,e.charCodeAt(o)===47?(v=Wr,o++):(v=t,b===0&&z($r)),v!==t&&(w=Ro())!==t?f=v=[v,w]:(o=f,f=t);f!==t;)u.push(f),f=o,e.charCodeAt(o)===47?(v=Wr,o++):(v=t,b===0&&z($r)),v!==t&&(w=Ro())!==t?f=v=[v,w]:(o=f,f=t);u!==t?(k=s,s=a=l4(a,c,u)):(o=s,s=t)}else o=s,s=t;else o=s,s=t;return s}function Vo(){var s,a,c,u,f,v;if(s=o,(a=ce())!==t){for(c=[],u=o,(f=$t())===t&&(e.charCodeAt(o)===44?(f=le,o++):(f=t,b===0&&z(ue))),f!==t&&(v=ce())!==t?u=f=[f,v]:(o=u,u=t);u!==t;)c.push(u),u=o,(f=$t())===t&&(e.charCodeAt(o)===44?(f=le,o++):(f=t,b===0&&z(ue))),f!==t&&(v=ce())!==t?u=f=[f,v]:(o=u,u=t);c!==t?(k=s,s=a=u4(a,c)):(o=s,s=t)}else o=s,s=t;return s===t&&(s=or()),s}function ki(){var s,a,c,u,f,v;if(s=o,(a=Vo())!==t){for(c=[],u=o,e.charCodeAt(o)===47?(f=Wr,o++):(f=t,b===0&&z($r)),f!==t&&(v=Vo())!==t?u=f=[f,v]:(o=u,u=t);u!==t;)c.push(u),u=o,e.charCodeAt(o)===47?(f=Wr,o++):(f=t,b===0&&z($r)),f!==t&&(v=Vo())!==t?u=f=[f,v]:(o=u,u=t);c!==t?(k=s,s=a=c4(a,c)):(o=s,s=t)}else o=s,s=t;return s}function Io(){var s,a,c,u,f,v,w;if(s=o,Dt()!==t){for(a=[],c=en();c!==t;)a.push(c),c=en();if(a!==t){if(c=[],u=o,(f=j0())!==t){for(v=[],w=en();w!==t;)v.push(w),w=en();v!==t?(k=u,u=f=du(a,f,v)):(o=u,u=t)}else o=u,u=t;if(u!==t)for(;u!==t;)if(c.push(u),u=o,(f=j0())!==t){for(v=[],w=en();w!==t;)v.push(w),w=en();v!==t?(k=u,u=f=du(a,f,v)):(o=u,u=t)}else o=u,u=t;else c=t;c!==t&&(u=Ot())!==t?(k=s,s=p4(a,c)):(o=s,s=t)}else o=s,s=t}else o=s,s=t;return s}function j0(){var s,a,c,u;return s=o,e.charCodeAt(o)===108?(a=d4,o++):(a=t,b===0&&z(m4)),a===t&&(e.charCodeAt(o)===99?(a=f4,o++):(a=t,b===0&&z(g4)),a===t&&(e.charCodeAt(o)===114?(a=b4,o++):(a=t,b===0&&z(y4)),a===t&&(a=o,e.charCodeAt(o)===112?(c=v4,o++):(c=t,b===0&&z(x4)),c!==t&&(u=Tr())!==t?(k=a,a=c=uo(u)):(o=a,a=t)))),a!==t&&(k=s,a=w4(a)),(s=a)===t&&(s=o,e.charCodeAt(o)===42?(a=nr,o++):(a=t,b===0&&z(ir)),a!==t&&(c=Do())!==t&&(u=Io())!==t?(k=s,s=a=k4(c,u)):(o=s,s=t)),s}function en(){var s,a,c,u;return s=o,e.charCodeAt(o)===124?(a=A4,o++):(a=t,b===0&&z(_4)),a===t&&(a=o,e.charCodeAt(o)===64?(c=S4,o++):(c=t,b===0&&z(q4)),c!==t&&(u=vi())!==t?(k=a,a=c=C4(u)):(o=a,a=t)),a!==t&&(k=s,a=z4(a)),s=a}function G0(){var s,a,c;return b++,s=o,_n()!==t&&Dt()!==t?(a=o,(c=oe())!==t&&(k=a,c=O4(c)),(a=c)!==t?((c=To())===t&&(c=null),c!==t&&Ot()!==t?(k=s,s=F4(a,c)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t),b--,s===t&&b===0&&z(N4),s}function Xe(){var s,a,c;return b++,s=o,Xt()!==t&&_t()!==t&&Ai()!==t&&Dt()!==t&&(a=oe())!==t&&X()!==t?(e.charCodeAt(o)===42?(c=nr,o++):(c=t,b===0&&z(ir)),c===t&&(c=null),c!==t&&Ot()!==t?(k=s,s=H4(a,c)):(o=s,s=t)):(o=s,s=t),b--,s===t&&b===0&&z(R4),s}function Ee(){var s,a,c,u,f;return s=o,Xt()!==t&&_t()!==t?(e.substr(o,4)===ku?(a=ku,o+=4):(a=t,b===0&&z(U4)),a!==t?(c=o,b++,u=It(),b--,u===t?c=void 0:(o=c,c=t),c!==t?(k=o,(u=(u=X4())?t:void 0)!==t?((f=Bo())===t&&(f=null),f!==t&&Xt()!==t?(k=s,s=Y4(f)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t),s}function U0(){var s,a,c,u,f,v,w,C;for(s=[],a=o,c=[],u=o,(f=Xt())!==t&&(v=Ue())!==t?u=f=[f,v]:(o=u,u=t);u!==t;)c.push(u),u=o,(f=Xt())!==t&&(v=Ue())!==t?u=f=[f,v]:(o=u,u=t);if(c!==t)if((u=Ee())!==t){for(f=[],v=o,w=o,b++,(C=Ee())===t&&(C=Xe()),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=Me())!==t?(k=v,v=w=dr(u,C)):(o=v,v=t);v!==t;)f.push(v),v=o,w=o,b++,(C=Ee())===t&&(C=Xe()),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=Me())!==t?(k=v,v=w=dr(u,C)):(o=v,v=t);f!==t?(k=a,a=c=li(u,f)):(o=a,a=t)}else o=a,a=t;else o=a,a=t;for(;a!==t;){for(s.push(a),a=o,c=[],u=o,(f=Xt())!==t&&(v=Ue())!==t?u=f=[f,v]:(o=u,u=t);u!==t;)c.push(u),u=o,(f=Xt())!==t&&(v=Ue())!==t?u=f=[f,v]:(o=u,u=t);if(c!==t)if((u=Ee())!==t){for(f=[],v=o,w=o,b++,(C=Ee())===t&&(C=Xe()),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=Me())!==t?(k=v,v=w=dr(u,C)):(o=v,v=t);v!==t;)f.push(v),v=o,w=o,b++,(C=Ee())===t&&(C=Xe()),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=Me())!==t?(k=v,v=w=dr(u,C)):(o=v,v=t);f!==t?(k=a,a=c=li(u,f)):(o=a,a=t)}else o=a,a=t;else o=a,a=t}return s}function X0(){var s,a,c,u,f,v,w,C;for(s=[],a=o,c=[],u=o,(f=Xt())!==t&&(v=Ue())!==t?u=f=[f,v]:(o=u,u=t);u!==t;)c.push(u),u=o,(f=Xt())!==t&&(v=Ue())!==t?u=f=[f,v]:(o=u,u=t);if(c!==t)if(u=o,(f=Ee())!==t&&(k=u,f=Au(f)),(u=f)!==t){for(f=[],v=o,w=o,b++,(C=Ee())===t&&(C=Xe()),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=Me())!==t?(k=v,v=w=dr(u,C)):(o=v,v=t);v!==t;)f.push(v),v=o,w=o,b++,(C=Ee())===t&&(C=Xe()),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=Me())!==t?(k=v,v=w=dr(u,C)):(o=v,v=t);f!==t?(k=a,a=c=li(u,f)):(o=a,a=t)}else o=a,a=t;else o=a,a=t;for(;a!==t;){for(s.push(a),a=o,c=[],u=o,(f=Xt())!==t&&(v=Ue())!==t?u=f=[f,v]:(o=u,u=t);u!==t;)c.push(u),u=o,(f=Xt())!==t&&(v=Ue())!==t?u=f=[f,v]:(o=u,u=t);if(c!==t)if(u=o,(f=Ee())!==t&&(k=u,f=Au(f)),(u=f)!==t){for(f=[],v=o,w=o,b++,(C=Ee())===t&&(C=Xe()),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=Me())!==t?(k=v,v=w=dr(u,C)):(o=v,v=t);v!==t;)f.push(v),v=o,w=o,b++,(C=Ee())===t&&(C=Xe()),b--,C===t?w=void 0:(o=w,w=t),w!==t&&(C=Me())!==t?(k=v,v=w=dr(u,C)):(o=v,v=t);f!==t?(k=a,a=c=li(u,f)):(o=a,a=t)}else o=a,a=t;else o=a,a=t}return s}function Po(){var s,a,c,u;return s=o,e.substr(o,4)===qu?(a=qu,o+=4):(a=t,b===0&&z(J4)),a!==t&&(c=X())!==t?(e.substr(o,9)===ui?(u=ui,o+=9):(u=t,b===0&&z(Su)),u!==t?s=a=[a,c,u]:(o=s,s=t)):(o=s,s=t),s}function Ye(){var s,a,c,u;if((s=kn())===t&&(s=W0())===t&&(s=$0())===t&&(s=Z0())===t&&(s=o,(a=_t())!==t&&(c=oe())!==t?s=a=[a,c]:(o=s,s=t),s===t&&(s=o,(a=Dt())!==t&&(c=X())!==t&&(u=Ot())!==t?s=a=[a,c,u]:(o=s,s=t),s===t))){if(s=o,(a=Dt())!==t){if(c=[],(u=Ye())!==t)for(;u!==t;)c.push(u),u=Ye();else c=t;c!==t&&(u=Ot())!==t?s=a=[a,c,u]:(o=s,s=t)}else o=s,s=t;s===t&&(s=$t())===t&&(s=te())===t&&(s=qi())===t&&(s=me())}return s}function _n(){var s,a,c,u;return s=o,e.substr(o,5)===Tu?(a=Tu,o+=5):(a=t,b===0&&z(Q4)),a!==t?(c=o,b++,u=It(),b--,u===t?c=void 0:(o=c,c=t),c!==t&&(u=X())!==t?(k=s,s=a=Qr()):(o=s,s=t)):(o=s,s=t),s}function Ai(){var s,a,c,u;return s=o,e.substr(o,3)===Mu?(a=Mu,o+=3):(a=t,b===0&&z(K4)),a!==t?(c=o,b++,u=It(),b--,u===t?c=void 0:(o=c,c=t),c!==t&&(u=X())!==t?(k=s,s=a=Qr()):(o=s,s=t)):(o=s,s=t),s}function Y0(){var s,a,c,u;return s=o,e.substr(o,3)===Eu?(a=Eu,o+=3):(a=t,b===0&&z(td)),a!==t?(c=o,b++,u=It(),b--,u===t?c=void 0:(o=c,c=t),c!==t?(k=s,s=a=Qr()):(o=s,s=t)):(o=s,s=t),s}function _i(){var s,a,c,u;return s=o,e.substr(o,8)===Du?(a=Du,o+=8):(a=t,b===0&&z(ed)),a!==t?(c=o,b++,u=It(),b--,u===t?c=void 0:(o=c,c=t),c!==t&&(u=X())!==t?(k=s,s=a=Qr()):(o=s,s=t)):(o=s,s=t),s}function _t(){var s,a;return s=o,e.charCodeAt(o)===92?(a=Ou,o++):(a=t,b===0&&z(Fu)),a!==t&&(k=s,a=nt()),s=a}function Dt(){var s,a;return s=o,e.charCodeAt(o)===123?(a=od,o++):(a=t,b===0&&z(ad)),a!==t&&(k=s,a=nt()),s=a}function Ot(){var s,a;return s=o,e.charCodeAt(o)===125?(a=sd,o++):(a=t,b===0&&z(ld)),a!==t&&(k=s,a=nt()),s=a}function Mr(){var s,a;return b++,s=o,e.charCodeAt(o)===36?(a=cd,o++):(a=t,b===0&&z(hd)),a!==t&&(k=s,a=nt()),b--,(s=a)===t&&(a=t,b===0&&z(ud)),s}function W0(){var s,a;return s=o,e.charCodeAt(o)===38?(a=pd,o++):(a=t,b===0&&z(dd)),a!==t&&(k=s,a=nt()),s=a}function $0(){var s,a;return s=o,e.charCodeAt(o)===94?(a=bd,o++):(a=t,b===0&&z(yd)),a!==t&&(k=s,a=nt()),s=a}function Z0(){var s,a;return s=o,e.charCodeAt(o)===95?(a=vd,o++):(a=t,b===0&&z(xd)),a!==t&&(k=s,a=nt()),s=a}function Si(){var s,a,c;return b++,s=o,b++,e.length>o?(a=e.charAt(o),o++):(a=t,b===0&&z(y)),b--,a===t?s=void 0:(o=s,s=t),s===t&&(s=o,(a=_t())!==t?(c=function(){var u,f,v,w,C,O;if(u=o,e.substr(o,8)===Nu?(f=Nu,o+=8):(f=t,b===0&&z(id)),f!==t)if(v=o,b++,w=It(),b--,w===t?v=void 0:(o=v,v=t),v!==t)if((w=X())!==t){for(C=[],e.length>o?(O=e.charAt(o),o++):(O=t,b===0&&z(y));O!==t;)C.push(O),e.length>o?(O=e.charAt(o),o++):(O=t,b===0&&z(y));C!==t?u=f=[f,v,w,C]:(o=u,u=t)}else o=u,u=t;else o=u,u=t;else o=u,u=t;return u}(),c!==t?s=a=[a,c]:(o=s,s=t)):(o=s,s=t)),b--,s===t&&(a=t,b===0&&z(Ad)),s}function te(){var s,a;return b++,e.charCodeAt(o)===10?(s=Sd,o++):(s=t,b===0&&z(qd)),s===t&&(e.substr(o,2)===Ru?(s=Ru,o+=2):(s=t,b===0&&z(Cd)),s===t&&(e.charCodeAt(o)===13?(s=zd,o++):(s=t,b===0&&z(Td)),s===t&&(e.charCodeAt(o)===8232?(s=Md,o++):(s=t,b===0&&z(Ed)),s===t&&(s=o,e.charCodeAt(o)===8233?(a=Dd,o++):(a=t,b===0&&z(Ld)),a!==t&&(k=s,a=nt()),s=a)))),b--,s===t&&(a=t,b===0&&z(_d)),s}function $t(){var s,a;return b++,s=o,Nd.test(e.charAt(o))?(a=e.charAt(o),o++):(a=t,b===0&&z(Od)),a!==t&&(k=s,a=nt()),b--,(s=a)===t&&(a=t,b===0&&z(Bd)),s}function me(){var s,a,c,u,f,v,w;if(b++,s=o,e.charCodeAt(o)===37?(a=Il,o++):(a=t,b===0&&z(Pl)),a!==t){for(c=[],u=o,f=o,b++,v=te(),b--,v===t?f=void 0:(o=f,f=t),f!==t?(e.length>o?(v=e.charAt(o),o++):(v=t,b===0&&z(y)),v!==t?u=f=[f,v]:(o=u,u=t)):(o=u,u=t);u!==t;)c.push(u),u=o,f=o,b++,v=te(),b--,v===t?f=void 0:(o=f,f=t),f!==t?(e.length>o?(v=e.charAt(o),o++):(v=t,b===0&&z(y)),v!==t?u=f=[f,v]:(o=u,u=t)):(o=u,u=t);if(c!==t){if(u=o,(f=te())!==t){for(v=[],w=$t();w!==t;)v.push(w),w=$t();v!==t?u=f=[f,v]:(o=u,u=t)}else o=u,u=t;u===t&&(u=Si()),u!==t?s=a=[a,c,u]:(o=s,s=t)}else o=s,s=t}else o=s,s=t;return s===t&&(s=o,a=function(){var C,O,P,K,V,tt,ot;if(b++,C=o,e.substr(o,6)===_u?(O=_u,o+=6):(O=t,b===0&&z($4)),O!==t)if(X()!==t)if(e.substr(o,9)===ui?(P=ui,o+=9):(P=t,b===0&&z(Su)),P!==t){for(K=[],V=o,tt=o,b++,ot=Po(),b--,ot===t?tt=void 0:(o=tt,tt=t),tt!==t?(e.length>o?(ot=e.charAt(o),o++):(ot=t,b===0&&z(y)),ot!==t?V=tt=[tt,ot]:(o=V,V=t)):(o=V,V=t);V!==t;)K.push(V),V=o,tt=o,b++,ot=Po(),b--,ot===t?tt=void 0:(o=tt,tt=t),tt!==t?(e.length>o?(ot=e.charAt(o),o++):(ot=t,b===0&&z(y)),ot!==t?V=tt=[tt,ot]:(o=V,V=t)):(o=V,V=t);K!==t&&(V=Po())!==t&&(tt=X())!==t?(k=C,C=O=Z4()):(o=C,C=t)}else o=C,C=t;else o=C,C=t;else o=C,C=t;return b--,C===t&&(O=t,b===0&&z(W4)),C}(),a!==t&&(k=s,a=nt()),s=a),b--,s===t&&(a=t,b===0&&z(Fd)),s}function X(){var s,a,c,u,f;for(b++,s=o,a=[],c=o,u=o,b++,f=Re(),b--,f===t?u=void 0:(o=u,u=t),u!==t?((f=te())===t&&(f=$t())===t&&(f=me()),f!==t?c=u=[u,f]:(o=c,c=t)):(o=c,c=t);c!==t;)a.push(c),c=o,u=o,b++,f=Re(),b--,f===t?u=void 0:(o=u,u=t),u!==t?((f=te())===t&&(f=$t())===t&&(f=me()),f!==t?c=u=[u,f]:(o=c,c=t)):(o=c,c=t);return a!==t&&(k=s,a=nt()),b--,(s=a)===t&&(a=t,b===0&&z(ko)),s}function Xt(){var s,a,c;for(b++,s=o,a=[],(c=te())===t&&(c=$t())===t&&(c=me());c!==t;)a.push(c),(c=te())===t&&(c=$t())===t&&(c=me());return a!==t&&(k=s,a=nt()),b--,(s=a)===t&&(a=t,b===0&&z(ko)),s}function mr(){var s,a,c,u,f,v,w,C;if(b++,s=o,a=o,b++,c=Re(),b--,c===t?a=void 0:(o=a,a=t),a!==t)if(c=o,b++,u=qi(),b--,u===t?c=void 0:(o=c,c=t),c!==t)if(u=o,b++,f=o,(v=Xt())!==t&&(w=_t())!==t?((C=qo())===t&&(C=x0()),C!==t?f=v=[v,w,C]:(o=f,f=t)):(o=f,f=t),b--,f===t?u=void 0:(o=u,u=t),u!==t){if(f=[],(v=$t())===t&&(v=te()),v!==t)for(;v!==t;)f.push(v),(v=$t())===t&&(v=te());else f=t;f!==t?(k=s,s=a=Hu()):(o=s,s=t)}else o=s,s=t;else o=s,s=t;else o=s,s=t;return b--,s===t&&(a=t,b===0&&z(ko)),s}function Re(){var s,a,c,u,f,v,w,C;if(b++,s=o,a=[],c=o,(u=Xt())!==t&&(f=_t())!==t&&(v=Y0())!==t&&(w=Xt())!==t?c=u=[u,f,v,w]:(o=c,c=t),c!==t)for(;c!==t;)a.push(c),c=o,(u=Xt())!==t&&(f=_t())!==t&&(v=Y0())!==t&&(w=Xt())!==t?c=u=[u,f,v,w]:(o=c,c=t);else a=t;if(a===t){for(a=o,c=[],u=$t();u!==t;)c.push(u),u=$t();if(c!==t){if(u=o,(f=te())!==t){for(v=[],w=me();w!==t;)v.push(w),w=me();v!==t?u=f=[f,v]:(o=u,u=t)}else o=u,u=t;if(u===t)if(u=[],(f=me())!==t)for(;f!==t;)u.push(f),f=me();else u=t;if(u!==t){for(f=[],v=o,w=[],C=$t();C!==t;)w.push(C),C=$t();if(w!==t&&(C=te())!==t?v=w=[w,C]:(o=v,v=t),v!==t)for(;v!==t;){for(f.push(v),v=o,w=[],C=$t();C!==t;)w.push(C),C=$t();w!==t&&(C=te())!==t?v=w=[w,C]:(o=v,v=t)}else f=t;if(f===t&&(f=o,b++,v=g0(),b--,v!==t?(o=f,f=void 0):f=t,f===t&&(f=Si())),f!==t){for(v=[],(w=$t())===t&&(w=te())===t&&(w=me());w!==t;)v.push(w),(w=$t())===t&&(w=te())===t&&(w=me());v!==t?a=c=[c,u,f,v]:(o=a,a=t)}else o=a,a=t}else o=a,a=t}else o=a,a=t}return a!==t&&(k=s,a=Gd()),b--,(s=a)===t&&(a=t,b===0&&z(jd)),s}function qi(){var s,a,c,u,f;return b++,s=o,X()!==t&&_t()!==t?(e.charCodeAt(o)===92?(a=Ou,o++):(a=t,b===0&&z(Fu)),a!==t&&X()!==t?(e.charCodeAt(o)===42?(c=nr,o++):(c=t,b===0&&z(ir)),c===t&&(c=null),c!==t&&X()!==t?(u=o,De()!==t&&X()!==t&&(f=gi())!==t&&We()!==t&&X()!==t?(k=u,u=Xd(f)):(o=u,u=t),u===t&&(u=null),u!==t?(k=s,s=Yd(u)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t)):(o=s,s=t),b--,s===t&&b===0&&z(Ud),s}function J0(){var s,a,c,u,f,v;return s=o,(a=X())!==t&&(c=_t())!==t?(e.substr(o,3)===Vu?(u=Vu,o+=3):(u=t,b===0&&z(Wd)),u===t&&(e.substr(o,7)===Iu?(u=Iu,o+=7):(u=t,b===0&&z($d))),u!==t?(f=o,b++,v=It(),b--,v===t?f=void 0:(o=f,f=t),f!==t?s=a=[a,c,u,f]:(o=s,s=t)):(o=s,s=t)):(o=s,s=t),s}function De(){var s,a;return s=o,e.charCodeAt(o)===91?(a=yo,o++):(a=t,b===0&&z(vo)),a!==t&&(k=s,a=nt()),s=a}function We(){var s,a;return s=o,e.charCodeAt(o)===93?(a=xo,o++):(a=t,b===0&&z(wo)),a!==t&&(k=s,a=nt()),s=a}function It(){var s,a;return b++,s=o,Jd.test(e.charAt(o))?(a=e.charAt(o),o++):(a=t,b===0&&z(Qd)),a!==t&&(k=s,a=Kd(a)),b--,(s=a)===t&&(a=t,b===0&&z(Zd)),s}function rn(){var s,a;return b++,s=o,Ao.test(e.charAt(o))?(a=e.charAt(o),o++):(a=t,b===0&&z(_o)),a!==t&&(k=s,a=em(a)),b--,(s=a)===t&&(a=t,b===0&&z(tm)),s}function Q0(){var s,a;return b++,s=o,e.charCodeAt(o)===91?(a=yo,o++):(a=t,b===0&&z(vo)),a!==t&&(k=s,a=Pu(a)),b--,(s=a)===t&&(a=t,b===0&&z(cm)),s}function K0(){var s,a;return b++,s=o,e.charCodeAt(o)===93?(a=xo,o++):(a=t,b===0&&z(wo)),a!==t&&(k=s,a=Pu(a)),b--,(s=a)===t&&(a=t,b===0&&z(hm)),s}function jo(){var s,a,c;return b++,s=o,a=o,b++,(c=$t())===t&&(c=te())===t&&(c=_t())===t&&(c=Dt())===t&&(c=Ot())===t&&(c=Mr())===t&&(c=W0())===t&&(c=function(){var u,f;return b++,u=o,e.charCodeAt(o)===35?(f=fd,o++):(f=t,b===0&&z(gd)),f!==t&&(k=u,f=nt()),b--,(u=f)===t&&(f=t,b===0&&z(md)),u}(),c===t&&(c=$0())===t&&(c=Z0())===t&&(c=function(){var u,f;return u=o,e.charCodeAt(o)===0?(f=wd,o++):(f=t,b===0&&z(kd)),f!==t&&(k=u,f=nt()),f}(),c===t&&(c=me())===t&&(c=De())===t&&(c=We()))),b--,c===t?a=void 0:(o=a,a=t),a!==t?(e.length>o?(c=e.charAt(o),o++):(c=t,b===0&&z(y)),c!==t?(k=s,s=a=dm(c)):(o=s,s=t)):(o=s,s=t),b--,s===t&&(a=t,b===0&&z(pm)),s}function tc(){var s,a;return b++,s=o,e.substr(o,3)===ju?(a=ju,o+=3):(a=t,b===0&&z(bm)),a===t&&(e.substr(o,3)===Gu?(a=Gu,o+=3):(a=t,b===0&&z(ym)),a===t&&(e.substr(o,2)===Uu?(a=Uu,o+=2):(a=t,b===0&&z(vm)),a===t&&(e.substr(o,2)===Xu?(a=Xu,o+=2):(a=t,b===0&&z(xm)),a===t&&(e.substr(o,2)===Yu?(a=Yu,o+=2):(a=t,b===0&&z(wm)),a===t&&(e.substr(o,3)===Wu?(a=Wu,o+=3):(a=t,b===0&&z(km)),a===t&&(e.substr(o,2)===$u?(a=$u,o+=2):(a=t,b===0&&z(Am)),a===t&&(e.substr(o,2)===Zu?(a=Zu,o+=2):(a=t,b===0&&z(_m)),a===t&&(e.substr(o,2)===Ju?(a=Ju,o+=2):(a=t,b===0&&z(Sm)),a===t&&(e.substr(o,2)===Qu?(a=Qu,o+=2):(a=t,b===0&&z(qm)),a===t&&(e.substr(o,2)===Ku?(a=Ku,o+=2):(a=t,b===0&&z(Cm)),a===t&&(e.substr(o,2)===t0?(a=t0,o+=2):(a=t,b===0&&z(zm)),a===t&&(e.substr(o,2)===e0?(a=e0,o+=2):(a=t,b===0&&z(Tm)))))))))))))),a!==t&&(k=s,a=Mm(a)),b--,(s=a)===t&&(a=t,b===0&&z(gm)),s}function Go(){var s,a,c;return s=o,(a=nn())!==t&&(k=s,a=Ym(a)),(s=a)===t&&(s=o,e.charCodeAt(o)===39?(a=jl,o++):(a=t,b===0&&z(Gl)),a!==t?(c=function(){var u,f,v;if(b++,u=o,f=[],s0.test(e.charAt(o))?(v=e.charAt(o),o++):(v=t,b===0&&z(l0)),v!==t)for(;v!==t;)f.push(v),s0.test(e.charAt(o))?(v=e.charAt(o),o++):(v=t,b===0&&z(l0));else f=t;return u=f!==t?e.substring(u,o):f,b--,u===t&&(f=t,b===0&&z(e5)),u}(),c!==t?(k=s,s=a=Wm(c)):(o=s,s=t)):(o=s,s=t),s===t&&(s=o,e.charCodeAt(o)===34?(a=$m,o++):(a=t,b===0&&z(Zm)),a!==t?((c=rc())===t&&(c=ec()),c!==t?(k=s,s=a=Jm(c)):(o=s,s=t)):(o=s,s=t))),s}function ec(){var s,a,c,u,f;return b++,s=o,a=o,c=o,(u=fr())!==t&&(f=fr())!==t?c=u=[u,f]:(o=c,c=t),(a=c!==t?e.substring(a,o):c)!==t&&(k=s,a=a0(a)),b--,(s=a)===t&&(a=t,b===0&&z(Qm)),s}function rc(){var s,a,c,u,f,v,w;return b++,s=o,a=o,c=o,(u=fr())!==t&&(f=fr())!==t&&(v=fr())!==t&&(w=fr())!==t?c=u=[u,f,v,w]:(o=c,c=t),(a=c!==t?e.substring(a,o):c)!==t&&(k=s,a=a0(a)),b--,(s=a)===t&&(a=t,b===0&&z(Km)),s}function nn(){var s,a,c;if(b++,s=o,a=[],Ao.test(e.charAt(o))?(c=e.charAt(o),o++):(c=t,b===0&&z(_o)),c!==t)for(;c!==t;)a.push(c),Ao.test(e.charAt(o))?(c=e.charAt(o),o++):(c=t,b===0&&z(_o));else a=t;return s=a!==t?e.substring(s,o):a,b--,s===t&&(a=t,b===0&&z(t5)),s}function fr(){var s;return b++,n5.test(e.charAt(o))?(s=e.charAt(o),o++):(s=t,b===0&&z(i5)),b--,s===t&&b===0&&z(r5),s}function ce(){var s,a,c,u,f,v,w,C,O;return b++,s=o,a=o,c=o,a5.test(e.charAt(o))?(u=e.charAt(o),o++):(u=t,b===0&&z(s5)),u===t&&(u=null),u!==t?(f=o,(v=nn())!==t?(w=o,e.charCodeAt(o)===46?(C=go,o++):(C=t,b===0&&z(bo)),C!==t?((O=nn())===t&&(O=null),O!==t?w=C=[C,O]:(o=w,w=t)):(o=w,w=t),w===t&&(w=null),w!==t?f=v=[v,w]:(o=f,f=t)):(o=f,f=t),f===t&&(f=o,e.charCodeAt(o)===46?(v=go,o++):(v=t,b===0&&z(bo)),v!==t&&(w=nn())!==t?f=v=[v,w]:(o=f,f=t)),f!==t?c=u=[u,f]:(o=c,c=t)):(o=c,c=t),(a=c!==t?e.substring(a,o):c)!==t&&(k=s,a=l5(a)),b--,(s=a)===t&&(a=t,b===0&&z(o5)),s}var{Vector:v5}=w5,N=n.generator;if(N.setErrorFn(we),N.location=function(){return di(k,o)},(i=h())!==t&&o===e.length)return i;throw i!==t&&o<e.length&&z({type:"end"}),function(s,a,c){return new r(r.buildMessage(s,a),s,a,c)}(So,Ge<e.length?e.charAt(Ge):null,Ge<e.length?di(Ge,Ge+1):di(Ge,Ge))}}}();_h=new Map([["ff",F.decode("&fflig;")],["ffi",F.decode("&ffilig;")],["ffl",F.decode("&ffllig;")],["fi",F.decode("&filig;")],["fl",F.decode("&fllig;")],["``",F.decode("&ldquo;")],["''",F.decode("&rdquo;")],["!´",F.decode("&iexcl;")],["?´",F.decode("&iquest;")],["--",F.decode("&ndash;")],["---",F.decode("&mdash;")],["<<",F.decode("&laquo;")],[">>",F.decode("&raquo;")],['"`',F.decode("&bdquo;")],[`"'`,F.decode("&ldquo;")]]),Pi=new Map([["b",["̲","_"]],["c",["̧","¸"]],["d",["̣","​ ̣"]],["H",["̋","˝"]],["k",["̨","˛"]],["r",["̊","˚"]],["t",["͡","​ ͡"]],["u",["̆","˘"]],["v",["̌","ˇ"]],['"',["̈","¨"]],["~",["̃","~"]],["^",["̂","^"]],["`",["̀","`"]],["'",["́","´"]],["=",["̄","¯"]],[".",["̇","˙"]]]),pn=new Map([["space"," "],["nobreakspace",F.decode("&nbsp;")],["thinspace",F.decode("&thinsp;")],["enspace",F.decode("&ensp;")],["enskip",F.decode("&ensp;")],["quad",F.decode("&emsp;")],["qquad",F.decode("&emsp;&emsp;")],["textvisiblespace",F.decode("&blank;")],["textcompwordmark",F.decode("&zwnj;")],["textdollar","$"],["$","$"],["slash",F.decode("&sol;")],["textless","<"],["textgreater",">"],["textbackslash","\\"],["textasciicircum","^"],["textunderscore","_"],["_","_"],["lbrack","["],["rbrack","]"],["textbraceleft","{"],["{","{"],["textbraceright","}"],["}","}"],["textasciitilde","˜"],["AA","Å"],["aa","å"],["AE",F.decode("&AElig;")],["ae",F.decode("&aelig;")],["OE",F.decode("&OElig;")],["oe",F.decode("&oelig;")],["DH",F.decode("&ETH;")],["dh",F.decode("&eth;")],["DJ",F.decode("&Dstrok;")],["dj",F.decode("&dstrok;")],["NG",F.decode("&ENG;")],["ng",F.decode("&eng;")],["TH",F.decode("&THORN;")],["th",F.decode("&thorn;")],["O",F.decode("&Oslash;")],["o",F.decode("&oslash;")],["i",F.decode("&imath;")],["j",F.decode("&jmath;")],["L",F.decode("&Lstrok;")],["l",F.decode("&lstrok;")],["IJ",F.decode("&IJlig;")],["ij",F.decode("&ijlig;")],["SS","ẞ"],["ss",F.decode("&szlig;")],["textquotesingle","'"],["textquoteleft",F.decode("&lsquo;")],["lq",F.decode("&lsquo;")],["textquoteright",F.decode("&rsquo;")],["rq",F.decode("&rsquo;")],["textquotedbl",F.decode("&quot;")],["textquotedblleft",F.decode("&ldquo;")],["textquotedblright",F.decode("&rdquo;")],["quotesinglbase",F.decode("&sbquo;")],["quotedblbase",F.decode("&bdquo;")],["guillemotleft",F.decode("&laquo;")],["guillemotright",F.decode("&raquo;")],["guilsinglleft",F.decode("&lsaquo;")],["guilsinglright",F.decode("&rsaquo;")],["textasciigrave","`"],["textgravedbl","˵"],["textasciidieresis",F.decode("&die;")],["textasciiacute",F.decode("&acute;")],["textacutedbl",F.decode("&dblac;")],["textasciimacron",F.decode("&macr;")],["textasciicaron",F.decode("&caron;")],["textasciibreve",F.decode("&breve;")],["texttildelow","˷"],["textendash",F.decode("&ndash;")],["textemdash",F.decode("&mdash;")],["textellipsis",F.decode("&hellip;")],["dots",F.decode("&hellip;")],["ldots",F.decode("&hellip;")],["textbullet",F.decode("&bull;")],["textopenbullet","◦"],["textperiodcentered",F.decode("&middot;")],["textdagger",F.decode("&dagger;")],["dag",F.decode("&dagger;")],["textdaggerdbl",F.decode("&Dagger;")],["ddag",F.decode("&Dagger;")],["textexclamdown",F.decode("&iexcl;")],["textquestiondown",F.decode("&iquest;")],["textinterrobang","‽"],["textinterrobangdown","⸘"],["textsection",F.decode("&sect;")],["S",F.decode("&sect;")],["textparagraph",F.decode("&para;")],["P",F.decode("&para;")],["textblank","␢"],["textlquill","⁅"],["textrquill","⁆"],["textlangle","〈"],["textrangle","〉"],["textlbrackdbl","〚"],["textrbrackdbl","〛"],["textcopyright",F.decode("&copy;")],["copyright",F.decode("&copy;")],["textregistered",F.decode("&reg;")],["textcircledP",F.decode("&copysr;")],["textservicemark","℠"],["texttrademark",F.decode("&trade;")],["textmarried","⚭"],["textdivorced","⚮"],["textordfeminine",F.decode("&ordf;")],["textordmasculine",F.decode("&ordm;")],["textdegree",F.decode("&deg;")],["textmu",F.decode("&micro;")],["textbar","|"],["textbardbl",F.decode("&Vert;")],["textbrokenbar",F.decode("&brvbar;")],["textreferencemark","※"],["textdiscount","⁒"],["textcelsius","℃"],["textnumero",F.decode("&numero;")],["textrecipe",F.decode("&rx;")],["textestimated","℮"],["textbigcircle",F.decode("&xcirc;")],["textmusicalnote",F.decode("&sung;")],["textohm","Ω"],["textmho","℧"],["textleftarrow",F.decode("&larr;")],["textuparrow",F.decode("&uarr;")],["textrightarrow",F.decode("&rarr;")],["textdownarrow",F.decode("&darr;")],["textperthousand",F.decode("&permil;")],["textpertenthousand","‱"],["textonehalf",F.decode("&frac12;")],["textthreequarters",F.decode("&frac34;")],["textonequarter",F.decode("&frac14;")],["textfractionsolidus",F.decode("&frasl;")],["textdiv",F.decode("&divide;")],["texttimes",F.decode("&times;")],["textminus",F.decode("&minus;")],["textasteriskcentered",F.decode("&lowast;")],["textpm",F.decode("&plusmn;")],["textsurd",F.decode("&radic;")],["textlnot",F.decode("&not;")],["textonesuperior",F.decode("&sup1;")],["texttwosuperior",F.decode("&sup2;")],["textthreesuperior",F.decode("&sup3;")],["texteuro",F.decode("&euro;")],["textcent",F.decode("&cent;")],["textsterling",F.decode("&pound;")],["pounds",F.decode("&pound;")],["textbaht","฿"],["textcolonmonetary","₡"],["textcurrency","¤"],["textdong","₫"],["textflorin","ƒ"],["textlira","₤"],["textnaira","₦"],["textpeso","₱"],["textwon","₩"],["textyen","¥"]]),Sn=function(){var r,e;function n(i,t){var l,h,p,m,y,_,S=this;this.g=i,t&&(this.options=t),this.g.newCounter("part"),this.g.newCounter("section"),this.g.newCounter("subsection","section"),this.g.newCounter("subsubsection","subsection"),this.g.newCounter("paragraph","subsubsection"),this.g.newCounter("subparagraph","paragraph"),this.g.newCounter("figure"),this.g.newCounter("table"),this.g.setLength("paperheight",new this.g.Length(11,"in")),this.g.setLength("paperwidth",new this.g.Length(8.5,"in")),this.g.setLength("@@size",new this.g.Length(10,"pt")),this.options.forEach(function(E,R){var I,U;switch(R){case"oneside":case"twoside":case"onecolumn":case"twocolumn":case"titlepage":case"notitlepage":case"fleqn":case"leqno":break;case"a4paper":return S.g.setLength("paperheight",new S.g.Length(297,"mm")),S.g.setLength("paperwidth",new S.g.Length(210,"mm"));case"a5paper":return S.g.setLength("paperheight",new S.g.Length(210,"mm")),S.g.setLength("paperwidth",new S.g.Length(148,"mm"));case"b5paper":return S.g.setLength("paperheight",new S.g.Length(250,"mm")),S.g.setLength("paperwidth",new S.g.Length(176,"mm"));case"letterpaper":return S.g.setLength("paperheight",new S.g.Length(11,"in")),S.g.setLength("paperwidth",new S.g.Length(8.5,"in"));case"legalpaper":return S.g.setLength("paperheight",new S.g.Length(14,"in")),S.g.setLength("paperwidth",new S.g.Length(8.5,"in"));case"executivepaper":return S.g.setLength("paperheight",new S.g.Length(10.5,"in")),S.g.setLength("paperwidth",new S.g.Length(7.25,"in"));case"landscape":return I=S.g.length("paperheight"),S.g.setLength("paperheight",S.g.length("paperwidth")),S.g.setLength("paperwidth",I);default:if((U=parseFloat(R))!==NaN&&R.endsWith("pt")&&String(U)===R.substring(0,R.length-2))return S.g.setLength("@@size",new S.g.Length(U,"pt"))}}),l=new this.g.Length(345,"pt"),h=new this.g.Length(1,"in"),(p=this.g.length("paperwidth").sub(h.mul(2))).cmp(l)===1&&(p=l),this.g.setLength("textwidth",p),this.g.setLength("marginparsep",new this.g.Length(11,"pt")),this.g.setLength("marginparpush",new this.g.Length(5,"pt")),y=(m=this.g.length("paperwidth").sub(this.g.length("textwidth"))).mul(.5).sub(h),(_=m.mul(.5).sub(this.g.length("marginparsep")).sub(h.mul(.8))).cmp(h.mul(2))===1&&(_=h.mul(2)),this.g.setLength("oddsidemargin",y),this.g.setLength("marginparwidth",_)}return n.displayName="Base",n.prototype,r=n.args={},n.prototype.options=new Map,n.prototype.contentsname=function(){return["Contents"]},n.prototype.listfigurename=function(){return["List of Figures"]},n.prototype.listtablename=function(){return["List of Tables"]},n.prototype.partname=function(){return["Part"]},n.prototype.figurename=function(){return["Figure"]},n.prototype.tablename=function(){return["Table"]},n.prototype.appendixname=function(){return["Appendix"]},n.prototype.indexname=function(){return["Index"]},(e=r).part=e.section=e.subsection=e.subsubsection=e.paragraph=e.subparagraph=["V","s","X","o?","g"],n.prototype.part=function(i,t,l){return[this.g.startsection("part",0,i,t,l)]},n.prototype.section=function(i,t,l){return[this.g.startsection("section",1,i,t,l)]},n.prototype.subsection=function(i,t,l){return[this.g.startsection("subsection",2,i,t,l)]},n.prototype.subsubsection=function(i,t,l){return[this.g.startsection("subsubsection",3,i,t,l)]},n.prototype.paragraph=function(i,t,l){return[this.g.startsection("paragraph",4,i,t,l)]},n.prototype.subparagraph=function(i,t,l){return[this.g.startsection("subparagraph",5,i,t,l)]},n.prototype.thepart=function(){return[this.g.Roman(this.g.counter("part"))]},n.prototype.thesection=function(){return[this.g.arabic(this.g.counter("section"))]},n.prototype.thesubsection=function(){return this.thesection().concat("."+this.g.arabic(this.g.counter("subsection")))},n.prototype.thesubsubsection=function(){return this.thesubsection().concat("."+this.g.arabic(this.g.counter("subsubsection")))},n.prototype.theparagraph=function(){return this.thesubsubsection().concat("."+this.g.arabic(this.g.counter("paragraph")))},n.prototype.thesubparagraph=function(){return this.theparagraph().concat("."+this.g.arabic(this.g.counter("subparagraph")))},r.maketitle=["V"],n.prototype.maketitle=function(){var i,t,l,h,p;return this.g.setTitle(this._title),i=this.g.create(this.g.title,this._title),t=this.g.create(this.g.author,this._author),l=this.g.create(this.g.date,(h=this._date)?h:this.g.macro("today")),p=this.g.create(this.g.list,[this.g.createVSpace(new this.g.Length(2,"em")),i,this.g.createVSpace(new this.g.Length(1.5,"em")),t,this.g.createVSpace(new this.g.Length(1,"em")),l,this.g.createVSpace(new this.g.Length(1.5,"em"))],"center"),this.g.setCounter("footnote",0),this._title=null,this._author=null,this._date=null,this._thanks=null,this.title=this.author=this.date=this.thanks=this.and=this.maketitle=function(){},[p]},n}(),Sh=function(r){var e;function n(i,t){n.superclass.apply(this,arguments),this.g.setCounter("secnumdepth",3),this.g.setCounter("tocdepth",3)}return function(i,t){function l(){}return l.prototype=(i.superclass=t).prototype,(i.prototype=new l).constructor=i,typeof t.extended=="function"&&t.extended(i),i}((function(i,t){var l={}.hasOwnProperty;for(var h in t)l.call(t,h)&&(i[h]=t[h]);return i}(n,r).displayName="Article",n),r).prototype,n.css="css/article.css",e=n.args=Sn.args,n.prototype.refname=function(){return["References"]},e.tableofcontents=["V"],n.prototype.tableofcontents=function(){return this.section(!0,void 0,this.g.macro("contentsname")).concat([this.g._toc])},e.abstract=["V"],n.prototype.abstract=function(){var i;return this.g.setFontSize("small"),this.g.enterGroup(),this.g.setFontWeight("bf"),i=this.g.create(this.g.list,this.g.macro("abstractname"),"center"),this.g.exitGroup(),[i].concat(this.quotation())},n.prototype.endabstract=function(){this.endquotation()},e.appendix=["V"],n.prototype.appendix=function(){this.g.setCounter("section",0),this.g.setCounter("subsection",0),this.thesection=function(){return[this.g.Alph(this.g.counter("section"))]}},n}(Sn),ji=function(r){var e,n;function i(t,l){i.superclass.apply(this,arguments),this.g.newCounter("chapter"),this.g.addToReset("section","chapter"),this.g.setCounter("secnumdepth",2),this.g.setCounter("tocdepth",2),this.g.addToReset("figure","chapter"),this.g.addToReset("table","chapter"),this.g.addToReset("footnote","chapter")}return function(t,l){function h(){}return h.prototype=(t.superclass=l).prototype,(t.prototype=new h).constructor=t,typeof l.extended=="function"&&l.extended(t),t}((function(t,l){var h={}.hasOwnProperty;for(var p in l)h.call(l,p)&&(t[p]=l[p]);return t}(i,r).displayName="Report",i),r).prototype,i.css="css/book.css",i.prototype.chaptername=function(){return["Chapter"]},i.prototype.bibname=function(){return["Bibliography"]},(n=e=i.args=Sn.args).part=n.chapter=["V","s","X","o?","g"],i.prototype.part=function(t,l,h){return[this.g.startsection("part",-1,t,l,h)]},i.prototype.chapter=function(t,l,h){return[this.g.startsection("chapter",0,t,l,h)]},i.prototype.thechapter=function(){return[this.g.arabic(this.g.counter("chapter"))]},i.prototype.thesection=function(){return this.thechapter().concat("."+this.g.arabic(this.g.counter("section")))},i.prototype.thefigure=function(){return(this.g.counter("chapter")>0?this.thechapter().concat("."):[]).concat(this.g.arabic(this.g.counter("figure")))},i.prototype.thetable=function(){return(this.g.counter("chapter")>0?this.thechapter().concat("."):[]).concat(this.g.arabic(this.g.counter("table")))},e.tableofcontents=["V"],i.prototype.tableofcontents=function(){return this.chapter(!0,void 0,this.g.macro("contentsname")).concat([this.g._toc])},e.abstract=["V"],i.prototype.abstract=function(){var t;return this.g.setFontSize("small"),this.g.enterGroup(),this.g.setFontWeight("bf"),t=this.g.create(this.g.list,this.g.macro("abstractname"),"center"),this.g.exitGroup(),[t].concat(this.quotation())},i.prototype.endabstract=function(){this.endquotation()},e.appendix=["V"],i.prototype.appendix=function(){this.g.setCounter("chapter",0),this.g.setCounter("section",0),this.chaptername=this.appendixname,this.thechapter=function(){return[this.g.Alph(this.g.counter("chapter"))]}},i}(Sn),qh=function(r){var e,n,i;function t(l,h){t.superclass.apply(this,arguments),this["@mainmatter"]=!0}return function(l,h){function p(){}return p.prototype=(l.superclass=h).prototype,(l.prototype=new p).constructor=l,typeof h.extended=="function"&&h.extended(l),l}((function(l,h){var p={}.hasOwnProperty;for(var m in h)p.call(h,m)&&(l[m]=h[m]);return l}(t,r).displayName="Book",t),r).prototype,t.css="css/book.css",(n=e=t.args=ji.args).part=n.chapter=["V","s","X","o?","g"],t.prototype.chapter=function(l,h,p){return[this.g.startsection("chapter",0,l||!this["@mainmatter"],h,p)]},(i=e).frontmatter=i.mainmatter=i.backmatter=["V"],t.prototype.frontmatter=function(){this["@mainmatter"]=!1},t.prototype.mainmatter=function(){this["@mainmatter"]=!0},t.prototype.backmatter=function(){this["@mainmatter"]=!1},t}(ji);var za,Ch,zh,Th,Ta,A5={article:Sh,book:qh,report:ji};za=function(){var r,e;function n(i,t){var l,h,p,m;for(this.g=i,t&&(this.options=t),l=0,p=(h=this.options).length;l<p;++l)m=h[l],m=Object.keys(m)[0]}return n.displayName="XColor",n.prototype,r=n.args={},e=n.colors=new Map([["red",{}],["green",{}],["blue",{}],["cyan",{}],["magenta",{}],["yellow",{}],["black",{}],["gray",{}],["white",{}],["darkgray",{}],["lightgray",{}],["brown",{}],["lime",{}],["olive",{}],["orange",{}],["pink",{}],["purple",{}],["teal",{}],["violet",{}]]),r.definecolorset=["P","i?","c-ml","ie","ie","c-ssp"],n.prototype.definecolorset=function(i,t,l,h,p){var m,y,_;for(i!==null&&i!=="named"&&i!=="ps"&&this.g.error("unknown color type"),l||(l=""),h||(h=""),m=0,y=p.length;m<y;++m)_=p[m],this.definecolor(i,l+_.name+h,t,_.speclist)},r.definecolor=["P","i?","i","c-ml","c-spl"],n.prototype.definecolor=function(i,t,l,h){var p,m,y,_,S;for(i!==null&&i!=="named"&&i!=="ps"&&this.g.error("unknown color type"),l.models.length!==h.length&&this.g.error("color models and specs don't match"),p={},m=0,_=(y=l.models).length;m<_;++m)S=m,p[y[m]]=h[S];e.set(t,p)},r.color=["HV",[["c-ml?","c-spl"],["c"]]],n.prototype.color=function(){arguments.length===1?console.log("got color expression"):console.log("got model/color spec")},r.textcolor=["HV",[["c-ml?","c-spl"],["c"]],"g"],n.prototype.textcolor=function(){},r.colorbox=["H","i?","c","g"],n.prototype.colorbox=function(i,t,l){},r.fcolorbox=["H","i?","c","c","g"],n.prototype.fcolorbox=function(i,t,l){},n}(),Ch=za,zh=function(){var r;function e(n,i){}return e.displayName="Echo",e.prototype,(r=e.args={}).gobbleO=["H","o?"],e.prototype.gobbleO=function(){return[]},r.echoO=["H","o?"],e.prototype.echoO=function(n){return["-",n,"-"]},r.echoOGO=["H","o?","g","o?"],e.prototype.echoOGO=function(n,i,t){var l;return l=[],n&&l.push("-",n,"-"),l.push("+",i,"+"),t&&l.push("-",t,"-"),l},r.echoGOG=["H","g","o?","g"],e.prototype.echoGOG=function(n,i,t){var l;return l=["+",n,"+"],i&&l.push("-",i,"-"),l.push("+",t,"+"),l},e}(),Th=function(){function r(e,n){}return r.displayName="Gensymb",r.prototype,r.args={},r.symbols=new Map([["degree",F.decode("&deg;")],["celsius","℃"],["perthousand",F.decode("&permil;")],["ohm","Ω"],["micro",F.decode("&mu;")]]),r}(),Ta=function(){var r;function e(n,i){}return e.displayName="Graphicx",e.prototype,(r=e.args={}).rotatebox=["H","kv?","n","hg"],e.prototype.rotatebox=function(n,i,t){},r.scalebox=["H","n","n?","g"],e.prototype.scalebox=function(n,i,t){},r.reflectbox=["H","g"],e.prototype.reflectbox=function(n){return this.scalebox(-1,1,n)},r.resizebox=["H","s","l","l","g"],e.prototype.resizebox=function(n,i,t,l){},r.graphicspath=["HV","gl"],e.prototype.graphicspath=function(n){},r.includegraphics=["H","s","kv?","kv?","k"],e.prototype.includegraphics=function(n,i,t,l){return[this.g.createImage(i.get("width"),i.get("height"),l)]},e}();var _5={color:Ch,xcolor:za,echo:zh,gensymb:Th,graphics:Ta,graphicx:Ta,hyperref:function(){var r;function e(n,i){}return e.displayName="Hyperref",e.prototype,(r=e.args={}).href=["H","o?","u","g"],e.prototype.href=function(n,i,t){return[this.g.create(this.g.link(i),t)]},r.url=["H","u"],e.prototype.url=function(n){return[this.g.create(this.g.link(n),this.g.createText(n))]},r.nolinkurl=["H","u"],e.prototype.nolinkurl=function(n){return[this.g.create(this.g.link(),this.g.createText(n))]},e}(),latexsym:function(){function r(e,n){}return r.displayName="Latexsym",r.prototype,r.args={},r.symbols=new Map([["mho","℧"],["Join","⨝"],["Box","□"],["Diamond","◇"],["leadsto","⤳"],["sqsubset","⊏"],["sqsupset","⊐"],["lhd","⊲"],["unlhd","⊴"],["rhd","⊳"],["unrhd","⊵"]]),r}(),multicol:function(){function r(e,n){}return r.displayName="Multicol",r.prototype,(r.args={}).multicols=["V","n","o?","o?"],r.prototype.multicols=function(e,n){return[n,this.g.create(this.g.multicols(e))]},r}(),stix:function(){function r(e,n){e.KaTeX.__defineSymbol("math","main","textord","♤","\\varspadesuit",!0),e.KaTeX.__defineSymbol("math","main","textord","♥","\\varheartsuit",!0),e.KaTeX.__defineSymbol("math","main","textord","♦","\\vardiamondsuit",!0),e.KaTeX.__defineSymbol("math","main","textord","♧","\\varclubsuit",!0)}return r.displayName="Stix",r.prototype,r.args={},r.symbols=new Map([["checkmark",F.decode("&check;")]]),r}(),textcomp:function(){function r(e,n){}return r.displayName="Textcomp",r.prototype,r.args={},r.symbols=new Map([["textcentoldstyle",""],["textdollaroldstyle",""],["textguarani","₲"],["textcopyleft","ἒF"],["textzerooldstyle",""],["textoneoldstyle",""],["texttwooldstyle",""],["textthreeoldstyle",""],["textfouroldstyle",""],["textfiveoldstyle",""],["textsixoldstyle",""],["textsevenoldstyle",""],["texteightoldstyle",""],["textnineoldstyle",""],["textborn","⭑"],["textdied",F.decode("&dagger;")],["textpilcrow",F.decode("&para;")],["textdblhyphen","⹀"]]),r}(),textgreek:function(){function r(e,n){}return r.displayName="Textgreek",r.prototype,r.args={},r.symbols=new Map([["textalpha",F.decode("&alpha;")],["textbeta",F.decode("&beta;")],["textgamma",F.decode("&gamma;")],["textdelta",F.decode("&delta;")],["textepsilon",F.decode("&epsilon;")],["textzeta",F.decode("&zeta;")],["texteta",F.decode("&eta;")],["texttheta",F.decode("&thetasym;")],["textiota",F.decode("&iota;")],["textkappa",F.decode("&kappa;")],["textlambda",F.decode("&lambda;")],["textmu",F.decode("&mu;")],["textmugreek",F.decode("&mu;")],["textnu",F.decode("&nu;")],["textxi",F.decode("&xi;")],["textomikron",F.decode("&omicron;")],["textpi",F.decode("&pi;")],["textrho",F.decode("&rho;")],["textsigma",F.decode("&sigma;")],["texttau",F.decode("&tau;")],["textupsilon",F.decode("&upsilon;")],["textphi",F.decode("&phi;")],["textchi",F.decode("&chi;")],["textpsi",F.decode("&psi;")],["textomega",F.decode("&omega;")],["textAlpha",F.decode("&Alpha;")],["textBeta",F.decode("&Beta;")],["textGamma",F.decode("&Gamma;")],["textDelta",F.decode("&Delta;")],["textEpsilon",F.decode("&Epsilon;")],["textZeta",F.decode("&Zeta;")],["textEta",F.decode("&Eta;")],["textTheta",F.decode("&Theta;")],["textIota",F.decode("&Iota;")],["textKappa",F.decode("&Kappa;")],["textLambda",F.decode("&Lambda;")],["textMu",F.decode("&Mu;")],["textNu",F.decode("&Nu;")],["textXi",F.decode("&Xi;")],["textOmikron",F.decode("&Omicron;")],["textPi",F.decode("&Pi;")],["textRho",F.decode("&Rho;")],["textSigma",F.decode("&Sigma;")],["textTau",F.decode("&Tau;")],["textUpsilon",F.decode("&Upsilon;")],["textPhi",F.decode("&Phi;")],["textChi",F.decode("&Chi;")],["textPsi",F.decode("&Psi;")],["textOmega",F.decode("&Omega;")],["textvarsigma",F.decode("&sigmaf;")],["straightphi","ϕ"],["scripttheta","ϑ"],["straighttheta",F.decode("&theta;")],["straightepsilon","ϵ"]]),r}()},Mh=typeof Nr=="object"&&Nr&&Nr.Object===Object&&Nr,S5=Mh,q5=typeof self=="object"&&self&&self.Object===Object&&self,os=S5||q5||Function("return this")(),Hn=os.Symbol,ic=Hn,Eh=Object.prototype,C5=Eh.hasOwnProperty,z5=Eh.toString,qn=ic?ic.toStringTag:void 0,T5=function(r){var e=C5.call(r,qn),n=r[qn];try{r[qn]=void 0;var i=!0}catch{}var t=z5.call(r);return i&&(e?r[qn]=n:delete r[qn]),t},M5=Object.prototype.toString,E5=T5,D5=function(r){return M5.call(r)},oc=Hn?Hn.toStringTag:void 0,as=function(r){return r==null?r===void 0?"[object Undefined]":"[object Null]":oc&&oc in Object(r)?E5(r):D5(r)},io=function(r){var e=typeof r;return r!=null&&(e=="object"||e=="function")},L5=as,B5=io,ac,Dh=function(r){if(!B5(r))return!1;var e=L5(r);return e=="[object Function]"||e=="[object GeneratorFunction]"||e=="[object AsyncFunction]"||e=="[object Proxy]"},Uo=os["__core-js_shared__"],sc=(ac=/[^.]+$/.exec(Uo&&Uo.keys&&Uo.keys.IE_PROTO||""))?"Symbol(src)_1."+ac:"",N5=function(r){return!!sc&&sc in r},O5=Function.prototype.toString,F5=Dh,R5=N5,H5=io,V5=function(r){if(r!=null){try{return O5.call(r)}catch{}try{return r+""}catch{}}return""},I5=/^\[object .+?Constructor\]$/,P5=Function.prototype,j5=Object.prototype,G5=P5.toString,U5=j5.hasOwnProperty,X5=RegExp("^"+G5.call(U5).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),Y5=function(r){return!(!H5(r)||R5(r))&&(F5(r)?X5:I5).test(V5(r))},W5=function(r,e){return r?.[e]},$5=function(r,e){var n=W5(r,e);return Y5(n)?n:void 0},Lh=function(){try{var r=$5(Object,"defineProperty");return r({},"",{}),r}catch{}}(),lc=Lh,Bh=function(r,e,n){e=="__proto__"&&lc?lc(r,e,{configurable:!0,enumerable:!0,value:n,writable:!0}):r[e]=n},Nh=function(r,e){return r===e||r!=r&&e!=e},Z5=Bh,J5=Nh,Q5=Object.prototype.hasOwnProperty,Oh=function(r,e,n){var i=r[e];Q5.call(r,e)&&J5(i,n)&&(n!==void 0||e in r)||Z5(r,e,n)},K5=Oh,t3=Bh,Fh=function(r,e,n,i){var t=!n;n||(n={});for(var l=-1,h=e.length;++l<h;){var p=e[l],m=i?i(n[p],r[p],p,n,r):void 0;m===void 0&&(m=r[p]),t?t3(n,p,m):K5(n,p,m)}return n},Rh=function(r){return r},e3=function(r,e,n){switch(n.length){case 0:return r.call(e);case 1:return r.call(e,n[0]);case 2:return r.call(e,n[0],n[1]);case 3:return r.call(e,n[0],n[1],n[2])}return r.apply(e,n)},uc=Math.max,r3=function(r,e,n){return e=uc(e===void 0?r.length-1:e,0),function(){for(var i=arguments,t=-1,l=uc(i.length-e,0),h=Array(l);++t<l;)h[t]=i[e+t];t=-1;for(var p=Array(e+1);++t<e;)p[t]=i[t];return p[e]=n(h),e3(r,this,p)}},n3=function(r){return function(){return r}},cc=Lh,i3=cc?function(r,e){return cc(r,"toString",{configurable:!0,enumerable:!1,value:n3(e),writable:!0})}:Rh,o3=Date.now,a3=function(r){var e=0,n=0;return function(){var i=o3(),t=16-(i-n);if(n=i,t>0){if(++e>=800)return arguments[0]}else e=0;return r.apply(void 0,arguments)}}(i3),s3=Rh,l3=r3,u3=a3,Hh=function(r){return typeof r=="number"&&r>-1&&r%1==0&&r<=9007199254740991},c3=Dh,h3=Hh,oo=function(r){return r!=null&&h3(r.length)&&!c3(r)},p3=/^(?:0|[1-9]\d*)$/,Vh=function(r,e){var n=typeof r;return!!(e=e??9007199254740991)&&(n=="number"||n!="symbol"&&p3.test(r))&&r>-1&&r%1==0&&r<e},d3=Nh,m3=oo,f3=Vh,g3=io,b3=function(r,e){return u3(l3(r,e,s3),r+"")},y3=function(r,e,n){if(!g3(n))return!1;var i=typeof e;return!!(i=="number"?m3(n)&&f3(e,n.length):i=="string"&&e in n)&&d3(n[e],r)},Ih=function(r){return b3(function(e,n){var i=-1,t=n.length,l=t>1?n[t-1]:void 0,h=t>2?n[2]:void 0;for(l=r.length>3&&typeof l=="function"?(t--,l):void 0,h&&y3(n[0],n[1],h)&&(l=t<3?void 0:l,t=1),e=Object(e);++i<t;){var p=n[i];p&&r(e,p,i,l)}return e})},v3=Object.prototype,ss=function(r){var e=r&&r.constructor;return r===(typeof e=="function"&&e.prototype||v3)},x3=function(r,e){for(var n=-1,i=Array(r);++n<r;)i[n]=e(n);return i},ls=function(r){return r!=null&&typeof r=="object"},w3=as,k3=ls,hc=function(r){return k3(r)&&w3(r)=="[object Arguments]"},A3=ls,Ph=Object.prototype,_3=Ph.hasOwnProperty,S3=Ph.propertyIsEnumerable,jh=hc(function(){return arguments}())?hc:function(r){return A3(r)&&_3.call(r,"callee")&&!S3.call(r,"callee")},Gh=Array.isArray,Ma={exports:{}},q3=function(){return!1};(function(r,e){var n=os,i=q3,t=e&&!e.nodeType&&e,l=t&&r&&!r.nodeType&&r,h=l&&l.exports===t?n.Buffer:void 0,p=(h?h.isBuffer:void 0)||i;r.exports=p})(Ma,Ma.exports);var C3=Ma.exports,z3=as,T3=Hh,M3=ls,jt={};jt["[object Float32Array]"]=jt["[object Float64Array]"]=jt["[object Int8Array]"]=jt["[object Int16Array]"]=jt["[object Int32Array]"]=jt["[object Uint8Array]"]=jt["[object Uint8ClampedArray]"]=jt["[object Uint16Array]"]=jt["[object Uint32Array]"]=!0,jt["[object Arguments]"]=jt["[object Array]"]=jt["[object ArrayBuffer]"]=jt["[object Boolean]"]=jt["[object DataView]"]=jt["[object Date]"]=jt["[object Error]"]=jt["[object Function]"]=jt["[object Map]"]=jt["[object Number]"]=jt["[object Object]"]=jt["[object RegExp]"]=jt["[object Set]"]=jt["[object String]"]=jt["[object WeakMap]"]=!1;var E3=function(r){return M3(r)&&T3(r.length)&&!!jt[z3(r)]},D3=function(r){return function(e){return r(e)}},Ea={exports:{}};(function(r,e){var n=Mh,i=e&&!e.nodeType&&e,t=i&&r&&!r.nodeType&&r,l=t&&t.exports===i&&n.process,h=function(){try{var p=t&&t.require&&t.require("util").types;return p||l&&l.binding&&l.binding("util")}catch{}}();r.exports=h})(Ea,Ea.exports);var pc=Ea.exports,L3=E3,B3=D3,dc=pc&&pc.isTypedArray,N3=dc?B3(dc):L3,O3=x3,F3=jh,R3=Gh,H3=C3,V3=Vh,I3=N3,P3=Object.prototype.hasOwnProperty,Uh=function(r,e){var n=R3(r),i=!n&&F3(r),t=!n&&!i&&H3(r),l=!n&&!i&&!t&&I3(r),h=n||i||t||l,p=h?O3(r.length,String):[],m=p.length;for(var y in r)!e&&!P3.call(r,y)||h&&(y=="length"||t&&(y=="offset"||y=="parent")||l&&(y=="buffer"||y=="byteLength"||y=="byteOffset")||V3(y,m))||p.push(y);return p},j3=function(r,e){return function(n){return r(e(n))}},G3=j3(Object.keys,Object),U3=ss,X3=G3,Y3=Object.prototype.hasOwnProperty,W3=Uh,$3=function(r){if(!U3(r))return X3(r);var e=[];for(var n in Object(r))Y3.call(r,n)&&n!="constructor"&&e.push(n);return e},Z3=oo,J3=Oh,Q3=Fh,K3=Ih,tf=oo,ef=ss,rf=function(r){return Z3(r)?W3(r):$3(r)},nf=Object.prototype.hasOwnProperty,Xo=Ir(K3(function(r,e){if(ef(e)||tf(e))Q3(e,rf(e),r);else for(var n in e)nf.call(e,n)&&J3(r,n,e[n])})),of=io,af=ss,sf=function(r){var e=[];if(r!=null)for(var n in Object(r))e.push(n);return e},lf=Object.prototype.hasOwnProperty,uf=Uh,cf=function(r){if(!of(r))return sf(r);var e=af(r),n=[];for(var i in r)(i!="constructor"||!e&&lf.call(r,i))&&n.push(i);return n},hf=oo,Xh,Yh,pf=Fh,df=function(r){return hf(r)?uf(r,!0):cf(r)},Yo=Ir(Ih(function(r,e){pf(e,df(e),r)})),mf=[].slice,ff=Array.from||function(r){return mf.call(r)};Xh=function(){D.displayName="LaTeX";var r,e,n,i,t,l,h,p,m,y,_,S,E,R,I,U,Y,it,nt,pt,dt,yt=D.prototype;function D(q,L){var G;L&&(Yo(this,new L(q)),Xo(e,L.args),(G=L.symbols)!=null&&G.forEach(function(j,Z){return pn.set(Z,j)})),this.g=q,this.g.newCounter("secnumdepth"),this.g.newCounter("tocdepth"),this.g.newCounter("footnote"),this.g.newCounter("mpfootnote"),this.g.newCounter("@listdepth"),this.g.newCounter("@itemdepth"),this.g.newCounter("@enumdepth"),this.g.newLength("@@size"),this.g.newLength("unitlength"),this.g.setLength("unitlength",new this.g.Length(1,"pt")),this.g.newLength("@wholewidth"),this.g.setLength("@wholewidth",new this.g.Length(.4,"pt")),this.g.newLength("paperheight"),this.g.newLength("paperwidth"),this.g.newLength("oddsidemargin"),this.g.newLength("evensidemargin"),this.g.newLength("textheight"),this.g.newLength("textwidth"),this.g.newLength("marginparwidth"),this.g.newLength("marginparsep"),this.g.newLength("marginparpush"),this.g.newLength("columnwidth"),this.g.newLength("columnsep"),this.g.newLength("columnseprule"),this.g.newLength("linewidth"),this.g.newLength("leftmargin"),this.g.newLength("rightmargin"),this.g.newLength("listparindent"),this.g.newLength("itemindent"),this.g.newLength("labelwidth"),this.g.newLength("labelsep"),this.g.newLength("leftmargini"),this.g.newLength("leftmarginii"),this.g.newLength("leftmarginiii"),this.g.newLength("leftmarginiv"),this.g.newLength("leftmarginv"),this.g.newLength("leftmarginvi"),this.g.newLength("fboxrule"),this.g.newLength("fboxsep"),this.g.newLength("tabbingsep"),this.g.newLength("arraycolsep"),this.g.newLength("tabcolsep"),this.g.newLength("arrayrulewidth"),this.g.newLength("doublerulesep"),this.g.newLength("footnotesep"),this.g.newLength("topmargin"),this.g.newLength("headheight"),this.g.newLength("headsep"),this.g.newLength("footskip"),this.g.newLength("topsep"),this.g.newLength("partopsep"),this.g.newLength("itemsep"),this.g.newLength("parsep"),this.g.newLength("floatsep"),this.g.newLength("textfloatsep"),this.g.newLength("intextsep"),this.g.newLength("dblfloatsep"),this.g.newLength("dbltextfloatsep")}for(r=["calc","pspicture","picture","pict2e","keyval","comment"],D.prototype._title=null,D.prototype._author=null,D.prototype._date=null,D.prototype._thanks=null,D.symbols=pn,(e=D.args={}).empty=["HV"],D.prototype.empty=function(){},D.prototype.TeX=function(){var q,L;return this.g.enterGroup(),(q=this.g.create(this.g.inline)).setAttribute("class","tex"),q.appendChild(this.g.createText("T")),L=this.g.create(this.g.inline,this.g.createText("e"),"e"),q.appendChild(L),q.appendChild(this.g.createText("X")),this.g.exitGroup(),[q]},D.prototype.LaTeX=function(){var q,L,G;return this.g.enterGroup(),(q=this.g.create(this.g.inline)).setAttribute("class","latex"),q.appendChild(this.g.createText("L")),L=this.g.create(this.g.inline,this.g.createText("a"),"a"),q.appendChild(L),q.appendChild(this.g.createText("T")),G=this.g.create(this.g.inline,this.g.createText("e"),"e"),q.appendChild(G),q.appendChild(this.g.createText("X")),this.g.exitGroup(),[q]},D.prototype.today=function(){return[new Date().toLocaleDateString("en",{weekday:"long",year:"numeric",month:"long",day:"numeric"})]},D.prototype.newline=function(){return[this.g.create(this.g.linebreak)]},D.prototype.negthinspace=function(){return[this.g.create(this.g.inline,void 0,"negthinspace")]},e.par=["V"],e.item=["V"],e.onecolumn=["V"],D.prototype.onecolumn=function(){},e.twocolumn=["V","o?"],D.prototype.twocolumn=function(){},(n=e).smallbreak=n.medbreak=n.bigbreak=["V"],D.prototype.smallbreak=function(){return[this.g.createVSpaceSkip("smallskip")]},D.prototype.medbreak=function(){return[this.g.createVSpaceSkip("medskip")]},D.prototype.bigbreak=function(){return[this.g.createVSpaceSkip("bigskip")]},e.addvspace=["V","l"],D.prototype.addvspace=function(q){return this.g.createVSpace(q)},e.marginpar=["H","g"],D.prototype.marginpar=function(q){return[this.g.marginpar(q)]},D.prototype.abstractname=function(){return["Abstract"]},e.title=["HV","g"],e.author=["HV","g"],e.and=["H"],e.date=["HV","g"],e.thanks=["HV","g"],D.prototype.title=function(q){this._title=q},D.prototype.author=function(q){this._author=q},D.prototype.date=function(q){this._date=q},D.prototype.and=function(){return this.g.macro("quad")},D.prototype.thanks=D.footnote,i=0,h=(l=["rm","sf","tt","md","bf","up","it","sl","sc","normal"]).length;i<h;++i)t=l[i],e["text"+t]=["H","X","g"];for(D.prototype.textrm=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontFamily("rm")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.textsf=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontFamily("sf")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.texttt=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontFamily("tt")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.textmd=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontWeight("md")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.textbf=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontWeight("bf")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.textup=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontShape("up")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.textit=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontShape("it")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.textsl=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontShape("sl")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.textsc=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontShape("sc")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},D.prototype.textnormal=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontFamily("rm"),this.g.setFontWeight("md"),this.g.setFontShape("up")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},e.emph=["H","X","g"],D.prototype.emph=function(q){return arguments.length===0?(this.g.enterGroup(),this.g.setFontShape("em")):(q=this.g.addAttributes(q),this.g.exitGroup(),[q])},i=0,h=(l=["rm","sf","tt"]).length;i<h;++i)p=l[i],e[p+"family"]=["HV"];for(i=0,h=(l=["md","bf"]).length;i<h;++i)m=l[i],e[m+"series"]=["HV"];for(i=0,h=(l=["up","it","sl","sc"]).length;i<h;++i)y=l[i],e[y+"shape"]=["HV"];for(i=0,h=(l=["normalfont","em"]).length;i<h;++i)_=l[i],e[_]=["HV"];for(i=0,h=(l=["tiny","scriptsize","footnotesize","small","normalsize","large","Large","LARGE","huge","Huge"]).length;i<h;++i)S=l[i],e[S]=["HV"];for(D.prototype.rmfamily=function(){this.g.setFontFamily("rm")},D.prototype.sffamily=function(){this.g.setFontFamily("sf")},D.prototype.ttfamily=function(){this.g.setFontFamily("tt")},D.prototype.mdseries=function(){this.g.setFontWeight("md")},D.prototype.bfseries=function(){this.g.setFontWeight("bf")},D.prototype.upshape=function(){this.g.setFontShape("up")},D.prototype.itshape=function(){this.g.setFontShape("it")},D.prototype.slshape=function(){this.g.setFontShape("sl")},D.prototype.scshape=function(){this.g.setFontShape("sc")},D.prototype.normalfont=function(){this.g.setFontFamily("rm"),this.g.setFontWeight("md"),this.g.setFontShape("up")},i=0,h=(l=["tiny","scriptsize","footnotesize","small","normalsize","large","Large","LARGE","huge","Huge"]).length;i<h;++i)yt[E=l[i]]=At(E);return D.prototype.em=function(){this.g.setFontShape("em")},D.prototype.theenumi=function(){return[this.g.arabic(this.g.counter("enumi"))]},D.prototype.theenumii=function(){return[this.g.alph(this.g.counter("enumii"))]},D.prototype.theenumiii=function(){return[this.g.roman(this.g.counter("enumiii"))]},D.prototype.theenumiv=function(){return[this.g.Alph(this.g.counter("enumiv"))]},D.prototype.labelenumi=function(){return this.theenumi().concat(".")},D.prototype.labelenumii=function(){return["("].concat(ff(this.theenumii()),[")"])},D.prototype.labelenumiii=function(){return this.theenumiii().concat(".")},D.prototype.labelenumiv=function(){return this.theenumiv().concat(".")},D.prototype["p@enumii"]=function(){return this.theenumi()},D.prototype["p@enumiii"]=function(){return this.theenumi().concat("(",this.theenumii(),")")},D.prototype["p@enumiv"]=function(){return this["p@enumiii"]().concat(this.theenumiii())},D.prototype.labelitemi=function(){return[this.g.symbol("textbullet")]},D.prototype.labelitemii=function(){return this.normalfont(),this.bfseries(),[this.g.symbol("textendash")]},D.prototype.labelitemiii=function(){return[this.g.symbol("textasteriskcentered")]},D.prototype.labelitemiv=function(){return[this.g.symbol("textperiodcentered")]},(R=e).centering=R.raggedright=R.raggedleft=["HV"],D.prototype.centering=function(){this.g.setAlignment("centering")},D.prototype.raggedright=function(){this.g.setAlignment("raggedright")},D.prototype.raggedleft=function(){this.g.setAlignment("raggedleft")},(I=e).center=I.flushleft=I.flushright=["V"],D.prototype.center=function(){return this.g.startlist(),[this.g.create(this.g.list,null,"center")]},D.prototype.endcenter=function(){this.g.endlist()},D.prototype.flushleft=function(){return this.g.startlist(),[this.g.create(this.g.list,null,"flushleft")]},D.prototype.endflushleft=function(){this.g.endlist()},D.prototype.flushright=function(){return this.g.startlist(),[this.g.create(this.g.list,null,"flushright")]},D.prototype.endflushright=function(){this.g.endlist()},e.titlepage=["V"],D.prototype.titlepage=function(){return[this.g.create(this.g.titlepage)]},(U=e).quote=U.quotation=U.verse=["V"],D.prototype.quote=function(){return this.g.startlist(),[this.g.create(this.g.quote)]},D.prototype.endquote=function(){this.g.endlist()},D.prototype.quotation=function(){return this.g.startlist(),[this.g.create(this.g.quotation)]},D.prototype.endquotation=function(){this.g.endlist()},D.prototype.verse=function(){return this.g.startlist(),[this.g.create(this.g.verse)]},D.prototype.endverse=function(){this.g.endlist()},e.itemize=["V","X","items"],D.prototype.itemize=function(q){var L,G=this;return arguments.length===0?(this.g.startlist(),this.g.stepCounter("@itemdepth"),void(this.g.counter("@itemdepth")>4&&this.g.error("too deeply nested"))):(L="labelitem"+this.g.roman(this.g.counter("@itemdepth")),[this.g.create(this.g.unorderedList,q.map(function(j){var Z;return G.g.enterGroup(),Z=G.g.create(G.g.itemlabel,G.llap(j.label!==null?j.label:G.g.macro(L))),G.g.exitGroup(),G.g.create(G.g.listitem,[Z,j.text])}))])},D.prototype.enditemize=function(){this.g.endlist(),this.g.setCounter("@itemdepth",this.g.counter("@itemdepth")-1)},e.enumerate=["V","X","enumitems"],D.prototype.enumerate=function(q){var L,G=this;return arguments.length===0?(this.g.startlist(),this.g.stepCounter("@enumdepth"),void(this.g.counter("@enumdepth")>4&&this.g.error("too deeply nested"))):(L="enum"+this.g.roman(this.g.counter("@enumdepth")),this.g.setCounter(L,0),[this.g.create(this.g.orderedList,q.map(function(j){var Z,et;return Z=G.g.create(G.g.inline,j.label.node),j.label.id&&(Z.id=j.label.id),et=G.g.create(G.g.itemlabel,G.llap(Z)),G.g.create(G.g.listitem,[et,j.text])}))])},D.prototype.endenumerate=function(){this.g.endlist(),this.g.setCounter("@enumdepth",this.g.counter("@enumdepth")-1)},e.description=["V","X","items"],D.prototype.description=function(q){var L=this;if(arguments.length!==0)return[this.g.create(this.g.descriptionList,q.map(function(G){var j,Z;return j=L.g.create(L.g.term,G.label),Z=L.g.create(L.g.description,G.text),L.g.createFragment([j,Z])}))];this.g.startlist()},D.prototype.enddescription=function(){this.g.endlist()},e.picture=["H","v","v?","h"],D.prototype.picture=function(q,L,G){return[this.g.createPicture(q,L,G)]},e.hspace=["H","s","l"],D.prototype.hspace=function(q,L){return[this.g.createHSpace(L)]},e.label=["HV","g"],D.prototype.label=function(q){this.g.setLabel(q.textContent)},e.ref=["H","g"],D.prototype.ref=function(q){return[this.g.ref(q.textContent)]},(Y=e).llap=Y.rlap=Y.clap=Y.smash=Y.hphantom=Y.vphantom=Y.phantom=["H","hg"],D.prototype.llap=function(q){return[this.g.create(this.g.inline,q,"hbox llap")]},D.prototype.rlap=function(q){return[this.g.create(this.g.inline,q,"hbox rlap")]},D.prototype.clap=function(q){return[this.g.create(this.g.inline,q,"hbox clap")]},D.prototype.smash=function(q){return[this.g.create(this.g.inline,q,"hbox smash")]},D.prototype.hphantom=function(q){return[this.g.create(this.g.inline,q,"phantom hbox smash")]},D.prototype.vphantom=function(q){return[this.g.create(this.g.inline,q,"phantom hbox rlap")]},D.prototype.phantom=function(q){return[this.g.create(this.g.inline,q,"phantom hbox")]},e.underline=["H","hg"],D.prototype.underline=function(q){return[this.g.create(this.g.inline,q,"hbox underline")]},e.mbox=["H","hg"],D.prototype.mbox=function(q){return this.makebox(void 0,void 0,void 0,q)},e.makebox=["H","v?","l?","i?","hg"],D.prototype.makebox=function(q,L,G,j){return q?(L&&G&&this.g.error("expected \\makebox(width,height)[position]{text} but got two optional arguments!"),G=L,[j]):this._box(L,G,j,"hbox")},e.fbox=["H","hg"],e.framebox=["H","v?","l?","i?","hg"],D.prototype.fbox=function(q){return this.framebox(void 0,void 0,void 0,q)},D.prototype.framebox=function(q,L,G,j){return q?L&&G?this.g.error("expected \\framebox(width,height)[position]{text} but got two optional arguments!"):void 0:j.hasAttribute==null||L||G||this.g.hasAttribute(j,"frame")?this._box(L,G,j,"hbox frame"):(this.g.addAttribute(j,"frame"),[j])},D.prototype._box=function(q,L,G,j){var Z,et;if(q)switch(L||(L="c"),L){case"s":j+=" stretch";break;case"c":j+=" clap";break;case"l":j+=" rlap";break;case"r":j+=" llap";break;default:this.g.error("unknown position: "+L)}return Z=this.g.create(this.g.inline,G),et=this.g.create(this.g.inline,Z,j),q&&et.setAttribute("style","width:"+q.value),[et]},e.parbox=["H","i?","l?","i?","l","g"],D.prototype.parbox=function(q,L,G,j,Z){var et,Q,ut,at;switch(q||(q="c"),G||(G=q),et="parbox",Q="width:"+j.value+";",L&&(et+=" pbh",Q+="height:"+L.value+";"),q){case"c":et+=" p-c";break;case"t":et+=" p-t";break;case"b":et+=" p-b";break;default:this.g.error("unknown position: "+q)}switch(G){case"s":et+=" stretch";break;case"c":et+=" p-cc";break;case"t":et+=" p-ct";break;case"b":et+=" p-cb";break;default:this.g.error("unknown inner-pos: "+G)}return ut=this.g.create(this.g.inline,Z),(at=this.g.create(this.g.inline,ut,et)).setAttribute("style",Q),[at]},(it=e).thicklines=["HV"],it.thinlines=["HV"],it.linethickness=["HV","l"],it.arrowlength=["HV","l"],D.prototype.thinlines=function(){this.g.setLength("@wholewidth",new this.g.Length(.4,"pt"))},D.prototype.thicklines=function(){this.g.setLength("@wholewidth",new this.g.Length(.8,"pt"))},D.prototype.linethickness=function(q){q.unit!=="sp"&&this.g.error("relative units for \\linethickness not supported!"),this.g.setLength("@wholewidth",q)},D.prototype.arrowlength=function(q){this.g.setLength("@arrowlength",q)},D.prototype.maxovalrad=function(){return"20pt"},D.prototype.qbeziermax=function(){return 500},e.dashbox=["H","cl","v","i?","g"],e.frame=["H","hg"],D.prototype.frame=function(q){var L,G;return L=this.g.create(this.g.inline,q,"hbox pframe"),G=this.g.length("@wholewidth"),L.setAttribute("style","border-width:"+G.value),[L]},e.put=["H","v","g","is"],D.prototype.put=function(q,L){var G,j;return G=this.g.create(this.g.inline,L,"put-obj"),q.y.cmp(this.g.Length.zero)>=0?(G.setAttribute("style","left:"+q.x.value),q.y.cmp(this.g.Length.zero)>0&&(j=this.g.create(this.g.inline,void 0,"strut")).setAttribute("style","height:"+q.y.value)):G.setAttribute("style","left:"+q.x.value+";bottom:"+q.y.value),this.rlap(this.g.create(this.g.inline,[G,j],"picture"))},e.multiput=["H","v","v","n","g"],D.prototype.multiput=function(q,L,G,j){var Z,et,Q;for(Z=[],et=0;et<G;++et)Q=et,Z=Z.concat(this.put(q.add(L.mul(Q)),j.cloneNode(!0)));return Z},e.qbezier=["H","n?","v","v","v"],D.prototype.qbezier=function(q,L,G,j){return[this._path("M"+L.x.pxpct+","+L.y.pxpct+" Q"+G.x.pxpct+","+G.y.pxpct+" "+j.x.pxpct+","+j.y.pxpct,q)]},e.cbezier=["H","n?","v","v","v","v"],D.prototype.cbezier=function(q,L,G,j,Z){return[this._path("M"+L.x.pxpct+","+L.y.pxpct+" C"+G.x.pxpct+","+G.y.pxpct+" "+j.x.pxpct+","+j.y.pxpct+" "+Z.x.pxpct+","+Z.y.pxpct,q)]},D.prototype._path=function(q,L){var G,j,Z,et,Q,ut,at;return G=this.g.length("@wholewidth"),j=this.g.create(this.g.inline,void 0,"picture-object"),et=(Z=this.g.SVG().addTo(j)).path(q).stroke({color:"#000",width:G.value}).fill("none"),L>0&&(L=Math.min(L,this.qbeziermax()-1),Q=G.px,(ut=(et.length()-(L+1)*Q)/L)>0&&et.stroke({dasharray:Q+" "+this.g.round(ut)})),(at=et.bbox()).x-=G.px,at.y-=G.px,at.width+=2*G.px,at.height+=2*G.px,j.setAttribute("style","left:"+this.g.round(at.x)+"px;bottom:"+this.g.round(at.y)+"px"),Z.size(this.g.round(at.width)+"px",this.g.round(at.height)+"px").viewbox(this.g.round(at.x),this.g.round(at.y),this.g.round(at.width),this.g.round(at.height)),Z.flip("y",0),this.g.create(this.g.inline,j,"picture")},e.circle=["H","s","cl"],D.prototype.circle=function(q,L){var G,j,Z,et;return L=L.abs(),G=this.g.create(this.g.inline,void 0,"picture-object"),j=this.g.length("@wholewidth"),Z=this.g.SVG().addTo(G),q?(et=L.div(2).mul(-1).value,Z.size(L.value,L.value).stroke({color:"#000",width:"0"}).circle(L.value).cx(L.div(2).value).cy(L.div(2).value).fill("")):(et=L.div(2).add(j).mul(-1).value,Z.size(L.add(j.mul(2)).value,L.add(j.mul(2)).value).stroke({color:"#000",width:j.value}).circle(L.value).cx(L.div(2).add(j).value).cy(L.div(2).add(j).value).fill("none")),G.setAttribute("style","left:"+et+";bottom:"+et),Z.flip("y",0),[this.g.create(this.g.inline,G,"picture")]},e.line=["H","v","cl"],D.prototype.line=function(q,L){return[this._line.apply(this,this._slopeLengthToCoords(q,L))]},e.vector=["H","v","cl"],D.prototype.vector=function(q,L){return[this._vector.apply(this,this._slopeLengthToCoords(q,L))]},e.Line=["H","v","v"],D.prototype.Line=function(q,L){return[this._line(q,L)]},e.Vector=["H","v","v"],D.prototype.Vector=function(q,L){return[this._vector(q,L)]},D.prototype._slopeLengthToCoords=function(q,L){var G,j,Z,et;return q.x.value===(G=q.y.value)&&G===0&&this.g.error("illegal slope (0,0)"),q.x.unit===q.y.unit&&q.x.unit==="sp"||this.g.error("relative units not allowed for slope"),this.g.length("@wholewidth"),j=new this.g.Length(0,L.unit),q.x.px===0?(Z=j,et=L):et=(Z=L).mul(Math.abs(q.y.ratio(q.x))),q.x.cmp(j)<0&&(Z=Z.mul(-1)),q.y.cmp(j)<0&&(et=et.mul(-1)),[new Ln(j,j),new Ln(Z,et)]},D.prototype._line=function(q,L){var G,j,Z,et;return q.x.unit===q.y.unit&&q.x.unit==="sp"||this.g.error("relative units not allowed for line"),L.x.unit===L.y.unit&&L.x.unit==="sp"||this.g.error("relative units not allowed for line"),G=this.g.create(this.g.inline,void 0,"picture-object"),j=this.g.SVG().addTo(G),Z=this.g.length("@wholewidth"),(et=j.line(q.x.px,q.y.px,L.x.px,L.y.px).stroke({color:"#000",width:Z.value}).bbox()).x-=Z.px,et.y-=Z.px,et.width+=2*Z.px,et.height+=2*Z.px,(et.x>0||et.y>0)&&console.error("line: bbox.x/y > 0!!",et.x,et.y),G.setAttribute("style","left:"+this.g.round(et.x)+"px;bottom:"+this.g.round(et.y)+"px"),j.size(this.g.round(et.width)+"px",this.g.round(et.height)+"px").viewbox(this.g.round(et.x),this.g.round(et.y),this.g.round(et.width),this.g.round(et.height)),j.flip("y",0),this.g.create(this.g.inline,G,"picture")},D.prototype._vector=function(q,L){var G,j,Z,et,Q,ut,at,Ct,kt,Mt=this;return q.x.unit===q.y.unit&&q.x.unit==="sp"||this.g.error("relative units not allowed for vector"),L.x.unit===L.y.unit&&L.x.unit==="sp"||this.g.error("relative units not allowed for vector"),G=this.g.length("@wholewidth"),j=this.g.create(this.g.inline,void 0,"picture-object"),Z=this.g.SVG(),et=6.5,Q=3.9,ut=new this.g.Length(.6,"pt"),G.cmp(ut)<0&&(et=this.g.round(et*ut.ratio(G)),Q=this.g.round(Q*ut.ratio(G))),at=G.mul(et/2),Ct=L.sub(q).norm().cmp(at)<0?L.shift_start(at):new Ln(this.g.Length.zero,this.g.Length.zero),L=L.shift_end(at.mul(-1)),(kt=Z.line(Ct.x.px,Ct.y.px,L.x.px,L.y.px).stroke({color:"#000",width:G.value}).marker("end",et,Q,function(Wt){return Wt.path("M0,0 Q"+Mt.g.round(2*et/3)+","+Mt.g.round(Q/2)+" "+et+","+Mt.g.round(Q/2)+" Q"+Mt.g.round(2*et/3)+","+Mt.g.round(Q/2)+" 0,"+Q+" z")}).bbox()).x-=G.px+at.px,kt.y-=G.px+at.px,kt.width+=G.px+2*at.px,kt.height+=G.px+2*at.px,(kt.x>0||kt.y>0)&&console.error("vector: bbox.x/y > 0!!",kt.x,kt.y),j.setAttribute("style","left:"+this.g.round(kt.x)+"px;bottom:"+this.g.round(kt.y)+"px"),Z.size(this.g.round(kt.width)+"px",this.g.round(kt.height)+"px").viewbox(this.g.round(kt.x),this.g.round(kt.y),this.g.round(kt.width),this.g.round(kt.height)),Z.flip("y",0),Z.addTo(j),this.g.create(this.g.inline,j,"picture")},e.oval=["H","cl?","v","i?"],D.prototype.oval=function(q,L,G){var j,Z,et,Q,ut,at,Ct,kt;return j=this.g.length("@wholewidth"),q||(q=new this.g.Length(20,"px")),G||(G=""),Z=L.x.cmp(L.y)<0?L.x.div(2):L.y.div(2),q.cmp(Z)<0&&(Z=q),Q=(et=this.g.SVG()).rect(L.x.value,L.y.value).radius(Z.value).move(L.x.div(-2).value,L.y.div(-2).value).stroke({color:"#000",width:j.value}).fill("none"),ut={x:L.x.div(-2).sub(j),y:L.y.div(-2).sub(j),w:L.x.add(j.mul(2)),h:L.y.add(j.mul(2))},G.includes("l")&&(ut=this._intersect(ut,{x:L.x.div(-2).sub(j),y:L.y.div(-2).sub(j),w:L.x.div(2).add(j),h:L.y.add(j.mul(2))})),G.includes("t")&&(ut=this._intersect(ut,{x:L.x.div(-2).sub(j),y:L.y.div(-2).sub(j),w:L.x.add(j.mul(2)),h:L.y.div(2).add(j)})),G.includes("r")&&(ut=this._intersect(ut,{x:this.g.Length.zero,y:L.y.div(-2).sub(j),w:L.x.div(2).add(j),h:L.y.add(j.mul(2))})),G.includes("b")&&(ut=this._intersect(ut,{x:L.x.div(-2).sub(j),y:this.g.Length.zero,w:L.x.add(j.mul(2)),h:L.y.div(2).add(j)})),(at=Q.bbox()).x-=j.px,at.y-=j.px,at.width+=2*j.px,at.height+=2*j.px,(at.x>0||at.y>0)&&console.error("oval: bbox.x/y > 0!!",at.x,at.y),(Ct=et.clip().add(et.rect(ut.w.value,ut.h.value).move(ut.x.value,ut.y.value))).flip("y",0),Q.clipWith(Ct),(kt=this.g.create(this.g.inline,void 0,"picture-object")).setAttribute("style","left:"+this.g.round(at.x)+"px;bottom:"+this.g.round(at.y)+"px"),et.size(this.g.round(at.width)+"px",this.g.round(at.height)+"px").viewbox(this.g.round(at.x),this.g.round(at.y),this.g.round(at.width),this.g.round(at.height)),et.flip("y",0),et.addTo(kt),[this.g.create(this.g.inline,kt,"picture")]},D.prototype._intersect=function(q,L){return{x:this.g.Length.max(q.x,L.x),y:this.g.Length.max(q.y,L.y),w:this.g.Length.max(this.g.Length.zero,this.g.Length.min(q.x.add(q.w),L.x.add(L.w)).sub(this.g.Length.max(q.x,L.x))),h:this.g.Length.max(this.g.Length.zero,this.g.Length.min(q.y.add(q.h),L.y.add(L.h)).sub(this.g.Length.max(q.y,L.y)))}},e.newlength=["HV","m"],D.prototype.newlength=function(q){this.g.newLength(q)},e.setlength=["HV","m","l"],D.prototype.setlength=function(q,L){this.g.setLength(q,L)},e.addtolength=["HV","m","l"],D.prototype.addtolength=function(q,L){this.g.setLength(q,this.g.length(q).add(L))},e.newcounter=["HV","i","i?"],D.prototype.newcounter=function(q,L){this.g.newCounter(q,L)},e.stepcounter=["HV","i"],D.prototype.stepcounter=function(q){this.g.stepCounter(q)},e.addtocounter=["HV","i","n"],D.prototype.addtocounter=function(q,L){this.g.setCounter(q,this.g.counter(q)+L)},e.setcounter=["HV","i","n"],D.prototype.setcounter=function(q,L){this.g.setCounter(q,L)},e.refstepcounter=["H","i"],D.prototype.refstepcounter=function(q){return this.g.stepCounter(q),[this.g.refCounter(q)]},(nt=e).alph=nt.Alph=nt.arabic=nt.roman=nt.Roman=nt.fnsymbol=["H","i"],D.prototype.alph=function(q){return[this.g.alph(this.g.counter(q))]},D.prototype.Alph=function(q){return[this.g.Alph(this.g.counter(q))]},D.prototype.arabic=function(q){return[this.g.arabic(this.g.counter(q))]},D.prototype.roman=function(q){return[this.g.roman(this.g.counter(q))]},D.prototype.Roman=function(q){return[this.g.Roman(this.g.counter(q))]},D.prototype.fnsymbol=function(q){return[this.g.fnsymbol(this.g.counter(q))]},e.input=["V","g"],D.prototype.input=function(q){},e.include=["V","g"],D.prototype.include=function(q){},e.documentclass=["P","kv?","k","k?"],D.prototype.documentclass=function(q,L,G){var j,Z,et;if(this.documentclass=function(){this.g.error("Two \\documentclass commands. The document may only declare one class.")},!(j=A5[L]))try{j=(Z=require("./documentclasses/"+L)).default||Z[Object.getOwnPropertyNames(Z)[0]]}catch(Q){throw et=Q,console.error('error loading documentclass "'+L+'": '+et),new Error('error loading documentclass "'+L+'"')}this.g.documentClass=new j(this.g,q),Yo(this,this.g.documentClass),Xo(e,j.args)},e.usepackage=["P","kv?","csv","k?"],D.prototype.usepackage=function(q,L,G){var j,Z,et,Q,ut,at,Ct,kt;for(j=Object.assign({},this.g.documentClass.options,q),Z=0,et=L.length;Z<et;++Z)if(Q=L[Z],!r.includes(Q)){ut=_5[Q];try{ut||(ut=(at=require("./packages/"+Q)).default||at[Object.getOwnPropertyNames(at)[0]]),Yo(this,new ut(this.g,j)),Xo(e,ut.args),(Ct=ut.symbols)!=null&&Ct.forEach(Mt)}catch(Wt){kt=Wt,console.error('error loading package "'+Q+'": '+kt)}}function Mt(Wt,Rt){return pn.set(Rt,Wt)}},e.includeonly=["P","csv"],D.prototype.includeonly=function(q){},e.makeatletter=["P"],D.prototype.makeatletter=function(){},e.makeatother=["P"],D.prototype.makeatother=function(){},e.pagestyle=["HV","i"],D.prototype.pagestyle=function(q){},(pt=e).linebreak=["HV","n?"],pt.nolinebreak=["HV","n?"],pt.fussy=["HV"],pt.sloppy=["HV"],D.prototype.linebreak=function(q){},D.prototype.nolinebreak=function(q){},D.prototype.fussy=function(){},D.prototype.sloppy=function(){},(dt=e).pagebreak=["HV","n?"],dt.nopagebreak=["HV","n?"],dt.samepage=["HV"],dt.enlargethispage=["HV","s","l"],dt.newpage=["HV"],dt.clearpage=["HV"],dt.cleardoublepage=["HV"],dt.vfill=["HV"],dt.thispagestyle=["HV","i"],D.prototype.pagebreak=function(q){},D.prototype.nopagebreak=function(q){},D.prototype.samepage=function(){},D.prototype.enlargethispage=function(q,L){},D.prototype.newpage=function(){},D.prototype.clearpage=function(){},D.prototype.cleardoublepage=function(){},D.prototype.vfill=function(){},D.prototype.thispagestyle=function(q){},D;function At(q){return function(){return this.g.setFontSize(q)}}}();var He,gf=[].slice,mc=Array.from||function(r){return gf.call(r)};function fc(r,e){for(var n=-1,i=e.length>>>0;++n<i;)if(r===e[n])return!0;return!1}He=Xh,Object.defineProperty(Array.prototype,"top",{enumerable:!1,configurable:!0,get:function(){return this[this.length-1]},set:function(r){this[this.length-1]=r}}),Yh=function(){var r,e;function n(){}return n.displayName="Generator",n.prototype,n.prototype.documentClass=null,n.prototype.documentTitle=null,n.prototype._options=null,n.prototype._macros=null,n.prototype._stack=null,n.prototype._groups=null,n.prototype._continue=!1,n.prototype._labels=null,n.prototype._refs=null,n.prototype._counters=null,n.prototype._resets=null,n.prototype._marginpars=null,n.prototype.Length=null,n.prototype.reset=function(){this.Length=is(this),this.documentClass=this._options.documentClass,this.documentTitle="untitled",this._uid=1,this._macros={},this._curArgs=[],this._stack=[{attrs:{},align:null,currentlabel:{id:"",label:document.createTextNode("")},lengths:new Map}],this._groups=[0],this._labels=new Map,this._refs=new Map,this._marginpars=[],this._counters=new Map,this._resets=new Map,this._continue=!1,this.newCounter("enumi"),this.newCounter("enumii"),this.newCounter("enumiii"),this.newCounter("enumiv"),this._macros=new He(this,this._options.CustomMacros)},n.prototype.nextId=function(){return this._uid++},n.prototype.round=function(i){var t;return t=Math.pow(10,this._options.precision),Math.round(i*t)/t},r=function(i){throw console.error(i),new Error(i)},n.prototype.error=function(i){r(i)},n.prototype.setErrorFn=function(i){r=i},n.prototype.location=function(){r("location function not set!")},n.prototype.setTitle=function(i){return this.documentTitle=i.textContent},n.prototype.hasSymbol=function(i){return He.symbols.has(i)},n.prototype.symbol=function(i){return this.hasSymbol(i)||this.error("no such symbol: "+i),He.symbols.get(i)},n.prototype.hasMacro=function(i){return typeof this._macros[i]=="function"&&!function(t,l,h){var p={}.toString;return m(t,l);function m(y,_,S){var E;if(y==null||_==null)return y===_;if(y.__placeholder__||_.__placeholder__)return!0;if(y===_)return y!==0||1/y==1/_;if(E=p.call(y),p.call(_)!=E)return!1;switch(E){case"[object String]":return y==String(_);case"[object Number]":return y!=+y?_!=+_:y==0?1/y==1/_:y==+_;case"[object Date]":case"[object Boolean]":return+y==+_;case"[object RegExp]":return y.source==_.source&&y.global==_.global&&y.multiline==_.multiline&&y.ignoreCase==_.ignoreCase}return!1}}(i,"constructor")&&(this._macros.hasOwnProperty(i)||He.prototype.hasOwnProperty(i))},n.prototype.isHmode=function(i){var t;return((t=He.args[i])!=null?t[0]:void 0)==="H"||!He.args[i]},n.prototype.isVmode=function(i){var t;return((t=He.args[i])!=null?t[0]:void 0)==="V"},n.prototype.isHVmode=function(i){var t;return((t=He.args[i])!=null?t[0]:void 0)==="HV"},n.prototype.isPreamble=function(i){var t;return((t=He.args[i])!=null?t[0]:void 0)==="P"},n.prototype.macro=function(i,t){var l,h=this;return pn.has(i)?[this.createText(pn.get(i))]:(l=this._macros[i].apply(this._macros,t))!=null?l.filter(function(p){return p!=null}).map(function(p){return typeof p=="string"||p instanceof String?h.createText(p):h.addAttributes(p)}):void 0},n.prototype.beginArgs=function(i){var t;this._curArgs.push((t=He.args[i])?{name:i,args:t.slice(1),parsed:[]}:{args:[],parsed:[]})},n.prototype.selectArgsBranch=function(i){var t,l,h,p,m,y;if(t=["o?","i?","k?","kv?","n?","l?","c-ml?","cl?"],Array.isArray(this._curArgs.top.args[0])){for(h=0,p=(l=this._curArgs.top.args[0]).length;h<p;++h)if(m=l[h],i==="["&&fc(m[0],t)||i==="{"&&!fc(m[0],t))return this._curArgs.top.args.shift(),(y=this._curArgs.top.args).unshift.apply(y,m),!0}},n.prototype.nextArg=function(i){if(this._curArgs.top.args[0]===i)return this._curArgs.top.args.shift(),!0},n.prototype.argError=function(i){return r("macro \\"+this._curArgs.top.name+": "+i)},n.prototype.addParsedArg=function(i){this._curArgs.top.parsed.push(i)},n.prototype.parsedArgs=function(){return this._curArgs.top.parsed},n.prototype.preExecMacro=function(){this.macro(this._curArgs.top.name,this.parsedArgs())},n.prototype.endArgs=function(){var i;return(i=this._curArgs.pop()).args.length===0||r("grammar error: arguments for "+i.name+" have not been parsed: "+i.args),i.parsed},n.prototype.begin=function(i){this.hasMacro(i)||r("unknown environment: "+i),this.startBalanced(),this.enterGroup(),this.beginArgs(i)},n.prototype.end=function(i,t){var l;return i!==t&&r("environment '"+i+"' is missing its end, found '"+t+"' instead"),this.hasMacro("end"+i)&&(l=this.macro("end"+i)),this.exitGroup(),this.isBalanced()||r(i+": groups need to be balanced in environments!"),this.endBalanced(),l},n.prototype.enterGroup=function(i){i==null&&(i=!1),this._stack.push({attrs:i?Object.assign({},this._stack.top.attrs):{},align:null,currentlabel:Object.assign({},this._stack.top.currentlabel),lengths:new Map(this._stack.top.lengths)}),++this._groups.top},n.prototype.exitGroup=function(){--this._groups.top>=0||r("there is no group to end here"),this._stack.pop()},n.prototype.startBalanced=function(){this._groups.push(0)},n.prototype.endBalanced=function(){return this._groups.pop(),this._groups.length},n.prototype.isBalanced=function(){return this._groups.top===0},n.prototype.continue=function(){this._continue=this.location().end.offset},n.prototype.break=function(){this.location().end.offset>this._continue&&(this._continue=!1)},n.prototype.setAlignment=function(i){this._stack.top.align=i},n.prototype.alignment=function(){return this._stack.top.align},n.prototype.setFontFamily=function(i){this._stack.top.attrs.fontFamily=i},n.prototype.setFontWeight=function(i){this._stack.top.attrs.fontWeight=i},n.prototype.setFontShape=function(i){i==="em"&&(i=this._activeAttributeValue("fontShape")==="it"?"up":"it"),this._stack.top.attrs.fontShape=i},n.prototype.setFontSize=function(i){this._stack.top.attrs.fontSize=i},n.prototype.setTextDecoration=function(i){this._stack.top.attrs.textDecoration=i},n.prototype._inlineAttributes=function(){var i;return[(i=this._stack.top.attrs).fontFamily,i.fontWeight,i.fontShape,i.fontSize,i.textDecoration].join(" ").replace(/\s+/g," ").trim()},n.prototype._activeAttributeValue=function(i){var t,l,h;for(t=this._stack.length-1;t>=0;--t)if(l=t,h=this._stack[l].attrs[i])return h},n.prototype.startsection=function(i,t,l,h,p){var m,y,_;if(h!=p||p!=null)return!l&&this.counter("secnumdepth")>=t?(i==="chapter"?(m=this.create(this.block,this.macro("chaptername").concat(this.createText(this.symbol("space")),this.macro("the"+i))),y=this.create(this[i],[m,p])):y=this.create(this[i],this.macro("the"+i).concat(this.createText(this.symbol("quad")),p)),(_=this._stack.top.currentlabel.id)!=null&&(y.id=_)):y=this.create(this[i],p),y;!l&&this.counter("secnumdepth")>=t&&(this.stepCounter(i),this.refCounter(i,"sec-"+this.nextId()))},n.prototype.startlist=function(){return this.stepCounter("@listdepth"),this.counter("@listdepth")>6&&r("too deeply nested"),!0},n.prototype.endlist=function(){this.setCounter("@listdepth",this.counter("@listdepth")-1),this.continue()},n.prototype.newLength=function(i){this.hasLength(i)&&r("length "+i+" already defined!"),this._stack.top.lengths.set(i,this.Length.zero)},n.prototype.hasLength=function(i){return this._stack.top.lengths.has(i)},n.prototype.setLength=function(i,t){this.hasLength(i)||r("no such length: "+i),this._stack.top.lengths.set(i,t)},n.prototype.length=function(i){return this.hasLength(i)||r("no such length: "+i),this._stack.top.lengths.get(i)},n.prototype.theLength=function(i){var t;return(t=this.create(this.inline,void 0,"the")).setAttribute("display-var",i),t},n.prototype.newCounter=function(i,t){this.hasCounter(i)&&r("counter "+i+" already defined!"),this._counters.set(i,0),this._resets.set(i,[]),t&&this.addToReset(i,t),this.hasMacro("the"+i)&&r("macro \\the"+i+" already defined!"),this._macros["the"+i]=function(){return[this.g.arabic(this.g.counter(i))]}},n.prototype.hasCounter=function(i){return this._counters.has(i)},n.prototype.setCounter=function(i,t){this.hasCounter(i)||r("no such counter: "+i),this._counters.set(i,t)},n.prototype.stepCounter=function(i){this.setCounter(i,this.counter(i)+1),this.clearCounter(i)},n.prototype.counter=function(i){return this.hasCounter(i)||r("no such counter: "+i),this._counters.get(i)},n.prototype.refCounter=function(i,t){var l;return t||(t=i+"-"+this.nextId(),l=this.create(this.anchor(t))),this._stack.top.currentlabel={id:t,label:this.createFragment(mc(this.hasMacro("p@"+i)?this.macro("p@"+i):[]).concat(mc(this.macro("the"+i))))},l},n.prototype.addToReset=function(i,t){this.hasCounter(t)||r("no such counter: "+t),this.hasCounter(i)||r("no such counter: "+i),this._resets.get(t).push(i)},n.prototype.clearCounter=function(i){var t,l,h,p;for(t=0,h=(l=this._resets.get(i)).length;t<h;++t)p=l[t],this.clearCounter(p),this.setCounter(p,0)},n.prototype.alph=function(i){return String.fromCharCode(96+i)},n.prototype.Alph=function(i){return String.fromCharCode(64+i)},n.prototype.arabic=function(i){return String(i)},n.prototype.roman=function(i){return e(i,[["m",1e3],["cm",900],["d",500],["cd",400],["c",100],["xc",90],["l",50],["xl",40],["x",10],["ix",9],["v",5],["iv",4],["i",1]])},n.prototype.Roman=function(i){return e(i,[["M",1e3],["CM",900],["D",500],["CD",400],["C",100],["XC",90],["L",50],["XL",40],["X",10],["IX",9],["V",5],["IV",4],["I",1]])},e=function(i,t){var l,h,p,m;for(l="",h=0,p=t.length;h<p;++h)for(m=t[h];i>=m[1];)l+=m[0],i-=m[1];return l},n.prototype.fnsymbol=function(i){switch(i){case 1:return this.symbol("textasteriskcentered");case 2:return this.symbol("textdagger");case 3:return this.symbol("textdaggerdbl");case 4:return this.symbol("textsection");case 5:return this.symbol("textparagraph");case 6:return this.symbol("textbardbl");case 7:return this.symbol("textasteriskcentered")+this.symbol("textasteriskcentered");case 8:return this.symbol("textdagger")+this.symbol("textdagger");case 9:return this.symbol("textdaggerdbl")+this.symbol("textdaggerdbl");default:return r("fnsymbol value must be between 1 and 9")}},n.prototype.setLabel=function(i){var t,l,h,p;if(this._labels.has(i)&&r("label "+i+" already defined!"),this._stack.top.currentlabel.id||console.warn("warning: no \\@currentlabel available for label "+i+"!"),this._labels.set(i,this._stack.top.currentlabel),this._refs.has(i)){for(t=0,h=(l=this._refs.get(i)).length;t<h;++t){for(p=l[t];p.firstChild;)p.removeChild(p.firstChild);p.appendChild(this._stack.top.currentlabel.label.cloneNode(!0)),p.setAttribute("href","#"+this._stack.top.currentlabel.id)}this._refs.delete(i)}},n.prototype.ref=function(i){var t,l;return(t=this._labels.get(i))?this.create(this.link("#"+t.id),t.label.cloneNode(!0)):(l=this.create(this.link("#"),this.createText("??")),this._refs.has(i)?this._refs.get(i).push(l):this._refs.set(i,[l]),l)},n.prototype.logUndefinedRefs=function(){var i,t;if(this._refs.size!==0){for(i=this._refs.keys();!(t=i.next()).done;)console.warn("warning: reference '"+t.value+"' undefined");console.warn("There were undefined references.")}},n.prototype.marginpar=function(i){var t,l,h;return t=this.nextId(),(l=this.create(this.block,[this.create(this.inline,null,"mpbaseline"),i])).id=t,this._marginpars.push(l),(h=this.create(this.inline,null,"mpbaseline")).id="marginref-"+t,h},n}();const Da={},Wh=[];function xt(r,e){if(Array.isArray(r))for(const n of r)xt(n,e);else if(typeof r!="object")$h(Object.getOwnPropertyNames(e)),Da[r]=Object.assign(Da[r]||{},e);else for(const n in r)xt(n,r[n])}function be(r){return Da[r]||{}}function $h(r){Wh.push(...r)}function us(r,e){let n;const i=r.length,t=[];for(n=0;n<i;n++)t.push(e(r[n]));return t}function Wo(r){return r%360*Math.PI/180}function zi(r){return r.toLowerCase().replace(/-(.)/g,function(e,n){return n.toUpperCase()})}function Zh(r){return r.charAt(0).toUpperCase()+r.slice(1)}function gn(r,e,n,i){return e!=null&&n!=null||(i=i||r.bbox(),e==null?e=i.width/i.height*n:n==null&&(n=i.height/i.width*e)),{width:e,height:n}}function La(r,e){const n=r.origin;let i=r.ox!=null?r.ox:r.originX!=null?r.originX:"center",t=r.oy!=null?r.oy:r.originY!=null?r.originY:"center";n!=null&&([i,t]=Array.isArray(n)?n:typeof n=="object"?[n.x,n.y]:[n,n]);const l=typeof i=="string",h=typeof t=="string";if(l||h){const{height:p,width:m,x:y,y:_}=e.bbox();l&&(i=i.includes("left")?y:i.includes("right")?y+m:y+m/2),h&&(t=t.includes("top")?_:t.includes("bottom")?_+p:_+p/2)}return[i,t]}const cs="http://www.w3.org/2000/svg",Ti="http://www.w3.org/2000/xmlns/",jn="http://www.w3.org/1999/xlink",Et={window:typeof window>"u"?null:window,document:typeof document>"u"?null:document};class hs{}const Or={},ps="___SYMBOL___ROOT___";function Vn(r,e=cs){return Et.document.createElementNS(e,r)}function de(r,e=!1){if(r instanceof hs)return r;if(typeof r=="object")return $o(r);if(r==null)return new Or[ps];if(typeof r=="string"&&r.charAt(0)!=="<")return $o(Et.document.querySelector(r));const n=e?Et.document.createElement("div"):Vn("svg");return n.innerHTML=r,r=$o(n.firstChild),n.removeChild(n.firstChild),r}function Ut(r,e){return e&&e.ownerDocument&&e instanceof e.ownerDocument.defaultView.Node?e:Vn(r)}function Le(r){if(!r)return null;if(r.instance instanceof hs)return r.instance;if(r.nodeName==="#document-fragment")return new Or.Fragment(r);let e=Zh(r.nodeName||"Dom");return e==="LinearGradient"||e==="RadialGradient"?e="Gradient":Or[e]||(e="Dom"),new Or[e](r)}let $o=Le;function zt(r,e=r.name,n=!1){return Or[e]=r,n&&(Or[ps]=r),$h(Object.getOwnPropertyNames(r.prototype)),r}let bf=1e3;function Jh(r){return"Svgjs"+Zh(r)+bf++}function Qh(r){for(let e=r.children.length-1;e>=0;e--)Qh(r.children[e]);return r.id&&(r.id=Jh(r.nodeName)),r}function St(r,e){let n,i;for(i=(r=Array.isArray(r)?r:[r]).length-1;i>=0;i--)for(n in e)r[i].prototype[n]=e[n]}function Gt(r){return function(...e){const n=e[e.length-1];return!n||n.constructor!==Object||n instanceof Array?r.apply(this,e):r.apply(this,e.slice(0,-1)).attr(n)}}xt("Dom",{siblings:function(){return this.parent().children()},position:function(){return this.parent().index(this)},next:function(){return this.siblings()[this.position()+1]},prev:function(){return this.siblings()[this.position()-1]},forward:function(){const r=this.position();return this.parent().add(this.remove(),r+1),this},backward:function(){const r=this.position();return this.parent().add(this.remove(),r?r-1:0),this},front:function(){return this.parent().add(this.remove()),this},back:function(){return this.parent().add(this.remove(),0),this},before:function(r){(r=de(r)).remove();const e=this.position();return this.parent().add(r,e),this},after:function(r){(r=de(r)).remove();const e=this.position();return this.parent().add(r,e+1),this},insertBefore:function(r){return(r=de(r)).before(this),this},insertAfter:function(r){return(r=de(r)).after(this),this}});const Kh=/^([+-]?(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?)([a-z%]*)$/i,yf=/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i,vf=/rgb\((\d+),(\d+),(\d+)\)/,xf=/(#[a-z_][a-z0-9\-_]*)/i,wf=/\)\s*,?\s*/,kf=/\s/g,gc=/^#[a-f0-9]{3}$|^#[a-f0-9]{6}$/i,bc=/^rgb\(/,yc=/^(\s+)?$/,vc=/^[+-]?(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?$/i,Af=/\.(jpg|jpeg|png|gif|svg)(\?[^=]+.*)?/i,hr=/[\s,]+/,ds=/[MLHVCSQTAZ]/i;function _f(r){const e=Math.round(r),n=Math.max(0,Math.min(255,e)).toString(16);return n.length===1?"0"+n:n}function an(r,e){for(let n=e.length;n--;)if(r[e[n]]==null)return!1;return!0}function Zo(r,e,n){return n<0&&(n+=1),n>1&&(n-=1),n<1/6?r+6*(e-r)*n:n<.5?e:n<2/3?r+(e-r)*(2/3-n)*6:r}xt("Dom",{classes:function(){const r=this.attr("class");return r==null?[]:r.trim().split(hr)},hasClass:function(r){return this.classes().indexOf(r)!==-1},addClass:function(r){if(!this.hasClass(r)){const e=this.classes();e.push(r),this.attr("class",e.join(" "))}return this},removeClass:function(r){return this.hasClass(r)&&this.attr("class",this.classes().filter(function(e){return e!==r}).join(" ")),this},toggleClass:function(r){return this.hasClass(r)?this.removeClass(r):this.addClass(r)}}),xt("Dom",{css:function(r,e){const n={};if(arguments.length===0)return this.node.style.cssText.split(/\s*;\s*/).filter(function(i){return!!i.length}).forEach(function(i){const t=i.split(/\s*:\s*/);n[t[0]]=t[1]}),n;if(arguments.length<2){if(Array.isArray(r)){for(const i of r){const t=zi(i);n[i]=this.node.style[t]}return n}if(typeof r=="string")return this.node.style[zi(r)];if(typeof r=="object")for(const i in r)this.node.style[zi(i)]=r[i]==null||yc.test(r[i])?"":r[i]}return arguments.length===2&&(this.node.style[zi(r)]=e==null||yc.test(e)?"":e),this},show:function(){return this.css("display","")},hide:function(){return this.css("display","none")},visible:function(){return this.css("display")!=="none"}}),xt("Dom",{data:function(r,e,n){if(r==null)return this.data(us(function(i,t){let l;const h=i.length,p=[];for(l=0;l<h;l++)t(i[l])&&p.push(i[l]);return p}(this.node.attributes,i=>i.nodeName.indexOf("data-")===0),i=>i.nodeName.slice(5)));if(r instanceof Array){const i={};for(const t of r)i[t]=this.data(t);return i}if(typeof r=="object")for(e in r)this.data(e,r[e]);else if(arguments.length<2)try{return JSON.parse(this.attr("data-"+r))}catch{return this.attr("data-"+r)}else this.attr("data-"+r,e===null?null:n===!0||typeof e=="string"||typeof e=="number"?e:JSON.stringify(e));return this}}),xt("Dom",{remember:function(r,e){if(typeof arguments[0]=="object")for(const n in r)this.remember(n,r[n]);else{if(arguments.length===1)return this.memory()[r];this.memory()[r]=e}return this},forget:function(){if(arguments.length===0)this._memory={};else for(let r=arguments.length-1;r>=0;r--)delete this.memory()[arguments[r]];return this},memory:function(){return this._memory=this._memory||{}}});class Ft{constructor(...e){this.init(...e)}static isColor(e){return e&&(e instanceof Ft||this.isRgb(e)||this.test(e))}static isRgb(e){return e&&typeof e.r=="number"&&typeof e.g=="number"&&typeof e.b=="number"}static random(e="vibrant",n,i){const{random:t,round:l,sin:h,PI:p}=Math;if(e==="vibrant"){const m=24*t()+57,y=38*t()+45,_=360*t();return new Ft(m,y,_,"lch")}if(e==="sine"){const m=l(80*h(2*p*(n=n??t())/.5+.01)+150),y=l(50*h(2*p*n/.5+4.6)+200),_=l(100*h(2*p*n/.5+2.3)+150);return new Ft(m,y,_)}if(e==="pastel"){const m=8*t()+86,y=17*t()+9,_=360*t();return new Ft(m,y,_,"lch")}if(e==="dark"){const m=10+10*t(),y=50*t()+86,_=360*t();return new Ft(m,y,_,"lch")}if(e==="rgb"){const m=255*t(),y=255*t(),_=255*t();return new Ft(m,y,_)}if(e==="lab"){const m=100*t(),y=256*t()-128,_=256*t()-128;return new Ft(m,y,_,"lab")}if(e==="grey"){const m=255*t();return new Ft(m,m,m)}throw new Error("Unsupported random color mode")}static test(e){return typeof e=="string"&&(gc.test(e)||bc.test(e))}cmyk(){const{_a:e,_b:n,_c:i}=this.rgb(),[t,l,h]=[e,n,i].map(m=>m/255),p=Math.min(1-t,1-l,1-h);return p===1?new Ft(0,0,0,1,"cmyk"):new Ft((1-t-p)/(1-p),(1-l-p)/(1-p),(1-h-p)/(1-p),p,"cmyk")}hsl(){const{_a:e,_b:n,_c:i}=this.rgb(),[t,l,h]=[e,n,i].map(E=>E/255),p=Math.max(t,l,h),m=Math.min(t,l,h),y=(p+m)/2,_=p===m,S=p-m;return new Ft(360*(_?0:p===t?((l-h)/S+(l<h?6:0))/6:p===l?((h-t)/S+2)/6:p===h?((t-l)/S+4)/6:0),100*(_?0:y>.5?S/(2-p-m):S/(p+m)),100*y,"hsl")}init(e=0,n=0,i=0,t=0,l="rgb"){if(e=e||0,this.space)for(const S in this.space)delete this[this.space[S]];if(typeof e=="number")l=typeof t=="string"?t:l,t=typeof t=="string"?0:t,Object.assign(this,{_a:e,_b:n,_c:i,_d:t,space:l});else if(e instanceof Array)this.space=n||(typeof e[3]=="string"?e[3]:e[4])||"rgb",Object.assign(this,{_a:e[0],_b:e[1],_c:e[2],_d:e[3]||0});else if(e instanceof Object){const S=function(E,R){const I=an(E,"rgb")?{_a:E.r,_b:E.g,_c:E.b,_d:0,space:"rgb"}:an(E,"xyz")?{_a:E.x,_b:E.y,_c:E.z,_d:0,space:"xyz"}:an(E,"hsl")?{_a:E.h,_b:E.s,_c:E.l,_d:0,space:"hsl"}:an(E,"lab")?{_a:E.l,_b:E.a,_c:E.b,_d:0,space:"lab"}:an(E,"lch")?{_a:E.l,_b:E.c,_c:E.h,_d:0,space:"lch"}:an(E,"cmyk")?{_a:E.c,_b:E.m,_c:E.y,_d:E.k,space:"cmyk"}:{_a:0,_b:0,_c:0,space:"rgb"};return I.space=R||I.space,I}(e,n);Object.assign(this,S)}else if(typeof e=="string")if(bc.test(e)){const S=e.replace(kf,""),[E,R,I]=vf.exec(S).slice(1,4).map(U=>parseInt(U));Object.assign(this,{_a:E,_b:R,_c:I,_d:0,space:"rgb"})}else{if(!gc.test(e))throw Error("Unsupported string format, can't construct Color");{const S=U=>parseInt(U,16),[,E,R,I]=yf.exec(function(U){return U.length===4?["#",U.substring(1,2),U.substring(1,2),U.substring(2,3),U.substring(2,3),U.substring(3,4),U.substring(3,4)].join(""):U}(e)).map(S);Object.assign(this,{_a:E,_b:R,_c:I,_d:0,space:"rgb"})}}const{_a:h,_b:p,_c:m,_d:y}=this,_=this.space==="rgb"?{r:h,g:p,b:m}:this.space==="xyz"?{x:h,y:p,z:m}:this.space==="hsl"?{h,s:p,l:m}:this.space==="lab"?{l:h,a:p,b:m}:this.space==="lch"?{l:h,c:p,h:m}:this.space==="cmyk"?{c:h,m:p,y:m,k:y}:{};Object.assign(this,_)}lab(){const{x:e,y:n,z:i}=this.xyz();return new Ft(116*n-16,500*(e-n),200*(n-i),"lab")}lch(){const{l:e,a:n,b:i}=this.lab(),t=Math.sqrt(n**2+i**2);let l=180*Math.atan2(i,n)/Math.PI;return l<0&&(l*=-1,l=360-l),new Ft(e,t,l,"lch")}rgb(){if(this.space==="rgb")return this;if((e=this.space)==="lab"||e==="xyz"||e==="lch"){let{x:n,y:i,z:t}=this;if(this.space==="lab"||this.space==="lch"){let{l:R,a:I,b:U}=this;if(this.space==="lch"){const{c:D,h:At}=this,q=Math.PI/180;I=D*Math.cos(q*At),U=D*Math.sin(q*At)}const Y=(R+16)/116,it=I/500+Y,nt=Y-U/200,pt=16/116,dt=.008856,yt=7.787;n=.95047*(it**3>dt?it**3:(it-pt)/yt),i=1*(Y**3>dt?Y**3:(Y-pt)/yt),t=1.08883*(nt**3>dt?nt**3:(nt-pt)/yt)}const l=3.2406*n+-1.5372*i+-.4986*t,h=-.9689*n+1.8758*i+.0415*t,p=.0557*n+-.204*i+1.057*t,m=Math.pow,y=.0031308,_=l>y?1.055*m(l,1/2.4)-.055:12.92*l,S=h>y?1.055*m(h,1/2.4)-.055:12.92*h,E=p>y?1.055*m(p,1/2.4)-.055:12.92*p;return new Ft(255*_,255*S,255*E)}if(this.space==="hsl"){let{h:n,s:i,l:t}=this;if(n/=360,i/=100,t/=100,i===0)return t*=255,new Ft(t,t,t);const l=t<.5?t*(1+i):t+i-t*i,h=2*t-l,p=255*Zo(h,l,n+1/3),m=255*Zo(h,l,n),y=255*Zo(h,l,n-1/3);return new Ft(p,m,y)}if(this.space==="cmyk"){const{c:n,m:i,y:t,k:l}=this,h=255*(1-Math.min(1,n*(1-l)+l)),p=255*(1-Math.min(1,i*(1-l)+l)),m=255*(1-Math.min(1,t*(1-l)+l));return new Ft(h,p,m)}return this;var e}toArray(){const{_a:e,_b:n,_c:i,_d:t,space:l}=this;return[e,n,i,t,l]}toHex(){const[e,n,i]=this._clamped().map(_f);return`#${e}${n}${i}`}toRgb(){const[e,n,i]=this._clamped();return`rgb(${e},${n},${i})`}toString(){return this.toHex()}xyz(){const{_a:e,_b:n,_c:i}=this.rgb(),[t,l,h]=[e,n,i].map(Y=>Y/255),p=t>.04045?Math.pow((t+.055)/1.055,2.4):t/12.92,m=l>.04045?Math.pow((l+.055)/1.055,2.4):l/12.92,y=h>.04045?Math.pow((h+.055)/1.055,2.4):h/12.92,_=(.4124*p+.3576*m+.1805*y)/.95047,S=(.2126*p+.7152*m+.0722*y)/1,E=(.0193*p+.1192*m+.9505*y)/1.08883,R=_>.008856?Math.pow(_,1/3):7.787*_+16/116,I=S>.008856?Math.pow(S,1/3):7.787*S+16/116,U=E>.008856?Math.pow(E,1/3):7.787*E+16/116;return new Ft(R,I,U,"xyz")}_clamped(){const{_a:e,_b:n,_c:i}=this.rgb(),{max:t,min:l,round:h}=Math;return[e,n,i].map(p=>t(0,l(h(p),255)))}}class Kt{constructor(...e){this.init(...e)}clone(){return new Kt(this)}init(e,n){const l=Array.isArray(e)?{x:e[0],y:e[1]}:typeof e=="object"?{x:e.x,y:e.y}:{x:e,y:n};return this.x=l.x==null?0:l.x,this.y=l.y==null?0:l.y,this}toArray(){return[this.x,this.y]}transform(e){return this.clone().transformO(e)}transformO(e){ft.isMatrixLike(e)||(e=new ft(e));const{x:n,y:i}=this;return this.x=e.a*n+e.c*i+e.e,this.y=e.b*n+e.d*i+e.f,this}}function sn(r,e,n){return Math.abs(e-r)<1e-6}class ft{constructor(...e){this.init(...e)}static formatTransforms(e){const n=e.flip==="both"||e.flip===!0,i=e.flip&&(n||e.flip==="x")?-1:1,t=e.flip&&(n||e.flip==="y")?-1:1,l=e.skew&&e.skew.length?e.skew[0]:isFinite(e.skew)?e.skew:isFinite(e.skewX)?e.skewX:0,h=e.skew&&e.skew.length?e.skew[1]:isFinite(e.skew)?e.skew:isFinite(e.skewY)?e.skewY:0,p=e.scale&&e.scale.length?e.scale[0]*i:isFinite(e.scale)?e.scale*i:isFinite(e.scaleX)?e.scaleX*i:i,m=e.scale&&e.scale.length?e.scale[1]*t:isFinite(e.scale)?e.scale*t:isFinite(e.scaleY)?e.scaleY*t:t,y=e.shear||0,_=e.rotate||e.theta||0,S=new Kt(e.origin||e.around||e.ox||e.originX,e.oy||e.originY),E=S.x,R=S.y,I=new Kt(e.position||e.px||e.positionX||NaN,e.py||e.positionY||NaN),U=I.x,Y=I.y,it=new Kt(e.translate||e.tx||e.translateX,e.ty||e.translateY),nt=it.x,pt=it.y,dt=new Kt(e.relative||e.rx||e.relativeX,e.ry||e.relativeY);return{scaleX:p,scaleY:m,skewX:l,skewY:h,shear:y,theta:_,rx:dt.x,ry:dt.y,tx:nt,ty:pt,ox:E,oy:R,px:U,py:Y}}static fromArray(e){return{a:e[0],b:e[1],c:e[2],d:e[3],e:e[4],f:e[5]}}static isMatrixLike(e){return e.a!=null||e.b!=null||e.c!=null||e.d!=null||e.e!=null||e.f!=null}static matrixMultiply(e,n,i){const t=e.a*n.a+e.c*n.b,l=e.b*n.a+e.d*n.b,h=e.a*n.c+e.c*n.d,p=e.b*n.c+e.d*n.d,m=e.e+e.a*n.e+e.c*n.f,y=e.f+e.b*n.e+e.d*n.f;return i.a=t,i.b=l,i.c=h,i.d=p,i.e=m,i.f=y,i}around(e,n,i){return this.clone().aroundO(e,n,i)}aroundO(e,n,i){const t=e||0,l=n||0;return this.translateO(-t,-l).lmultiplyO(i).translateO(t,l)}clone(){return new ft(this)}decompose(e=0,n=0){const i=this.a,t=this.b,l=this.c,h=this.d,p=this.e,m=this.f,y=i*h-t*l,_=y>0?1:-1,S=_*Math.sqrt(i*i+t*t),E=Math.atan2(_*t,_*i),R=180/Math.PI*E,I=Math.cos(E),U=Math.sin(E),Y=(i*l+t*h)/y,it=l*S/(Y*i-t)||h*S/(Y*t+i);return{scaleX:S,scaleY:it,shear:Y,rotate:R,translateX:p-e+e*I*S+n*(Y*I*S-U*it),translateY:m-n+e*U*S+n*(Y*U*S+I*it),originX:e,originY:n,a:this.a,b:this.b,c:this.c,d:this.d,e:this.e,f:this.f}}equals(e){if(e===this)return!0;const n=new ft(e);return sn(this.a,n.a)&&sn(this.b,n.b)&&sn(this.c,n.c)&&sn(this.d,n.d)&&sn(this.e,n.e)&&sn(this.f,n.f)}flip(e,n){return this.clone().flipO(e,n)}flipO(e,n){return e==="x"?this.scaleO(-1,1,n,0):e==="y"?this.scaleO(1,-1,0,n):this.scaleO(-1,-1,e,n||e)}init(e){const n=ft.fromArray([1,0,0,1,0,0]);return e=e instanceof tr?e.matrixify():typeof e=="string"?ft.fromArray(e.split(hr).map(parseFloat)):Array.isArray(e)?ft.fromArray(e):typeof e=="object"&&ft.isMatrixLike(e)?e:typeof e=="object"?new ft().transform(e):arguments.length===6?ft.fromArray([].slice.call(arguments)):n,this.a=e.a!=null?e.a:n.a,this.b=e.b!=null?e.b:n.b,this.c=e.c!=null?e.c:n.c,this.d=e.d!=null?e.d:n.d,this.e=e.e!=null?e.e:n.e,this.f=e.f!=null?e.f:n.f,this}inverse(){return this.clone().inverseO()}inverseO(){const e=this.a,n=this.b,i=this.c,t=this.d,l=this.e,h=this.f,p=e*t-n*i;if(!p)throw new Error("Cannot invert "+this);const m=t/p,y=-n/p,_=-i/p,S=e/p,E=-(m*l+_*h),R=-(y*l+S*h);return this.a=m,this.b=y,this.c=_,this.d=S,this.e=E,this.f=R,this}lmultiply(e){return this.clone().lmultiplyO(e)}lmultiplyO(e){const n=e instanceof ft?e:new ft(e);return ft.matrixMultiply(n,this,this)}multiply(e){return this.clone().multiplyO(e)}multiplyO(e){const n=e instanceof ft?e:new ft(e);return ft.matrixMultiply(this,n,this)}rotate(e,n,i){return this.clone().rotateO(e,n,i)}rotateO(e,n=0,i=0){e=Wo(e);const t=Math.cos(e),l=Math.sin(e),{a:h,b:p,c:m,d:y,e:_,f:S}=this;return this.a=h*t-p*l,this.b=p*t+h*l,this.c=m*t-y*l,this.d=y*t+m*l,this.e=_*t-S*l+i*l-n*t+n,this.f=S*t+_*l-n*l-i*t+i,this}scale(e,n,i,t){return this.clone().scaleO(...arguments)}scaleO(e,n=e,i=0,t=0){arguments.length===3&&(t=i,i=n,n=e);const{a:l,b:h,c:p,d:m,e:y,f:_}=this;return this.a=l*e,this.b=h*n,this.c=p*e,this.d=m*n,this.e=y*e-i*e+i,this.f=_*n-t*n+t,this}shear(e,n,i){return this.clone().shearO(e,n,i)}shearO(e,n=0,i=0){const{a:t,b:l,c:h,d:p,e:m,f:y}=this;return this.a=t+l*e,this.c=h+p*e,this.e=m+y*e-i*e,this}skew(e,n,i,t){return this.clone().skewO(...arguments)}skewO(e,n=e,i=0,t=0){arguments.length===3&&(t=i,i=n,n=e),e=Wo(e),n=Wo(n);const l=Math.tan(e),h=Math.tan(n),{a:p,b:m,c:y,d:_,e:S,f:E}=this;return this.a=p+m*l,this.b=m+p*h,this.c=y+_*l,this.d=_+y*h,this.e=S+E*l-t*l,this.f=E+S*h-i*h,this}skewX(e,n,i){return this.skew(e,0,n,i)}skewY(e,n,i){return this.skew(0,e,n,i)}toArray(){return[this.a,this.b,this.c,this.d,this.e,this.f]}toString(){return"matrix("+this.a+","+this.b+","+this.c+","+this.d+","+this.e+","+this.f+")"}transform(e){if(ft.isMatrixLike(e))return new ft(e).multiplyO(this);const n=ft.formatTransforms(e),{x:i,y:t}=new Kt(n.ox,n.oy).transform(this),l=new ft().translateO(n.rx,n.ry).lmultiplyO(this).translateO(-i,-t).scaleO(n.scaleX,n.scaleY).skewO(n.skewX,n.skewY).shearO(n.shear).rotateO(n.theta).translateO(i,t);if(isFinite(n.px)||isFinite(n.py)){const h=new Kt(i,t).transform(l),p=isFinite(n.px)?n.px-h.x:0,m=isFinite(n.py)?n.py-h.y:0;l.translateO(p,m)}return l.translateO(n.tx,n.ty),l}translate(e,n){return this.clone().translateO(e,n)}translateO(e,n){return this.e+=e||0,this.f+=n||0,this}valueOf(){return{a:this.a,b:this.b,c:this.c,d:this.d,e:this.e,f:this.f}}}function vr(){if(!vr.nodes){const r=de().size(2,0);r.node.style.cssText=["opacity: 0","position: absolute","left: -100%","top: -100%","overflow: hidden"].join(";"),r.attr("focusable","false"),r.attr("aria-hidden","true");const e=r.path().node;vr.nodes={svg:r,path:e}}if(!vr.nodes.svg.node.parentNode){const r=Et.document.body||Et.document.documentElement;vr.nodes.svg.addTo(r)}return vr.nodes}function tp(r){return!(r.width||r.height||r.x||r.y)}zt(ft,"Matrix");class he{constructor(...e){this.init(...e)}addOffset(){return this.x+=Et.window.pageXOffset,this.y+=Et.window.pageYOffset,new he(this)}init(e){return e=typeof e=="string"?e.split(hr).map(parseFloat):Array.isArray(e)?e:typeof e=="object"?[e.left!=null?e.left:e.x,e.top!=null?e.top:e.y,e.width,e.height]:arguments.length===4?[].slice.call(arguments):[0,0,0,0],this.x=e[0]||0,this.y=e[1]||0,this.width=this.w=e[2]||0,this.height=this.h=e[3]||0,this.x2=this.x+this.w,this.y2=this.y+this.h,this.cx=this.x+this.w/2,this.cy=this.y+this.h/2,this}isNulled(){return tp(this)}merge(e){const n=Math.min(this.x,e.x),i=Math.min(this.y,e.y),t=Math.max(this.x+this.width,e.x+e.width)-n,l=Math.max(this.y+this.height,e.y+e.height)-i;return new he(n,i,t,l)}toArray(){return[this.x,this.y,this.width,this.height]}toString(){return this.x+" "+this.y+" "+this.width+" "+this.height}transform(e){e instanceof ft||(e=new ft(e));let n=1/0,i=-1/0,t=1/0,l=-1/0;return[new Kt(this.x,this.y),new Kt(this.x2,this.y),new Kt(this.x,this.y2),new Kt(this.x2,this.y2)].forEach(function(h){h=h.transform(e),n=Math.min(n,h.x),i=Math.max(i,h.x),t=Math.min(t,h.y),l=Math.max(l,h.y)}),new he(n,t,i-n,l-t)}}function xc(r,e,n){let i;try{if(i=e(r.node),tp(i)&&(t=r.node)!==Et.document&&!(Et.document.documentElement.contains||function(l){for(;l.parentNode;)l=l.parentNode;return l===Et.document}).call(Et.document.documentElement,t))throw new Error("Element not in the dom")}catch{i=n(r)}var t;return i}xt({viewbox:{viewbox(r,e,n,i){return r==null?new he(this.attr("viewBox")):this.attr("viewBox",new he(r,e,n,i))},zoom(r,e){let{width:n,height:i}=this.attr(["width","height"]);if((n||i)&&typeof n!="string"&&typeof i!="string"||(n=this.node.clientWidth,i=this.node.clientHeight),!n||!i)throw new Error("Impossible to get absolute width and height. Please provide an absolute width and height attribute on the zooming element");const t=this.viewbox(),l=n/t.width,h=i/t.height,p=Math.min(l,h);if(r==null)return p;let m=p/r;m===1/0&&(m=Number.MAX_SAFE_INTEGER/100),e=e||new Kt(n/2/l+t.x,i/2/h+t.y);const y=new he(t).transform(new ft({scale:m,origin:e}));return this.viewbox(y)}}}),zt(he,"Box");class Fr extends Array{constructor(e=[],...n){if(super(e,...n),typeof e=="number")return this;this.length=0,this.push(...e)}}St([Fr],{each(r,...e){return typeof r=="function"?this.map((n,i,t)=>r.call(n,n,i,t)):this.map(n=>n[r](...e))},toArray(){return Array.prototype.concat.apply([],this)}});const Sf=["toArray","constructor","each"];function bn(r,e){return new Fr(us((e||Et.document).querySelectorAll(r),function(n){return Le(n)}))}Fr.extend=function(r){r=r.reduce((e,n)=>(Sf.includes(n)||n[0]==="_"||(e[n]=function(...i){return this.each(n,...i)}),e),{}),St([Fr],r)};let qf=0;const ep={};function rp(r){let e=r.getEventHolder();return e===Et.window&&(e=ep),e.events||(e.events={}),e.events}function ms(r){return r.getEventTarget()}function Ba(r,e,n,i,t){const l=n.bind(i||r),h=de(r),p=rp(h),m=ms(h);e=Array.isArray(e)?e:e.split(hr),n._svgjsListenerId||(n._svgjsListenerId=++qf),e.forEach(function(y){const _=y.split(".")[0],S=y.split(".")[1]||"*";p[_]=p[_]||{},p[_][S]=p[_][S]||{},p[_][S][n._svgjsListenerId]=l,m.addEventListener(_,l,t||!1)})}function cn(r,e,n,i){const t=de(r),l=rp(t),h=ms(t);(typeof n!="function"||(n=n._svgjsListenerId))&&(e=Array.isArray(e)?e:(e||"").split(hr)).forEach(function(p){const m=p&&p.split(".")[0],y=p&&p.split(".")[1];let _,S;if(n)l[m]&&l[m][y||"*"]&&(h.removeEventListener(m,l[m][y||"*"][n],i||!1),delete l[m][y||"*"][n]);else if(m&&y){if(l[m]&&l[m][y]){for(S in l[m][y])cn(h,[m,y].join("."),S);delete l[m][y]}}else if(y)for(p in l)for(_ in l[p])y===_&&cn(h,[p,y].join("."));else if(m){if(l[m]){for(_ in l[m])cn(h,[m,_].join("."));delete l[m]}}else{for(p in l)cn(h,p);(function(E){let R=E.getEventHolder();R===Et.window&&(R=ep),R.events&&(R.events={})})(t)}})}class Gn extends hs{addEventListener(){}dispatch(e,n,i){return function(t,l,h,p){const m=ms(t);return l instanceof Et.window.Event||(l=new Et.window.CustomEvent(l,{detail:h,cancelable:!0,...p})),m.dispatchEvent(l),l}(this,e,n,i)}dispatchEvent(e){const n=this.getEventHolder().events;if(!n)return!0;const i=n[e.type];for(const t in i)for(const l in i[t])i[t][l](e);return!e.defaultPrevented}fire(e,n,i){return this.dispatch(e,n,i),this}getEventHolder(){return this}getEventTarget(){return this}off(e,n,i){return cn(this,e,n,i),this}on(e,n,i,t){return Ba(this,e,n,i,t),this}removeEventListener(){}}function wc(){}zt(Gn,"EventTarget");const Jo=400,Cf=">",zf=0,Tf={"fill-opacity":1,"stroke-opacity":1,"stroke-width":0,"stroke-linejoin":"miter","stroke-linecap":"butt",fill:"#000000",stroke:"#000000",opacity:1,x:0,y:0,cx:0,cy:0,width:0,height:0,r:0,rx:0,ry:0,offset:0,"stop-opacity":1,"stop-color":"#000000","text-anchor":"start"};class fn extends Array{constructor(...e){super(...e),this.init(...e)}clone(){return new this.constructor(this)}init(e){return typeof e=="number"||(this.length=0,this.push(...this.parse(e))),this}parse(e=[]){return e instanceof Array?e:e.trim().split(hr).map(parseFloat)}toArray(){return Array.prototype.concat.apply([],this)}toSet(){return new Set(this)}toString(){return this.join(" ")}valueOf(){const e=[];return e.push(...this),e}}class vt{constructor(...e){this.init(...e)}convert(e){return new vt(this.value,e)}divide(e){return e=new vt(e),new vt(this/e,this.unit||e.unit)}init(e,n){return n=Array.isArray(e)?e[1]:n,e=Array.isArray(e)?e[0]:e,this.value=0,this.unit=n||"",typeof e=="number"?this.value=isNaN(e)?0:isFinite(e)?e:e<0?-34e37:34e37:typeof e=="string"?(n=e.match(Kh))&&(this.value=parseFloat(n[1]),n[5]==="%"?this.value/=100:n[5]==="s"&&(this.value*=1e3),this.unit=n[5]):e instanceof vt&&(this.value=e.valueOf(),this.unit=e.unit),this}minus(e){return e=new vt(e),new vt(this-e,this.unit||e.unit)}plus(e){return e=new vt(e),new vt(this+e,this.unit||e.unit)}times(e){return e=new vt(e),new vt(this*e,this.unit||e.unit)}toArray(){return[this.value,this.unit]}toJSON(){return this.toString()}toString(){return(this.unit==="%"?~~(1e8*this.value)/1e6:this.unit==="s"?this.value/1e3:this.value)+this.unit}valueOf(){return this.value}}const np=[];class kr extends Gn{constructor(e,n){super(),this.node=e,this.type=e.nodeName,n&&e!==n&&this.attr(n)}add(e,n){return(e=de(e)).removeNamespace&&this.node instanceof Et.window.SVGElement&&e.removeNamespace(),n==null?this.node.appendChild(e.node):e.node!==this.node.childNodes[n]&&this.node.insertBefore(e.node,this.node.childNodes[n]),this}addTo(e,n){return de(e).put(this,n)}children(){return new Fr(us(this.node.children,function(e){return Le(e)}))}clear(){for(;this.node.hasChildNodes();)this.node.removeChild(this.node.lastChild);return this}clone(e=!0){return this.writeDataToDom(),new this.constructor(Qh(this.node.cloneNode(e)))}each(e,n){const i=this.children();let t,l;for(t=0,l=i.length;t<l;t++)e.apply(i[t],[t,i]),n&&i[t].each(e,n);return this}element(e,n){return this.put(new kr(Vn(e),n))}first(){return Le(this.node.firstChild)}get(e){return Le(this.node.childNodes[e])}getEventHolder(){return this.node}getEventTarget(){return this.node}has(e){return this.index(e)>=0}html(e,n){return this.xml(e,n,"http://www.w3.org/1999/xhtml")}id(e){return e!==void 0||this.node.id||(this.node.id=Jh(this.type)),this.attr("id",e)}index(e){return[].slice.call(this.node.childNodes).indexOf(e.node)}last(){return Le(this.node.lastChild)}matches(e){const n=this.node,i=n.matches||n.matchesSelector||n.msMatchesSelector||n.mozMatchesSelector||n.webkitMatchesSelector||n.oMatchesSelector||null;return i&&i.call(n,e)}parent(e){let n=this;if(!n.node.parentNode)return null;if(n=Le(n.node.parentNode),!e)return n;do if(typeof e=="string"?n.matches(e):n instanceof e)return n;while(n=Le(n.node.parentNode));return n}put(e,n){return e=de(e),this.add(e,n),e}putIn(e,n){return de(e).add(this,n)}remove(){return this.parent()&&this.parent().removeElement(this),this}removeElement(e){return this.node.removeChild(e.node),this}replace(e){return e=de(e),this.node.parentNode&&this.node.parentNode.replaceChild(e.node,this.node),e}round(e=2,n=null){const i=10**e,t=this.attr(n);for(const l in t)typeof t[l]=="number"&&(t[l]=Math.round(t[l]*i)/i);return this.attr(t),this}svg(e,n){return this.xml(e,n,cs)}toString(){return this.id()}words(e){return this.node.textContent=e,this}wrap(e){const n=this.parent();if(!n)return this.addTo(e);const i=n.index(this);return n.put(e,i).put(this)}writeDataToDom(){return this.each(function(){this.writeDataToDom()}),this}xml(e,n,i){if(typeof e=="boolean"&&(i=n,n=e,e=null),e==null||typeof e=="function"){n=n==null||n,this.writeDataToDom();let p=this;if(e!=null){if(p=Le(p.node.cloneNode(!0)),n){const m=e(p);if(p=m||p,m===!1)return""}p.each(function(){const m=e(this),y=m||this;m===!1?this.remove():m&&this!==y&&this.replace(y)},!0)}return n?p.node.outerHTML:p.node.innerHTML}n=n!=null&&n;const t=Vn("wrapper",i),l=Et.document.createDocumentFragment();t.innerHTML=e;for(let p=t.children.length;p--;)l.appendChild(t.firstElementChild);const h=this.parent();return n?this.replace(l)&&h:this.add(l)}}St(kr,{attr:function(r,e,n){if(r==null){r={},e=this.node.attributes;for(const i of e)r[i.nodeName]=vc.test(i.nodeValue)?parseFloat(i.nodeValue):i.nodeValue;return r}if(r instanceof Array)return r.reduce((i,t)=>(i[t]=this.attr(t),i),{});if(typeof r=="object"&&r.constructor===Object)for(e in r)this.attr(e,r[e]);else if(e===null)this.node.removeAttribute(r);else{if(e==null)return(e=this.node.getAttribute(r))==null?Tf[r]:vc.test(e)?parseFloat(e):e;typeof(e=np.reduce((i,t)=>t(r,i,this),e))=="number"?e=new vt(e):Ft.isColor(e)?e=new Ft(e):e.constructor===Array&&(e=new fn(e)),r==="leading"?this.leading&&this.leading(e):typeof n=="string"?this.node.setAttributeNS(n,r,e.toString()):this.node.setAttribute(r,e.toString()),!this.rebuild||r!=="font-size"&&r!=="x"||this.rebuild()}return this},find:function(r){return bn(r,this.node)},findOne:function(r){return Le(this.node.querySelector(r))}}),zt(kr,"Dom");class tr extends kr{constructor(e,n){super(e,n),this.dom={},this.node.instance=this,e.hasAttribute("svgjs:data")&&this.setData(JSON.parse(e.getAttribute("svgjs:data"))||{})}center(e,n){return this.cx(e).cy(n)}cx(e){return e==null?this.x()+this.width()/2:this.x(e-this.width()/2)}cy(e){return e==null?this.y()+this.height()/2:this.y(e-this.height()/2)}defs(){const e=this.root();return e&&e.defs()}dmove(e,n){return this.dx(e).dy(n)}dx(e=0){return this.x(new vt(e).plus(this.x()))}dy(e=0){return this.y(new vt(e).plus(this.y()))}getEventHolder(){return this}height(e){return this.attr("height",e)}move(e,n){return this.x(e).y(n)}parents(e=this.root()){const n=typeof e=="string";n||(e=de(e));const i=new Fr;let t=this;for(;(t=t.parent())&&t.node!==Et.document&&t.nodeName!=="#document-fragment"&&(i.push(t),n||t.node!==e.node)&&(!n||!t.matches(e));)if(t.node===this.root().node)return null;return i}reference(e){if(!(e=this.attr(e)))return null;const n=(e+"").match(xf);return n?de(n[1]):null}root(){const e=this.parent(Or[ps]);return e&&e.root()}setData(e){return this.dom=e,this}size(e,n){const i=gn(this,e,n);return this.width(new vt(i.width)).height(new vt(i.height))}width(e){return this.attr("width",e)}writeDataToDom(){return this.node.removeAttribute("svgjs:data"),Object.keys(this.dom).length&&this.node.setAttribute("svgjs:data",JSON.stringify(this.dom)),super.writeDataToDom()}x(e){return this.attr("x",e)}y(e){return this.attr("y",e)}}St(tr,{bbox:function(){const r=xc(this,e=>e.getBBox(),e=>{try{const n=e.clone().addTo(vr().svg).show(),i=n.node.getBBox();return n.remove(),i}catch(n){throw new Error(`Getting bbox of element "${e.node.nodeName}" is not possible: ${n.toString()}`)}});return new he(r)},rbox:function(r){const e=xc(this,i=>i.getBoundingClientRect(),i=>{throw new Error(`Getting rbox of element "${i.node.nodeName}" is not possible`)}),n=new he(e);return r?n.transform(r.screenCTM().inverseO()):n.addOffset()},inside:function(r,e){const n=this.bbox();return r>n.x&&e>n.y&&r<n.x+n.width&&e<n.y+n.height},point:function(r,e){return new Kt(r,e).transform(this.screenCTM().inverse())},ctm:function(){return new ft(this.node.getCTM())},screenCTM:function(){if(typeof this.isRoot=="function"&&!this.isRoot()){const r=this.rect(1,1),e=r.node.getScreenCTM();return r.remove(),new ft(e)}return new ft(this.node.getScreenCTM())}}),zt(tr,"Element");const Cn={stroke:["color","width","opacity","linecap","linejoin","miterlimit","dasharray","dashoffset"],fill:["color","opacity","rule"],prefix:function(r,e){return e==="color"?r:r+"-"+e}};["fill","stroke"].forEach(function(r){const e={};let n;e[r]=function(i){if(i===void 0)return this.attr(r);if(typeof i=="string"||i instanceof Ft||Ft.isRgb(i)||i instanceof tr)this.attr(r,i);else for(n=Cn[r].length-1;n>=0;n--)i[Cn[r][n]]!=null&&this.attr(Cn.prefix(r,Cn[r][n]),i[Cn[r][n]]);return this},xt(["Element","Runner"],e)}),xt(["Element","Runner"],{matrix:function(r,e,n,i,t,l){return r==null?new ft(this):this.attr("transform",new ft(r,e,n,i,t,l))},rotate:function(r,e,n){return this.transform({rotate:r,ox:e,oy:n},!0)},skew:function(r,e,n,i){return arguments.length===1||arguments.length===3?this.transform({skew:r,ox:e,oy:n},!0):this.transform({skew:[r,e],ox:n,oy:i},!0)},shear:function(r,e,n){return this.transform({shear:r,ox:e,oy:n},!0)},scale:function(r,e,n,i){return arguments.length===1||arguments.length===3?this.transform({scale:r,ox:e,oy:n},!0):this.transform({scale:[r,e],ox:n,oy:i},!0)},translate:function(r,e){return this.transform({translate:[r,e]},!0)},relative:function(r,e){return this.transform({relative:[r,e]},!0)},flip:function(r="both",e="center"){return"xybothtrue".indexOf(r)===-1&&(e=r,r="both"),this.transform({flip:r,origin:e},!0)},opacity:function(r){return this.attr("opacity",r)}}),xt("radius",{radius:function(r,e=r){return(this._element||this).type==="radialGradient"?this.attr("r",new vt(r)):this.rx(r).ry(e)}}),xt("Path",{length:function(){return this.node.getTotalLength()},pointAt:function(r){return new Kt(this.node.getPointAtLength(r))}}),xt(["Element","Runner"],{font:function(r,e){if(typeof r=="object"){for(e in r)this.font(e,r[e]);return this}return r==="leading"?this.leading(e):r==="anchor"?this.attr("text-anchor",e):r==="size"||r==="family"||r==="weight"||r==="stretch"||r==="variant"||r==="style"?this.attr("font-"+r,e):this.attr(r,e)}});xt("Element",["click","dblclick","mousedown","mouseup","mouseover","mouseout","mousemove","mouseenter","mouseleave","touchstart","touchmove","touchleave","touchend","touchcancel"].reduce(function(r,e){return r[e]=function(n){return n===null?this.off(e):this.on(e,n),this},r},{})),xt("Element",{untransform:function(){return this.attr("transform",null)},matrixify:function(){return(this.attr("transform")||"").split(wf).slice(0,-1).map(function(e){const n=e.trim().split("(");return[n[0],n[1].split(hr).map(function(i){return parseFloat(i)})]}).reverse().reduce(function(e,n){return n[0]==="matrix"?e.lmultiply(ft.fromArray(n[1])):e[n[0]].apply(e,n[1])},new ft)},toParent:function(r,e){if(this===r)return this;const n=this.screenCTM(),i=r.screenCTM().inverse();return this.addTo(r,e).untransform().transform(i.multiply(n)),this},toRoot:function(r){return this.toParent(this.root(),r)},transform:function(r,e){if(r==null||typeof r=="string"){const i=new ft(this).decompose();return r==null?i:i[r]}ft.isMatrixLike(r)||(r={...r,origin:La(r,this)});const n=new ft(e===!0?this:e||!1).transform(r);return this.attr("transform",n)}});class xe extends tr{flatten(e=this,n){return this.each(function(){if(this instanceof xe)return this.flatten().ungroup()}),this}ungroup(e=this.parent(),n=e.index(this)){return n=n===-1?e.children().length:n,this.each(function(i,t){return t[t.length-i-1].toParent(e,n)}),this.remove()}}zt(xe,"Container");class fs extends xe{constructor(e,n=e){super(Ut("defs",e),n)}flatten(){return this}ungroup(){return this}}zt(fs,"Defs");class qe extends tr{}function gs(r){return this.attr("rx",r)}function bs(r){return this.attr("ry",r)}function ip(r){return r==null?this.cx()-this.rx():this.cx(r+this.rx())}function op(r){return r==null?this.cy()-this.ry():this.cy(r+this.ry())}function ap(r){return this.attr("cx",r)}function sp(r){return this.attr("cy",r)}function lp(r){return r==null?2*this.rx():this.rx(new vt(r).divide(2))}function up(r){return r==null?2*this.ry():this.ry(new vt(r).divide(2))}zt(qe,"Shape");var Mf=Object.freeze({__proto__:null,cx:ap,cy:sp,height:up,rx:gs,ry:bs,width:lp,x:ip,y:op});class Gi extends qe{constructor(e,n=e){super(Ut("ellipse",e),n)}size(e,n){const i=gn(this,e,n);return this.rx(new vt(i.width).divide(2)).ry(new vt(i.height).divide(2))}}St(Gi,Mf),xt("Container",{ellipse:Gt(function(r=0,e=r){return this.put(new Gi).size(r,e).move(0,0)})}),zt(Gi,"Ellipse");class cp extends kr{constructor(e=Et.document.createDocumentFragment()){super(e)}xml(e,n,i){if(typeof e=="boolean"&&(i=n,n=e,e=null),e==null||typeof e=="function"){const t=new kr(Vn("wrapper",i));return t.add(this.node.cloneNode(!0)),t.xml(!1,i)}return super.xml(e,!1,i)}}function hp(r,e){return(this._element||this).type==="radialGradient"?this.attr({fx:new vt(r),fy:new vt(e)}):this.attr({x1:new vt(r),y1:new vt(e)})}function pp(r,e){return(this._element||this).type==="radialGradient"?this.attr({cx:new vt(r),cy:new vt(e)}):this.attr({x2:new vt(r),y2:new vt(e)})}zt(cp,"Fragment");var kc,Ef=Object.freeze({__proto__:null,from:hp,to:pp});class Bn extends xe{constructor(e,n){super(Ut(e+"Gradient",typeof e=="string"?null:e),n)}attr(e,n,i){return e==="transform"&&(e="gradientTransform"),super.attr(e,n,i)}bbox(){return new he}targets(){return bn('svg [fill*="'+this.id()+'"]')}toString(){return this.url()}update(e){return this.clear(),typeof e=="function"&&e.call(this,this),this}url(){return'url("#'+this.id()+'")'}}St(Bn,Ef),xt({Container:{gradient(...r){return this.defs().gradient(...r)}},Defs:{gradient:Gt(function(r,e){return this.put(new Bn(r)).update(e)})}}),zt(Bn,"Gradient");class In extends xe{constructor(e,n=e){super(Ut("pattern",e),n)}attr(e,n,i){return e==="transform"&&(e="patternTransform"),super.attr(e,n,i)}bbox(){return new he}targets(){return bn('svg [fill*="'+this.id()+'"]')}toString(){return this.url()}update(e){return this.clear(),typeof e=="function"&&e.call(this,this),this}url(){return'url("#'+this.id()+'")'}}xt({Container:{pattern(...r){return this.defs().pattern(...r)}},Defs:{pattern:Gt(function(r,e,n){return this.put(new In).update(n).attr({x:0,y:0,width:r,height:e,patternUnits:"userSpaceOnUse"})})}}),zt(In,"Pattern");class Ui extends qe{constructor(e,n=e){super(Ut("image",e),n)}load(e,n){if(!e)return this;const i=new Et.window.Image;return Ba(i,"load",function(t){const l=this.parent(In);this.width()===0&&this.height()===0&&this.size(i.width,i.height),l instanceof In&&l.width()===0&&l.height()===0&&l.size(this.width(),this.height()),typeof n=="function"&&n.call(this,t)},this),Ba(i,"load error",function(){cn(i)}),this.attr("href",i.src=e,jn)}}kc=function(r,e,n){return r!=="fill"&&r!=="stroke"||Af.test(e)&&(e=n.root().defs().image(e)),e instanceof Ui&&(e=n.root().defs().pattern(0,0,i=>{i.add(e)})),e},np.push(kc),xt({Container:{image:Gt(function(r,e){return this.put(new Ui).size(0,0).load(r,e)})}}),zt(Ui,"Image");class Ar extends fn{bbox(){let e=-1/0,n=-1/0,i=1/0,t=1/0;return this.forEach(function(l){e=Math.max(l[0],e),n=Math.max(l[1],n),i=Math.min(l[0],i),t=Math.min(l[1],t)}),new he(i,t,e-i,n-t)}move(e,n){const i=this.bbox();if(e-=i.x,n-=i.y,!isNaN(e)&&!isNaN(n))for(let t=this.length-1;t>=0;t--)this[t]=[this[t][0]+e,this[t][1]+n];return this}parse(e=[0,0]){const n=[];(e=e instanceof Array?Array.prototype.concat.apply([],e):e.trim().split(hr).map(parseFloat)).length%2!=0&&e.pop();for(let i=0,t=e.length;i<t;i+=2)n.push([e[i],e[i+1]]);return n}size(e,n){let i;const t=this.bbox();for(i=this.length-1;i>=0;i--)t.width&&(this[i][0]=(this[i][0]-t.x)*e/t.width+t.x),t.height&&(this[i][1]=(this[i][1]-t.y)*n/t.height+t.y);return this}toLine(){return{x1:this[0][0],y1:this[0][1],x2:this[1][0],y2:this[1][1]}}toString(){const e=[];for(let n=0,i=this.length;n<i;n++)e.push(this[n].join(","));return e.join(" ")}transform(e){return this.clone().transformO(e)}transformO(e){ft.isMatrixLike(e)||(e=new ft(e));for(let n=this.length;n--;){const[i,t]=this[n];this[n][0]=e.a*i+e.c*t+e.e,this[n][1]=e.b*i+e.d*t+e.f}return this}}const Df=Ar;var ys=Object.freeze({__proto__:null,MorphArray:Df,height:function(r){const e=this.bbox();return r==null?e.height:this.size(e.width,r)},width:function(r){const e=this.bbox();return r==null?e.width:this.size(r,e.height)},x:function(r){return r==null?this.bbox().x:this.move(r,this.bbox().y)},y:function(r){return r==null?this.bbox().y:this.move(this.bbox().x,r)}});class zn extends qe{constructor(e,n=e){super(Ut("line",e),n)}array(){return new Ar([[this.attr("x1"),this.attr("y1")],[this.attr("x2"),this.attr("y2")]])}move(e,n){return this.attr(this.array().move(e,n).toLine())}plot(e,n,i,t){return e==null?this.array():(e=n!==void 0?{x1:e,y1:n,x2:i,y2:t}:new Ar(e).toLine(),this.attr(e))}size(e,n){const i=gn(this,e,n);return this.attr(this.array().size(i.width,i.height).toLine())}}St(zn,ys),xt({Container:{line:Gt(function(...r){return zn.prototype.plot.apply(this.put(new zn),r[0]!=null?r:[0,0,0,0])})}}),zt(zn,"Line");class Xi extends xe{constructor(e,n=e){super(Ut("marker",e),n)}height(e){return this.attr("markerHeight",e)}orient(e){return this.attr("orient",e)}ref(e,n){return this.attr("refX",e).attr("refY",n)}toString(){return"url(#"+this.id()+")"}update(e){return this.clear(),typeof e=="function"&&e.call(this,this),this}width(e){return this.attr("markerWidth",e)}}function hn(r,e){return function(n){return n==null?this[r]:(this[r]=n,e&&e.call(this),this)}}xt({Container:{marker(...r){return this.defs().marker(...r)}},Defs:{marker:Gt(function(r,e,n){return this.put(new Xi).size(r,e).ref(r/2,e/2).viewbox(0,0,r,e).attr("orient","auto").update(n)})},marker:{marker(r,e,n,i){let t=["marker"];return r!=="all"&&t.push(r),t=t.join("-"),r=arguments[1]instanceof Xi?arguments[1]:this.defs().marker(e,n,i),this.attr(t,r)}}}),zt(Xi,"Marker");const Lf={"-":function(r){return r},"<>":function(r){return-Math.cos(r*Math.PI)/2+.5},">":function(r){return Math.sin(r*Math.PI/2)},"<":function(r){return 1-Math.cos(r*Math.PI/2)},bezier:function(r,e,n,i){return function(t){return t<0?r>0?e/r*t:n>0?i/n*t:0:t>1?n<1?(1-i)/(1-n)*t+(i-n)/(1-n):r<1?(1-e)/(1-r)*t+(e-r)/(1-r):1:3*t*(1-t)**2*e+3*t**2*(1-t)*i+t**3}},steps:function(r,e="end"){e=e.split("-").reverse()[0];let n=r;return e==="none"?--n:e==="both"&&++n,(i,t=!1)=>{let l=Math.floor(i*r);const h=i*l%1==0;return e!=="start"&&e!=="both"||++l,t&&h&&--l,i>=0&&l<0&&(l=0),i<=1&&l>n&&(l=n),l/n}}};class vs{done(){return!1}}class Na extends vs{constructor(e=Cf){super(),this.ease=Lf[e]||e}step(e,n,i){return typeof e!="number"?i<1?e:n:e+(n-e)*this.ease(i)}}class Qi extends vs{constructor(e){super(),this.stepper=e}done(e){return e.done}step(e,n,i,t){return this.stepper(e,n,i,t)}}function Ac(){const r=(this._duration||500)/1e3,e=this._overshoot||0,n=Math.PI,i=Math.log(e/100+1e-10),t=-i/Math.sqrt(n*n+i*i),l=3.9/(t*r);this.d=2*t*l,this.k=l*l}St(class extends Qi{constructor(r=500,e=0){super(),this.duration(r).overshoot(e)}step(r,e,n,i){if(typeof r=="string")return r;if(i.done=n===1/0,n===1/0)return e;if(n===0)return r;n>100&&(n=16),n/=1e3;const t=i.velocity||0,l=-this.d*t-this.k*(r-e),h=r+t*n+l*n*n/2;return i.velocity=t+l*n,i.done=Math.abs(e-h)+Math.abs(t)<.002,i.done?e:h}},{duration:hn("_duration",Ac),overshoot:hn("_overshoot",Ac)});St(class extends Qi{constructor(r=.1,e=.01,n=0,i=1e3){super(),this.p(r).i(e).d(n).windup(i)}step(r,e,n,i){if(typeof r=="string")return r;if(i.done=n===1/0,n===1/0)return e;if(n===0)return r;const t=e-r;let l=(i.integral||0)+t*n;const h=(t-(i.error||0))/n,p=this._windup;return p!==!1&&(l=Math.max(-p,Math.min(l,p))),i.error=t,i.integral=l,i.done=Math.abs(t)<.001,i.done?e:r+(this.P*t+this.I*l+this.D*h)}},{windup:hn("_windup"),p:hn("P"),i:hn("I"),d:hn("D")});const Bf={M:2,L:2,H:1,V:1,C:6,S:4,Q:4,T:2,A:7,Z:0},Oa={M:function(r,e,n){return e.x=n.x=r[0],e.y=n.y=r[1],["M",e.x,e.y]},L:function(r,e){return e.x=r[0],e.y=r[1],["L",r[0],r[1]]},H:function(r,e){return e.x=r[0],["H",r[0]]},V:function(r,e){return e.y=r[0],["V",r[0]]},C:function(r,e){return e.x=r[4],e.y=r[5],["C",r[0],r[1],r[2],r[3],r[4],r[5]]},S:function(r,e){return e.x=r[2],e.y=r[3],["S",r[0],r[1],r[2],r[3]]},Q:function(r,e){return e.x=r[2],e.y=r[3],["Q",r[0],r[1],r[2],r[3]]},T:function(r,e){return e.x=r[0],e.y=r[1],["T",r[0],r[1]]},Z:function(r,e,n){return e.x=n.x,e.y=n.y,["Z"]},A:function(r,e){return e.x=r[5],e.y=r[6],["A",r[0],r[1],r[2],r[3],r[4],r[5],r[6]]}},Qo="mlhvqtcsaz".split("");for(let r=0,e=Qo.length;r<e;++r)Oa[Qo[r]]=function(n){return function(i,t,l){if(n==="H")i[0]=i[0]+t.x;else if(n==="V")i[0]=i[0]+t.y;else if(n==="A")i[5]=i[5]+t.x,i[6]=i[6]+t.y;else for(let h=0,p=i.length;h<p;++h)i[h]=i[h]+(h%2?t.y:t.x);return Oa[n](i,t,l)}}(Qo[r].toUpperCase());function Fa(r){return r.segment.length&&r.segment.length-1===Bf[r.segment[0].toUpperCase()]}function Nf(r,e){r.inNumber&&Lr(r,!1);const n=ds.test(e);if(n)r.segment=[e];else{const i=r.lastCommand,t=i.toLowerCase(),l=i===t;r.segment=[t==="m"?l?"l":"L":i]}return r.inSegment=!0,r.lastCommand=r.segment[0],n}function Lr(r,e){if(!r.inNumber)throw new Error("Parser Error");r.number&&r.segment.push(parseFloat(r.number)),r.inNumber=e,r.number="",r.pointSeen=!1,r.hasExponent=!1,Fa(r)&&Ra(r)}function Ra(r){r.inSegment=!1,r.absolute&&(r.segment=function(e){const n=e.segment[0];return Oa[n](e.segment.slice(1),e.p,e.p0)}(r)),r.segments.push(r.segment)}function Of(r){if(!r.segment.length)return!1;const e=r.segment[0].toUpperCase()==="A",n=r.segment.length;return e&&(n===4||n===5)}function Ff(r){return r.lastToken.toUpperCase()==="E"}class Rr extends fn{bbox(){return vr().path.setAttribute("d",this.toString()),new he(vr.nodes.path.getBBox())}move(e,n){const i=this.bbox();if(e-=i.x,n-=i.y,!isNaN(e)&&!isNaN(n))for(let t,l=this.length-1;l>=0;l--)t=this[l][0],t==="M"||t==="L"||t==="T"?(this[l][1]+=e,this[l][2]+=n):t==="H"?this[l][1]+=e:t==="V"?this[l][1]+=n:t==="C"||t==="S"||t==="Q"?(this[l][1]+=e,this[l][2]+=n,this[l][3]+=e,this[l][4]+=n,t==="C"&&(this[l][5]+=e,this[l][6]+=n)):t==="A"&&(this[l][6]+=e,this[l][7]+=n);return this}parse(e="M0 0"){return Array.isArray(e)&&(e=Array.prototype.concat.apply([],e).toString()),function(n,i=!0){let t=0,l="";const h={segment:[],inNumber:!1,number:"",lastToken:"",inSegment:!1,segments:[],pointSeen:!1,hasExponent:!1,absolute:i,p0:new Kt,p:new Kt};for(;h.lastToken=l,l=n.charAt(t++);)if(h.inSegment||!Nf(h,l))if(l!==".")if(isNaN(parseInt(l)))if(l!==" "&&l!==",")if(l!=="-")if(l.toUpperCase()!=="E"){if(ds.test(l)){if(h.inNumber)Lr(h,!1);else{if(!Fa(h))throw new Error("parser Error");Ra(h)}--t}}else h.number+=l,h.hasExponent=!0;else{if(h.inNumber&&!Ff(h)){Lr(h,!1),--t;continue}h.number+=l,h.inNumber=!0}else h.inNumber&&Lr(h,!1);else{if(h.number==="0"||Of(h)){h.inNumber=!0,h.number=l,Lr(h,!0);continue}h.inNumber=!0,h.number+=l}else{if(h.pointSeen||h.hasExponent){Lr(h,!1),--t;continue}h.inNumber=!0,h.pointSeen=!0,h.number+=l}return h.inNumber&&Lr(h,!1),h.inSegment&&Fa(h)&&Ra(h),h.segments}(e)}size(e,n){const i=this.bbox();let t,l;for(i.width=i.width===0?1:i.width,i.height=i.height===0?1:i.height,t=this.length-1;t>=0;t--)l=this[t][0],l==="M"||l==="L"||l==="T"?(this[t][1]=(this[t][1]-i.x)*e/i.width+i.x,this[t][2]=(this[t][2]-i.y)*n/i.height+i.y):l==="H"?this[t][1]=(this[t][1]-i.x)*e/i.width+i.x:l==="V"?this[t][1]=(this[t][1]-i.y)*n/i.height+i.y:l==="C"||l==="S"||l==="Q"?(this[t][1]=(this[t][1]-i.x)*e/i.width+i.x,this[t][2]=(this[t][2]-i.y)*n/i.height+i.y,this[t][3]=(this[t][3]-i.x)*e/i.width+i.x,this[t][4]=(this[t][4]-i.y)*n/i.height+i.y,l==="C"&&(this[t][5]=(this[t][5]-i.x)*e/i.width+i.x,this[t][6]=(this[t][6]-i.y)*n/i.height+i.y)):l==="A"&&(this[t][1]=this[t][1]*e/i.width,this[t][2]=this[t][2]*n/i.height,this[t][6]=(this[t][6]-i.x)*e/i.width+i.x,this[t][7]=(this[t][7]-i.y)*n/i.height+i.y);return this}toString(){return function(e){let n="";for(let i=0,t=e.length;i<t;i++)n+=e[i][0],e[i][1]!=null&&(n+=e[i][1],e[i][2]!=null&&(n+=" ",n+=e[i][2],e[i][3]!=null&&(n+=" ",n+=e[i][3],n+=" ",n+=e[i][4],e[i][5]!=null&&(n+=" ",n+=e[i][5],n+=" ",n+=e[i][6],e[i][7]!=null&&(n+=" ",n+=e[i][7])))));return n+" "}(this)}}const dp=r=>{const e=typeof r;return e==="number"?vt:e==="string"?Ft.isColor(r)?Ft:hr.test(r)?ds.test(r)?Rr:fn:Kh.test(r)?vt:Ha:Va.indexOf(r.constructor)>-1?r.constructor:Array.isArray(r)?fn:e==="object"?Pn:Ha};class Br{constructor(e){this._stepper=e||new Na("-"),this._from=null,this._to=null,this._type=null,this._context=null,this._morphObj=null}at(e){return this._morphObj.morph(this._from,this._to,e,this._stepper,this._context)}done(){return this._context.map(this._stepper.done).reduce(function(e,n){return e&&n},!0)}from(e){return e==null?this._from:(this._from=this._set(e),this)}stepper(e){return e==null?this._stepper:(this._stepper=e,this)}to(e){return e==null?this._to:(this._to=this._set(e),this)}type(e){return e==null?this._type:(this._type=e,this)}_set(e){this._type||this.type(dp(e));let n=new this._type(e);return this._type===Ft&&(n=this._to?n[this._to[4]]():this._from?n[this._from[4]]():n),this._type===Pn&&(n=this._to?n.align(this._to):this._from?n.align(this._from):n),n=n.toConsumable(),this._morphObj=this._morphObj||new this._type,this._context=this._context||Array.apply(null,Array(n.length)).map(Object).map(function(i){return i.done=!0,i}),n}}class Ha{constructor(...e){this.init(...e)}init(e){return e=Array.isArray(e)?e[0]:e,this.value=e,this}toArray(){return[this.value]}valueOf(){return this.value}}class Un{constructor(...e){this.init(...e)}init(e){return Array.isArray(e)&&(e={scaleX:e[0],scaleY:e[1],shear:e[2],rotate:e[3],translateX:e[4],translateY:e[5],originX:e[6],originY:e[7]}),Object.assign(this,Un.defaults,e),this}toArray(){const e=this;return[e.scaleX,e.scaleY,e.shear,e.rotate,e.translateX,e.translateY,e.originX,e.originY]}}Un.defaults={scaleX:1,scaleY:1,shear:0,rotate:0,translateX:0,translateY:0,originX:0,originY:0};const Rf=(r,e)=>r[0]<e[0]?-1:r[0]>e[0]?1:0;class Pn{constructor(...e){this.init(...e)}align(e){const n=this.values;for(let i=0,t=n.length;i<t;++i){if(n[i+1]===e[i+1]){if(n[i+1]===Ft&&e[i+7]!==n[i+7]){const p=e[i+7],m=new Ft(this.values.splice(i+3,5))[p]().toArray();this.values.splice(i+3,0,...m)}i+=n[i+2]+2;continue}if(!e[i+1])return this;const l=new e[i+1]().toArray(),h=n[i+2]+3;n.splice(i,h,e[i],e[i+1],e[i+2],...l),i+=n[i+2]+2}return this}init(e){if(this.values=[],Array.isArray(e))return void(this.values=e.slice());e=e||{};const n=[];for(const i in e){const t=dp(e[i]),l=new t(e[i]).toArray();n.push([i,t,l.length,...l])}return n.sort(Rf),this.values=n.reduce((i,t)=>i.concat(t),[]),this}toArray(){return this.values}valueOf(){const e={},n=this.values;for(;n.length;){const i=n.shift(),t=n.shift(),l=n.shift(),h=n.splice(0,l);e[i]=new t(h)}return e}}const Va=[Ha,Un,Pn];class dn extends qe{constructor(e,n=e){super(Ut("path",e),n)}array(){return this._array||(this._array=new Rr(this.attr("d")))}clear(){return delete this._array,this}height(e){return e==null?this.bbox().height:this.size(this.bbox().width,e)}move(e,n){return this.attr("d",this.array().move(e,n))}plot(e){return e==null?this.array():this.clear().attr("d",typeof e=="string"?e:this._array=new Rr(e))}size(e,n){const i=gn(this,e,n);return this.attr("d",this.array().size(i.width,i.height))}width(e){return e==null?this.bbox().width:this.size(e,this.bbox().height)}x(e){return e==null?this.bbox().x:this.move(e,this.bbox().y)}y(e){return e==null?this.bbox().y:this.move(this.bbox().x,e)}}dn.prototype.MorphArray=Rr,xt({Container:{path:Gt(function(r){return this.put(new dn).plot(r||new Rr)})}}),zt(dn,"Path");var mp=Object.freeze({__proto__:null,array:function(){return this._array||(this._array=new Ar(this.attr("points")))},clear:function(){return delete this._array,this},move:function(r,e){return this.attr("points",this.array().move(r,e))},plot:function(r){return r==null?this.array():this.clear().attr("points",typeof r=="string"?r:this._array=new Ar(r))},size:function(r,e){const n=gn(this,r,e);return this.attr("points",this.array().size(n.width,n.height))}});class Tn extends qe{constructor(e,n=e){super(Ut("polygon",e),n)}}xt({Container:{polygon:Gt(function(r){return this.put(new Tn).plot(r||new Ar)})}}),St(Tn,ys),St(Tn,mp),zt(Tn,"Polygon");class Mn extends qe{constructor(e,n=e){super(Ut("polyline",e),n)}}xt({Container:{polyline:Gt(function(r){return this.put(new Mn).plot(r||new Ar)})}}),St(Mn,ys),St(Mn,mp),zt(Mn,"Polyline");class Yi extends qe{constructor(e,n=e){super(Ut("rect",e),n)}}St(Yi,{rx:gs,ry:bs}),xt({Container:{rect:Gt(function(r,e){return this.put(new Yi).size(r,e)})}}),zt(Yi,"Rect");class Ko{constructor(){this._first=null,this._last=null}first(){return this._first&&this._first.value}last(){return this._last&&this._last.value}push(e){const n=e.next!==void 0?e:{value:e,next:null,prev:null};return this._last?(n.prev=this._last,this._last.next=n,this._last=n):(this._last=n,this._first=n),n}remove(e){e.prev&&(e.prev.next=e.next),e.next&&(e.next.prev=e.prev),e===this._last&&(this._last=e.prev),e===this._first&&(this._first=e.next),e.prev=null,e.next=null}shift(){const e=this._first;return e?(this._first=e.next,this._first&&(this._first.prev=null),this._last=this._first?this._last:null,e.value):null}}const Bt={nextDraw:null,frames:new Ko,timeouts:new Ko,immediates:new Ko,timer:()=>Et.window.performance||Et.window.Date,transforms:[],frame(r){const e=Bt.frames.push({run:r});return Bt.nextDraw===null&&(Bt.nextDraw=Et.window.requestAnimationFrame(Bt._draw)),e},timeout(r,e){e=e||0;const n=Bt.timer().now()+e,i=Bt.timeouts.push({run:r,time:n});return Bt.nextDraw===null&&(Bt.nextDraw=Et.window.requestAnimationFrame(Bt._draw)),i},immediate(r){const e=Bt.immediates.push(r);return Bt.nextDraw===null&&(Bt.nextDraw=Et.window.requestAnimationFrame(Bt._draw)),e},cancelFrame(r){r!=null&&Bt.frames.remove(r)},clearTimeout(r){r!=null&&Bt.timeouts.remove(r)},cancelImmediate(r){r!=null&&Bt.immediates.remove(r)},_draw(r){let e=null;const n=Bt.timeouts.last();for(;(e=Bt.timeouts.shift())&&(r>=e.time?e.run():Bt.timeouts.push(e),e!==n););let i=null;const t=Bt.frames.last();for(;i!==t&&(i=Bt.frames.shift());)i.run(r);let l=null;for(;l=Bt.immediates.shift();)l();Bt.nextDraw=Bt.timeouts.first()||Bt.frames.first()?Et.window.requestAnimationFrame(Bt._draw):null}},Hf=function(r){const e=r.start,n=r.runner.duration();return{start:e,duration:n,end:e+n,runner:r.runner}},Vf=function(){const r=Et.window;return(r.performance||r.Date).now()};class fp extends Gn{constructor(e=Vf){super(),this._timeSource=e,this._startTime=0,this._speed=1,this._persist=0,this._nextFrame=null,this._paused=!0,this._runners=[],this._runnerIds=[],this._lastRunnerId=-1,this._time=0,this._lastSourceTime=0,this._lastStepTime=0,this._step=this._stepFn.bind(this,!1),this._stepImmediate=this._stepFn.bind(this,!0)}active(){return!!this._nextFrame}finish(){return this.time(this.getEndTimeOfTimeline()+1),this.pause()}getEndTime(){const e=this.getLastRunnerInfo(),n=e?e.runner.duration():0;return(e?e.start:this._time)+n}getEndTimeOfTimeline(){const e=this._runners.map(n=>n.start+n.runner.duration());return Math.max(0,...e)}getLastRunnerInfo(){return this.getRunnerInfoById(this._lastRunnerId)}getRunnerInfoById(e){return this._runners[this._runnerIds.indexOf(e)]||null}pause(){return this._paused=!0,this._continue()}persist(e){return e==null?this._persist:(this._persist=e,this)}play(){return this._paused=!1,this.updateTime()._continue()}reverse(e){const n=this.speed();if(e==null)return this.speed(-n);const i=Math.abs(n);return this.speed(e?-i:i)}schedule(e,n,i){if(e==null)return this._runners.map(Hf);let t=0;const l=this.getEndTime();if(n=n||0,i==null||i==="last"||i==="after")t=l;else if(i==="absolute"||i==="start")t=n,n=0;else if(i==="now")t=this._time;else if(i==="relative"){const m=this.getRunnerInfoById(e.id);m&&(t=m.start+n,n=0)}else{if(i!=="with-last")throw new Error('Invalid value for the "when" parameter');{const m=this.getLastRunnerInfo();t=m?m.start:this._time}}e.unschedule(),e.timeline(this);const h=e.persist(),p={persist:h===null?this._persist:h,start:t+n,runner:e};return this._lastRunnerId=e.id,this._runners.push(p),this._runners.sort((m,y)=>m.start-y.start),this._runnerIds=this._runners.map(m=>m.runner.id),this.updateTime()._continue(),this}seek(e){return this.time(this._time+e)}source(e){return e==null?this._timeSource:(this._timeSource=e,this)}speed(e){return e==null?this._speed:(this._speed=e,this)}stop(){return this.time(0),this.pause()}time(e){return e==null?this._time:(this._time=e,this._continue(!0))}unschedule(e){const n=this._runnerIds.indexOf(e.id);return n<0||(this._runners.splice(n,1),this._runnerIds.splice(n,1),e.timeline(null)),this}updateTime(){return this.active()||(this._lastSourceTime=this._timeSource()),this}_continue(e=!1){return Bt.cancelFrame(this._nextFrame),this._nextFrame=null,e?this._stepImmediate():(this._paused||(this._nextFrame=Bt.frame(this._step)),this)}_stepFn(e=!1){const n=this._timeSource();let i=n-this._lastSourceTime;e&&(i=0);const t=this._speed*i+(this._time-this._lastStepTime);this._lastSourceTime=n,e||(this._time+=t,this._time=this._time<0?0:this._time),this._lastStepTime=this._time,this.fire("time",this._time);for(let h=this._runners.length;h--;){const p=this._runners[h],m=p.runner;this._time-p.start<=0&&m.reset()}let l=!1;for(let h=0,p=this._runners.length;h<p;h++){const m=this._runners[h],y=m.runner;let _=t;const S=this._time-m.start;if(S<=0){l=!0;continue}S<_&&(_=S),y.active()&&(y.step(_).done?m.persist!==!0&&y.duration()-y.time()+this._time+m.persist<this._time&&(y.unschedule(),--h,--p):l=!0)}return l&&!(this._speed<0&&this._time===0)||this._runnerIds.length&&this._speed<0&&this._time>0?this._continue():(this.pause(),this.fire("finished")),this}}xt({Element:{timeline:function(r){return r==null?(this._timeline=this._timeline||new fp,this._timeline):(this._timeline=r,this)}}});class Se extends Gn{constructor(e){super(),this.id=Se.id++,e=typeof(e=e??Jo)=="function"?new Qi(e):e,this._element=null,this._timeline=null,this.done=!1,this._queue=[],this._duration=typeof e=="number"&&e,this._isDeclarative=e instanceof Qi,this._stepper=this._isDeclarative?e:new Na,this._history={},this.enabled=!0,this._time=0,this._lastTime=0,this._reseted=!0,this.transforms=new ft,this.transformId=1,this._haveReversed=!1,this._reverse=!1,this._loopsDone=0,this._swing=!1,this._wait=0,this._times=1,this._frameId=null,this._persist=!!this._isDeclarative||null}static sanitise(e,n,i){let t=1,l=!1,h=0;return n=n||zf,i=i||"last",typeof(e=e||Jo)!="object"||e instanceof vs||(n=e.delay||n,i=e.when||i,l=e.swing||l,t=e.times||t,h=e.wait||h,e=e.duration||Jo),{duration:e,delay:n,swing:l,times:t,wait:h,when:i}}active(e){return e==null?this.enabled:(this.enabled=e,this)}addTransform(e,n){return this.transforms.lmultiplyO(e),this}after(e){return this.on("finished",e)}animate(e,n,i){const t=Se.sanitise(e,n,i),l=new Se(t.duration);return this._timeline&&l.timeline(this._timeline),this._element&&l.element(this._element),l.loop(t).schedule(t.delay,t.when)}clearTransform(){return this.transforms=new ft,this}clearTransformsFromQueue(){this.done&&this._timeline&&this._timeline._runnerIds.includes(this.id)||(this._queue=this._queue.filter(e=>!e.isTransform))}delay(e){return this.animate(0,e)}duration(){return this._times*(this._wait+this._duration)-this._wait}during(e){return this.queue(null,e)}ease(e){return this._stepper=new Na(e),this}element(e){return e==null?this._element:(this._element=e,e._prepareRunner(),this)}finish(){return this.step(1/0)}loop(e,n,i){return typeof e=="object"&&(n=e.swing,i=e.wait,e=e.times),this._times=e||1/0,this._swing=n||!1,this._wait=i||0,this._times===!0&&(this._times=1/0),this}loops(e){const n=this._duration+this._wait;if(e==null){const l=Math.floor(this._time/n),h=(this._time-l*n)/this._duration;return Math.min(l+h,this._times)}const i=e%1,t=n*Math.floor(e)+this._duration*i;return this.time(t)}persist(e){return e==null?this._persist:(this._persist=e,this)}position(e){const n=this._time,i=this._duration,t=this._wait,l=this._times,h=this._swing,p=this._reverse;let m;if(e==null){const S=function(R){const I=h*Math.floor(R%(2*(t+i))/(t+i)),U=I&&!p||!I&&p,Y=Math.pow(-1,U)*(R%(t+i))/i+U;return Math.max(Math.min(Y,1),0)},E=l*(t+i)-t;return m=n<=0?Math.round(S(1e-5)):n<E?S(n):Math.round(S(E-1e-5)),m}const y=Math.floor(this.loops()),_=h&&y%2==0;return m=y+(_&&!p||p&&_?e:1-e),this.loops(m)}progress(e){return e==null?Math.min(1,this._time/this.duration()):this.time(e*this.duration())}queue(e,n,i,t){return this._queue.push({initialiser:e||wc,runner:n||wc,retarget:i,isTransform:t,initialised:!1,finished:!1}),this.timeline()&&this.timeline()._continue(),this}reset(){return this._reseted||(this.time(0),this._reseted=!0),this}reverse(e){return this._reverse=e??!this._reverse,this}schedule(e,n,i){if(e instanceof fp||(i=n,n=e,e=this.timeline()),!e)throw Error("Runner cannot be scheduled without timeline");return e.schedule(this,n,i),this}step(e){if(!this.enabled)return this;e=e??16,this._time+=e;const n=this.position(),i=this._lastPosition!==n&&this._time>=0;this._lastPosition=n;const t=this.duration(),l=this._lastTime<=0&&this._time>0,h=this._lastTime<t&&this._time>=t;this._lastTime=this._time,l&&this.fire("start",this);const p=this._isDeclarative;this.done=!p&&!h&&this._time>=t,this._reseted=!1;let m=!1;return(i||p)&&(this._initialise(i),this.transforms=new ft,m=this._run(p?e:n),this.fire("step",this)),this.done=this.done||m&&p,h&&this.fire("finished",this),this}time(e){if(e==null)return this._time;const n=e-this._time;return this.step(n),this}timeline(e){return e===void 0?this._timeline:(this._timeline=e,this)}unschedule(){const e=this.timeline();return e&&e.unschedule(this),this}_initialise(e){if(e||this._isDeclarative)for(let n=0,i=this._queue.length;n<i;++n){const t=this._queue[n],l=this._isDeclarative||!t.initialised&&e;e=!t.finished,l&&e&&(t.initialiser.call(this),t.initialised=!0)}}_rememberMorpher(e,n){if(this._history[e]={morpher:n,caller:this._queue[this._queue.length-1]},this._isDeclarative){const i=this.timeline();i&&i.play()}}_run(e){let n=!0;for(let i=0,t=this._queue.length;i<t;++i){const l=this._queue[i],h=l.runner.call(this,e);l.finished=l.finished||h===!0,n=n&&l.finished}return n}_tryRetarget(e,n,i){if(this._history[e]){if(!this._history[e].caller.initialised){const l=this._queue.indexOf(this._history[e].caller);return this._queue.splice(l,1),!1}this._history[e].caller.retarget?this._history[e].caller.retarget.call(this,n,i):this._history[e].morpher.to(n),this._history[e].caller.finished=!1;const t=this.timeline();return t&&t.play(),!0}return!1}}Se.id=0;class Ki{constructor(e=new ft,n=-1,i=!0){this.transforms=e,this.id=n,this.done=i}clearTransformsFromQueue(){}}St([Se,Ki],{mergeWith(r){return new Ki(r.transforms.lmultiply(this.transforms),r.id)}});const gp=(r,e)=>r.lmultiplyO(e),bp=r=>r.transforms;function If(){const r=this._transformationRunners.runners.map(bp).reduce(gp,new ft);this.transform(r),this._transformationRunners.merge(),this._transformationRunners.length()===1&&(this._frameId=null)}class Pf{constructor(){this.runners=[],this.ids=[]}add(e){if(this.runners.includes(e))return;const n=e.id+1;return this.runners.push(e),this.ids.push(n),this}clearBefore(e){const n=this.ids.indexOf(e+1)||1;return this.ids.splice(0,n,0),this.runners.splice(0,n,new Ki).forEach(i=>i.clearTransformsFromQueue()),this}edit(e,n){const i=this.ids.indexOf(e+1);return this.ids.splice(i,1,e+1),this.runners.splice(i,1,n),this}getByID(e){return this.runners[this.ids.indexOf(e+1)]}length(){return this.ids.length}merge(){let e=null;for(let n=0;n<this.runners.length;++n){const i=this.runners[n];if(e&&i.done&&e.done&&(!i._timeline||!i._timeline._runnerIds.includes(i.id))&&(!e._timeline||!e._timeline._runnerIds.includes(e.id))){this.remove(i.id);const t=i.mergeWith(e);this.edit(e.id,t),e=t,--n}else e=i}return this}remove(e){const n=this.ids.indexOf(e+1);return this.ids.splice(n,1),this.runners.splice(n,1),this}}xt({Element:{animate(r,e,n){const i=Se.sanitise(r,e,n),t=this.timeline();return new Se(i.duration).loop(i).element(this).timeline(t.play()).schedule(i.delay,i.when)},delay(r,e){return this.animate(0,r,e)},_clearTransformRunnersBefore(r){this._transformationRunners.clearBefore(r.id)},_currentTransform(r){return this._transformationRunners.runners.filter(e=>e.id<=r.id).map(bp).reduce(gp,new ft)},_addRunner(r){this._transformationRunners.add(r),Bt.cancelImmediate(this._frameId),this._frameId=Bt.immediate(If.bind(this))},_prepareRunner(){this._frameId==null&&(this._transformationRunners=new Pf().add(new Ki(new ft(this))))}}});St(Se,{attr(r,e){return this.styleAttr("attr",r,e)},css(r,e){return this.styleAttr("css",r,e)},styleAttr(r,e,n){if(typeof e=="string")return this.styleAttr(r,{[e]:n});let i=e;if(this._tryRetarget(r,i))return this;let t=new Br(this._stepper).to(i),l=Object.keys(i);return this.queue(function(){t=t.from(this.element()[r](l))},function(h){return this.element()[r](t.at(h).valueOf()),t.done()},function(h){const p=Object.keys(h),m=(y=l,p.filter(S=>!y.includes(S)));var y;if(m.length){const S=this.element()[r](m),E=new Pn(t.from()).valueOf();Object.assign(E,S),t.from(E)}const _=new Pn(t.to()).valueOf();Object.assign(_,h),t.to(_),l=p,i=h}),this._rememberMorpher(r,t),this},zoom(r,e){if(this._tryRetarget("zoom",r,e))return this;let n=new Br(this._stepper).to(new vt(r));return this.queue(function(){n=n.from(this.element().zoom())},function(i){return this.element().zoom(n.at(i),e),n.done()},function(i,t){e=t,n.to(i)}),this._rememberMorpher("zoom",n),this},transform(r,e,n){if(e=r.relative||e,this._isDeclarative&&!e&&this._tryRetarget("transform",r))return this;const i=ft.isMatrixLike(r);n=r.affine!=null?r.affine:n??!i;const t=new Br(this._stepper).type(n?Un:ft);let l,h,p,m,y;return this.queue(function(){h=h||this.element(),l=l||La(r,h),y=new ft(e?void 0:h),h._addRunner(this),e||h._clearTransformRunnersBefore(this)},function(_){e||this.clearTransform();const{x:S,y:E}=new Kt(l).transform(h._currentTransform(this));let R=new ft({...r,origin:[S,E]}),I=this._isDeclarative&&p?p:y;if(n){R=R.decompose(S,E),I=I.decompose(S,E);const Y=R.rotate,it=I.rotate,nt=[Y-360,Y,Y+360],pt=nt.map(D=>Math.abs(D-it)),dt=Math.min(...pt),yt=pt.indexOf(dt);R.rotate=nt[yt]}e&&(i||(R.rotate=r.rotate||0),this._isDeclarative&&m&&(I.rotate=m)),t.from(I),t.to(R);const U=t.at(_);return m=U.rotate,p=new ft(U),this.addTransform(p),h._addRunner(this),t.done()},function(_){(_.origin||"center").toString()!==(r.origin||"center").toString()&&(l=La(_,h)),r={..._,origin:l}},!0),this._isDeclarative&&this._rememberMorpher("transform",t),this},x(r,e){return this._queueNumber("x",r)},y(r){return this._queueNumber("y",r)},dx(r=0){return this._queueNumberDelta("x",r)},dy(r=0){return this._queueNumberDelta("y",r)},dmove(r,e){return this.dx(r).dy(e)},_queueNumberDelta(r,e){if(e=new vt(e),this._tryRetarget(r,e))return this;const n=new Br(this._stepper).to(e);let i=null;return this.queue(function(){i=this.element()[r](),n.from(i),n.to(i+e)},function(t){return this.element()[r](n.at(t)),n.done()},function(t){n.to(i+new vt(t))}),this._rememberMorpher(r,n),this},_queueObject(r,e){if(this._tryRetarget(r,e))return this;const n=new Br(this._stepper).to(e);return this.queue(function(){n.from(this.element()[r]())},function(i){return this.element()[r](n.at(i)),n.done()}),this._rememberMorpher(r,n),this},_queueNumber(r,e){return this._queueObject(r,new vt(e))},cx(r){return this._queueNumber("cx",r)},cy(r){return this._queueNumber("cy",r)},move(r,e){return this.x(r).y(e)},center(r,e){return this.cx(r).cy(e)},size(r,e){let n;return r&&e||(n=this._element.bbox()),r||(r=n.width/n.height*e),e||(e=n.height/n.width*r),this.width(r).height(e)},width(r){return this._queueNumber("width",r)},height(r){return this._queueNumber("height",r)},plot(r,e,n,i){if(arguments.length===4)return this.plot([r,e,n,i]);if(this._tryRetarget("plot",r))return this;const t=new Br(this._stepper).type(this._element.MorphArray).to(r);return this.queue(function(){t.from(this._element.array())},function(l){return this._element.plot(t.at(l)),t.done()}),this._rememberMorpher("plot",t),this},leading(r){return this._queueNumber("leading",r)},viewbox(r,e,n,i){return this._queueObject("viewbox",new he(r,e,n,i))},update(r){return typeof r!="object"?this.update({offset:arguments[0],color:arguments[1],opacity:arguments[2]}):(r.opacity!=null&&this.attr("stop-opacity",r.opacity),r.color!=null&&this.attr("stop-color",r.color),r.offset!=null&&this.attr("offset",r.offset),this)}}),St(Se,{rx:gs,ry:bs,from:hp,to:pp}),zt(Se,"Runner");class Ia extends xe{constructor(e,n=e){super(Ut("svg",e),n),this.namespace()}defs(){return this.isRoot()?Le(this.node.querySelector("defs"))||this.put(new fs):this.root().defs()}isRoot(){return!this.node.parentNode||!(this.node.parentNode instanceof Et.window.SVGElement)&&this.node.parentNode.nodeName!=="#document-fragment"}namespace(){return this.isRoot()?this.attr({xmlns:cs,version:"1.1"}).attr("xmlns:xlink",jn,Ti).attr("xmlns:svgjs","http://svgjs.dev/svgjs",Ti):this.root().namespace()}removeNamespace(){return this.attr({xmlns:null,version:null}).attr("xmlns:xlink",null,Ti).attr("xmlns:svgjs",null,Ti)}root(){return this.isRoot()?this:super.root()}}xt({Container:{nested:Gt(function(){return this.put(new Ia)})}}),zt(Ia,"Svg",!0);let Pa=class extends xe{constructor(r,e=r){super(Ut("symbol",r),e)}};xt({Container:{symbol:Gt(function(){return this.put(new Pa)})}}),zt(Pa,"Symbol");var yp=Object.freeze({__proto__:null,amove:function(r,e){return this.ax(r).ay(e)},ax:function(r){return this.attr("x",r)},ay:function(r){return this.attr("y",r)},build:function(r){return this._build=!!r,this},center:function(r,e,n=this.bbox()){return this.cx(r,n).cy(e,n)},cx:function(r,e=this.bbox()){return r==null?e.cx:this.attr("x",this.attr("x")+r-e.cx)},cy:function(r,e=this.bbox()){return r==null?e.cy:this.attr("y",this.attr("y")+r-e.cy)},length:function(){return this.node.getComputedTextLength()},move:function(r,e,n=this.bbox()){return this.x(r,n).y(e,n)},plain:function(r){return this._build===!1&&this.clear(),this.node.appendChild(Et.document.createTextNode(r)),this},x:function(r,e=this.bbox()){return r==null?e.x:this.attr("x",this.attr("x")+r-e.x)},y:function(r,e=this.bbox()){return r==null?e.y:this.attr("y",this.attr("y")+r-e.y)}});class Ie extends qe{constructor(e,n=e){super(Ut("text",e),n),this.dom.leading=new vt(1.3),this._rebuild=!0,this._build=!1}leading(e){return e==null?this.dom.leading:(this.dom.leading=new vt(e),this.rebuild())}rebuild(e){if(typeof e=="boolean"&&(this._rebuild=e),this._rebuild){const n=this;let i=0;const t=this.dom.leading;this.each(function(l){const h=Et.window.getComputedStyle(this.node).getPropertyValue("font-size"),p=t*new vt(h);this.dom.newLined&&(this.attr("x",n.attr("x")),this.text()===`
`?i+=p:(this.attr("dy",l?p+i:0),i=0))}),this.fire("rebuild")}return this}setData(e){return this.dom=e,this.dom.leading=new vt(e.leading||1.3),this}text(e){if(e===void 0){const n=this.node.childNodes;let i=0;e="";for(let t=0,l=n.length;t<l;++t)n[t].nodeName!=="textPath"?(t!==i&&n[t].nodeType!==3&&Le(n[t]).dom.newLined===!0&&(e+=`
`),e+=n[t].textContent):t===0&&(i=1);return e}if(this.clear().build(!0),typeof e=="function")e.call(this,this);else for(let n=0,i=(e=(e+"").split(`
`)).length;n<i;n++)this.newLine(e[n]);return this.build(!1).rebuild()}}St(Ie,yp),xt({Container:{text:Gt(function(r=""){return this.put(new Ie).text(r)}),plain:Gt(function(r=""){return this.put(new Ie).plain(r)})}}),zt(Ie,"Text");class Wi extends qe{constructor(e,n=e){super(Ut("tspan",e),n),this._build=!1}dx(e){return this.attr("dx",e)}dy(e){return this.attr("dy",e)}newLine(){this.dom.newLined=!0;const e=this.parent();if(!(e instanceof Ie))return this;const n=e.index(this),i=Et.window.getComputedStyle(this.node).getPropertyValue("font-size"),t=e.dom.leading*new vt(i);return this.dy(n?t:0).attr("x",e.x())}text(e){return e==null?this.node.textContent+(this.dom.newLined?`
`:""):(typeof e=="function"?(this.clear().build(!0),e.call(this,this),this.build(!1)):this.plain(e),this)}}St(Wi,yp),xt({Tspan:{tspan:Gt(function(r=""){const e=new Wi;return this._build||this.clear(),this.put(e).text(r)})},Text:{newLine:function(r=""){return this.tspan(r).newLine()}}}),zt(Wi,"Tspan");class ta extends qe{constructor(e,n=e){super(Ut("circle",e),n)}radius(e){return this.attr("r",e)}rx(e){return this.attr("r",e)}ry(e){return this.rx(e)}size(e){return this.radius(new vt(e).divide(2))}}St(ta,{x:ip,y:op,cx:ap,cy:sp,width:lp,height:up}),xt({Container:{circle:Gt(function(r=0){return this.put(new ta).size(r).move(0,0)})}}),zt(ta,"Circle");class ea extends xe{constructor(e,n=e){super(Ut("clipPath",e),n)}remove(){return this.targets().forEach(function(e){e.unclip()}),super.remove()}targets(){return bn('svg [clip-path*="'+this.id()+'"]')}}xt({Container:{clip:Gt(function(){return this.defs().put(new ea)})},Element:{clipper(){return this.reference("clip-path")},clipWith(r){const e=r instanceof ea?r:this.parent().clip().add(r);return this.attr("clip-path",'url("#'+e.id()+'")')},unclip(){return this.attr("clip-path",null)}}}),zt(ea,"ClipPath");class _c extends tr{constructor(e,n=e){super(Ut("foreignObject",e),n)}}xt({Container:{foreignObject:Gt(function(r,e){return this.put(new _c).size(r,e)})}}),zt(_c,"ForeignObject");var vp=Object.freeze({__proto__:null,dmove:function(r,e){return this.children().forEach((n,i)=>{let t;try{t=n.bbox()}catch{return}const l=new ft(n),h=l.translate(r,e).transform(l.inverse()),p=new Kt(t.x,t.y).transform(h);n.move(p.x,p.y)}),this},dx:function(r){return this.dmove(r,0)},dy:function(r){return this.dmove(0,r)},height:function(r,e=this.bbox()){return r==null?e.height:this.size(e.width,r,e)},move:function(r=0,e=0,n=this.bbox()){const i=r-n.x,t=e-n.y;return this.dmove(i,t)},size:function(r,e,n=this.bbox()){const i=gn(this,r,e,n),t=i.width/n.width,l=i.height/n.height;return this.children().forEach((h,p)=>{const m=new Kt(n).transform(new ft(h).inverse());h.scale(t,l,m.x,m.y)}),this},width:function(r,e=this.bbox()){return r==null?e.width:this.size(r,e.height,e)},x:function(r,e=this.bbox()){return r==null?e.x:this.move(r,e.y,e)},y:function(r,e=this.bbox()){return r==null?e.y:this.move(e.x,r,e)}});class ra extends xe{constructor(e,n=e){super(Ut("g",e),n)}}St(ra,vp),xt({Container:{group:Gt(function(){return this.put(new ra)})}}),zt(ra,"G");class Mi extends xe{constructor(e,n=e){super(Ut("a",e),n)}target(e){return this.attr("target",e)}to(e){return this.attr("href",e,jn)}}St(Mi,vp),xt({Container:{link:Gt(function(r){return this.put(new Mi).to(r)})},Element:{unlink(){const r=this.linker();if(!r)return this;const e=r.parent();if(!e)return this.remove();const n=e.index(r);return e.add(this,n),r.remove(),this},linkTo(r){let e=this.linker();return e||(e=new Mi,this.wrap(e)),typeof r=="function"?r.call(e,e):e.to(r),this},linker(){const r=this.parent();return r&&r.node.nodeName.toLowerCase()==="a"?r:null}}}),zt(Mi,"A");class na extends xe{constructor(e,n=e){super(Ut("mask",e),n)}remove(){return this.targets().forEach(function(e){e.unmask()}),super.remove()}targets(){return bn('svg [mask*="'+this.id()+'"]')}}xt({Container:{mask:Gt(function(){return this.defs().put(new na)})},Element:{masker(){return this.reference("mask")},maskWith(r){const e=r instanceof na?r:this.parent().mask().add(r);return this.attr("mask",'url("#'+e.id()+'")')},unmask(){return this.attr("mask",null)}}}),zt(na,"Mask");class Sc extends tr{constructor(e,n=e){super(Ut("stop",e),n)}update(e){return(typeof e=="number"||e instanceof vt)&&(e={offset:arguments[0],color:arguments[1],opacity:arguments[2]}),e.opacity!=null&&this.attr("stop-opacity",e.opacity),e.color!=null&&this.attr("stop-color",e.color),e.offset!=null&&this.attr("offset",new vt(e.offset)),this}}xt({Gradient:{stop:function(r,e,n){return this.put(new Sc).update(r,e,n)}}}),zt(Sc,"Stop");let ia=class extends tr{constructor(r,e=r){super(Ut("style",r),e)}addText(r=""){return this.node.textContent+=r,this}font(r,e,n={}){return this.rule("@font-face",{fontFamily:r,src:e,...n})}rule(r,e){return this.addText(function(n,i){if(!n)return"";if(!i)return n;let t=n+"{";for(const l in i)t+=l.replace(/([A-Z])/g,function(h,p){return"-"+p.toLowerCase()})+":"+i[l]+";";return t+="}",t}(r,e))}};xt("Dom",{style(r,e){return this.put(new ia).rule(r,e)},fontface(r,e,n){return this.put(new ia).font(r,e,n)}}),zt(ia,"Style");class oa extends Ie{constructor(e,n=e){super(Ut("textPath",e),n)}array(){const e=this.track();return e?e.array():null}plot(e){const n=this.track();let i=null;return n&&(i=n.plot(e)),e==null?i:this}track(){return this.reference("href")}}xt({Container:{textPath:Gt(function(r,e){return r instanceof Ie||(r=this.text(r)),r.path(e)})},Text:{path:Gt(function(r,e=!0){const n=new oa;let i;if(r instanceof dn||(r=this.defs().path(r)),n.attr("href","#"+r,jn),e)for(;i=this.node.firstChild;)n.node.appendChild(i);return this.put(n)}),textPath(){return this.findOne("textPath")}},Path:{text:Gt(function(r){return r instanceof Ie||(r=new Ie().addTo(this.parent()).text(r)),r.path(this)}),targets(){return bn("svg textPath").filter(r=>(r.attr("href")||"").includes(this.id()))}}}),oa.prototype.MorphArray=Rr,zt(oa,"TextPath");class qc extends qe{constructor(e,n=e){super(Ut("use",e),n)}use(e,n){return this.attr("href",(n||"")+"#"+e,jn)}}xt({Container:{use:Gt(function(r,e){return this.put(new qc).use(r,e)})}}),zt(qc,"Use");const jf=de;St([Ia,Pa,Ui,In,Xi],be("viewbox")),St([zn,Mn,Tn,dn],be("marker")),St(Ie,be("Text")),St(dn,be("Path")),St(fs,be("Defs")),St([Ie,Wi],be("Tspan")),St([Yi,Gi,Bn,Se],be("radius")),St(Gn,be("EventTarget")),St(kr,be("Dom")),St(tr,be("Element")),St(qe,be("Shape")),St([xe,cp],be("Container")),St(Bn,be("Gradient")),St(Se,be("Runner")),Fr.extend([...new Set(Wh)]),function(r=[]){Va.push(...[].concat(r))}([vt,Ft,he,ft,fn,Ar,Rr,Kt]),St(Va,{to(r){return new Br().type(this.constructor).from(this.toArray()).to(r)},fromArray(r){return this.init(r),this},toConsumable(){return this.toArray()},morph(r,e,n,i,t){return this.fromArray(r.map(function(l,h){return i.step(l,e[h],n,t[h],t)}))}});class Ae{constructor(e,n,i){this.lexer=void 0,this.start=void 0,this.end=void 0,this.lexer=e,this.start=n,this.end=i}static range(e,n){return n?e&&e.loc&&n.loc&&e.loc.lexer===n.loc.lexer?new Ae(e.loc.lexer,e.loc.start,n.loc.end):null:e&&e.loc}}class ur{constructor(e,n){this.text=void 0,this.loc=void 0,this.noexpand=void 0,this.treatAsRelax=void 0,this.text=e,this.loc=n}range(e,n){return new ur(n,Ae.range(this,e))}}class rt{constructor(e,n){this.position=void 0;var i,t="KaTeX parse error: "+e,l=n&&n.loc;if(l&&l.start<=l.end){var h=l.lexer.input;i=l.start;var p=l.end;i===h.length?t+=" at end of input: ":t+=" at position "+(i+1)+": ";var m=h.slice(i,p).replace(/[^]/g,"$&̲");t+=(i>15?"…"+h.slice(i-15,i):h.slice(0,i))+m+(p+15<h.length?h.slice(p,p+15)+"…":h.slice(p))}var y=new Error(t);return y.name="ParseError",y.__proto__=rt.prototype,y.position=i,y}}rt.prototype.__proto__=Error.prototype;var Gf=/([A-Z])/g,Uf={"&":"&amp;",">":"&gt;","<":"&lt;",'"':"&quot;","'":"&#x27;"},Xf=/[&><"']/g,Cc=function r(e){return e.type==="ordgroup"||e.type==="color"?e.body.length===1?r(e.body[0]):e:e.type==="font"?r(e.body):e},ht={contains:function(r,e){return r.indexOf(e)!==-1},deflt:function(r,e){return r===void 0?e:r},escape:function(r){return String(r).replace(Xf,e=>Uf[e])},hyphenate:function(r){return r.replace(Gf,"-$1").toLowerCase()},getBaseElem:Cc,isCharacterBox:function(r){var e=Cc(r);return e.type==="mathord"||e.type==="textord"||e.type==="atom"},protocolFromUrl:function(r){var e=/^\s*([^\\/#]*?)(?::|&#0*58|&#x0*3a)/i.exec(r);return e!=null?e[1]:"_relative"}};class ja{constructor(e){this.displayMode=void 0,this.output=void 0,this.leqno=void 0,this.fleqn=void 0,this.throwOnError=void 0,this.errorColor=void 0,this.macros=void 0,this.minRuleThickness=void 0,this.colorIsTextColor=void 0,this.strict=void 0,this.trust=void 0,this.maxSize=void 0,this.maxExpand=void 0,this.globalGroup=void 0,e=e||{},this.displayMode=ht.deflt(e.displayMode,!1),this.output=ht.deflt(e.output,"htmlAndMathml"),this.leqno=ht.deflt(e.leqno,!1),this.fleqn=ht.deflt(e.fleqn,!1),this.throwOnError=ht.deflt(e.throwOnError,!0),this.errorColor=ht.deflt(e.errorColor,"#cc0000"),this.macros=e.macros||{},this.minRuleThickness=Math.max(0,ht.deflt(e.minRuleThickness,0)),this.colorIsTextColor=ht.deflt(e.colorIsTextColor,!1),this.strict=ht.deflt(e.strict,"warn"),this.trust=ht.deflt(e.trust,!1),this.maxSize=Math.max(0,ht.deflt(e.maxSize,1/0)),this.maxExpand=Math.max(0,ht.deflt(e.maxExpand,1e3)),this.globalGroup=ht.deflt(e.globalGroup,!1)}reportNonstrict(e,n,i){var t=this.strict;if(typeof t=="function"&&(t=t(e,n,i)),t&&t!=="ignore"){if(t===!0||t==="error")throw new rt("LaTeX-incompatible input and strict mode is set to 'error': "+n+" ["+e+"]",i);t==="warn"?typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+n+" ["+e+"]"):typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to unrecognized '"+t+"': "+n+" ["+e+"]")}}useStrictBehavior(e,n,i){var t=this.strict;if(typeof t=="function")try{t=t(e,n,i)}catch{t="error"}return!(!t||t==="ignore")&&(t===!0||t==="error"||(t==="warn"?(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+n+" ["+e+"]"),!1):(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to unrecognized '"+t+"': "+n+" ["+e+"]"),!1)))}isTrusted(e){e.url&&!e.protocol&&(e.protocol=ht.protocolFromUrl(e.url));var n=typeof this.trust=="function"?this.trust(e):this.trust;return!!n}}class gr{constructor(e,n,i){this.id=void 0,this.size=void 0,this.cramped=void 0,this.id=e,this.size=n,this.cramped=i}sup(){return Qe[Yf[this.id]]}sub(){return Qe[Wf[this.id]]}fracNum(){return Qe[$f[this.id]]}fracDen(){return Qe[Zf[this.id]]}cramp(){return Qe[Jf[this.id]]}text(){return Qe[Qf[this.id]]}isTight(){return this.size>=2}}var Qe=[new gr(0,0,!1),new gr(1,0,!0),new gr(2,1,!1),new gr(3,1,!0),new gr(4,2,!1),new gr(5,2,!0),new gr(6,3,!1),new gr(7,3,!0)],Yf=[4,5,4,5,6,7,6,7],Wf=[5,5,5,5,7,7,7,7],$f=[2,3,4,5,6,7,6,7],Zf=[3,3,5,5,7,7,7,7],Jf=[1,1,3,3,5,5,7,7],Qf=[0,1,2,3,2,3,2,3],gt={DISPLAY:Qe[0],TEXT:Qe[2],SCRIPT:Qe[4],SCRIPTSCRIPT:Qe[6]},Ga=[{name:"latin",blocks:[[256,591],[768,879]]},{name:"cyrillic",blocks:[[1024,1279]]},{name:"armenian",blocks:[[1328,1423]]},{name:"brahmic",blocks:[[2304,4255]]},{name:"georgian",blocks:[[4256,4351]]},{name:"cjk",blocks:[[12288,12543],[19968,40879],[65280,65376]]},{name:"hangul",blocks:[[44032,55215]]}],$i=[];function xp(r){for(var e=0;e<$i.length;e+=2)if(r>=$i[e]&&r<=$i[e+1])return!0;return!1}Ga.forEach(r=>r.blocks.forEach(e=>$i.push(...e)));var ln=80,zc={doubleleftarrow:`M262 157
l10-10c34-36 62.7-77 86-123 3.3-8 5-13.3 5-16 0-5.3-6.7-8-20-8-7.3
 0-12.2.5-14.5 1.5-2.3 1-4.8 4.5-7.5 10.5-49.3 97.3-121.7 169.3-217 216-28
 14-57.3 25-88 33-6.7 2-11 3.8-13 5.5-2 1.7-3 4.2-3 7.5s1 5.8 3 7.5
c2 1.7 6.3 3.5 13 5.5 68 17.3 128.2 47.8 180.5 91.5 52.3 43.7 93.8 96.2 124.5
 157.5 9.3 8 15.3 12.3 18 13h6c12-.7 18-4 18-10 0-2-1.7-7-5-15-23.3-46-52-87
-86-123l-10-10h399738v-40H218c328 0 0 0 0 0l-10-8c-26.7-20-65.7-43-117-69 2.7
-2 6-3.7 10-5 36.7-16 72.3-37.3 107-64l10-8h399782v-40z
m8 0v40h399730v-40zm0 194v40h399730v-40z`,doublerightarrow:`M399738 392l
-10 10c-34 36-62.7 77-86 123-3.3 8-5 13.3-5 16 0 5.3 6.7 8 20 8 7.3 0 12.2-.5
 14.5-1.5 2.3-1 4.8-4.5 7.5-10.5 49.3-97.3 121.7-169.3 217-216 28-14 57.3-25 88
-33 6.7-2 11-3.8 13-5.5 2-1.7 3-4.2 3-7.5s-1-5.8-3-7.5c-2-1.7-6.3-3.5-13-5.5-68
-17.3-128.2-47.8-180.5-91.5-52.3-43.7-93.8-96.2-124.5-157.5-9.3-8-15.3-12.3-18
-13h-6c-12 .7-18 4-18 10 0 2 1.7 7 5 15 23.3 46 52 87 86 123l10 10H0v40h399782
c-328 0 0 0 0 0l10 8c26.7 20 65.7 43 117 69-2.7 2-6 3.7-10 5-36.7 16-72.3 37.3
-107 64l-10 8H0v40zM0 157v40h399730v-40zm0 194v40h399730v-40z`,leftarrow:`M400000 241H110l3-3c68.7-52.7 113.7-120
 135-202 4-14.7 6-23 6-25 0-7.3-7-11-21-11-8 0-13.2.8-15.5 2.5-2.3 1.7-4.2 5.8
-5.5 12.5-1.3 4.7-2.7 10.3-4 17-12 48.7-34.8 92-68.5 130S65.3 228.3 18 247
c-10 4-16 7.7-18 11 0 8.7 6 14.3 18 17 47.3 18.7 87.8 47 121.5 85S196 441.3 208
 490c.7 2 1.3 5 2 9s1.2 6.7 1.5 8c.3 1.3 1 3.3 2 6s2.2 4.5 3.5 5.5c1.3 1 3.3
 1.8 6 2.5s6 1 10 1c14 0 21-3.7 21-11 0-2-2-10.3-6-25-20-79.3-65-146.7-135-202
 l-3-3h399890zM100 241v40h399900v-40z`,leftbrace:`M6 548l-6-6v-35l6-11c56-104 135.3-181.3 238-232 57.3-28.7 117
-45 179-50h399577v120H403c-43.3 7-81 15-113 26-100.7 33-179.7 91-237 174-2.7
 5-6 9-10 13-.7 1-7.3 1-20 1H6z`,leftbraceunder:`M0 6l6-6h17c12.688 0 19.313.3 20 1 4 4 7.313 8.3 10 13
 35.313 51.3 80.813 93.8 136.5 127.5 55.688 33.7 117.188 55.8 184.5 66.5.688
 0 2 .3 4 1 18.688 2.7 76 4.3 172 5h399450v120H429l-6-1c-124.688-8-235-61.7
-331-161C60.687 138.7 32.312 99.3 7 54L0 41V6z`,leftgroup:`M400000 80
H435C64 80 168.3 229.4 21 260c-5.9 1.2-18 0-18 0-2 0-3-1-3-3v-38C76 61 257 0
 435 0h399565z`,leftgroupunder:`M400000 262
H435C64 262 168.3 112.6 21 82c-5.9-1.2-18 0-18 0-2 0-3 1-3 3v38c76 158 257 219
 435 219h399565z`,leftharpoon:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3
-3.3 10.2-9.5 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5
-18.3 3-21-1.3-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7
-196 228-6.7 4.7-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40z`,leftharpoonplus:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3-3.3 10.2-9.5
 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5-18.3 3-21-1.3
-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7-196 228-6.7 4.7
-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40zM0 435v40h400000v-40z
m0 0v40h400000v-40z`,leftharpoondown:`M7 241c-4 4-6.333 8.667-7 14 0 5.333.667 9 2 11s5.333
 5.333 12 10c90.667 54 156 130 196 228 3.333 10.667 6.333 16.333 9 17 2 .667 5
 1 9 1h5c10.667 0 16.667-2 18-6 2-2.667 1-9.667-3-21-32-87.333-82.667-157.667
-152-211l-3-3h399907v-40zM93 281 H400000 v-40L7 241z`,leftharpoondownplus:`M7 435c-4 4-6.3 8.7-7 14 0 5.3.7 9 2 11s5.3 5.3 12
 10c90.7 54 156 130 196 228 3.3 10.7 6.3 16.3 9 17 2 .7 5 1 9 1h5c10.7 0 16.7
-2 18-6 2-2.7 1-9.7-3-21-32-87.3-82.7-157.7-152-211l-3-3h399907v-40H7zm93 0
v40h399900v-40zM0 241v40h399900v-40zm0 0v40h399900v-40z`,lefthook:`M400000 281 H103s-33-11.2-61-33.5S0 197.3 0 164s14.2-61.2 42.5
-83.5C70.8 58.2 104 47 142 47 c16.7 0 25 6.7 25 20 0 12-8.7 18.7-26 20-40 3.3
-68.7 15.7-86 37-10 12-15 25.3-15 40 0 22.7 9.8 40.7 29.5 54 19.7 13.3 43.5 21
 71.5 23h399859zM103 281v-40h399897v40z`,leftlinesegment:`M40 281 V428 H0 V94 H40 V241 H400000 v40z
M40 281 V428 H0 V94 H40 V241 H400000 v40z`,leftmapsto:`M40 281 V448H0V74H40V241H400000v40z
M40 281 V448H0V74H40V241H400000v40z`,leftToFrom:`M0 147h400000v40H0zm0 214c68 40 115.7 95.7 143 167h22c15.3 0 23
-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69-70-101l-7-8h399905v-40H95l7-8
c28.7-32 52-65.7 70-101 10.7-23.3 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 265.3
 68 321 0 361zm0-174v-40h399900v40zm100 154v40h399900v-40z`,longequal:`M0 50 h400000 v40H0z m0 194h40000v40H0z
M0 50 h400000 v40H0z m0 194h40000v40H0z`,midbrace:`M200428 334
c-100.7-8.3-195.3-44-280-108-55.3-42-101.7-93-139-153l-9-14c-2.7 4-5.7 8.7-9 14
-53.3 86.7-123.7 153-211 199-66.7 36-137.3 56.3-212 62H0V214h199568c178.3-11.7
 311.7-78.3 403-201 6-8 9.7-12 11-12 .7-.7 6.7-1 18-1s17.3.3 18 1c1.3 0 5 4 11
 12 44.7 59.3 101.3 106.3 170 141s145.3 54.3 229 60h199572v120z`,midbraceunder:`M199572 214
c100.7 8.3 195.3 44 280 108 55.3 42 101.7 93 139 153l9 14c2.7-4 5.7-8.7 9-14
 53.3-86.7 123.7-153 211-199 66.7-36 137.3-56.3 212-62h199568v120H200432c-178.3
 11.7-311.7 78.3-403 201-6 8-9.7 12-11 12-.7.7-6.7 1-18 1s-17.3-.3-18-1c-1.3 0
-5-4-11-12-44.7-59.3-101.3-106.3-170-141s-145.3-54.3-229-60H0V214z`,oiintSize1:`M512.6 71.6c272.6 0 320.3 106.8 320.3 178.2 0 70.8-47.7 177.6
-320.3 177.6S193.1 320.6 193.1 249.8c0-71.4 46.9-178.2 319.5-178.2z
m368.1 178.2c0-86.4-60.9-215.4-368.1-215.4-306.4 0-367.3 129-367.3 215.4 0 85.8
60.9 214.8 367.3 214.8 307.2 0 368.1-129 368.1-214.8z`,oiintSize2:`M757.8 100.1c384.7 0 451.1 137.6 451.1 230 0 91.3-66.4 228.8
-451.1 228.8-386.3 0-452.7-137.5-452.7-228.8 0-92.4 66.4-230 452.7-230z
m502.4 230c0-111.2-82.4-277.2-502.4-277.2s-504 166-504 277.2
c0 110 84 276 504 276s502.4-166 502.4-276z`,oiiintSize1:`M681.4 71.6c408.9 0 480.5 106.8 480.5 178.2 0 70.8-71.6 177.6
-480.5 177.6S202.1 320.6 202.1 249.8c0-71.4 70.5-178.2 479.3-178.2z
m525.8 178.2c0-86.4-86.8-215.4-525.7-215.4-437.9 0-524.7 129-524.7 215.4 0
85.8 86.8 214.8 524.7 214.8 438.9 0 525.7-129 525.7-214.8z`,oiiintSize2:`M1021.2 53c603.6 0 707.8 165.8 707.8 277.2 0 110-104.2 275.8
-707.8 275.8-606 0-710.2-165.8-710.2-275.8C311 218.8 415.2 53 1021.2 53z
m770.4 277.1c0-131.2-126.4-327.6-770.5-327.6S248.4 198.9 248.4 330.1
c0 130 128.8 326.4 772.7 326.4s770.5-196.4 770.5-326.4z`,rightarrow:`M0 241v40h399891c-47.3 35.3-84 78-110 128
-16.7 32-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20
 11 8 0 13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7
 39-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85
-40.5-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
 151.7 139 205zm0 0v40h399900v-40z`,rightbrace:`M400000 542l
-6 6h-17c-12.7 0-19.3-.3-20-1-4-4-7.3-8.3-10-13-35.3-51.3-80.8-93.8-136.5-127.5
s-117.2-55.8-184.5-66.5c-.7 0-2-.3-4-1-18.7-2.7-76-4.3-172-5H0V214h399571l6 1
c124.7 8 235 61.7 331 161 31.3 33.3 59.7 72.7 85 118l7 13v35z`,rightbraceunder:`M399994 0l6 6v35l-6 11c-56 104-135.3 181.3-238 232-57.3
 28.7-117 45-179 50H-300V214h399897c43.3-7 81-15 113-26 100.7-33 179.7-91 237
-174 2.7-5 6-9 10-13 .7-1 7.3-1 20-1h17z`,rightgroup:`M0 80h399565c371 0 266.7 149.4 414 180 5.9 1.2 18 0 18 0 2 0
 3-1 3-3v-38c-76-158-257-219-435-219H0z`,rightgroupunder:`M0 262h399565c371 0 266.7-149.4 414-180 5.9-1.2 18 0 18
 0 2 0 3 1 3 3v38c-76 158-257 219-435 219H0z`,rightharpoon:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3
-3.7-15.3-11-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2
-10.7 0-16.7 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58
 69.2 92 94.5zm0 0v40h399900v-40z`,rightharpoonplus:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3-3.7-15.3-11
-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2-10.7 0-16.7
 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58 69.2 92 94.5z
m0 0v40h399900v-40z m100 194v40h399900v-40zm0 0v40h399900v-40z`,rightharpoondown:`M399747 511c0 7.3 6.7 11 20 11 8 0 13-.8 15-2.5s4.7-6.8
 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3 8.5-5.8 9.5
-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3-64.7 57-92 95
-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 241v40h399900v-40z`,rightharpoondownplus:`M399747 705c0 7.3 6.7 11 20 11 8 0 13-.8
 15-2.5s4.7-6.8 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3
 8.5-5.8 9.5-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3
-64.7 57-92 95-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 435v40h399900v-40z
m0-194v40h400000v-40zm0 0v40h400000v-40z`,righthook:`M399859 241c-764 0 0 0 0 0 40-3.3 68.7-15.7 86-37 10-12 15-25.3
 15-40 0-22.7-9.8-40.7-29.5-54-19.7-13.3-43.5-21-71.5-23-17.3-1.3-26-8-26-20 0
-13.3 8.7-20 26-20 38 0 71 11.2 99 33.5 0 0 7 5.6 21 16.7 14 11.2 21 33.5 21
 66.8s-14 61.2-42 83.5c-28 22.3-61 33.5-99 33.5L0 241z M0 281v-40h399859v40z`,rightlinesegment:`M399960 241 V94 h40 V428 h-40 V281 H0 v-40z
M399960 241 V94 h40 V428 h-40 V281 H0 v-40z`,rightToFrom:`M400000 167c-70.7-42-118-97.7-142-167h-23c-15.3 0-23 .3-23
 1 0 1.3 5.3 13.7 16 37 18 35.3 41.3 69 70 101l7 8H0v40h399905l-7 8c-28.7 32
-52 65.7-70 101-10.7 23.3-16 35.7-16 37 0 .7 7.7 1 23 1h23c24-69.3 71.3-125 142
-167z M100 147v40h399900v-40zM0 341v40h399900v-40z`,twoheadleftarrow:`M0 167c68 40
 115.7 95.7 143 167h22c15.3 0 23-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69
-70-101l-7-8h125l9 7c50.7 39.3 85 86 103 140h46c0-4.7-6.3-18.7-19-42-18-35.3
-40-67.3-66-96l-9-9h399716v-40H284l9-9c26-28.7 48-60.7 66-96 12.7-23.333 19
-37.333 19-42h-46c-18 54-52.3 100.7-103 140l-9 7H95l7-8c28.7-32 52-65.7 70-101
 10.7-23.333 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 71.3 68 127 0 167z`,twoheadrightarrow:`M400000 167
c-68-40-115.7-95.7-143-167h-22c-15.3 0-23 .3-23 1 0 1.3 5.3 13.7 16 37 18 35.3
 41.3 69 70 101l7 8h-125l-9-7c-50.7-39.3-85-86-103-140h-46c0 4.7 6.3 18.7 19 42
 18 35.3 40 67.3 66 96l9 9H0v40h399716l-9 9c-26 28.7-48 60.7-66 96-12.7 23.333
-19 37.333-19 42h46c18-54 52.3-100.7 103-140l9-7h125l-7 8c-28.7 32-52 65.7-70
 101-10.7 23.333-16 35.7-16 37 0 .7 7.7 1 23 1h22c27.3-71.3 75-127 143-167z`,tilde1:`M200 55.538c-77 0-168 73.953-177 73.953-3 0-7
-2.175-9-5.437L2 97c-1-2-2-4-2-6 0-4 2-7 5-9l20-12C116 12 171 0 207 0c86 0
 114 68 191 68 78 0 168-68 177-68 4 0 7 2 9 5l12 19c1 2.175 2 4.35 2 6.525 0
 4.35-2 7.613-5 9.788l-19 13.05c-92 63.077-116.937 75.308-183 76.128
-68.267.847-113-73.952-191-73.952z`,tilde2:`M344 55.266c-142 0-300.638 81.316-311.5 86.418
-8.01 3.762-22.5 10.91-23.5 5.562L1 120c-1-2-1-3-1-4 0-5 3-9 8-10l18.4-9C160.9
 31.9 283 0 358 0c148 0 188 122 331 122s314-97 326-97c4 0 8 2 10 7l7 21.114
c1 2.14 1 3.21 1 4.28 0 5.347-3 9.626-7 10.696l-22.3 12.622C852.6 158.372 751
 181.476 676 181.476c-149 0-189-126.21-332-126.21z`,tilde3:`M786 59C457 59 32 175.242 13 175.242c-6 0-10-3.457
-11-10.37L.15 138c-1-7 3-12 10-13l19.2-6.4C378.4 40.7 634.3 0 804.3 0c337 0
 411.8 157 746.8 157 328 0 754-112 773-112 5 0 10 3 11 9l1 14.075c1 8.066-.697
 16.595-6.697 17.492l-21.052 7.31c-367.9 98.146-609.15 122.696-778.15 122.696
 -338 0-409-156.573-744-156.573z`,tilde4:`M786 58C457 58 32 177.487 13 177.487c-6 0-10-3.345
-11-10.035L.15 143c-1-7 3-12 10-13l22-6.7C381.2 35 637.15 0 807.15 0c337 0 409
 177 744 177 328 0 754-127 773-127 5 0 10 3 11 9l1 14.794c1 7.805-3 13.38-9
 14.495l-20.7 5.574c-366.85 99.79-607.3 139.372-776.3 139.372-338 0-409
 -175.236-744-175.236z`,vec:`M377 20c0-5.333 1.833-10 5.5-14S391 0 397 0c4.667 0 8.667 1.667 12 5
3.333 2.667 6.667 9 10 19 6.667 24.667 20.333 43.667 41 57 7.333 4.667 11
10.667 11 18 0 6-1 10-3 12s-6.667 5-14 9c-28.667 14.667-53.667 35.667-75 63
-1.333 1.333-3.167 3.5-5.5 6.5s-4 4.833-5 5.5c-1 .667-2.5 1.333-4.5 2s-4.333 1
-7 1c-4.667 0-9.167-1.833-13.5-5.5S337 184 337 178c0-12.667 15.667-32.333 47-59
H213l-171-1c-8.667-6-13-12.333-13-19 0-4.667 4.333-11.333 13-20h359
c-16-25.333-24-45-24-59z`,widehat1:`M529 0h5l519 115c5 1 9 5 9 10 0 1-1 2-1 3l-4 22
c-1 5-5 9-11 9h-2L532 67 19 159h-2c-5 0-9-4-11-9l-5-22c-1-6 2-12 8-13z`,widehat2:`M1181 0h2l1171 176c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 220h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat3:`M1181 0h2l1171 236c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 280h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat4:`M1181 0h2l1171 296c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 340h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widecheck1:`M529,159h5l519,-115c5,-1,9,-5,9,-10c0,-1,-1,-2,-1,-3l-4,-22c-1,
-5,-5,-9,-11,-9h-2l-512,92l-513,-92h-2c-5,0,-9,4,-11,9l-5,22c-1,6,2,12,8,13z`,widecheck2:`M1181,220h2l1171,-176c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,153l-1167,-153h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck3:`M1181,280h2l1171,-236c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,213l-1167,-213h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck4:`M1181,340h2l1171,-296c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,273l-1167,-273h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,baraboveleftarrow:`M400000 620h-399890l3 -3c68.7 -52.7 113.7 -120 135 -202
c4 -14.7 6 -23 6 -25c0 -7.3 -7 -11 -21 -11c-8 0 -13.2 0.8 -15.5 2.5
c-2.3 1.7 -4.2 5.8 -5.5 12.5c-1.3 4.7 -2.7 10.3 -4 17c-12 48.7 -34.8 92 -68.5 130
s-74.2 66.3 -121.5 85c-10 4 -16 7.7 -18 11c0 8.7 6 14.3 18 17c47.3 18.7 87.8 47
121.5 85s56.5 81.3 68.5 130c0.7 2 1.3 5 2 9s1.2 6.7 1.5 8c0.3 1.3 1 3.3 2 6
s2.2 4.5 3.5 5.5c1.3 1 3.3 1.8 6 2.5s6 1 10 1c14 0 21 -3.7 21 -11
c0 -2 -2 -10.3 -6 -25c-20 -79.3 -65 -146.7 -135 -202l-3 -3h399890z
M100 620v40h399900v-40z M0 241v40h399900v-40zM0 241v40h399900v-40z`,rightarrowabovebar:`M0 241v40h399891c-47.3 35.3-84 78-110 128-16.7 32
-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20 11 8 0
13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7 39
-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85-40.5
-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
151.7 139 205zm96 379h399894v40H0zm0 0h399904v40H0z`,baraboveshortleftharpoon:`M507,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17
c2,0.7,5,1,9,1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21
c-32,-87.3,-82.7,-157.7,-152,-211c0,0,-3,-3,-3,-3l399351,0l0,-40
c-398570,0,-399437,0,-399437,0z M593 435 v40 H399500 v-40z
M0 281 v-40 H399908 v40z M0 281 v-40 H399908 v40z`,rightharpoonaboveshortbar:`M0,241 l0,40c399126,0,399993,0,399993,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M0 241 v40 H399908 v-40z M0 475 v-40 H399500 v40z M0 475 v-40 H399500 v40z`,shortbaraboveleftharpoon:`M7,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17c2,0.7,5,1,9,
1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21c-32,-87.3,-82.7,-157.7,
-152,-211c0,0,-3,-3,-3,-3l399907,0l0,-40c-399126,0,-399993,0,-399993,0z
M93 435 v40 H400000 v-40z M500 241 v40 H400000 v-40z M500 241 v40 H400000 v-40z`,shortrightharpoonabovebar:`M53,241l0,40c398570,0,399437,0,399437,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M500 241 v40 H399408 v-40z M500 435 v40 H400000 v-40z`};class Xn{constructor(e){this.children=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.children=e,this.classes=[],this.height=0,this.depth=0,this.maxFontSize=0,this.style={}}hasClass(e){return ht.contains(this.classes,e)}toNode(){for(var e=document.createDocumentFragment(),n=0;n<this.children.length;n++)e.appendChild(this.children[n].toNode());return e}toMarkup(){for(var e="",n=0;n<this.children.length;n++)e+=this.children[n].toMarkup();return e}toText(){return this.children.map(e=>e.toText()).join("")}}var _r=function(r){return r.filter(e=>e).join(" ")},wp=function(r,e,n){if(this.classes=r||[],this.attributes={},this.height=0,this.depth=0,this.maxFontSize=0,this.style=n||{},e){e.style.isTight()&&this.classes.push("mtight");var i=e.getColor();i&&(this.style.color=i)}},kp=function(r){var e=document.createElement(r);for(var n in e.className=_r(this.classes),this.style)this.style.hasOwnProperty(n)&&(e.style[n]=this.style[n]);for(var i in this.attributes)this.attributes.hasOwnProperty(i)&&e.setAttribute(i,this.attributes[i]);for(var t=0;t<this.children.length;t++)e.appendChild(this.children[t].toNode());return e},Ap=function(r){var e="<"+r;this.classes.length&&(e+=' class="'+ht.escape(_r(this.classes))+'"');var n="";for(var i in this.style)this.style.hasOwnProperty(i)&&(n+=ht.hyphenate(i)+":"+this.style[i]+";");for(var t in n&&(e+=' style="'+ht.escape(n)+'"'),this.attributes)this.attributes.hasOwnProperty(t)&&(e+=" "+t+'="'+ht.escape(this.attributes[t])+'"');e+=">";for(var l=0;l<this.children.length;l++)e+=this.children[l].toMarkup();return e+="</"+r+">"};class Yn{constructor(e,n,i,t){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.width=void 0,this.maxFontSize=void 0,this.style=void 0,wp.call(this,e,i,t),this.children=n||[]}setAttribute(e,n){this.attributes[e]=n}hasClass(e){return ht.contains(this.classes,e)}toNode(){return kp.call(this,"span")}toMarkup(){return Ap.call(this,"span")}}class xs{constructor(e,n,i,t){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,wp.call(this,n,t),this.children=i||[],this.setAttribute("href",e)}setAttribute(e,n){this.attributes[e]=n}hasClass(e){return ht.contains(this.classes,e)}toNode(){return kp.call(this,"a")}toMarkup(){return Ap.call(this,"a")}}class Kf{constructor(e,n,i){this.src=void 0,this.alt=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.alt=n,this.src=e,this.classes=["mord"],this.style=i}hasClass(e){return ht.contains(this.classes,e)}toNode(){var e=document.createElement("img");for(var n in e.src=this.src,e.alt=this.alt,e.className="mord",this.style)this.style.hasOwnProperty(n)&&(e.style[n]=this.style[n]);return e}toMarkup(){var e="<img  src='"+this.src+" 'alt='"+this.alt+"' ",n="";for(var i in this.style)this.style.hasOwnProperty(i)&&(n+=ht.hyphenate(i)+":"+this.style[i]+";");return n&&(e+=' style="'+ht.escape(n)+'"'),e+="'/>"}}var tg={î:"ı̂",ï:"ı̈",í:"ı́",ì:"ı̀"};class Oe{constructor(e,n,i,t,l,h,p,m){this.text=void 0,this.height=void 0,this.depth=void 0,this.italic=void 0,this.skew=void 0,this.width=void 0,this.maxFontSize=void 0,this.classes=void 0,this.style=void 0,this.text=e,this.height=n||0,this.depth=i||0,this.italic=t||0,this.skew=l||0,this.width=h||0,this.classes=p||[],this.style=m||{},this.maxFontSize=0;var y=function(_){for(var S=0;S<Ga.length;S++)for(var E=Ga[S],R=0;R<E.blocks.length;R++){var I=E.blocks[R];if(_>=I[0]&&_<=I[1])return E.name}return null}(this.text.charCodeAt(0));y&&this.classes.push(y+"_fallback"),/[îïíì]/.test(this.text)&&(this.text=tg[this.text])}hasClass(e){return ht.contains(this.classes,e)}toNode(){var e=document.createTextNode(this.text),n=null;for(var i in this.italic>0&&((n=document.createElement("span")).style.marginRight=this.italic+"em"),this.classes.length>0&&((n=n||document.createElement("span")).className=_r(this.classes)),this.style)this.style.hasOwnProperty(i)&&((n=n||document.createElement("span")).style[i]=this.style[i]);return n?(n.appendChild(e),n):e}toMarkup(){var e=!1,n="<span";this.classes.length&&(e=!0,n+=' class="',n+=ht.escape(_r(this.classes)),n+='"');var i="";for(var t in this.italic>0&&(i+="margin-right:"+this.italic+"em;"),this.style)this.style.hasOwnProperty(t)&&(i+=ht.hyphenate(t)+":"+this.style[t]+";");i&&(e=!0,n+=' style="'+ht.escape(i)+'"');var l=ht.escape(this.text);return e?(n+=">",n+=l,n+="</span>"):l}}class Sr{constructor(e,n){this.children=void 0,this.attributes=void 0,this.children=e||[],this.attributes=n||{}}toNode(){var e=document.createElementNS("http://www.w3.org/2000/svg","svg");for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&e.setAttribute(n,this.attributes[n]);for(var i=0;i<this.children.length;i++)e.appendChild(this.children[i].toNode());return e}toMarkup(){var e='<svg xmlns="http://www.w3.org/2000/svg"';for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(e+=" "+n+"='"+this.attributes[n]+"'");e+=">";for(var i=0;i<this.children.length;i++)e+=this.children[i].toMarkup();return e+="</svg>"}}class Hr{constructor(e,n){this.pathName=void 0,this.alternate=void 0,this.pathName=e,this.alternate=n}toNode(){var e=document.createElementNS("http://www.w3.org/2000/svg","path");return this.alternate?e.setAttribute("d",this.alternate):e.setAttribute("d",zc[this.pathName]),e}toMarkup(){return this.alternate?"<path d='"+this.alternate+"'/>":"<path d='"+zc[this.pathName]+"'/>"}}class Ua{constructor(e){this.attributes=void 0,this.attributes=e||{}}toNode(){var e=document.createElementNS("http://www.w3.org/2000/svg","line");for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&e.setAttribute(n,this.attributes[n]);return e}toMarkup(){var e="<line";for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(e+=" "+n+"='"+this.attributes[n]+"'");return e+="/>"}}function Tc(r){if(r instanceof Oe)return r;throw new Error("Expected symbolNode but got "+String(r)+".")}var Ke={"AMS-Regular":{32:[0,0,0,0,.25],65:[0,.68889,0,0,.72222],66:[0,.68889,0,0,.66667],67:[0,.68889,0,0,.72222],68:[0,.68889,0,0,.72222],69:[0,.68889,0,0,.66667],70:[0,.68889,0,0,.61111],71:[0,.68889,0,0,.77778],72:[0,.68889,0,0,.77778],73:[0,.68889,0,0,.38889],74:[.16667,.68889,0,0,.5],75:[0,.68889,0,0,.77778],76:[0,.68889,0,0,.66667],77:[0,.68889,0,0,.94445],78:[0,.68889,0,0,.72222],79:[.16667,.68889,0,0,.77778],80:[0,.68889,0,0,.61111],81:[.16667,.68889,0,0,.77778],82:[0,.68889,0,0,.72222],83:[0,.68889,0,0,.55556],84:[0,.68889,0,0,.66667],85:[0,.68889,0,0,.72222],86:[0,.68889,0,0,.72222],87:[0,.68889,0,0,1],88:[0,.68889,0,0,.72222],89:[0,.68889,0,0,.72222],90:[0,.68889,0,0,.66667],107:[0,.68889,0,0,.55556],160:[0,0,0,0,.25],165:[0,.675,.025,0,.75],174:[.15559,.69224,0,0,.94666],240:[0,.68889,0,0,.55556],295:[0,.68889,0,0,.54028],710:[0,.825,0,0,2.33334],732:[0,.9,0,0,2.33334],770:[0,.825,0,0,2.33334],771:[0,.9,0,0,2.33334],989:[.08167,.58167,0,0,.77778],1008:[0,.43056,.04028,0,.66667],8245:[0,.54986,0,0,.275],8463:[0,.68889,0,0,.54028],8487:[0,.68889,0,0,.72222],8498:[0,.68889,0,0,.55556],8502:[0,.68889,0,0,.66667],8503:[0,.68889,0,0,.44445],8504:[0,.68889,0,0,.66667],8513:[0,.68889,0,0,.63889],8592:[-.03598,.46402,0,0,.5],8594:[-.03598,.46402,0,0,.5],8602:[-.13313,.36687,0,0,1],8603:[-.13313,.36687,0,0,1],8606:[.01354,.52239,0,0,1],8608:[.01354,.52239,0,0,1],8610:[.01354,.52239,0,0,1.11111],8611:[.01354,.52239,0,0,1.11111],8619:[0,.54986,0,0,1],8620:[0,.54986,0,0,1],8621:[-.13313,.37788,0,0,1.38889],8622:[-.13313,.36687,0,0,1],8624:[0,.69224,0,0,.5],8625:[0,.69224,0,0,.5],8630:[0,.43056,0,0,1],8631:[0,.43056,0,0,1],8634:[.08198,.58198,0,0,.77778],8635:[.08198,.58198,0,0,.77778],8638:[.19444,.69224,0,0,.41667],8639:[.19444,.69224,0,0,.41667],8642:[.19444,.69224,0,0,.41667],8643:[.19444,.69224,0,0,.41667],8644:[.1808,.675,0,0,1],8646:[.1808,.675,0,0,1],8647:[.1808,.675,0,0,1],8648:[.19444,.69224,0,0,.83334],8649:[.1808,.675,0,0,1],8650:[.19444,.69224,0,0,.83334],8651:[.01354,.52239,0,0,1],8652:[.01354,.52239,0,0,1],8653:[-.13313,.36687,0,0,1],8654:[-.13313,.36687,0,0,1],8655:[-.13313,.36687,0,0,1],8666:[.13667,.63667,0,0,1],8667:[.13667,.63667,0,0,1],8669:[-.13313,.37788,0,0,1],8672:[-.064,.437,0,0,1.334],8674:[-.064,.437,0,0,1.334],8705:[0,.825,0,0,.5],8708:[0,.68889,0,0,.55556],8709:[.08167,.58167,0,0,.77778],8717:[0,.43056,0,0,.42917],8722:[-.03598,.46402,0,0,.5],8724:[.08198,.69224,0,0,.77778],8726:[.08167,.58167,0,0,.77778],8733:[0,.69224,0,0,.77778],8736:[0,.69224,0,0,.72222],8737:[0,.69224,0,0,.72222],8738:[.03517,.52239,0,0,.72222],8739:[.08167,.58167,0,0,.22222],8740:[.25142,.74111,0,0,.27778],8741:[.08167,.58167,0,0,.38889],8742:[.25142,.74111,0,0,.5],8756:[0,.69224,0,0,.66667],8757:[0,.69224,0,0,.66667],8764:[-.13313,.36687,0,0,.77778],8765:[-.13313,.37788,0,0,.77778],8769:[-.13313,.36687,0,0,.77778],8770:[-.03625,.46375,0,0,.77778],8774:[.30274,.79383,0,0,.77778],8776:[-.01688,.48312,0,0,.77778],8778:[.08167,.58167,0,0,.77778],8782:[.06062,.54986,0,0,.77778],8783:[.06062,.54986,0,0,.77778],8785:[.08198,.58198,0,0,.77778],8786:[.08198,.58198,0,0,.77778],8787:[.08198,.58198,0,0,.77778],8790:[0,.69224,0,0,.77778],8791:[.22958,.72958,0,0,.77778],8796:[.08198,.91667,0,0,.77778],8806:[.25583,.75583,0,0,.77778],8807:[.25583,.75583,0,0,.77778],8808:[.25142,.75726,0,0,.77778],8809:[.25142,.75726,0,0,.77778],8812:[.25583,.75583,0,0,.5],8814:[.20576,.70576,0,0,.77778],8815:[.20576,.70576,0,0,.77778],8816:[.30274,.79383,0,0,.77778],8817:[.30274,.79383,0,0,.77778],8818:[.22958,.72958,0,0,.77778],8819:[.22958,.72958,0,0,.77778],8822:[.1808,.675,0,0,.77778],8823:[.1808,.675,0,0,.77778],8828:[.13667,.63667,0,0,.77778],8829:[.13667,.63667,0,0,.77778],8830:[.22958,.72958,0,0,.77778],8831:[.22958,.72958,0,0,.77778],8832:[.20576,.70576,0,0,.77778],8833:[.20576,.70576,0,0,.77778],8840:[.30274,.79383,0,0,.77778],8841:[.30274,.79383,0,0,.77778],8842:[.13597,.63597,0,0,.77778],8843:[.13597,.63597,0,0,.77778],8847:[.03517,.54986,0,0,.77778],8848:[.03517,.54986,0,0,.77778],8858:[.08198,.58198,0,0,.77778],8859:[.08198,.58198,0,0,.77778],8861:[.08198,.58198,0,0,.77778],8862:[0,.675,0,0,.77778],8863:[0,.675,0,0,.77778],8864:[0,.675,0,0,.77778],8865:[0,.675,0,0,.77778],8872:[0,.69224,0,0,.61111],8873:[0,.69224,0,0,.72222],8874:[0,.69224,0,0,.88889],8876:[0,.68889,0,0,.61111],8877:[0,.68889,0,0,.61111],8878:[0,.68889,0,0,.72222],8879:[0,.68889,0,0,.72222],8882:[.03517,.54986,0,0,.77778],8883:[.03517,.54986,0,0,.77778],8884:[.13667,.63667,0,0,.77778],8885:[.13667,.63667,0,0,.77778],8888:[0,.54986,0,0,1.11111],8890:[.19444,.43056,0,0,.55556],8891:[.19444,.69224,0,0,.61111],8892:[.19444,.69224,0,0,.61111],8901:[0,.54986,0,0,.27778],8903:[.08167,.58167,0,0,.77778],8905:[.08167,.58167,0,0,.77778],8906:[.08167,.58167,0,0,.77778],8907:[0,.69224,0,0,.77778],8908:[0,.69224,0,0,.77778],8909:[-.03598,.46402,0,0,.77778],8910:[0,.54986,0,0,.76042],8911:[0,.54986,0,0,.76042],8912:[.03517,.54986,0,0,.77778],8913:[.03517,.54986,0,0,.77778],8914:[0,.54986,0,0,.66667],8915:[0,.54986,0,0,.66667],8916:[0,.69224,0,0,.66667],8918:[.0391,.5391,0,0,.77778],8919:[.0391,.5391,0,0,.77778],8920:[.03517,.54986,0,0,1.33334],8921:[.03517,.54986,0,0,1.33334],8922:[.38569,.88569,0,0,.77778],8923:[.38569,.88569,0,0,.77778],8926:[.13667,.63667,0,0,.77778],8927:[.13667,.63667,0,0,.77778],8928:[.30274,.79383,0,0,.77778],8929:[.30274,.79383,0,0,.77778],8934:[.23222,.74111,0,0,.77778],8935:[.23222,.74111,0,0,.77778],8936:[.23222,.74111,0,0,.77778],8937:[.23222,.74111,0,0,.77778],8938:[.20576,.70576,0,0,.77778],8939:[.20576,.70576,0,0,.77778],8940:[.30274,.79383,0,0,.77778],8941:[.30274,.79383,0,0,.77778],8994:[.19444,.69224,0,0,.77778],8995:[.19444,.69224,0,0,.77778],9416:[.15559,.69224,0,0,.90222],9484:[0,.69224,0,0,.5],9488:[0,.69224,0,0,.5],9492:[0,.37788,0,0,.5],9496:[0,.37788,0,0,.5],9585:[.19444,.68889,0,0,.88889],9586:[.19444,.74111,0,0,.88889],9632:[0,.675,0,0,.77778],9633:[0,.675,0,0,.77778],9650:[0,.54986,0,0,.72222],9651:[0,.54986,0,0,.72222],9654:[.03517,.54986,0,0,.77778],9660:[0,.54986,0,0,.72222],9661:[0,.54986,0,0,.72222],9664:[.03517,.54986,0,0,.77778],9674:[.11111,.69224,0,0,.66667],9733:[.19444,.69224,0,0,.94445],10003:[0,.69224,0,0,.83334],10016:[0,.69224,0,0,.83334],10731:[.11111,.69224,0,0,.66667],10846:[.19444,.75583,0,0,.61111],10877:[.13667,.63667,0,0,.77778],10878:[.13667,.63667,0,0,.77778],10885:[.25583,.75583,0,0,.77778],10886:[.25583,.75583,0,0,.77778],10887:[.13597,.63597,0,0,.77778],10888:[.13597,.63597,0,0,.77778],10889:[.26167,.75726,0,0,.77778],10890:[.26167,.75726,0,0,.77778],10891:[.48256,.98256,0,0,.77778],10892:[.48256,.98256,0,0,.77778],10901:[.13667,.63667,0,0,.77778],10902:[.13667,.63667,0,0,.77778],10933:[.25142,.75726,0,0,.77778],10934:[.25142,.75726,0,0,.77778],10935:[.26167,.75726,0,0,.77778],10936:[.26167,.75726,0,0,.77778],10937:[.26167,.75726,0,0,.77778],10938:[.26167,.75726,0,0,.77778],10949:[.25583,.75583,0,0,.77778],10950:[.25583,.75583,0,0,.77778],10955:[.28481,.79383,0,0,.77778],10956:[.28481,.79383,0,0,.77778],57350:[.08167,.58167,0,0,.22222],57351:[.08167,.58167,0,0,.38889],57352:[.08167,.58167,0,0,.77778],57353:[0,.43056,.04028,0,.66667],57356:[.25142,.75726,0,0,.77778],57357:[.25142,.75726,0,0,.77778],57358:[.41951,.91951,0,0,.77778],57359:[.30274,.79383,0,0,.77778],57360:[.30274,.79383,0,0,.77778],57361:[.41951,.91951,0,0,.77778],57366:[.25142,.75726,0,0,.77778],57367:[.25142,.75726,0,0,.77778],57368:[.25142,.75726,0,0,.77778],57369:[.25142,.75726,0,0,.77778],57370:[.13597,.63597,0,0,.77778],57371:[.13597,.63597,0,0,.77778]},"Caligraphic-Regular":{32:[0,0,0,0,.25],65:[0,.68333,0,.19445,.79847],66:[0,.68333,.03041,.13889,.65681],67:[0,.68333,.05834,.13889,.52653],68:[0,.68333,.02778,.08334,.77139],69:[0,.68333,.08944,.11111,.52778],70:[0,.68333,.09931,.11111,.71875],71:[.09722,.68333,.0593,.11111,.59487],72:[0,.68333,.00965,.11111,.84452],73:[0,.68333,.07382,0,.54452],74:[.09722,.68333,.18472,.16667,.67778],75:[0,.68333,.01445,.05556,.76195],76:[0,.68333,0,.13889,.68972],77:[0,.68333,0,.13889,1.2009],78:[0,.68333,.14736,.08334,.82049],79:[0,.68333,.02778,.11111,.79611],80:[0,.68333,.08222,.08334,.69556],81:[.09722,.68333,0,.11111,.81667],82:[0,.68333,0,.08334,.8475],83:[0,.68333,.075,.13889,.60556],84:[0,.68333,.25417,0,.54464],85:[0,.68333,.09931,.08334,.62583],86:[0,.68333,.08222,0,.61278],87:[0,.68333,.08222,.08334,.98778],88:[0,.68333,.14643,.13889,.7133],89:[.09722,.68333,.08222,.08334,.66834],90:[0,.68333,.07944,.13889,.72473],160:[0,0,0,0,.25]},"Fraktur-Regular":{32:[0,0,0,0,.25],33:[0,.69141,0,0,.29574],34:[0,.69141,0,0,.21471],38:[0,.69141,0,0,.73786],39:[0,.69141,0,0,.21201],40:[.24982,.74947,0,0,.38865],41:[.24982,.74947,0,0,.38865],42:[0,.62119,0,0,.27764],43:[.08319,.58283,0,0,.75623],44:[0,.10803,0,0,.27764],45:[.08319,.58283,0,0,.75623],46:[0,.10803,0,0,.27764],47:[.24982,.74947,0,0,.50181],48:[0,.47534,0,0,.50181],49:[0,.47534,0,0,.50181],50:[0,.47534,0,0,.50181],51:[.18906,.47534,0,0,.50181],52:[.18906,.47534,0,0,.50181],53:[.18906,.47534,0,0,.50181],54:[0,.69141,0,0,.50181],55:[.18906,.47534,0,0,.50181],56:[0,.69141,0,0,.50181],57:[.18906,.47534,0,0,.50181],58:[0,.47534,0,0,.21606],59:[.12604,.47534,0,0,.21606],61:[-.13099,.36866,0,0,.75623],63:[0,.69141,0,0,.36245],65:[0,.69141,0,0,.7176],66:[0,.69141,0,0,.88397],67:[0,.69141,0,0,.61254],68:[0,.69141,0,0,.83158],69:[0,.69141,0,0,.66278],70:[.12604,.69141,0,0,.61119],71:[0,.69141,0,0,.78539],72:[.06302,.69141,0,0,.7203],73:[0,.69141,0,0,.55448],74:[.12604,.69141,0,0,.55231],75:[0,.69141,0,0,.66845],76:[0,.69141,0,0,.66602],77:[0,.69141,0,0,1.04953],78:[0,.69141,0,0,.83212],79:[0,.69141,0,0,.82699],80:[.18906,.69141,0,0,.82753],81:[.03781,.69141,0,0,.82699],82:[0,.69141,0,0,.82807],83:[0,.69141,0,0,.82861],84:[0,.69141,0,0,.66899],85:[0,.69141,0,0,.64576],86:[0,.69141,0,0,.83131],87:[0,.69141,0,0,1.04602],88:[0,.69141,0,0,.71922],89:[.18906,.69141,0,0,.83293],90:[.12604,.69141,0,0,.60201],91:[.24982,.74947,0,0,.27764],93:[.24982,.74947,0,0,.27764],94:[0,.69141,0,0,.49965],97:[0,.47534,0,0,.50046],98:[0,.69141,0,0,.51315],99:[0,.47534,0,0,.38946],100:[0,.62119,0,0,.49857],101:[0,.47534,0,0,.40053],102:[.18906,.69141,0,0,.32626],103:[.18906,.47534,0,0,.5037],104:[.18906,.69141,0,0,.52126],105:[0,.69141,0,0,.27899],106:[0,.69141,0,0,.28088],107:[0,.69141,0,0,.38946],108:[0,.69141,0,0,.27953],109:[0,.47534,0,0,.76676],110:[0,.47534,0,0,.52666],111:[0,.47534,0,0,.48885],112:[.18906,.52396,0,0,.50046],113:[.18906,.47534,0,0,.48912],114:[0,.47534,0,0,.38919],115:[0,.47534,0,0,.44266],116:[0,.62119,0,0,.33301],117:[0,.47534,0,0,.5172],118:[0,.52396,0,0,.5118],119:[0,.52396,0,0,.77351],120:[.18906,.47534,0,0,.38865],121:[.18906,.47534,0,0,.49884],122:[.18906,.47534,0,0,.39054],160:[0,0,0,0,.25],8216:[0,.69141,0,0,.21471],8217:[0,.69141,0,0,.21471],58112:[0,.62119,0,0,.49749],58113:[0,.62119,0,0,.4983],58114:[.18906,.69141,0,0,.33328],58115:[.18906,.69141,0,0,.32923],58116:[.18906,.47534,0,0,.50343],58117:[0,.69141,0,0,.33301],58118:[0,.62119,0,0,.33409],58119:[0,.47534,0,0,.50073]},"Main-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.35],34:[0,.69444,0,0,.60278],35:[.19444,.69444,0,0,.95833],36:[.05556,.75,0,0,.575],37:[.05556,.75,0,0,.95833],38:[0,.69444,0,0,.89444],39:[0,.69444,0,0,.31944],40:[.25,.75,0,0,.44722],41:[.25,.75,0,0,.44722],42:[0,.75,0,0,.575],43:[.13333,.63333,0,0,.89444],44:[.19444,.15556,0,0,.31944],45:[0,.44444,0,0,.38333],46:[0,.15556,0,0,.31944],47:[.25,.75,0,0,.575],48:[0,.64444,0,0,.575],49:[0,.64444,0,0,.575],50:[0,.64444,0,0,.575],51:[0,.64444,0,0,.575],52:[0,.64444,0,0,.575],53:[0,.64444,0,0,.575],54:[0,.64444,0,0,.575],55:[0,.64444,0,0,.575],56:[0,.64444,0,0,.575],57:[0,.64444,0,0,.575],58:[0,.44444,0,0,.31944],59:[.19444,.44444,0,0,.31944],60:[.08556,.58556,0,0,.89444],61:[-.10889,.39111,0,0,.89444],62:[.08556,.58556,0,0,.89444],63:[0,.69444,0,0,.54305],64:[0,.69444,0,0,.89444],65:[0,.68611,0,0,.86944],66:[0,.68611,0,0,.81805],67:[0,.68611,0,0,.83055],68:[0,.68611,0,0,.88194],69:[0,.68611,0,0,.75555],70:[0,.68611,0,0,.72361],71:[0,.68611,0,0,.90416],72:[0,.68611,0,0,.9],73:[0,.68611,0,0,.43611],74:[0,.68611,0,0,.59444],75:[0,.68611,0,0,.90138],76:[0,.68611,0,0,.69166],77:[0,.68611,0,0,1.09166],78:[0,.68611,0,0,.9],79:[0,.68611,0,0,.86388],80:[0,.68611,0,0,.78611],81:[.19444,.68611,0,0,.86388],82:[0,.68611,0,0,.8625],83:[0,.68611,0,0,.63889],84:[0,.68611,0,0,.8],85:[0,.68611,0,0,.88472],86:[0,.68611,.01597,0,.86944],87:[0,.68611,.01597,0,1.18888],88:[0,.68611,0,0,.86944],89:[0,.68611,.02875,0,.86944],90:[0,.68611,0,0,.70277],91:[.25,.75,0,0,.31944],92:[.25,.75,0,0,.575],93:[.25,.75,0,0,.31944],94:[0,.69444,0,0,.575],95:[.31,.13444,.03194,0,.575],97:[0,.44444,0,0,.55902],98:[0,.69444,0,0,.63889],99:[0,.44444,0,0,.51111],100:[0,.69444,0,0,.63889],101:[0,.44444,0,0,.52708],102:[0,.69444,.10903,0,.35139],103:[.19444,.44444,.01597,0,.575],104:[0,.69444,0,0,.63889],105:[0,.69444,0,0,.31944],106:[.19444,.69444,0,0,.35139],107:[0,.69444,0,0,.60694],108:[0,.69444,0,0,.31944],109:[0,.44444,0,0,.95833],110:[0,.44444,0,0,.63889],111:[0,.44444,0,0,.575],112:[.19444,.44444,0,0,.63889],113:[.19444,.44444,0,0,.60694],114:[0,.44444,0,0,.47361],115:[0,.44444,0,0,.45361],116:[0,.63492,0,0,.44722],117:[0,.44444,0,0,.63889],118:[0,.44444,.01597,0,.60694],119:[0,.44444,.01597,0,.83055],120:[0,.44444,0,0,.60694],121:[.19444,.44444,.01597,0,.60694],122:[0,.44444,0,0,.51111],123:[.25,.75,0,0,.575],124:[.25,.75,0,0,.31944],125:[.25,.75,0,0,.575],126:[.35,.34444,0,0,.575],160:[0,0,0,0,.25],163:[0,.69444,0,0,.86853],168:[0,.69444,0,0,.575],172:[0,.44444,0,0,.76666],176:[0,.69444,0,0,.86944],177:[.13333,.63333,0,0,.89444],184:[.17014,0,0,0,.51111],198:[0,.68611,0,0,1.04166],215:[.13333,.63333,0,0,.89444],216:[.04861,.73472,0,0,.89444],223:[0,.69444,0,0,.59722],230:[0,.44444,0,0,.83055],247:[.13333,.63333,0,0,.89444],248:[.09722,.54167,0,0,.575],305:[0,.44444,0,0,.31944],338:[0,.68611,0,0,1.16944],339:[0,.44444,0,0,.89444],567:[.19444,.44444,0,0,.35139],710:[0,.69444,0,0,.575],711:[0,.63194,0,0,.575],713:[0,.59611,0,0,.575],714:[0,.69444,0,0,.575],715:[0,.69444,0,0,.575],728:[0,.69444,0,0,.575],729:[0,.69444,0,0,.31944],730:[0,.69444,0,0,.86944],732:[0,.69444,0,0,.575],733:[0,.69444,0,0,.575],915:[0,.68611,0,0,.69166],916:[0,.68611,0,0,.95833],920:[0,.68611,0,0,.89444],923:[0,.68611,0,0,.80555],926:[0,.68611,0,0,.76666],928:[0,.68611,0,0,.9],931:[0,.68611,0,0,.83055],933:[0,.68611,0,0,.89444],934:[0,.68611,0,0,.83055],936:[0,.68611,0,0,.89444],937:[0,.68611,0,0,.83055],8211:[0,.44444,.03194,0,.575],8212:[0,.44444,.03194,0,1.14999],8216:[0,.69444,0,0,.31944],8217:[0,.69444,0,0,.31944],8220:[0,.69444,0,0,.60278],8221:[0,.69444,0,0,.60278],8224:[.19444,.69444,0,0,.51111],8225:[.19444,.69444,0,0,.51111],8242:[0,.55556,0,0,.34444],8407:[0,.72444,.15486,0,.575],8463:[0,.69444,0,0,.66759],8465:[0,.69444,0,0,.83055],8467:[0,.69444,0,0,.47361],8472:[.19444,.44444,0,0,.74027],8476:[0,.69444,0,0,.83055],8501:[0,.69444,0,0,.70277],8592:[-.10889,.39111,0,0,1.14999],8593:[.19444,.69444,0,0,.575],8594:[-.10889,.39111,0,0,1.14999],8595:[.19444,.69444,0,0,.575],8596:[-.10889,.39111,0,0,1.14999],8597:[.25,.75,0,0,.575],8598:[.19444,.69444,0,0,1.14999],8599:[.19444,.69444,0,0,1.14999],8600:[.19444,.69444,0,0,1.14999],8601:[.19444,.69444,0,0,1.14999],8636:[-.10889,.39111,0,0,1.14999],8637:[-.10889,.39111,0,0,1.14999],8640:[-.10889,.39111,0,0,1.14999],8641:[-.10889,.39111,0,0,1.14999],8656:[-.10889,.39111,0,0,1.14999],8657:[.19444,.69444,0,0,.70277],8658:[-.10889,.39111,0,0,1.14999],8659:[.19444,.69444,0,0,.70277],8660:[-.10889,.39111,0,0,1.14999],8661:[.25,.75,0,0,.70277],8704:[0,.69444,0,0,.63889],8706:[0,.69444,.06389,0,.62847],8707:[0,.69444,0,0,.63889],8709:[.05556,.75,0,0,.575],8711:[0,.68611,0,0,.95833],8712:[.08556,.58556,0,0,.76666],8715:[.08556,.58556,0,0,.76666],8722:[.13333,.63333,0,0,.89444],8723:[.13333,.63333,0,0,.89444],8725:[.25,.75,0,0,.575],8726:[.25,.75,0,0,.575],8727:[-.02778,.47222,0,0,.575],8728:[-.02639,.47361,0,0,.575],8729:[-.02639,.47361,0,0,.575],8730:[.18,.82,0,0,.95833],8733:[0,.44444,0,0,.89444],8734:[0,.44444,0,0,1.14999],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.31944],8741:[.25,.75,0,0,.575],8743:[0,.55556,0,0,.76666],8744:[0,.55556,0,0,.76666],8745:[0,.55556,0,0,.76666],8746:[0,.55556,0,0,.76666],8747:[.19444,.69444,.12778,0,.56875],8764:[-.10889,.39111,0,0,.89444],8768:[.19444,.69444,0,0,.31944],8771:[.00222,.50222,0,0,.89444],8776:[.02444,.52444,0,0,.89444],8781:[.00222,.50222,0,0,.89444],8801:[.00222,.50222,0,0,.89444],8804:[.19667,.69667,0,0,.89444],8805:[.19667,.69667,0,0,.89444],8810:[.08556,.58556,0,0,1.14999],8811:[.08556,.58556,0,0,1.14999],8826:[.08556,.58556,0,0,.89444],8827:[.08556,.58556,0,0,.89444],8834:[.08556,.58556,0,0,.89444],8835:[.08556,.58556,0,0,.89444],8838:[.19667,.69667,0,0,.89444],8839:[.19667,.69667,0,0,.89444],8846:[0,.55556,0,0,.76666],8849:[.19667,.69667,0,0,.89444],8850:[.19667,.69667,0,0,.89444],8851:[0,.55556,0,0,.76666],8852:[0,.55556,0,0,.76666],8853:[.13333,.63333,0,0,.89444],8854:[.13333,.63333,0,0,.89444],8855:[.13333,.63333,0,0,.89444],8856:[.13333,.63333,0,0,.89444],8857:[.13333,.63333,0,0,.89444],8866:[0,.69444,0,0,.70277],8867:[0,.69444,0,0,.70277],8868:[0,.69444,0,0,.89444],8869:[0,.69444,0,0,.89444],8900:[-.02639,.47361,0,0,.575],8901:[-.02639,.47361,0,0,.31944],8902:[-.02778,.47222,0,0,.575],8968:[.25,.75,0,0,.51111],8969:[.25,.75,0,0,.51111],8970:[.25,.75,0,0,.51111],8971:[.25,.75,0,0,.51111],8994:[-.13889,.36111,0,0,1.14999],8995:[-.13889,.36111,0,0,1.14999],9651:[.19444,.69444,0,0,1.02222],9657:[-.02778,.47222,0,0,.575],9661:[.19444,.69444,0,0,1.02222],9667:[-.02778,.47222,0,0,.575],9711:[.19444,.69444,0,0,1.14999],9824:[.12963,.69444,0,0,.89444],9825:[.12963,.69444,0,0,.89444],9826:[.12963,.69444,0,0,.89444],9827:[.12963,.69444,0,0,.89444],9837:[0,.75,0,0,.44722],9838:[.19444,.69444,0,0,.44722],9839:[.19444,.69444,0,0,.44722],10216:[.25,.75,0,0,.44722],10217:[.25,.75,0,0,.44722],10815:[0,.68611,0,0,.9],10927:[.19667,.69667,0,0,.89444],10928:[.19667,.69667,0,0,.89444],57376:[.19444,.69444,0,0,0]},"Main-BoldItalic":{32:[0,0,0,0,.25],33:[0,.69444,.11417,0,.38611],34:[0,.69444,.07939,0,.62055],35:[.19444,.69444,.06833,0,.94444],37:[.05556,.75,.12861,0,.94444],38:[0,.69444,.08528,0,.88555],39:[0,.69444,.12945,0,.35555],40:[.25,.75,.15806,0,.47333],41:[.25,.75,.03306,0,.47333],42:[0,.75,.14333,0,.59111],43:[.10333,.60333,.03306,0,.88555],44:[.19444,.14722,0,0,.35555],45:[0,.44444,.02611,0,.41444],46:[0,.14722,0,0,.35555],47:[.25,.75,.15806,0,.59111],48:[0,.64444,.13167,0,.59111],49:[0,.64444,.13167,0,.59111],50:[0,.64444,.13167,0,.59111],51:[0,.64444,.13167,0,.59111],52:[.19444,.64444,.13167,0,.59111],53:[0,.64444,.13167,0,.59111],54:[0,.64444,.13167,0,.59111],55:[.19444,.64444,.13167,0,.59111],56:[0,.64444,.13167,0,.59111],57:[0,.64444,.13167,0,.59111],58:[0,.44444,.06695,0,.35555],59:[.19444,.44444,.06695,0,.35555],61:[-.10889,.39111,.06833,0,.88555],63:[0,.69444,.11472,0,.59111],64:[0,.69444,.09208,0,.88555],65:[0,.68611,0,0,.86555],66:[0,.68611,.0992,0,.81666],67:[0,.68611,.14208,0,.82666],68:[0,.68611,.09062,0,.87555],69:[0,.68611,.11431,0,.75666],70:[0,.68611,.12903,0,.72722],71:[0,.68611,.07347,0,.89527],72:[0,.68611,.17208,0,.8961],73:[0,.68611,.15681,0,.47166],74:[0,.68611,.145,0,.61055],75:[0,.68611,.14208,0,.89499],76:[0,.68611,0,0,.69777],77:[0,.68611,.17208,0,1.07277],78:[0,.68611,.17208,0,.8961],79:[0,.68611,.09062,0,.85499],80:[0,.68611,.0992,0,.78721],81:[.19444,.68611,.09062,0,.85499],82:[0,.68611,.02559,0,.85944],83:[0,.68611,.11264,0,.64999],84:[0,.68611,.12903,0,.7961],85:[0,.68611,.17208,0,.88083],86:[0,.68611,.18625,0,.86555],87:[0,.68611,.18625,0,1.15999],88:[0,.68611,.15681,0,.86555],89:[0,.68611,.19803,0,.86555],90:[0,.68611,.14208,0,.70888],91:[.25,.75,.1875,0,.35611],93:[.25,.75,.09972,0,.35611],94:[0,.69444,.06709,0,.59111],95:[.31,.13444,.09811,0,.59111],97:[0,.44444,.09426,0,.59111],98:[0,.69444,.07861,0,.53222],99:[0,.44444,.05222,0,.53222],100:[0,.69444,.10861,0,.59111],101:[0,.44444,.085,0,.53222],102:[.19444,.69444,.21778,0,.4],103:[.19444,.44444,.105,0,.53222],104:[0,.69444,.09426,0,.59111],105:[0,.69326,.11387,0,.35555],106:[.19444,.69326,.1672,0,.35555],107:[0,.69444,.11111,0,.53222],108:[0,.69444,.10861,0,.29666],109:[0,.44444,.09426,0,.94444],110:[0,.44444,.09426,0,.64999],111:[0,.44444,.07861,0,.59111],112:[.19444,.44444,.07861,0,.59111],113:[.19444,.44444,.105,0,.53222],114:[0,.44444,.11111,0,.50167],115:[0,.44444,.08167,0,.48694],116:[0,.63492,.09639,0,.385],117:[0,.44444,.09426,0,.62055],118:[0,.44444,.11111,0,.53222],119:[0,.44444,.11111,0,.76777],120:[0,.44444,.12583,0,.56055],121:[.19444,.44444,.105,0,.56166],122:[0,.44444,.13889,0,.49055],126:[.35,.34444,.11472,0,.59111],160:[0,0,0,0,.25],168:[0,.69444,.11473,0,.59111],176:[0,.69444,0,0,.94888],184:[.17014,0,0,0,.53222],198:[0,.68611,.11431,0,1.02277],216:[.04861,.73472,.09062,0,.88555],223:[.19444,.69444,.09736,0,.665],230:[0,.44444,.085,0,.82666],248:[.09722,.54167,.09458,0,.59111],305:[0,.44444,.09426,0,.35555],338:[0,.68611,.11431,0,1.14054],339:[0,.44444,.085,0,.82666],567:[.19444,.44444,.04611,0,.385],710:[0,.69444,.06709,0,.59111],711:[0,.63194,.08271,0,.59111],713:[0,.59444,.10444,0,.59111],714:[0,.69444,.08528,0,.59111],715:[0,.69444,0,0,.59111],728:[0,.69444,.10333,0,.59111],729:[0,.69444,.12945,0,.35555],730:[0,.69444,0,0,.94888],732:[0,.69444,.11472,0,.59111],733:[0,.69444,.11472,0,.59111],915:[0,.68611,.12903,0,.69777],916:[0,.68611,0,0,.94444],920:[0,.68611,.09062,0,.88555],923:[0,.68611,0,0,.80666],926:[0,.68611,.15092,0,.76777],928:[0,.68611,.17208,0,.8961],931:[0,.68611,.11431,0,.82666],933:[0,.68611,.10778,0,.88555],934:[0,.68611,.05632,0,.82666],936:[0,.68611,.10778,0,.88555],937:[0,.68611,.0992,0,.82666],8211:[0,.44444,.09811,0,.59111],8212:[0,.44444,.09811,0,1.18221],8216:[0,.69444,.12945,0,.35555],8217:[0,.69444,.12945,0,.35555],8220:[0,.69444,.16772,0,.62055],8221:[0,.69444,.07939,0,.62055]},"Main-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.12417,0,.30667],34:[0,.69444,.06961,0,.51444],35:[.19444,.69444,.06616,0,.81777],37:[.05556,.75,.13639,0,.81777],38:[0,.69444,.09694,0,.76666],39:[0,.69444,.12417,0,.30667],40:[.25,.75,.16194,0,.40889],41:[.25,.75,.03694,0,.40889],42:[0,.75,.14917,0,.51111],43:[.05667,.56167,.03694,0,.76666],44:[.19444,.10556,0,0,.30667],45:[0,.43056,.02826,0,.35778],46:[0,.10556,0,0,.30667],47:[.25,.75,.16194,0,.51111],48:[0,.64444,.13556,0,.51111],49:[0,.64444,.13556,0,.51111],50:[0,.64444,.13556,0,.51111],51:[0,.64444,.13556,0,.51111],52:[.19444,.64444,.13556,0,.51111],53:[0,.64444,.13556,0,.51111],54:[0,.64444,.13556,0,.51111],55:[.19444,.64444,.13556,0,.51111],56:[0,.64444,.13556,0,.51111],57:[0,.64444,.13556,0,.51111],58:[0,.43056,.0582,0,.30667],59:[.19444,.43056,.0582,0,.30667],61:[-.13313,.36687,.06616,0,.76666],63:[0,.69444,.1225,0,.51111],64:[0,.69444,.09597,0,.76666],65:[0,.68333,0,0,.74333],66:[0,.68333,.10257,0,.70389],67:[0,.68333,.14528,0,.71555],68:[0,.68333,.09403,0,.755],69:[0,.68333,.12028,0,.67833],70:[0,.68333,.13305,0,.65277],71:[0,.68333,.08722,0,.77361],72:[0,.68333,.16389,0,.74333],73:[0,.68333,.15806,0,.38555],74:[0,.68333,.14028,0,.525],75:[0,.68333,.14528,0,.76888],76:[0,.68333,0,0,.62722],77:[0,.68333,.16389,0,.89666],78:[0,.68333,.16389,0,.74333],79:[0,.68333,.09403,0,.76666],80:[0,.68333,.10257,0,.67833],81:[.19444,.68333,.09403,0,.76666],82:[0,.68333,.03868,0,.72944],83:[0,.68333,.11972,0,.56222],84:[0,.68333,.13305,0,.71555],85:[0,.68333,.16389,0,.74333],86:[0,.68333,.18361,0,.74333],87:[0,.68333,.18361,0,.99888],88:[0,.68333,.15806,0,.74333],89:[0,.68333,.19383,0,.74333],90:[0,.68333,.14528,0,.61333],91:[.25,.75,.1875,0,.30667],93:[.25,.75,.10528,0,.30667],94:[0,.69444,.06646,0,.51111],95:[.31,.12056,.09208,0,.51111],97:[0,.43056,.07671,0,.51111],98:[0,.69444,.06312,0,.46],99:[0,.43056,.05653,0,.46],100:[0,.69444,.10333,0,.51111],101:[0,.43056,.07514,0,.46],102:[.19444,.69444,.21194,0,.30667],103:[.19444,.43056,.08847,0,.46],104:[0,.69444,.07671,0,.51111],105:[0,.65536,.1019,0,.30667],106:[.19444,.65536,.14467,0,.30667],107:[0,.69444,.10764,0,.46],108:[0,.69444,.10333,0,.25555],109:[0,.43056,.07671,0,.81777],110:[0,.43056,.07671,0,.56222],111:[0,.43056,.06312,0,.51111],112:[.19444,.43056,.06312,0,.51111],113:[.19444,.43056,.08847,0,.46],114:[0,.43056,.10764,0,.42166],115:[0,.43056,.08208,0,.40889],116:[0,.61508,.09486,0,.33222],117:[0,.43056,.07671,0,.53666],118:[0,.43056,.10764,0,.46],119:[0,.43056,.10764,0,.66444],120:[0,.43056,.12042,0,.46389],121:[.19444,.43056,.08847,0,.48555],122:[0,.43056,.12292,0,.40889],126:[.35,.31786,.11585,0,.51111],160:[0,0,0,0,.25],168:[0,.66786,.10474,0,.51111],176:[0,.69444,0,0,.83129],184:[.17014,0,0,0,.46],198:[0,.68333,.12028,0,.88277],216:[.04861,.73194,.09403,0,.76666],223:[.19444,.69444,.10514,0,.53666],230:[0,.43056,.07514,0,.71555],248:[.09722,.52778,.09194,0,.51111],338:[0,.68333,.12028,0,.98499],339:[0,.43056,.07514,0,.71555],710:[0,.69444,.06646,0,.51111],711:[0,.62847,.08295,0,.51111],713:[0,.56167,.10333,0,.51111],714:[0,.69444,.09694,0,.51111],715:[0,.69444,0,0,.51111],728:[0,.69444,.10806,0,.51111],729:[0,.66786,.11752,0,.30667],730:[0,.69444,0,0,.83129],732:[0,.66786,.11585,0,.51111],733:[0,.69444,.1225,0,.51111],915:[0,.68333,.13305,0,.62722],916:[0,.68333,0,0,.81777],920:[0,.68333,.09403,0,.76666],923:[0,.68333,0,0,.69222],926:[0,.68333,.15294,0,.66444],928:[0,.68333,.16389,0,.74333],931:[0,.68333,.12028,0,.71555],933:[0,.68333,.11111,0,.76666],934:[0,.68333,.05986,0,.71555],936:[0,.68333,.11111,0,.76666],937:[0,.68333,.10257,0,.71555],8211:[0,.43056,.09208,0,.51111],8212:[0,.43056,.09208,0,1.02222],8216:[0,.69444,.12417,0,.30667],8217:[0,.69444,.12417,0,.30667],8220:[0,.69444,.1685,0,.51444],8221:[0,.69444,.06961,0,.51444],8463:[0,.68889,0,0,.54028]},"Main-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.27778],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.77778],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.19444,.10556,0,0,.27778],45:[0,.43056,0,0,.33333],46:[0,.10556,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.64444,0,0,.5],49:[0,.64444,0,0,.5],50:[0,.64444,0,0,.5],51:[0,.64444,0,0,.5],52:[0,.64444,0,0,.5],53:[0,.64444,0,0,.5],54:[0,.64444,0,0,.5],55:[0,.64444,0,0,.5],56:[0,.64444,0,0,.5],57:[0,.64444,0,0,.5],58:[0,.43056,0,0,.27778],59:[.19444,.43056,0,0,.27778],60:[.0391,.5391,0,0,.77778],61:[-.13313,.36687,0,0,.77778],62:[.0391,.5391,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.77778],65:[0,.68333,0,0,.75],66:[0,.68333,0,0,.70834],67:[0,.68333,0,0,.72222],68:[0,.68333,0,0,.76389],69:[0,.68333,0,0,.68056],70:[0,.68333,0,0,.65278],71:[0,.68333,0,0,.78472],72:[0,.68333,0,0,.75],73:[0,.68333,0,0,.36111],74:[0,.68333,0,0,.51389],75:[0,.68333,0,0,.77778],76:[0,.68333,0,0,.625],77:[0,.68333,0,0,.91667],78:[0,.68333,0,0,.75],79:[0,.68333,0,0,.77778],80:[0,.68333,0,0,.68056],81:[.19444,.68333,0,0,.77778],82:[0,.68333,0,0,.73611],83:[0,.68333,0,0,.55556],84:[0,.68333,0,0,.72222],85:[0,.68333,0,0,.75],86:[0,.68333,.01389,0,.75],87:[0,.68333,.01389,0,1.02778],88:[0,.68333,0,0,.75],89:[0,.68333,.025,0,.75],90:[0,.68333,0,0,.61111],91:[.25,.75,0,0,.27778],92:[.25,.75,0,0,.5],93:[.25,.75,0,0,.27778],94:[0,.69444,0,0,.5],95:[.31,.12056,.02778,0,.5],97:[0,.43056,0,0,.5],98:[0,.69444,0,0,.55556],99:[0,.43056,0,0,.44445],100:[0,.69444,0,0,.55556],101:[0,.43056,0,0,.44445],102:[0,.69444,.07778,0,.30556],103:[.19444,.43056,.01389,0,.5],104:[0,.69444,0,0,.55556],105:[0,.66786,0,0,.27778],106:[.19444,.66786,0,0,.30556],107:[0,.69444,0,0,.52778],108:[0,.69444,0,0,.27778],109:[0,.43056,0,0,.83334],110:[0,.43056,0,0,.55556],111:[0,.43056,0,0,.5],112:[.19444,.43056,0,0,.55556],113:[.19444,.43056,0,0,.52778],114:[0,.43056,0,0,.39167],115:[0,.43056,0,0,.39445],116:[0,.61508,0,0,.38889],117:[0,.43056,0,0,.55556],118:[0,.43056,.01389,0,.52778],119:[0,.43056,.01389,0,.72222],120:[0,.43056,0,0,.52778],121:[.19444,.43056,.01389,0,.52778],122:[0,.43056,0,0,.44445],123:[.25,.75,0,0,.5],124:[.25,.75,0,0,.27778],125:[.25,.75,0,0,.5],126:[.35,.31786,0,0,.5],160:[0,0,0,0,.25],163:[0,.69444,0,0,.76909],167:[.19444,.69444,0,0,.44445],168:[0,.66786,0,0,.5],172:[0,.43056,0,0,.66667],176:[0,.69444,0,0,.75],177:[.08333,.58333,0,0,.77778],182:[.19444,.69444,0,0,.61111],184:[.17014,0,0,0,.44445],198:[0,.68333,0,0,.90278],215:[.08333,.58333,0,0,.77778],216:[.04861,.73194,0,0,.77778],223:[0,.69444,0,0,.5],230:[0,.43056,0,0,.72222],247:[.08333,.58333,0,0,.77778],248:[.09722,.52778,0,0,.5],305:[0,.43056,0,0,.27778],338:[0,.68333,0,0,1.01389],339:[0,.43056,0,0,.77778],567:[.19444,.43056,0,0,.30556],710:[0,.69444,0,0,.5],711:[0,.62847,0,0,.5],713:[0,.56778,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.66786,0,0,.27778],730:[0,.69444,0,0,.75],732:[0,.66786,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.68333,0,0,.625],916:[0,.68333,0,0,.83334],920:[0,.68333,0,0,.77778],923:[0,.68333,0,0,.69445],926:[0,.68333,0,0,.66667],928:[0,.68333,0,0,.75],931:[0,.68333,0,0,.72222],933:[0,.68333,0,0,.77778],934:[0,.68333,0,0,.72222],936:[0,.68333,0,0,.77778],937:[0,.68333,0,0,.72222],8211:[0,.43056,.02778,0,.5],8212:[0,.43056,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5],8224:[.19444,.69444,0,0,.44445],8225:[.19444,.69444,0,0,.44445],8230:[0,.12,0,0,1.172],8242:[0,.55556,0,0,.275],8407:[0,.71444,.15382,0,.5],8463:[0,.68889,0,0,.54028],8465:[0,.69444,0,0,.72222],8467:[0,.69444,0,.11111,.41667],8472:[.19444,.43056,0,.11111,.63646],8476:[0,.69444,0,0,.72222],8501:[0,.69444,0,0,.61111],8592:[-.13313,.36687,0,0,1],8593:[.19444,.69444,0,0,.5],8594:[-.13313,.36687,0,0,1],8595:[.19444,.69444,0,0,.5],8596:[-.13313,.36687,0,0,1],8597:[.25,.75,0,0,.5],8598:[.19444,.69444,0,0,1],8599:[.19444,.69444,0,0,1],8600:[.19444,.69444,0,0,1],8601:[.19444,.69444,0,0,1],8614:[.011,.511,0,0,1],8617:[.011,.511,0,0,1.126],8618:[.011,.511,0,0,1.126],8636:[-.13313,.36687,0,0,1],8637:[-.13313,.36687,0,0,1],8640:[-.13313,.36687,0,0,1],8641:[-.13313,.36687,0,0,1],8652:[.011,.671,0,0,1],8656:[-.13313,.36687,0,0,1],8657:[.19444,.69444,0,0,.61111],8658:[-.13313,.36687,0,0,1],8659:[.19444,.69444,0,0,.61111],8660:[-.13313,.36687,0,0,1],8661:[.25,.75,0,0,.61111],8704:[0,.69444,0,0,.55556],8706:[0,.69444,.05556,.08334,.5309],8707:[0,.69444,0,0,.55556],8709:[.05556,.75,0,0,.5],8711:[0,.68333,0,0,.83334],8712:[.0391,.5391,0,0,.66667],8715:[.0391,.5391,0,0,.66667],8722:[.08333,.58333,0,0,.77778],8723:[.08333,.58333,0,0,.77778],8725:[.25,.75,0,0,.5],8726:[.25,.75,0,0,.5],8727:[-.03472,.46528,0,0,.5],8728:[-.05555,.44445,0,0,.5],8729:[-.05555,.44445,0,0,.5],8730:[.2,.8,0,0,.83334],8733:[0,.43056,0,0,.77778],8734:[0,.43056,0,0,1],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.27778],8741:[.25,.75,0,0,.5],8743:[0,.55556,0,0,.66667],8744:[0,.55556,0,0,.66667],8745:[0,.55556,0,0,.66667],8746:[0,.55556,0,0,.66667],8747:[.19444,.69444,.11111,0,.41667],8764:[-.13313,.36687,0,0,.77778],8768:[.19444,.69444,0,0,.27778],8771:[-.03625,.46375,0,0,.77778],8773:[-.022,.589,0,0,1],8776:[-.01688,.48312,0,0,.77778],8781:[-.03625,.46375,0,0,.77778],8784:[-.133,.67,0,0,.778],8801:[-.03625,.46375,0,0,.77778],8804:[.13597,.63597,0,0,.77778],8805:[.13597,.63597,0,0,.77778],8810:[.0391,.5391,0,0,1],8811:[.0391,.5391,0,0,1],8826:[.0391,.5391,0,0,.77778],8827:[.0391,.5391,0,0,.77778],8834:[.0391,.5391,0,0,.77778],8835:[.0391,.5391,0,0,.77778],8838:[.13597,.63597,0,0,.77778],8839:[.13597,.63597,0,0,.77778],8846:[0,.55556,0,0,.66667],8849:[.13597,.63597,0,0,.77778],8850:[.13597,.63597,0,0,.77778],8851:[0,.55556,0,0,.66667],8852:[0,.55556,0,0,.66667],8853:[.08333,.58333,0,0,.77778],8854:[.08333,.58333,0,0,.77778],8855:[.08333,.58333,0,0,.77778],8856:[.08333,.58333,0,0,.77778],8857:[.08333,.58333,0,0,.77778],8866:[0,.69444,0,0,.61111],8867:[0,.69444,0,0,.61111],8868:[0,.69444,0,0,.77778],8869:[0,.69444,0,0,.77778],8872:[.249,.75,0,0,.867],8900:[-.05555,.44445,0,0,.5],8901:[-.05555,.44445,0,0,.27778],8902:[-.03472,.46528,0,0,.5],8904:[.005,.505,0,0,.9],8942:[.03,.9,0,0,.278],8943:[-.19,.31,0,0,1.172],8945:[-.1,.82,0,0,1.282],8968:[.25,.75,0,0,.44445],8969:[.25,.75,0,0,.44445],8970:[.25,.75,0,0,.44445],8971:[.25,.75,0,0,.44445],8994:[-.14236,.35764,0,0,1],8995:[-.14236,.35764,0,0,1],9136:[.244,.744,0,0,.412],9137:[.244,.744,0,0,.412],9651:[.19444,.69444,0,0,.88889],9657:[-.03472,.46528,0,0,.5],9661:[.19444,.69444,0,0,.88889],9667:[-.03472,.46528,0,0,.5],9711:[.19444,.69444,0,0,1],9824:[.12963,.69444,0,0,.77778],9825:[.12963,.69444,0,0,.77778],9826:[.12963,.69444,0,0,.77778],9827:[.12963,.69444,0,0,.77778],9837:[0,.75,0,0,.38889],9838:[.19444,.69444,0,0,.38889],9839:[.19444,.69444,0,0,.38889],10216:[.25,.75,0,0,.38889],10217:[.25,.75,0,0,.38889],10222:[.244,.744,0,0,.412],10223:[.244,.744,0,0,.412],10229:[.011,.511,0,0,1.609],10230:[.011,.511,0,0,1.638],10231:[.011,.511,0,0,1.859],10232:[.024,.525,0,0,1.609],10233:[.024,.525,0,0,1.638],10234:[.024,.525,0,0,1.858],10236:[.011,.511,0,0,1.638],10815:[0,.68333,0,0,.75],10927:[.13597,.63597,0,0,.77778],10928:[.13597,.63597,0,0,.77778],57376:[.19444,.69444,0,0,0]},"Math-BoldItalic":{32:[0,0,0,0,.25],48:[0,.44444,0,0,.575],49:[0,.44444,0,0,.575],50:[0,.44444,0,0,.575],51:[.19444,.44444,0,0,.575],52:[.19444,.44444,0,0,.575],53:[.19444,.44444,0,0,.575],54:[0,.64444,0,0,.575],55:[.19444,.44444,0,0,.575],56:[0,.64444,0,0,.575],57:[.19444,.44444,0,0,.575],65:[0,.68611,0,0,.86944],66:[0,.68611,.04835,0,.8664],67:[0,.68611,.06979,0,.81694],68:[0,.68611,.03194,0,.93812],69:[0,.68611,.05451,0,.81007],70:[0,.68611,.15972,0,.68889],71:[0,.68611,0,0,.88673],72:[0,.68611,.08229,0,.98229],73:[0,.68611,.07778,0,.51111],74:[0,.68611,.10069,0,.63125],75:[0,.68611,.06979,0,.97118],76:[0,.68611,0,0,.75555],77:[0,.68611,.11424,0,1.14201],78:[0,.68611,.11424,0,.95034],79:[0,.68611,.03194,0,.83666],80:[0,.68611,.15972,0,.72309],81:[.19444,.68611,0,0,.86861],82:[0,.68611,.00421,0,.87235],83:[0,.68611,.05382,0,.69271],84:[0,.68611,.15972,0,.63663],85:[0,.68611,.11424,0,.80027],86:[0,.68611,.25555,0,.67778],87:[0,.68611,.15972,0,1.09305],88:[0,.68611,.07778,0,.94722],89:[0,.68611,.25555,0,.67458],90:[0,.68611,.06979,0,.77257],97:[0,.44444,0,0,.63287],98:[0,.69444,0,0,.52083],99:[0,.44444,0,0,.51342],100:[0,.69444,0,0,.60972],101:[0,.44444,0,0,.55361],102:[.19444,.69444,.11042,0,.56806],103:[.19444,.44444,.03704,0,.5449],104:[0,.69444,0,0,.66759],105:[0,.69326,0,0,.4048],106:[.19444,.69326,.0622,0,.47083],107:[0,.69444,.01852,0,.6037],108:[0,.69444,.0088,0,.34815],109:[0,.44444,0,0,1.0324],110:[0,.44444,0,0,.71296],111:[0,.44444,0,0,.58472],112:[.19444,.44444,0,0,.60092],113:[.19444,.44444,.03704,0,.54213],114:[0,.44444,.03194,0,.5287],115:[0,.44444,0,0,.53125],116:[0,.63492,0,0,.41528],117:[0,.44444,0,0,.68102],118:[0,.44444,.03704,0,.56666],119:[0,.44444,.02778,0,.83148],120:[0,.44444,0,0,.65903],121:[.19444,.44444,.03704,0,.59028],122:[0,.44444,.04213,0,.55509],160:[0,0,0,0,.25],915:[0,.68611,.15972,0,.65694],916:[0,.68611,0,0,.95833],920:[0,.68611,.03194,0,.86722],923:[0,.68611,0,0,.80555],926:[0,.68611,.07458,0,.84125],928:[0,.68611,.08229,0,.98229],931:[0,.68611,.05451,0,.88507],933:[0,.68611,.15972,0,.67083],934:[0,.68611,0,0,.76666],936:[0,.68611,.11653,0,.71402],937:[0,.68611,.04835,0,.8789],945:[0,.44444,0,0,.76064],946:[.19444,.69444,.03403,0,.65972],947:[.19444,.44444,.06389,0,.59003],948:[0,.69444,.03819,0,.52222],949:[0,.44444,0,0,.52882],950:[.19444,.69444,.06215,0,.50833],951:[.19444,.44444,.03704,0,.6],952:[0,.69444,.03194,0,.5618],953:[0,.44444,0,0,.41204],954:[0,.44444,0,0,.66759],955:[0,.69444,0,0,.67083],956:[.19444,.44444,0,0,.70787],957:[0,.44444,.06898,0,.57685],958:[.19444,.69444,.03021,0,.50833],959:[0,.44444,0,0,.58472],960:[0,.44444,.03704,0,.68241],961:[.19444,.44444,0,0,.6118],962:[.09722,.44444,.07917,0,.42361],963:[0,.44444,.03704,0,.68588],964:[0,.44444,.13472,0,.52083],965:[0,.44444,.03704,0,.63055],966:[.19444,.44444,0,0,.74722],967:[.19444,.44444,0,0,.71805],968:[.19444,.69444,.03704,0,.75833],969:[0,.44444,.03704,0,.71782],977:[0,.69444,0,0,.69155],981:[.19444,.69444,0,0,.7125],982:[0,.44444,.03194,0,.975],1009:[.19444,.44444,0,0,.6118],1013:[0,.44444,0,0,.48333],57649:[0,.44444,0,0,.39352],57911:[.19444,.44444,0,0,.43889]},"Math-Italic":{32:[0,0,0,0,.25],48:[0,.43056,0,0,.5],49:[0,.43056,0,0,.5],50:[0,.43056,0,0,.5],51:[.19444,.43056,0,0,.5],52:[.19444,.43056,0,0,.5],53:[.19444,.43056,0,0,.5],54:[0,.64444,0,0,.5],55:[.19444,.43056,0,0,.5],56:[0,.64444,0,0,.5],57:[.19444,.43056,0,0,.5],65:[0,.68333,0,.13889,.75],66:[0,.68333,.05017,.08334,.75851],67:[0,.68333,.07153,.08334,.71472],68:[0,.68333,.02778,.05556,.82792],69:[0,.68333,.05764,.08334,.7382],70:[0,.68333,.13889,.08334,.64306],71:[0,.68333,0,.08334,.78625],72:[0,.68333,.08125,.05556,.83125],73:[0,.68333,.07847,.11111,.43958],74:[0,.68333,.09618,.16667,.55451],75:[0,.68333,.07153,.05556,.84931],76:[0,.68333,0,.02778,.68056],77:[0,.68333,.10903,.08334,.97014],78:[0,.68333,.10903,.08334,.80347],79:[0,.68333,.02778,.08334,.76278],80:[0,.68333,.13889,.08334,.64201],81:[.19444,.68333,0,.08334,.79056],82:[0,.68333,.00773,.08334,.75929],83:[0,.68333,.05764,.08334,.6132],84:[0,.68333,.13889,.08334,.58438],85:[0,.68333,.10903,.02778,.68278],86:[0,.68333,.22222,0,.58333],87:[0,.68333,.13889,0,.94445],88:[0,.68333,.07847,.08334,.82847],89:[0,.68333,.22222,0,.58056],90:[0,.68333,.07153,.08334,.68264],97:[0,.43056,0,0,.52859],98:[0,.69444,0,0,.42917],99:[0,.43056,0,.05556,.43276],100:[0,.69444,0,.16667,.52049],101:[0,.43056,0,.05556,.46563],102:[.19444,.69444,.10764,.16667,.48959],103:[.19444,.43056,.03588,.02778,.47697],104:[0,.69444,0,0,.57616],105:[0,.65952,0,0,.34451],106:[.19444,.65952,.05724,0,.41181],107:[0,.69444,.03148,0,.5206],108:[0,.69444,.01968,.08334,.29838],109:[0,.43056,0,0,.87801],110:[0,.43056,0,0,.60023],111:[0,.43056,0,.05556,.48472],112:[.19444,.43056,0,.08334,.50313],113:[.19444,.43056,.03588,.08334,.44641],114:[0,.43056,.02778,.05556,.45116],115:[0,.43056,0,.05556,.46875],116:[0,.61508,0,.08334,.36111],117:[0,.43056,0,.02778,.57246],118:[0,.43056,.03588,.02778,.48472],119:[0,.43056,.02691,.08334,.71592],120:[0,.43056,0,.02778,.57153],121:[.19444,.43056,.03588,.05556,.49028],122:[0,.43056,.04398,.05556,.46505],160:[0,0,0,0,.25],915:[0,.68333,.13889,.08334,.61528],916:[0,.68333,0,.16667,.83334],920:[0,.68333,.02778,.08334,.76278],923:[0,.68333,0,.16667,.69445],926:[0,.68333,.07569,.08334,.74236],928:[0,.68333,.08125,.05556,.83125],931:[0,.68333,.05764,.08334,.77986],933:[0,.68333,.13889,.05556,.58333],934:[0,.68333,0,.08334,.66667],936:[0,.68333,.11,.05556,.61222],937:[0,.68333,.05017,.08334,.7724],945:[0,.43056,.0037,.02778,.6397],946:[.19444,.69444,.05278,.08334,.56563],947:[.19444,.43056,.05556,0,.51773],948:[0,.69444,.03785,.05556,.44444],949:[0,.43056,0,.08334,.46632],950:[.19444,.69444,.07378,.08334,.4375],951:[.19444,.43056,.03588,.05556,.49653],952:[0,.69444,.02778,.08334,.46944],953:[0,.43056,0,.05556,.35394],954:[0,.43056,0,0,.57616],955:[0,.69444,0,0,.58334],956:[.19444,.43056,0,.02778,.60255],957:[0,.43056,.06366,.02778,.49398],958:[.19444,.69444,.04601,.11111,.4375],959:[0,.43056,0,.05556,.48472],960:[0,.43056,.03588,0,.57003],961:[.19444,.43056,0,.08334,.51702],962:[.09722,.43056,.07986,.08334,.36285],963:[0,.43056,.03588,0,.57141],964:[0,.43056,.1132,.02778,.43715],965:[0,.43056,.03588,.02778,.54028],966:[.19444,.43056,0,.08334,.65417],967:[.19444,.43056,0,.05556,.62569],968:[.19444,.69444,.03588,.11111,.65139],969:[0,.43056,.03588,0,.62245],977:[0,.69444,0,.08334,.59144],981:[.19444,.69444,0,.08334,.59583],982:[0,.43056,.02778,0,.82813],1009:[.19444,.43056,0,.08334,.51702],1013:[0,.43056,0,.05556,.4059],57649:[0,.43056,0,.02778,.32246],57911:[.19444,.43056,0,.08334,.38403]},"SansSerif-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.36667],34:[0,.69444,0,0,.55834],35:[.19444,.69444,0,0,.91667],36:[.05556,.75,0,0,.55],37:[.05556,.75,0,0,1.02912],38:[0,.69444,0,0,.83056],39:[0,.69444,0,0,.30556],40:[.25,.75,0,0,.42778],41:[.25,.75,0,0,.42778],42:[0,.75,0,0,.55],43:[.11667,.61667,0,0,.85556],44:[.10556,.13056,0,0,.30556],45:[0,.45833,0,0,.36667],46:[0,.13056,0,0,.30556],47:[.25,.75,0,0,.55],48:[0,.69444,0,0,.55],49:[0,.69444,0,0,.55],50:[0,.69444,0,0,.55],51:[0,.69444,0,0,.55],52:[0,.69444,0,0,.55],53:[0,.69444,0,0,.55],54:[0,.69444,0,0,.55],55:[0,.69444,0,0,.55],56:[0,.69444,0,0,.55],57:[0,.69444,0,0,.55],58:[0,.45833,0,0,.30556],59:[.10556,.45833,0,0,.30556],61:[-.09375,.40625,0,0,.85556],63:[0,.69444,0,0,.51945],64:[0,.69444,0,0,.73334],65:[0,.69444,0,0,.73334],66:[0,.69444,0,0,.73334],67:[0,.69444,0,0,.70278],68:[0,.69444,0,0,.79445],69:[0,.69444,0,0,.64167],70:[0,.69444,0,0,.61111],71:[0,.69444,0,0,.73334],72:[0,.69444,0,0,.79445],73:[0,.69444,0,0,.33056],74:[0,.69444,0,0,.51945],75:[0,.69444,0,0,.76389],76:[0,.69444,0,0,.58056],77:[0,.69444,0,0,.97778],78:[0,.69444,0,0,.79445],79:[0,.69444,0,0,.79445],80:[0,.69444,0,0,.70278],81:[.10556,.69444,0,0,.79445],82:[0,.69444,0,0,.70278],83:[0,.69444,0,0,.61111],84:[0,.69444,0,0,.73334],85:[0,.69444,0,0,.76389],86:[0,.69444,.01528,0,.73334],87:[0,.69444,.01528,0,1.03889],88:[0,.69444,0,0,.73334],89:[0,.69444,.0275,0,.73334],90:[0,.69444,0,0,.67223],91:[.25,.75,0,0,.34306],93:[.25,.75,0,0,.34306],94:[0,.69444,0,0,.55],95:[.35,.10833,.03056,0,.55],97:[0,.45833,0,0,.525],98:[0,.69444,0,0,.56111],99:[0,.45833,0,0,.48889],100:[0,.69444,0,0,.56111],101:[0,.45833,0,0,.51111],102:[0,.69444,.07639,0,.33611],103:[.19444,.45833,.01528,0,.55],104:[0,.69444,0,0,.56111],105:[0,.69444,0,0,.25556],106:[.19444,.69444,0,0,.28611],107:[0,.69444,0,0,.53056],108:[0,.69444,0,0,.25556],109:[0,.45833,0,0,.86667],110:[0,.45833,0,0,.56111],111:[0,.45833,0,0,.55],112:[.19444,.45833,0,0,.56111],113:[.19444,.45833,0,0,.56111],114:[0,.45833,.01528,0,.37222],115:[0,.45833,0,0,.42167],116:[0,.58929,0,0,.40417],117:[0,.45833,0,0,.56111],118:[0,.45833,.01528,0,.5],119:[0,.45833,.01528,0,.74445],120:[0,.45833,0,0,.5],121:[.19444,.45833,.01528,0,.5],122:[0,.45833,0,0,.47639],126:[.35,.34444,0,0,.55],160:[0,0,0,0,.25],168:[0,.69444,0,0,.55],176:[0,.69444,0,0,.73334],180:[0,.69444,0,0,.55],184:[.17014,0,0,0,.48889],305:[0,.45833,0,0,.25556],567:[.19444,.45833,0,0,.28611],710:[0,.69444,0,0,.55],711:[0,.63542,0,0,.55],713:[0,.63778,0,0,.55],728:[0,.69444,0,0,.55],729:[0,.69444,0,0,.30556],730:[0,.69444,0,0,.73334],732:[0,.69444,0,0,.55],733:[0,.69444,0,0,.55],915:[0,.69444,0,0,.58056],916:[0,.69444,0,0,.91667],920:[0,.69444,0,0,.85556],923:[0,.69444,0,0,.67223],926:[0,.69444,0,0,.73334],928:[0,.69444,0,0,.79445],931:[0,.69444,0,0,.79445],933:[0,.69444,0,0,.85556],934:[0,.69444,0,0,.79445],936:[0,.69444,0,0,.85556],937:[0,.69444,0,0,.79445],8211:[0,.45833,.03056,0,.55],8212:[0,.45833,.03056,0,1.10001],8216:[0,.69444,0,0,.30556],8217:[0,.69444,0,0,.30556],8220:[0,.69444,0,0,.55834],8221:[0,.69444,0,0,.55834]},"SansSerif-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.05733,0,.31945],34:[0,.69444,.00316,0,.5],35:[.19444,.69444,.05087,0,.83334],36:[.05556,.75,.11156,0,.5],37:[.05556,.75,.03126,0,.83334],38:[0,.69444,.03058,0,.75834],39:[0,.69444,.07816,0,.27778],40:[.25,.75,.13164,0,.38889],41:[.25,.75,.02536,0,.38889],42:[0,.75,.11775,0,.5],43:[.08333,.58333,.02536,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,.01946,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,.13164,0,.5],48:[0,.65556,.11156,0,.5],49:[0,.65556,.11156,0,.5],50:[0,.65556,.11156,0,.5],51:[0,.65556,.11156,0,.5],52:[0,.65556,.11156,0,.5],53:[0,.65556,.11156,0,.5],54:[0,.65556,.11156,0,.5],55:[0,.65556,.11156,0,.5],56:[0,.65556,.11156,0,.5],57:[0,.65556,.11156,0,.5],58:[0,.44444,.02502,0,.27778],59:[.125,.44444,.02502,0,.27778],61:[-.13,.37,.05087,0,.77778],63:[0,.69444,.11809,0,.47222],64:[0,.69444,.07555,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,.08293,0,.66667],67:[0,.69444,.11983,0,.63889],68:[0,.69444,.07555,0,.72223],69:[0,.69444,.11983,0,.59722],70:[0,.69444,.13372,0,.56945],71:[0,.69444,.11983,0,.66667],72:[0,.69444,.08094,0,.70834],73:[0,.69444,.13372,0,.27778],74:[0,.69444,.08094,0,.47222],75:[0,.69444,.11983,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,.08094,0,.875],78:[0,.69444,.08094,0,.70834],79:[0,.69444,.07555,0,.73611],80:[0,.69444,.08293,0,.63889],81:[.125,.69444,.07555,0,.73611],82:[0,.69444,.08293,0,.64584],83:[0,.69444,.09205,0,.55556],84:[0,.69444,.13372,0,.68056],85:[0,.69444,.08094,0,.6875],86:[0,.69444,.1615,0,.66667],87:[0,.69444,.1615,0,.94445],88:[0,.69444,.13372,0,.66667],89:[0,.69444,.17261,0,.66667],90:[0,.69444,.11983,0,.61111],91:[.25,.75,.15942,0,.28889],93:[.25,.75,.08719,0,.28889],94:[0,.69444,.0799,0,.5],95:[.35,.09444,.08616,0,.5],97:[0,.44444,.00981,0,.48056],98:[0,.69444,.03057,0,.51667],99:[0,.44444,.08336,0,.44445],100:[0,.69444,.09483,0,.51667],101:[0,.44444,.06778,0,.44445],102:[0,.69444,.21705,0,.30556],103:[.19444,.44444,.10836,0,.5],104:[0,.69444,.01778,0,.51667],105:[0,.67937,.09718,0,.23889],106:[.19444,.67937,.09162,0,.26667],107:[0,.69444,.08336,0,.48889],108:[0,.69444,.09483,0,.23889],109:[0,.44444,.01778,0,.79445],110:[0,.44444,.01778,0,.51667],111:[0,.44444,.06613,0,.5],112:[.19444,.44444,.0389,0,.51667],113:[.19444,.44444,.04169,0,.51667],114:[0,.44444,.10836,0,.34167],115:[0,.44444,.0778,0,.38333],116:[0,.57143,.07225,0,.36111],117:[0,.44444,.04169,0,.51667],118:[0,.44444,.10836,0,.46111],119:[0,.44444,.10836,0,.68334],120:[0,.44444,.09169,0,.46111],121:[.19444,.44444,.10836,0,.46111],122:[0,.44444,.08752,0,.43472],126:[.35,.32659,.08826,0,.5],160:[0,0,0,0,.25],168:[0,.67937,.06385,0,.5],176:[0,.69444,0,0,.73752],184:[.17014,0,0,0,.44445],305:[0,.44444,.04169,0,.23889],567:[.19444,.44444,.04169,0,.26667],710:[0,.69444,.0799,0,.5],711:[0,.63194,.08432,0,.5],713:[0,.60889,.08776,0,.5],714:[0,.69444,.09205,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,.09483,0,.5],729:[0,.67937,.07774,0,.27778],730:[0,.69444,0,0,.73752],732:[0,.67659,.08826,0,.5],733:[0,.69444,.09205,0,.5],915:[0,.69444,.13372,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,.07555,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,.12816,0,.66667],928:[0,.69444,.08094,0,.70834],931:[0,.69444,.11983,0,.72222],933:[0,.69444,.09031,0,.77778],934:[0,.69444,.04603,0,.72222],936:[0,.69444,.09031,0,.77778],937:[0,.69444,.08293,0,.72222],8211:[0,.44444,.08616,0,.5],8212:[0,.44444,.08616,0,1],8216:[0,.69444,.07816,0,.27778],8217:[0,.69444,.07816,0,.27778],8220:[0,.69444,.14205,0,.5],8221:[0,.69444,.00316,0,.5]},"SansSerif-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.31945],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.75834],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,0,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.65556,0,0,.5],49:[0,.65556,0,0,.5],50:[0,.65556,0,0,.5],51:[0,.65556,0,0,.5],52:[0,.65556,0,0,.5],53:[0,.65556,0,0,.5],54:[0,.65556,0,0,.5],55:[0,.65556,0,0,.5],56:[0,.65556,0,0,.5],57:[0,.65556,0,0,.5],58:[0,.44444,0,0,.27778],59:[.125,.44444,0,0,.27778],61:[-.13,.37,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,0,0,.66667],67:[0,.69444,0,0,.63889],68:[0,.69444,0,0,.72223],69:[0,.69444,0,0,.59722],70:[0,.69444,0,0,.56945],71:[0,.69444,0,0,.66667],72:[0,.69444,0,0,.70834],73:[0,.69444,0,0,.27778],74:[0,.69444,0,0,.47222],75:[0,.69444,0,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,0,0,.875],78:[0,.69444,0,0,.70834],79:[0,.69444,0,0,.73611],80:[0,.69444,0,0,.63889],81:[.125,.69444,0,0,.73611],82:[0,.69444,0,0,.64584],83:[0,.69444,0,0,.55556],84:[0,.69444,0,0,.68056],85:[0,.69444,0,0,.6875],86:[0,.69444,.01389,0,.66667],87:[0,.69444,.01389,0,.94445],88:[0,.69444,0,0,.66667],89:[0,.69444,.025,0,.66667],90:[0,.69444,0,0,.61111],91:[.25,.75,0,0,.28889],93:[.25,.75,0,0,.28889],94:[0,.69444,0,0,.5],95:[.35,.09444,.02778,0,.5],97:[0,.44444,0,0,.48056],98:[0,.69444,0,0,.51667],99:[0,.44444,0,0,.44445],100:[0,.69444,0,0,.51667],101:[0,.44444,0,0,.44445],102:[0,.69444,.06944,0,.30556],103:[.19444,.44444,.01389,0,.5],104:[0,.69444,0,0,.51667],105:[0,.67937,0,0,.23889],106:[.19444,.67937,0,0,.26667],107:[0,.69444,0,0,.48889],108:[0,.69444,0,0,.23889],109:[0,.44444,0,0,.79445],110:[0,.44444,0,0,.51667],111:[0,.44444,0,0,.5],112:[.19444,.44444,0,0,.51667],113:[.19444,.44444,0,0,.51667],114:[0,.44444,.01389,0,.34167],115:[0,.44444,0,0,.38333],116:[0,.57143,0,0,.36111],117:[0,.44444,0,0,.51667],118:[0,.44444,.01389,0,.46111],119:[0,.44444,.01389,0,.68334],120:[0,.44444,0,0,.46111],121:[.19444,.44444,.01389,0,.46111],122:[0,.44444,0,0,.43472],126:[.35,.32659,0,0,.5],160:[0,0,0,0,.25],168:[0,.67937,0,0,.5],176:[0,.69444,0,0,.66667],184:[.17014,0,0,0,.44445],305:[0,.44444,0,0,.23889],567:[.19444,.44444,0,0,.26667],710:[0,.69444,0,0,.5],711:[0,.63194,0,0,.5],713:[0,.60889,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.67937,0,0,.27778],730:[0,.69444,0,0,.66667],732:[0,.67659,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.69444,0,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,0,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,0,0,.66667],928:[0,.69444,0,0,.70834],931:[0,.69444,0,0,.72222],933:[0,.69444,0,0,.77778],934:[0,.69444,0,0,.72222],936:[0,.69444,0,0,.77778],937:[0,.69444,0,0,.72222],8211:[0,.44444,.02778,0,.5],8212:[0,.44444,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5]},"Script-Regular":{32:[0,0,0,0,.25],65:[0,.7,.22925,0,.80253],66:[0,.7,.04087,0,.90757],67:[0,.7,.1689,0,.66619],68:[0,.7,.09371,0,.77443],69:[0,.7,.18583,0,.56162],70:[0,.7,.13634,0,.89544],71:[0,.7,.17322,0,.60961],72:[0,.7,.29694,0,.96919],73:[0,.7,.19189,0,.80907],74:[.27778,.7,.19189,0,1.05159],75:[0,.7,.31259,0,.91364],76:[0,.7,.19189,0,.87373],77:[0,.7,.15981,0,1.08031],78:[0,.7,.3525,0,.9015],79:[0,.7,.08078,0,.73787],80:[0,.7,.08078,0,1.01262],81:[0,.7,.03305,0,.88282],82:[0,.7,.06259,0,.85],83:[0,.7,.19189,0,.86767],84:[0,.7,.29087,0,.74697],85:[0,.7,.25815,0,.79996],86:[0,.7,.27523,0,.62204],87:[0,.7,.27523,0,.80532],88:[0,.7,.26006,0,.94445],89:[0,.7,.2939,0,.70961],90:[0,.7,.24037,0,.8212],160:[0,0,0,0,.25]},"Size1-Regular":{32:[0,0,0,0,.25],40:[.35001,.85,0,0,.45834],41:[.35001,.85,0,0,.45834],47:[.35001,.85,0,0,.57778],91:[.35001,.85,0,0,.41667],92:[.35001,.85,0,0,.57778],93:[.35001,.85,0,0,.41667],123:[.35001,.85,0,0,.58334],125:[.35001,.85,0,0,.58334],160:[0,0,0,0,.25],710:[0,.72222,0,0,.55556],732:[0,.72222,0,0,.55556],770:[0,.72222,0,0,.55556],771:[0,.72222,0,0,.55556],8214:[-99e-5,.601,0,0,.77778],8593:[1e-5,.6,0,0,.66667],8595:[1e-5,.6,0,0,.66667],8657:[1e-5,.6,0,0,.77778],8659:[1e-5,.6,0,0,.77778],8719:[.25001,.75,0,0,.94445],8720:[.25001,.75,0,0,.94445],8721:[.25001,.75,0,0,1.05556],8730:[.35001,.85,0,0,1],8739:[-.00599,.606,0,0,.33333],8741:[-.00599,.606,0,0,.55556],8747:[.30612,.805,.19445,0,.47222],8748:[.306,.805,.19445,0,.47222],8749:[.306,.805,.19445,0,.47222],8750:[.30612,.805,.19445,0,.47222],8896:[.25001,.75,0,0,.83334],8897:[.25001,.75,0,0,.83334],8898:[.25001,.75,0,0,.83334],8899:[.25001,.75,0,0,.83334],8968:[.35001,.85,0,0,.47222],8969:[.35001,.85,0,0,.47222],8970:[.35001,.85,0,0,.47222],8971:[.35001,.85,0,0,.47222],9168:[-99e-5,.601,0,0,.66667],10216:[.35001,.85,0,0,.47222],10217:[.35001,.85,0,0,.47222],10752:[.25001,.75,0,0,1.11111],10753:[.25001,.75,0,0,1.11111],10754:[.25001,.75,0,0,1.11111],10756:[.25001,.75,0,0,.83334],10758:[.25001,.75,0,0,.83334]},"Size2-Regular":{32:[0,0,0,0,.25],40:[.65002,1.15,0,0,.59722],41:[.65002,1.15,0,0,.59722],47:[.65002,1.15,0,0,.81111],91:[.65002,1.15,0,0,.47222],92:[.65002,1.15,0,0,.81111],93:[.65002,1.15,0,0,.47222],123:[.65002,1.15,0,0,.66667],125:[.65002,1.15,0,0,.66667],160:[0,0,0,0,.25],710:[0,.75,0,0,1],732:[0,.75,0,0,1],770:[0,.75,0,0,1],771:[0,.75,0,0,1],8719:[.55001,1.05,0,0,1.27778],8720:[.55001,1.05,0,0,1.27778],8721:[.55001,1.05,0,0,1.44445],8730:[.65002,1.15,0,0,1],8747:[.86225,1.36,.44445,0,.55556],8748:[.862,1.36,.44445,0,.55556],8749:[.862,1.36,.44445,0,.55556],8750:[.86225,1.36,.44445,0,.55556],8896:[.55001,1.05,0,0,1.11111],8897:[.55001,1.05,0,0,1.11111],8898:[.55001,1.05,0,0,1.11111],8899:[.55001,1.05,0,0,1.11111],8968:[.65002,1.15,0,0,.52778],8969:[.65002,1.15,0,0,.52778],8970:[.65002,1.15,0,0,.52778],8971:[.65002,1.15,0,0,.52778],10216:[.65002,1.15,0,0,.61111],10217:[.65002,1.15,0,0,.61111],10752:[.55001,1.05,0,0,1.51112],10753:[.55001,1.05,0,0,1.51112],10754:[.55001,1.05,0,0,1.51112],10756:[.55001,1.05,0,0,1.11111],10758:[.55001,1.05,0,0,1.11111]},"Size3-Regular":{32:[0,0,0,0,.25],40:[.95003,1.45,0,0,.73611],41:[.95003,1.45,0,0,.73611],47:[.95003,1.45,0,0,1.04445],91:[.95003,1.45,0,0,.52778],92:[.95003,1.45,0,0,1.04445],93:[.95003,1.45,0,0,.52778],123:[.95003,1.45,0,0,.75],125:[.95003,1.45,0,0,.75],160:[0,0,0,0,.25],710:[0,.75,0,0,1.44445],732:[0,.75,0,0,1.44445],770:[0,.75,0,0,1.44445],771:[0,.75,0,0,1.44445],8730:[.95003,1.45,0,0,1],8968:[.95003,1.45,0,0,.58334],8969:[.95003,1.45,0,0,.58334],8970:[.95003,1.45,0,0,.58334],8971:[.95003,1.45,0,0,.58334],10216:[.95003,1.45,0,0,.75],10217:[.95003,1.45,0,0,.75]},"Size4-Regular":{32:[0,0,0,0,.25],40:[1.25003,1.75,0,0,.79167],41:[1.25003,1.75,0,0,.79167],47:[1.25003,1.75,0,0,1.27778],91:[1.25003,1.75,0,0,.58334],92:[1.25003,1.75,0,0,1.27778],93:[1.25003,1.75,0,0,.58334],123:[1.25003,1.75,0,0,.80556],125:[1.25003,1.75,0,0,.80556],160:[0,0,0,0,.25],710:[0,.825,0,0,1.8889],732:[0,.825,0,0,1.8889],770:[0,.825,0,0,1.8889],771:[0,.825,0,0,1.8889],8730:[1.25003,1.75,0,0,1],8968:[1.25003,1.75,0,0,.63889],8969:[1.25003,1.75,0,0,.63889],8970:[1.25003,1.75,0,0,.63889],8971:[1.25003,1.75,0,0,.63889],9115:[.64502,1.155,0,0,.875],9116:[1e-5,.6,0,0,.875],9117:[.64502,1.155,0,0,.875],9118:[.64502,1.155,0,0,.875],9119:[1e-5,.6,0,0,.875],9120:[.64502,1.155,0,0,.875],9121:[.64502,1.155,0,0,.66667],9122:[-99e-5,.601,0,0,.66667],9123:[.64502,1.155,0,0,.66667],9124:[.64502,1.155,0,0,.66667],9125:[-99e-5,.601,0,0,.66667],9126:[.64502,1.155,0,0,.66667],9127:[1e-5,.9,0,0,.88889],9128:[.65002,1.15,0,0,.88889],9129:[.90001,0,0,0,.88889],9130:[0,.3,0,0,.88889],9131:[1e-5,.9,0,0,.88889],9132:[.65002,1.15,0,0,.88889],9133:[.90001,0,0,0,.88889],9143:[.88502,.915,0,0,1.05556],10216:[1.25003,1.75,0,0,.80556],10217:[1.25003,1.75,0,0,.80556],57344:[-.00499,.605,0,0,1.05556],57345:[-.00499,.605,0,0,1.05556],57680:[0,.12,0,0,.45],57681:[0,.12,0,0,.45],57682:[0,.12,0,0,.45],57683:[0,.12,0,0,.45]},"Typewriter-Regular":{32:[0,0,0,0,.525],33:[0,.61111,0,0,.525],34:[0,.61111,0,0,.525],35:[0,.61111,0,0,.525],36:[.08333,.69444,0,0,.525],37:[.08333,.69444,0,0,.525],38:[0,.61111,0,0,.525],39:[0,.61111,0,0,.525],40:[.08333,.69444,0,0,.525],41:[.08333,.69444,0,0,.525],42:[0,.52083,0,0,.525],43:[-.08056,.53055,0,0,.525],44:[.13889,.125,0,0,.525],45:[-.08056,.53055,0,0,.525],46:[0,.125,0,0,.525],47:[.08333,.69444,0,0,.525],48:[0,.61111,0,0,.525],49:[0,.61111,0,0,.525],50:[0,.61111,0,0,.525],51:[0,.61111,0,0,.525],52:[0,.61111,0,0,.525],53:[0,.61111,0,0,.525],54:[0,.61111,0,0,.525],55:[0,.61111,0,0,.525],56:[0,.61111,0,0,.525],57:[0,.61111,0,0,.525],58:[0,.43056,0,0,.525],59:[.13889,.43056,0,0,.525],60:[-.05556,.55556,0,0,.525],61:[-.19549,.41562,0,0,.525],62:[-.05556,.55556,0,0,.525],63:[0,.61111,0,0,.525],64:[0,.61111,0,0,.525],65:[0,.61111,0,0,.525],66:[0,.61111,0,0,.525],67:[0,.61111,0,0,.525],68:[0,.61111,0,0,.525],69:[0,.61111,0,0,.525],70:[0,.61111,0,0,.525],71:[0,.61111,0,0,.525],72:[0,.61111,0,0,.525],73:[0,.61111,0,0,.525],74:[0,.61111,0,0,.525],75:[0,.61111,0,0,.525],76:[0,.61111,0,0,.525],77:[0,.61111,0,0,.525],78:[0,.61111,0,0,.525],79:[0,.61111,0,0,.525],80:[0,.61111,0,0,.525],81:[.13889,.61111,0,0,.525],82:[0,.61111,0,0,.525],83:[0,.61111,0,0,.525],84:[0,.61111,0,0,.525],85:[0,.61111,0,0,.525],86:[0,.61111,0,0,.525],87:[0,.61111,0,0,.525],88:[0,.61111,0,0,.525],89:[0,.61111,0,0,.525],90:[0,.61111,0,0,.525],91:[.08333,.69444,0,0,.525],92:[.08333,.69444,0,0,.525],93:[.08333,.69444,0,0,.525],94:[0,.61111,0,0,.525],95:[.09514,0,0,0,.525],96:[0,.61111,0,0,.525],97:[0,.43056,0,0,.525],98:[0,.61111,0,0,.525],99:[0,.43056,0,0,.525],100:[0,.61111,0,0,.525],101:[0,.43056,0,0,.525],102:[0,.61111,0,0,.525],103:[.22222,.43056,0,0,.525],104:[0,.61111,0,0,.525],105:[0,.61111,0,0,.525],106:[.22222,.61111,0,0,.525],107:[0,.61111,0,0,.525],108:[0,.61111,0,0,.525],109:[0,.43056,0,0,.525],110:[0,.43056,0,0,.525],111:[0,.43056,0,0,.525],112:[.22222,.43056,0,0,.525],113:[.22222,.43056,0,0,.525],114:[0,.43056,0,0,.525],115:[0,.43056,0,0,.525],116:[0,.55358,0,0,.525],117:[0,.43056,0,0,.525],118:[0,.43056,0,0,.525],119:[0,.43056,0,0,.525],120:[0,.43056,0,0,.525],121:[.22222,.43056,0,0,.525],122:[0,.43056,0,0,.525],123:[.08333,.69444,0,0,.525],124:[.08333,.69444,0,0,.525],125:[.08333,.69444,0,0,.525],126:[0,.61111,0,0,.525],127:[0,.61111,0,0,.525],160:[0,0,0,0,.525],176:[0,.61111,0,0,.525],184:[.19445,0,0,0,.525],305:[0,.43056,0,0,.525],567:[.22222,.43056,0,0,.525],711:[0,.56597,0,0,.525],713:[0,.56555,0,0,.525],714:[0,.61111,0,0,.525],715:[0,.61111,0,0,.525],728:[0,.61111,0,0,.525],730:[0,.61111,0,0,.525],770:[0,.61111,0,0,.525],771:[0,.61111,0,0,.525],776:[0,.61111,0,0,.525],915:[0,.61111,0,0,.525],916:[0,.61111,0,0,.525],920:[0,.61111,0,0,.525],923:[0,.61111,0,0,.525],926:[0,.61111,0,0,.525],928:[0,.61111,0,0,.525],931:[0,.61111,0,0,.525],933:[0,.61111,0,0,.525],934:[0,.61111,0,0,.525],936:[0,.61111,0,0,.525],937:[0,.61111,0,0,.525],8216:[0,.61111,0,0,.525],8217:[0,.61111,0,0,.525],8242:[0,.61111,0,0,.525],9251:[.11111,.21944,0,0,.525]}},Ei={slant:[.25,.25,.25],space:[0,0,0],stretch:[0,0,0],shrink:[0,0,0],xHeight:[.431,.431,.431],quad:[1,1.171,1.472],extraSpace:[0,0,0],num1:[.677,.732,.925],num2:[.394,.384,.387],num3:[.444,.471,.504],denom1:[.686,.752,1.025],denom2:[.345,.344,.532],sup1:[.413,.503,.504],sup2:[.363,.431,.404],sup3:[.289,.286,.294],sub1:[.15,.143,.2],sub2:[.247,.286,.4],supDrop:[.386,.353,.494],subDrop:[.05,.071,.1],delim1:[2.39,1.7,1.98],delim2:[1.01,1.157,1.42],axisHeight:[.25,.25,.25],defaultRuleThickness:[.04,.049,.049],bigOpSpacing1:[.111,.111,.111],bigOpSpacing2:[.166,.166,.166],bigOpSpacing3:[.2,.2,.2],bigOpSpacing4:[.6,.611,.611],bigOpSpacing5:[.1,.143,.143],sqrtRuleThickness:[.04,.04,.04],ptPerEm:[10,10,10],doubleRuleSep:[.2,.2,.2],arrayRuleWidth:[.04,.04,.04],fboxsep:[.3,.3,.3],fboxrule:[.04,.04,.04]},Mc={Å:"A",Ç:"C",Ð:"D",Þ:"o",å:"a",ç:"c",ð:"d",þ:"o",А:"A",Б:"B",В:"B",Г:"F",Д:"A",Е:"E",Ж:"K",З:"3",И:"N",Й:"N",К:"K",Л:"N",М:"M",Н:"H",О:"O",П:"N",Р:"P",С:"C",Т:"T",У:"y",Ф:"O",Х:"X",Ц:"U",Ч:"h",Ш:"W",Щ:"W",Ъ:"B",Ы:"X",Ь:"B",Э:"3",Ю:"X",Я:"R",а:"a",б:"b",в:"a",г:"r",д:"y",е:"e",ж:"m",з:"e",и:"n",й:"n",к:"n",л:"n",м:"m",н:"n",о:"o",п:"n",р:"p",с:"c",т:"o",у:"y",ф:"b",х:"x",ц:"n",ч:"n",ш:"w",щ:"w",ъ:"a",ы:"m",ь:"a",э:"e",ю:"m",я:"r"};function ws(r,e,n){if(!Ke[e])throw new Error("Font metrics not found for font: "+e+".");var i=r.charCodeAt(0),t=Ke[e][i];if(!t&&r[0]in Mc&&(i=Mc[r[0]].charCodeAt(0),t=Ke[e][i]),t||n!=="text"||xp(i)&&(t=Ke[e][77]),t)return{depth:t[0],height:t[1],italic:t[2],skew:t[3],width:t[4]}}var aa={},eg={bin:1,close:1,inner:1,open:1,punct:1,rel:1},rg={"accent-token":1,mathord:1,"op-token":1,spacing:1,textord:1},Pt={math:{},text:{}};function d(r,e,n,i,t,l){Pt[r][t]={font:e,group:n,replace:i},l&&i&&(Pt[r][i]=Pt[r][t])}var g="math",$="text",x="main",T="ams",Zt="accent-token",lt="bin",pe="close",un="inner",bt="mathord",ee="op-token",ke="open",Di="punct",M="rel",ar="spacing",B="textord";d(g,x,M,"≡","\\equiv",!0),d(g,x,M,"≺","\\prec",!0),d(g,x,M,"≻","\\succ",!0),d(g,x,M,"∼","\\sim",!0),d(g,x,M,"⊥","\\perp"),d(g,x,M,"⪯","\\preceq",!0),d(g,x,M,"⪰","\\succeq",!0),d(g,x,M,"≃","\\simeq",!0),d(g,x,M,"∣","\\mid",!0),d(g,x,M,"≪","\\ll",!0),d(g,x,M,"≫","\\gg",!0),d(g,x,M,"≍","\\asymp",!0),d(g,x,M,"∥","\\parallel"),d(g,x,M,"⋈","\\bowtie",!0),d(g,x,M,"⌣","\\smile",!0),d(g,x,M,"⊑","\\sqsubseteq",!0),d(g,x,M,"⊒","\\sqsupseteq",!0),d(g,x,M,"≐","\\doteq",!0),d(g,x,M,"⌢","\\frown",!0),d(g,x,M,"∋","\\ni",!0),d(g,x,M,"∝","\\propto",!0),d(g,x,M,"⊢","\\vdash",!0),d(g,x,M,"⊣","\\dashv",!0),d(g,x,M,"∋","\\owns"),d(g,x,Di,".","\\ldotp"),d(g,x,Di,"⋅","\\cdotp"),d(g,x,B,"#","\\#"),d($,x,B,"#","\\#"),d(g,x,B,"&","\\&"),d($,x,B,"&","\\&"),d(g,x,B,"ℵ","\\aleph",!0),d(g,x,B,"∀","\\forall",!0),d(g,x,B,"ℏ","\\hbar",!0),d(g,x,B,"∃","\\exists",!0),d(g,x,B,"∇","\\nabla",!0),d(g,x,B,"♭","\\flat",!0),d(g,x,B,"ℓ","\\ell",!0),d(g,x,B,"♮","\\natural",!0),d(g,x,B,"♣","\\clubsuit",!0),d(g,x,B,"℘","\\wp",!0),d(g,x,B,"♯","\\sharp",!0),d(g,x,B,"♢","\\diamondsuit",!0),d(g,x,B,"ℜ","\\Re",!0),d(g,x,B,"♡","\\heartsuit",!0),d(g,x,B,"ℑ","\\Im",!0),d(g,x,B,"♠","\\spadesuit",!0),d(g,x,B,"§","\\S",!0),d($,x,B,"§","\\S"),d(g,x,B,"¶","\\P",!0),d($,x,B,"¶","\\P"),d(g,x,B,"†","\\dag"),d($,x,B,"†","\\dag"),d($,x,B,"†","\\textdagger"),d(g,x,B,"‡","\\ddag"),d($,x,B,"‡","\\ddag"),d($,x,B,"‡","\\textdaggerdbl"),d(g,x,pe,"⎱","\\rmoustache",!0),d(g,x,ke,"⎰","\\lmoustache",!0),d(g,x,pe,"⟯","\\rgroup",!0),d(g,x,ke,"⟮","\\lgroup",!0),d(g,x,lt,"∓","\\mp",!0),d(g,x,lt,"⊖","\\ominus",!0),d(g,x,lt,"⊎","\\uplus",!0),d(g,x,lt,"⊓","\\sqcap",!0),d(g,x,lt,"∗","\\ast"),d(g,x,lt,"⊔","\\sqcup",!0),d(g,x,lt,"◯","\\bigcirc",!0),d(g,x,lt,"∙","\\bullet"),d(g,x,lt,"‡","\\ddagger"),d(g,x,lt,"≀","\\wr",!0),d(g,x,lt,"⨿","\\amalg"),d(g,x,lt,"&","\\And"),d(g,x,M,"⟵","\\longleftarrow",!0),d(g,x,M,"⇐","\\Leftarrow",!0),d(g,x,M,"⟸","\\Longleftarrow",!0),d(g,x,M,"⟶","\\longrightarrow",!0),d(g,x,M,"⇒","\\Rightarrow",!0),d(g,x,M,"⟹","\\Longrightarrow",!0),d(g,x,M,"↔","\\leftrightarrow",!0),d(g,x,M,"⟷","\\longleftrightarrow",!0),d(g,x,M,"⇔","\\Leftrightarrow",!0),d(g,x,M,"⟺","\\Longleftrightarrow",!0),d(g,x,M,"↦","\\mapsto",!0),d(g,x,M,"⟼","\\longmapsto",!0),d(g,x,M,"↗","\\nearrow",!0),d(g,x,M,"↩","\\hookleftarrow",!0),d(g,x,M,"↪","\\hookrightarrow",!0),d(g,x,M,"↘","\\searrow",!0),d(g,x,M,"↼","\\leftharpoonup",!0),d(g,x,M,"⇀","\\rightharpoonup",!0),d(g,x,M,"↙","\\swarrow",!0),d(g,x,M,"↽","\\leftharpoondown",!0),d(g,x,M,"⇁","\\rightharpoondown",!0),d(g,x,M,"↖","\\nwarrow",!0),d(g,x,M,"⇌","\\rightleftharpoons",!0),d(g,T,M,"≮","\\nless",!0),d(g,T,M,"","\\@nleqslant"),d(g,T,M,"","\\@nleqq"),d(g,T,M,"⪇","\\lneq",!0),d(g,T,M,"≨","\\lneqq",!0),d(g,T,M,"","\\@lvertneqq"),d(g,T,M,"⋦","\\lnsim",!0),d(g,T,M,"⪉","\\lnapprox",!0),d(g,T,M,"⊀","\\nprec",!0),d(g,T,M,"⋠","\\npreceq",!0),d(g,T,M,"⋨","\\precnsim",!0),d(g,T,M,"⪹","\\precnapprox",!0),d(g,T,M,"≁","\\nsim",!0),d(g,T,M,"","\\@nshortmid"),d(g,T,M,"∤","\\nmid",!0),d(g,T,M,"⊬","\\nvdash",!0),d(g,T,M,"⊭","\\nvDash",!0),d(g,T,M,"⋪","\\ntriangleleft"),d(g,T,M,"⋬","\\ntrianglelefteq",!0),d(g,T,M,"⊊","\\subsetneq",!0),d(g,T,M,"","\\@varsubsetneq"),d(g,T,M,"⫋","\\subsetneqq",!0),d(g,T,M,"","\\@varsubsetneqq"),d(g,T,M,"≯","\\ngtr",!0),d(g,T,M,"","\\@ngeqslant"),d(g,T,M,"","\\@ngeqq"),d(g,T,M,"⪈","\\gneq",!0),d(g,T,M,"≩","\\gneqq",!0),d(g,T,M,"","\\@gvertneqq"),d(g,T,M,"⋧","\\gnsim",!0),d(g,T,M,"⪊","\\gnapprox",!0),d(g,T,M,"⊁","\\nsucc",!0),d(g,T,M,"⋡","\\nsucceq",!0),d(g,T,M,"⋩","\\succnsim",!0),d(g,T,M,"⪺","\\succnapprox",!0),d(g,T,M,"≆","\\ncong",!0),d(g,T,M,"","\\@nshortparallel"),d(g,T,M,"∦","\\nparallel",!0),d(g,T,M,"⊯","\\nVDash",!0),d(g,T,M,"⋫","\\ntriangleright"),d(g,T,M,"⋭","\\ntrianglerighteq",!0),d(g,T,M,"","\\@nsupseteqq"),d(g,T,M,"⊋","\\supsetneq",!0),d(g,T,M,"","\\@varsupsetneq"),d(g,T,M,"⫌","\\supsetneqq",!0),d(g,T,M,"","\\@varsupsetneqq"),d(g,T,M,"⊮","\\nVdash",!0),d(g,T,M,"⪵","\\precneqq",!0),d(g,T,M,"⪶","\\succneqq",!0),d(g,T,M,"","\\@nsubseteqq"),d(g,T,lt,"⊴","\\unlhd"),d(g,T,lt,"⊵","\\unrhd"),d(g,T,M,"↚","\\nleftarrow",!0),d(g,T,M,"↛","\\nrightarrow",!0),d(g,T,M,"⇍","\\nLeftarrow",!0),d(g,T,M,"⇏","\\nRightarrow",!0),d(g,T,M,"↮","\\nleftrightarrow",!0),d(g,T,M,"⇎","\\nLeftrightarrow",!0),d(g,T,M,"△","\\vartriangle"),d(g,T,B,"ℏ","\\hslash"),d(g,T,B,"▽","\\triangledown"),d(g,T,B,"◊","\\lozenge"),d(g,T,B,"Ⓢ","\\circledS"),d(g,T,B,"®","\\circledR"),d($,T,B,"®","\\circledR"),d(g,T,B,"∡","\\measuredangle",!0),d(g,T,B,"∄","\\nexists"),d(g,T,B,"℧","\\mho"),d(g,T,B,"Ⅎ","\\Finv",!0),d(g,T,B,"⅁","\\Game",!0),d(g,T,B,"‵","\\backprime"),d(g,T,B,"▲","\\blacktriangle"),d(g,T,B,"▼","\\blacktriangledown"),d(g,T,B,"■","\\blacksquare"),d(g,T,B,"⧫","\\blacklozenge"),d(g,T,B,"★","\\bigstar"),d(g,T,B,"∢","\\sphericalangle",!0),d(g,T,B,"∁","\\complement",!0),d(g,T,B,"ð","\\eth",!0),d($,x,B,"ð","ð"),d(g,T,B,"╱","\\diagup"),d(g,T,B,"╲","\\diagdown"),d(g,T,B,"□","\\square"),d(g,T,B,"□","\\Box"),d(g,T,B,"◊","\\Diamond"),d(g,T,B,"¥","\\yen",!0),d($,T,B,"¥","\\yen",!0),d(g,T,B,"✓","\\checkmark",!0),d($,T,B,"✓","\\checkmark"),d(g,T,B,"ℶ","\\beth",!0),d(g,T,B,"ℸ","\\daleth",!0),d(g,T,B,"ℷ","\\gimel",!0),d(g,T,B,"ϝ","\\digamma",!0),d(g,T,B,"ϰ","\\varkappa"),d(g,T,ke,"┌","\\@ulcorner",!0),d(g,T,pe,"┐","\\@urcorner",!0),d(g,T,ke,"└","\\@llcorner",!0),d(g,T,pe,"┘","\\@lrcorner",!0),d(g,T,M,"≦","\\leqq",!0),d(g,T,M,"⩽","\\leqslant",!0),d(g,T,M,"⪕","\\eqslantless",!0),d(g,T,M,"≲","\\lesssim",!0),d(g,T,M,"⪅","\\lessapprox",!0),d(g,T,M,"≊","\\approxeq",!0),d(g,T,lt,"⋖","\\lessdot"),d(g,T,M,"⋘","\\lll",!0),d(g,T,M,"≶","\\lessgtr",!0),d(g,T,M,"⋚","\\lesseqgtr",!0),d(g,T,M,"⪋","\\lesseqqgtr",!0),d(g,T,M,"≑","\\doteqdot"),d(g,T,M,"≓","\\risingdotseq",!0),d(g,T,M,"≒","\\fallingdotseq",!0),d(g,T,M,"∽","\\backsim",!0),d(g,T,M,"⋍","\\backsimeq",!0),d(g,T,M,"⫅","\\subseteqq",!0),d(g,T,M,"⋐","\\Subset",!0),d(g,T,M,"⊏","\\sqsubset",!0),d(g,T,M,"≼","\\preccurlyeq",!0),d(g,T,M,"⋞","\\curlyeqprec",!0),d(g,T,M,"≾","\\precsim",!0),d(g,T,M,"⪷","\\precapprox",!0),d(g,T,M,"⊲","\\vartriangleleft"),d(g,T,M,"⊴","\\trianglelefteq"),d(g,T,M,"⊨","\\vDash",!0),d(g,T,M,"⊪","\\Vvdash",!0),d(g,T,M,"⌣","\\smallsmile"),d(g,T,M,"⌢","\\smallfrown"),d(g,T,M,"≏","\\bumpeq",!0),d(g,T,M,"≎","\\Bumpeq",!0),d(g,T,M,"≧","\\geqq",!0),d(g,T,M,"⩾","\\geqslant",!0),d(g,T,M,"⪖","\\eqslantgtr",!0),d(g,T,M,"≳","\\gtrsim",!0),d(g,T,M,"⪆","\\gtrapprox",!0),d(g,T,lt,"⋗","\\gtrdot"),d(g,T,M,"⋙","\\ggg",!0),d(g,T,M,"≷","\\gtrless",!0),d(g,T,M,"⋛","\\gtreqless",!0),d(g,T,M,"⪌","\\gtreqqless",!0),d(g,T,M,"≖","\\eqcirc",!0),d(g,T,M,"≗","\\circeq",!0),d(g,T,M,"≜","\\triangleq",!0),d(g,T,M,"∼","\\thicksim"),d(g,T,M,"≈","\\thickapprox"),d(g,T,M,"⫆","\\supseteqq",!0),d(g,T,M,"⋑","\\Supset",!0),d(g,T,M,"⊐","\\sqsupset",!0),d(g,T,M,"≽","\\succcurlyeq",!0),d(g,T,M,"⋟","\\curlyeqsucc",!0),d(g,T,M,"≿","\\succsim",!0),d(g,T,M,"⪸","\\succapprox",!0),d(g,T,M,"⊳","\\vartriangleright"),d(g,T,M,"⊵","\\trianglerighteq"),d(g,T,M,"⊩","\\Vdash",!0),d(g,T,M,"∣","\\shortmid"),d(g,T,M,"∥","\\shortparallel"),d(g,T,M,"≬","\\between",!0),d(g,T,M,"⋔","\\pitchfork",!0),d(g,T,M,"∝","\\varpropto"),d(g,T,M,"◀","\\blacktriangleleft"),d(g,T,M,"∴","\\therefore",!0),d(g,T,M,"∍","\\backepsilon"),d(g,T,M,"▶","\\blacktriangleright"),d(g,T,M,"∵","\\because",!0),d(g,T,M,"⋘","\\llless"),d(g,T,M,"⋙","\\gggtr"),d(g,T,lt,"⊲","\\lhd"),d(g,T,lt,"⊳","\\rhd"),d(g,T,M,"≂","\\eqsim",!0),d(g,x,M,"⋈","\\Join"),d(g,T,M,"≑","\\Doteq",!0),d(g,T,lt,"∔","\\dotplus",!0),d(g,T,lt,"∖","\\smallsetminus"),d(g,T,lt,"⋒","\\Cap",!0),d(g,T,lt,"⋓","\\Cup",!0),d(g,T,lt,"⩞","\\doublebarwedge",!0),d(g,T,lt,"⊟","\\boxminus",!0),d(g,T,lt,"⊞","\\boxplus",!0),d(g,T,lt,"⋇","\\divideontimes",!0),d(g,T,lt,"⋉","\\ltimes",!0),d(g,T,lt,"⋊","\\rtimes",!0),d(g,T,lt,"⋋","\\leftthreetimes",!0),d(g,T,lt,"⋌","\\rightthreetimes",!0),d(g,T,lt,"⋏","\\curlywedge",!0),d(g,T,lt,"⋎","\\curlyvee",!0),d(g,T,lt,"⊝","\\circleddash",!0),d(g,T,lt,"⊛","\\circledast",!0),d(g,T,lt,"⋅","\\centerdot"),d(g,T,lt,"⊺","\\intercal",!0),d(g,T,lt,"⋒","\\doublecap"),d(g,T,lt,"⋓","\\doublecup"),d(g,T,lt,"⊠","\\boxtimes",!0),d(g,T,M,"⇢","\\dashrightarrow",!0),d(g,T,M,"⇠","\\dashleftarrow",!0),d(g,T,M,"⇇","\\leftleftarrows",!0),d(g,T,M,"⇆","\\leftrightarrows",!0),d(g,T,M,"⇚","\\Lleftarrow",!0),d(g,T,M,"↞","\\twoheadleftarrow",!0),d(g,T,M,"↢","\\leftarrowtail",!0),d(g,T,M,"↫","\\looparrowleft",!0),d(g,T,M,"⇋","\\leftrightharpoons",!0),d(g,T,M,"↶","\\curvearrowleft",!0),d(g,T,M,"↺","\\circlearrowleft",!0),d(g,T,M,"↰","\\Lsh",!0),d(g,T,M,"⇈","\\upuparrows",!0),d(g,T,M,"↿","\\upharpoonleft",!0),d(g,T,M,"⇃","\\downharpoonleft",!0),d(g,x,M,"⊶","\\origof",!0),d(g,x,M,"⊷","\\imageof",!0),d(g,T,M,"⊸","\\multimap",!0),d(g,T,M,"↭","\\leftrightsquigarrow",!0),d(g,T,M,"⇉","\\rightrightarrows",!0),d(g,T,M,"⇄","\\rightleftarrows",!0),d(g,T,M,"↠","\\twoheadrightarrow",!0),d(g,T,M,"↣","\\rightarrowtail",!0),d(g,T,M,"↬","\\looparrowright",!0),d(g,T,M,"↷","\\curvearrowright",!0),d(g,T,M,"↻","\\circlearrowright",!0),d(g,T,M,"↱","\\Rsh",!0),d(g,T,M,"⇊","\\downdownarrows",!0),d(g,T,M,"↾","\\upharpoonright",!0),d(g,T,M,"⇂","\\downharpoonright",!0),d(g,T,M,"⇝","\\rightsquigarrow",!0),d(g,T,M,"⇝","\\leadsto"),d(g,T,M,"⇛","\\Rrightarrow",!0),d(g,T,M,"↾","\\restriction"),d(g,x,B,"‘","`"),d(g,x,B,"$","\\$"),d($,x,B,"$","\\$"),d($,x,B,"$","\\textdollar"),d(g,x,B,"%","\\%"),d($,x,B,"%","\\%"),d(g,x,B,"_","\\_"),d($,x,B,"_","\\_"),d($,x,B,"_","\\textunderscore"),d(g,x,B,"∠","\\angle",!0),d(g,x,B,"∞","\\infty",!0),d(g,x,B,"′","\\prime"),d(g,x,B,"△","\\triangle"),d(g,x,B,"Γ","\\Gamma",!0),d(g,x,B,"Δ","\\Delta",!0),d(g,x,B,"Θ","\\Theta",!0),d(g,x,B,"Λ","\\Lambda",!0),d(g,x,B,"Ξ","\\Xi",!0),d(g,x,B,"Π","\\Pi",!0),d(g,x,B,"Σ","\\Sigma",!0),d(g,x,B,"Υ","\\Upsilon",!0),d(g,x,B,"Φ","\\Phi",!0),d(g,x,B,"Ψ","\\Psi",!0),d(g,x,B,"Ω","\\Omega",!0),d(g,x,B,"A","Α"),d(g,x,B,"B","Β"),d(g,x,B,"E","Ε"),d(g,x,B,"Z","Ζ"),d(g,x,B,"H","Η"),d(g,x,B,"I","Ι"),d(g,x,B,"K","Κ"),d(g,x,B,"M","Μ"),d(g,x,B,"N","Ν"),d(g,x,B,"O","Ο"),d(g,x,B,"P","Ρ"),d(g,x,B,"T","Τ"),d(g,x,B,"X","Χ"),d(g,x,B,"¬","\\neg",!0),d(g,x,B,"¬","\\lnot"),d(g,x,B,"⊤","\\top"),d(g,x,B,"⊥","\\bot"),d(g,x,B,"∅","\\emptyset"),d(g,T,B,"∅","\\varnothing"),d(g,x,bt,"α","\\alpha",!0),d(g,x,bt,"β","\\beta",!0),d(g,x,bt,"γ","\\gamma",!0),d(g,x,bt,"δ","\\delta",!0),d(g,x,bt,"ϵ","\\epsilon",!0),d(g,x,bt,"ζ","\\zeta",!0),d(g,x,bt,"η","\\eta",!0),d(g,x,bt,"θ","\\theta",!0),d(g,x,bt,"ι","\\iota",!0),d(g,x,bt,"κ","\\kappa",!0),d(g,x,bt,"λ","\\lambda",!0),d(g,x,bt,"μ","\\mu",!0),d(g,x,bt,"ν","\\nu",!0),d(g,x,bt,"ξ","\\xi",!0),d(g,x,bt,"ο","\\omicron",!0),d(g,x,bt,"π","\\pi",!0),d(g,x,bt,"ρ","\\rho",!0),d(g,x,bt,"σ","\\sigma",!0),d(g,x,bt,"τ","\\tau",!0),d(g,x,bt,"υ","\\upsilon",!0),d(g,x,bt,"ϕ","\\phi",!0),d(g,x,bt,"χ","\\chi",!0),d(g,x,bt,"ψ","\\psi",!0),d(g,x,bt,"ω","\\omega",!0),d(g,x,bt,"ε","\\varepsilon",!0),d(g,x,bt,"ϑ","\\vartheta",!0),d(g,x,bt,"ϖ","\\varpi",!0),d(g,x,bt,"ϱ","\\varrho",!0),d(g,x,bt,"ς","\\varsigma",!0),d(g,x,bt,"φ","\\varphi",!0),d(g,x,lt,"∗","*"),d(g,x,lt,"+","+"),d(g,x,lt,"−","-"),d(g,x,lt,"⋅","\\cdot",!0),d(g,x,lt,"∘","\\circ"),d(g,x,lt,"÷","\\div",!0),d(g,x,lt,"±","\\pm",!0),d(g,x,lt,"×","\\times",!0),d(g,x,lt,"∩","\\cap",!0),d(g,x,lt,"∪","\\cup",!0),d(g,x,lt,"∖","\\setminus"),d(g,x,lt,"∧","\\land"),d(g,x,lt,"∨","\\lor"),d(g,x,lt,"∧","\\wedge",!0),d(g,x,lt,"∨","\\vee",!0),d(g,x,B,"√","\\surd"),d(g,x,ke,"⟨","\\langle",!0),d(g,x,ke,"∣","\\lvert"),d(g,x,ke,"∥","\\lVert"),d(g,x,pe,"?","?"),d(g,x,pe,"!","!"),d(g,x,pe,"⟩","\\rangle",!0),d(g,x,pe,"∣","\\rvert"),d(g,x,pe,"∥","\\rVert"),d(g,x,M,"=","="),d(g,x,M,":",":"),d(g,x,M,"≈","\\approx",!0),d(g,x,M,"≅","\\cong",!0),d(g,x,M,"≥","\\ge"),d(g,x,M,"≥","\\geq",!0),d(g,x,M,"←","\\gets"),d(g,x,M,">","\\gt",!0),d(g,x,M,"∈","\\in",!0),d(g,x,M,"","\\@not"),d(g,x,M,"⊂","\\subset",!0),d(g,x,M,"⊃","\\supset",!0),d(g,x,M,"⊆","\\subseteq",!0),d(g,x,M,"⊇","\\supseteq",!0),d(g,T,M,"⊈","\\nsubseteq",!0),d(g,T,M,"⊉","\\nsupseteq",!0),d(g,x,M,"⊨","\\models"),d(g,x,M,"←","\\leftarrow",!0),d(g,x,M,"≤","\\le"),d(g,x,M,"≤","\\leq",!0),d(g,x,M,"<","\\lt",!0),d(g,x,M,"→","\\rightarrow",!0),d(g,x,M,"→","\\to"),d(g,T,M,"≱","\\ngeq",!0),d(g,T,M,"≰","\\nleq",!0),d(g,x,ar," ","\\ "),d(g,x,ar," ","\\space"),d(g,x,ar," ","\\nobreakspace"),d($,x,ar," ","\\ "),d($,x,ar," "," "),d($,x,ar," ","\\space"),d($,x,ar," ","\\nobreakspace"),d(g,x,ar,null,"\\nobreak"),d(g,x,ar,null,"\\allowbreak"),d(g,x,Di,",",","),d(g,x,Di,";",";"),d(g,T,lt,"⊼","\\barwedge",!0),d(g,T,lt,"⊻","\\veebar",!0),d(g,x,lt,"⊙","\\odot",!0),d(g,x,lt,"⊕","\\oplus",!0),d(g,x,lt,"⊗","\\otimes",!0),d(g,x,B,"∂","\\partial",!0),d(g,x,lt,"⊘","\\oslash",!0),d(g,T,lt,"⊚","\\circledcirc",!0),d(g,T,lt,"⊡","\\boxdot",!0),d(g,x,lt,"△","\\bigtriangleup"),d(g,x,lt,"▽","\\bigtriangledown"),d(g,x,lt,"†","\\dagger"),d(g,x,lt,"⋄","\\diamond"),d(g,x,lt,"⋆","\\star"),d(g,x,lt,"◃","\\triangleleft"),d(g,x,lt,"▹","\\triangleright"),d(g,x,ke,"{","\\{"),d($,x,B,"{","\\{"),d($,x,B,"{","\\textbraceleft"),d(g,x,pe,"}","\\}"),d($,x,B,"}","\\}"),d($,x,B,"}","\\textbraceright"),d(g,x,ke,"{","\\lbrace"),d(g,x,pe,"}","\\rbrace"),d(g,x,ke,"[","\\lbrack",!0),d($,x,B,"[","\\lbrack",!0),d(g,x,pe,"]","\\rbrack",!0),d($,x,B,"]","\\rbrack",!0),d(g,x,ke,"(","\\lparen",!0),d(g,x,pe,")","\\rparen",!0),d($,x,B,"<","\\textless",!0),d($,x,B,">","\\textgreater",!0),d(g,x,ke,"⌊","\\lfloor",!0),d(g,x,pe,"⌋","\\rfloor",!0),d(g,x,ke,"⌈","\\lceil",!0),d(g,x,pe,"⌉","\\rceil",!0),d(g,x,B,"\\","\\backslash"),d(g,x,B,"∣","|"),d(g,x,B,"∣","\\vert"),d($,x,B,"|","\\textbar",!0),d(g,x,B,"∥","\\|"),d(g,x,B,"∥","\\Vert"),d($,x,B,"∥","\\textbardbl"),d($,x,B,"~","\\textasciitilde"),d($,x,B,"\\","\\textbackslash"),d($,x,B,"^","\\textasciicircum"),d(g,x,M,"↑","\\uparrow",!0),d(g,x,M,"⇑","\\Uparrow",!0),d(g,x,M,"↓","\\downarrow",!0),d(g,x,M,"⇓","\\Downarrow",!0),d(g,x,M,"↕","\\updownarrow",!0),d(g,x,M,"⇕","\\Updownarrow",!0),d(g,x,ee,"∐","\\coprod"),d(g,x,ee,"⋁","\\bigvee"),d(g,x,ee,"⋀","\\bigwedge"),d(g,x,ee,"⨄","\\biguplus"),d(g,x,ee,"⋂","\\bigcap"),d(g,x,ee,"⋃","\\bigcup"),d(g,x,ee,"∫","\\int"),d(g,x,ee,"∫","\\intop"),d(g,x,ee,"∬","\\iint"),d(g,x,ee,"∭","\\iiint"),d(g,x,ee,"∏","\\prod"),d(g,x,ee,"∑","\\sum"),d(g,x,ee,"⨂","\\bigotimes"),d(g,x,ee,"⨁","\\bigoplus"),d(g,x,ee,"⨀","\\bigodot"),d(g,x,ee,"∮","\\oint"),d(g,x,ee,"∯","\\oiint"),d(g,x,ee,"∰","\\oiiint"),d(g,x,ee,"⨆","\\bigsqcup"),d(g,x,ee,"∫","\\smallint"),d($,x,un,"…","\\textellipsis"),d(g,x,un,"…","\\mathellipsis"),d($,x,un,"…","\\ldots",!0),d(g,x,un,"…","\\ldots",!0),d(g,x,un,"⋯","\\@cdots",!0),d(g,x,un,"⋱","\\ddots",!0),d(g,x,B,"⋮","\\varvdots"),d(g,x,Zt,"ˊ","\\acute"),d(g,x,Zt,"ˋ","\\grave"),d(g,x,Zt,"¨","\\ddot"),d(g,x,Zt,"~","\\tilde"),d(g,x,Zt,"ˉ","\\bar"),d(g,x,Zt,"˘","\\breve"),d(g,x,Zt,"ˇ","\\check"),d(g,x,Zt,"^","\\hat"),d(g,x,Zt,"⃗","\\vec"),d(g,x,Zt,"˙","\\dot"),d(g,x,Zt,"˚","\\mathring"),d(g,x,bt,"","\\@imath"),d(g,x,bt,"","\\@jmath"),d(g,x,B,"ı","ı"),d(g,x,B,"ȷ","ȷ"),d($,x,B,"ı","\\i",!0),d($,x,B,"ȷ","\\j",!0),d($,x,B,"ß","\\ss",!0),d($,x,B,"æ","\\ae",!0),d($,x,B,"œ","\\oe",!0),d($,x,B,"ø","\\o",!0),d($,x,B,"Æ","\\AE",!0),d($,x,B,"Œ","\\OE",!0),d($,x,B,"Ø","\\O",!0),d($,x,Zt,"ˊ","\\'"),d($,x,Zt,"ˋ","\\`"),d($,x,Zt,"ˆ","\\^"),d($,x,Zt,"˜","\\~"),d($,x,Zt,"ˉ","\\="),d($,x,Zt,"˘","\\u"),d($,x,Zt,"˙","\\."),d($,x,Zt,"˚","\\r"),d($,x,Zt,"ˇ","\\v"),d($,x,Zt,"¨",'\\"'),d($,x,Zt,"˝","\\H"),d($,x,Zt,"◯","\\textcircled");var _p={"--":!0,"---":!0,"``":!0,"''":!0};d($,x,B,"–","--",!0),d($,x,B,"–","\\textendash"),d($,x,B,"—","---",!0),d($,x,B,"—","\\textemdash"),d($,x,B,"‘","`",!0),d($,x,B,"‘","\\textquoteleft"),d($,x,B,"’","'",!0),d($,x,B,"’","\\textquoteright"),d($,x,B,"“","``",!0),d($,x,B,"“","\\textquotedblleft"),d($,x,B,"”","''",!0),d($,x,B,"”","\\textquotedblright"),d(g,x,B,"°","\\degree",!0),d($,x,B,"°","\\degree"),d($,x,B,"°","\\textdegree",!0),d(g,x,B,"£","\\pounds"),d(g,x,B,"£","\\mathsterling",!0),d($,x,B,"£","\\pounds"),d($,x,B,"£","\\textsterling",!0),d(g,T,B,"✠","\\maltese"),d($,T,B,"✠","\\maltese");for(var ng='0123456789/@."',sa=0;sa<14;sa++){var Ec=ng.charAt(sa);d(g,x,B,Ec,Ec)}for(var ig='0123456789!@*()-=+";:?/.,',la=0;la<25;la++){var Dc=ig.charAt(la);d($,x,B,Dc,Dc)}for(var Sp="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz",ua=0;ua<52;ua++){var Li=Sp.charAt(ua);d(g,x,bt,Li,Li),d($,x,B,Li,Li)}d(g,T,B,"C","ℂ"),d($,T,B,"C","ℂ"),d(g,T,B,"H","ℍ"),d($,T,B,"H","ℍ"),d(g,T,B,"N","ℕ"),d($,T,B,"N","ℕ"),d(g,T,B,"P","ℙ"),d($,T,B,"P","ℙ"),d(g,T,B,"Q","ℚ"),d($,T,B,"Q","ℚ"),d(g,T,B,"R","ℝ"),d($,T,B,"R","ℝ"),d(g,T,B,"Z","ℤ"),d($,T,B,"Z","ℤ"),d(g,x,bt,"h","ℎ"),d($,x,bt,"h","ℎ");for(var Nt="",ye=0;ye<52;ye++){var re=Sp.charAt(ye);d(g,x,bt,re,Nt=String.fromCharCode(55349,56320+ye)),d($,x,B,re,Nt),d(g,x,bt,re,Nt=String.fromCharCode(55349,56372+ye)),d($,x,B,re,Nt),d(g,x,bt,re,Nt=String.fromCharCode(55349,56424+ye)),d($,x,B,re,Nt),d(g,x,bt,re,Nt=String.fromCharCode(55349,56580+ye)),d($,x,B,re,Nt),d(g,x,bt,re,Nt=String.fromCharCode(55349,56736+ye)),d($,x,B,re,Nt),d(g,x,bt,re,Nt=String.fromCharCode(55349,56788+ye)),d($,x,B,re,Nt),d(g,x,bt,re,Nt=String.fromCharCode(55349,56840+ye)),d($,x,B,re,Nt),d(g,x,bt,re,Nt=String.fromCharCode(55349,56944+ye)),d($,x,B,re,Nt),ye<26&&(d(g,x,bt,re,Nt=String.fromCharCode(55349,56632+ye)),d($,x,B,re,Nt),d(g,x,bt,re,Nt=String.fromCharCode(55349,56476+ye)),d($,x,B,re,Nt))}d(g,x,bt,"k",Nt="𝕜"),d($,x,B,"k",Nt);for(var Er=0;Er<10;Er++){var br=Er.toString();d(g,x,bt,br,Nt=String.fromCharCode(55349,57294+Er)),d($,x,B,br,Nt),d(g,x,bt,br,Nt=String.fromCharCode(55349,57314+Er)),d($,x,B,br,Nt),d(g,x,bt,br,Nt=String.fromCharCode(55349,57324+Er)),d($,x,B,br,Nt),d(g,x,bt,br,Nt=String.fromCharCode(55349,57334+Er)),d($,x,B,br,Nt)}for(var qp="ÇÐÞçþ",ca=0;ca<5;ca++){var Bi=qp.charAt(ca);d(g,x,bt,Bi,Bi),d($,x,B,Bi,Bi)}var Ni=[["mathbf","textbf","Main-Bold"],["mathbf","textbf","Main-Bold"],["mathnormal","textit","Math-Italic"],["mathnormal","textit","Math-Italic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["mathscr","textscr","Script-Regular"],["","",""],["","",""],["","",""],["mathfrak","textfrak","Fraktur-Regular"],["mathfrak","textfrak","Fraktur-Regular"],["mathbb","textbb","AMS-Regular"],["mathbb","textbb","AMS-Regular"],["","",""],["","",""],["mathsf","textsf","SansSerif-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathitsf","textitsf","SansSerif-Italic"],["mathitsf","textitsf","SansSerif-Italic"],["","",""],["","",""],["mathtt","texttt","Typewriter-Regular"],["mathtt","texttt","Typewriter-Regular"]],Lc=[["mathbf","textbf","Main-Bold"],["","",""],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathtt","texttt","Typewriter-Regular"]],og=[[1,1,1],[2,1,1],[3,1,1],[4,2,1],[5,2,1],[6,3,1],[7,4,2],[8,6,3],[9,7,6],[10,8,7],[11,10,9]],Bc=[.5,.6,.7,.8,.9,1,1.2,1.44,1.728,2.074,2.488],Nc=function(r,e){return e.size<2?r:og[r-1][e.size-1]};class lr{constructor(e){this.style=void 0,this.color=void 0,this.size=void 0,this.textSize=void 0,this.phantom=void 0,this.font=void 0,this.fontFamily=void 0,this.fontWeight=void 0,this.fontShape=void 0,this.sizeMultiplier=void 0,this.maxSize=void 0,this.minRuleThickness=void 0,this._fontMetrics=void 0,this.style=e.style,this.color=e.color,this.size=e.size||lr.BASESIZE,this.textSize=e.textSize||this.size,this.phantom=!!e.phantom,this.font=e.font||"",this.fontFamily=e.fontFamily||"",this.fontWeight=e.fontWeight||"",this.fontShape=e.fontShape||"",this.sizeMultiplier=Bc[this.size-1],this.maxSize=e.maxSize,this.minRuleThickness=e.minRuleThickness,this._fontMetrics=void 0}extend(e){var n={style:this.style,size:this.size,textSize:this.textSize,color:this.color,phantom:this.phantom,font:this.font,fontFamily:this.fontFamily,fontWeight:this.fontWeight,fontShape:this.fontShape,maxSize:this.maxSize,minRuleThickness:this.minRuleThickness};for(var i in e)e.hasOwnProperty(i)&&(n[i]=e[i]);return new lr(n)}havingStyle(e){return this.style===e?this:this.extend({style:e,size:Nc(this.textSize,e)})}havingCrampedStyle(){return this.havingStyle(this.style.cramp())}havingSize(e){return this.size===e&&this.textSize===e?this:this.extend({style:this.style.text(),size:e,textSize:e,sizeMultiplier:Bc[e-1]})}havingBaseStyle(e){e=e||this.style.text();var n=Nc(lr.BASESIZE,e);return this.size===n&&this.textSize===lr.BASESIZE&&this.style===e?this:this.extend({style:e,size:n})}havingBaseSizing(){var e;switch(this.style.id){case 4:case 5:e=3;break;case 6:case 7:e=1;break;default:e=6}return this.extend({style:this.style.text(),size:e})}withColor(e){return this.extend({color:e})}withPhantom(){return this.extend({phantom:!0})}withFont(e){return this.extend({font:e})}withTextFontFamily(e){return this.extend({fontFamily:e,font:""})}withTextFontWeight(e){return this.extend({fontWeight:e,font:""})}withTextFontShape(e){return this.extend({fontShape:e,font:""})}sizingClasses(e){return e.size!==this.size?["sizing","reset-size"+e.size,"size"+this.size]:[]}baseSizingClasses(){return this.size!==lr.BASESIZE?["sizing","reset-size"+this.size,"size"+lr.BASESIZE]:[]}fontMetrics(){return this._fontMetrics||(this._fontMetrics=function(e){var n;if(!aa[n=e>=5?0:e>=3?1:2]){var i=aa[n]={cssEmPerMu:Ei.quad[n]/18};for(var t in Ei)Ei.hasOwnProperty(t)&&(i[t]=Ei[t][n])}return aa[n]}(this.size)),this._fontMetrics}getColor(){return this.phantom?"transparent":this.color}}lr.BASESIZE=6;var Xa={pt:1,mm:7227/2540,cm:7227/254,in:72.27,bp:1.00375,pc:12,dd:1238/1157,cc:14856/1157,nd:685/642,nc:1370/107,sp:1/65536,px:1.00375},ag={ex:!0,em:!0,mu:!0},Cp=function(r){return typeof r!="string"&&(r=r.unit),r in Xa||r in ag||r==="ex"},Qt=function(r,e){var n;if(r.unit in Xa)n=Xa[r.unit]/e.fontMetrics().ptPerEm/e.sizeMultiplier;else if(r.unit==="mu")n=e.fontMetrics().cssEmPerMu;else{var i;if(i=e.style.isTight()?e.havingStyle(e.style.text()):e,r.unit==="ex")n=i.fontMetrics().xHeight;else{if(r.unit!=="em")throw new rt("Invalid unit: '"+r.unit+"'");n=i.fontMetrics().quad}i!==e&&(n*=i.sizeMultiplier/e.sizeMultiplier)}return Math.min(r.number*n,e.maxSize)},Zi=function(r,e,n){return Pt[n][r]&&Pt[n][r].replace&&(r=Pt[n][r].replace),{value:r,metrics:ws(r,e,n)}},Ve=function(r,e,n,i,t){var l,h=Zi(r,e,n),p=h.metrics;if(r=h.value,p){var m=p.italic;(n==="text"||i&&i.font==="mathit")&&(m=0),l=new Oe(r,p.height,p.depth,m,p.skew,p.width,t)}else typeof console<"u"&&console.warn("No character metrics for '"+r+"' in style '"+e+"' and mode '"+n+"'"),l=new Oe(r,0,0,0,0,0,t);if(i){l.maxFontSize=i.sizeMultiplier,i.style.isTight()&&l.classes.push("mtight");var y=i.getColor();y&&(l.style.color=y)}return l},sg=(r,e)=>{if(_r(r.classes)!==_r(e.classes)||r.skew!==e.skew||r.maxFontSize!==e.maxFontSize)return!1;if(r.classes.length===1){var n=r.classes[0];if(n==="mbin"||n==="mord")return!1}for(var i in r.style)if(r.style.hasOwnProperty(i)&&r.style[i]!==e.style[i])return!1;for(var t in e.style)if(e.style.hasOwnProperty(t)&&r.style[t]!==e.style[t])return!1;return!0},ks=function(r){for(var e=0,n=0,i=0,t=0;t<r.children.length;t++){var l=r.children[t];l.height>e&&(e=l.height),l.depth>n&&(n=l.depth),l.maxFontSize>i&&(i=l.maxFontSize)}r.height=e,r.depth=n,r.maxFontSize=i},ve=function(r,e,n,i){var t=new Yn(r,e,n,i);return ks(t),t},Oc=(r,e,n,i)=>new Yn(r,e,n,i),Fc=function(r){var e=new Xn(r);return ks(e),e},Oi=function(r,e,n){var i="";switch(r){case"amsrm":i="AMS";break;case"textrm":i="Main";break;case"textsf":i="SansSerif";break;case"texttt":i="Typewriter";break;default:i=r}return i+"-"+(e==="textbf"&&n==="textit"?"BoldItalic":e==="textbf"?"Bold":e==="textit"?"Italic":"Regular")},Rc={mathbf:{variant:"bold",fontName:"Main-Bold"},mathrm:{variant:"normal",fontName:"Main-Regular"},textit:{variant:"italic",fontName:"Main-Italic"},mathit:{variant:"italic",fontName:"Main-Italic"},mathnormal:{variant:"italic",fontName:"Math-Italic"},mathbb:{variant:"double-struck",fontName:"AMS-Regular"},mathcal:{variant:"script",fontName:"Caligraphic-Regular"},mathfrak:{variant:"fraktur",fontName:"Fraktur-Regular"},mathscr:{variant:"script",fontName:"Script-Regular"},mathsf:{variant:"sans-serif",fontName:"SansSerif-Regular"},mathtt:{variant:"monospace",fontName:"Typewriter-Regular"}},Hc={vec:["vec",.471,.714],oiintSize1:["oiintSize1",.957,.499],oiintSize2:["oiintSize2",1.472,.659],oiiintSize1:["oiiintSize1",1.304,.499],oiiintSize2:["oiiintSize2",1.98,.659]},H={fontMap:Rc,makeSymbol:Ve,mathsym:function(r,e,n,i){return i===void 0&&(i=[]),n.font==="boldsymbol"&&Zi(r,"Main-Bold",e).metrics?Ve(r,"Main-Bold",e,n,i.concat(["mathbf"])):r==="\\"||Pt[e][r].font==="main"?Ve(r,"Main-Regular",e,n,i):Ve(r,"AMS-Regular",e,n,i.concat(["amsrm"]))},makeSpan:ve,makeSvgSpan:Oc,makeLineSpan:function(r,e,n){var i=ve([r],[],e);return i.height=Math.max(n||e.fontMetrics().defaultRuleThickness,e.minRuleThickness),i.style.borderBottomWidth=i.height+"em",i.maxFontSize=1,i},makeAnchor:function(r,e,n,i){var t=new xs(r,e,n,i);return ks(t),t},makeFragment:Fc,wrapFragment:function(r,e){return r instanceof Xn?ve([],[r],e):r},makeVList:function(r,e){for(var{children:n,depth:i}=function(L){if(L.positionType==="individualShift"){for(var G=L.children,j=[G[0]],Z=-G[0].shift-G[0].elem.depth,et=Z,Q=1;Q<G.length;Q++){var ut=-G[Q].shift-et-G[Q].elem.depth,at=ut-(G[Q-1].elem.height+G[Q-1].elem.depth);et+=ut,j.push({type:"kern",size:at}),j.push(G[Q])}return{children:j,depth:Z}}var Ct;if(L.positionType==="top"){for(var kt=L.positionData,Mt=0;Mt<L.children.length;Mt++){var Wt=L.children[Mt];kt-=Wt.type==="kern"?Wt.size:Wt.elem.height+Wt.elem.depth}Ct=kt}else if(L.positionType==="bottom")Ct=-L.positionData;else{var Rt=L.children[0];if(Rt.type!=="elem")throw new Error('First child must have type "elem".');if(L.positionType==="shift")Ct=-Rt.elem.depth-L.positionData;else{if(L.positionType!=="firstBaseline")throw new Error("Invalid positionType "+L.positionType+".");Ct=-Rt.elem.depth}}return{children:L.children,depth:Ct}}(r),t=0,l=0;l<n.length;l++){var h=n[l];if(h.type==="elem"){var p=h.elem;t=Math.max(t,p.maxFontSize,p.height)}}t+=2;var m=ve(["pstrut"],[]);m.style.height=t+"em";for(var y=[],_=i,S=i,E=i,R=0;R<n.length;R++){var I=n[R];if(I.type==="kern")E+=I.size;else{var U=I.elem,Y=I.wrapperClasses||[],it=I.wrapperStyle||{},nt=ve(Y,[m,U],void 0,it);nt.style.top=-t-E-U.depth+"em",I.marginLeft&&(nt.style.marginLeft=I.marginLeft),I.marginRight&&(nt.style.marginRight=I.marginRight),y.push(nt),E+=U.height+U.depth}_=Math.min(_,E),S=Math.max(S,E)}var pt,dt=ve(["vlist"],y);if(dt.style.height=S+"em",_<0){var yt=ve([],[]),D=ve(["vlist"],[yt]);D.style.height=-_+"em";var At=ve(["vlist-s"],[new Oe("​")]);pt=[ve(["vlist-r"],[dt,At]),ve(["vlist-r"],[D])]}else pt=[ve(["vlist-r"],[dt])];var q=ve(["vlist-t"],pt);return pt.length===2&&q.classes.push("vlist-t2"),q.height=S,q.depth=-_,q},makeOrd:function(r,e,n){var i=r.mode,t=r.text,l=["mord"],h=i==="math"||i==="text"&&e.font,p=h?e.font:e.fontFamily;if(t.charCodeAt(0)===55349){var[m,y]=function(pt,dt){var yt=1024*(pt.charCodeAt(0)-55296)+(pt.charCodeAt(1)-56320)+65536,D=dt==="math"?0:1;if(119808<=yt&&yt<120484){var At=Math.floor((yt-119808)/26);return[Ni[At][2],Ni[At][D]]}if(120782<=yt&&yt<=120831){var q=Math.floor((yt-120782)/10);return[Lc[q][2],Lc[q][D]]}if(yt===120485||yt===120486)return[Ni[0][2],Ni[0][D]];if(120486<yt&&yt<120782)return["",""];throw new rt("Unsupported character: "+pt)}(t,i);return Ve(t,m,i,e,l.concat(y))}if(p){var _,S;if(p==="boldsymbol"){var E=function(pt,dt,yt,D,At){return At!=="textord"&&Zi(pt,"Math-BoldItalic",dt).metrics?{fontName:"Math-BoldItalic",fontClass:"boldsymbol"}:{fontName:"Main-Bold",fontClass:"mathbf"}}(t,i,0,0,n);_=E.fontName,S=[E.fontClass]}else h?(_=Rc[p].fontName,S=[p]):(_=Oi(p,e.fontWeight,e.fontShape),S=[p,e.fontWeight,e.fontShape]);if(Zi(t,_,i).metrics)return Ve(t,_,i,e,l.concat(S));if(_p.hasOwnProperty(t)&&_.substr(0,10)==="Typewriter"){for(var R=[],I=0;I<t.length;I++)R.push(Ve(t[I],_,i,e,l.concat(S)));return Fc(R)}}if(n==="mathord")return Ve(t,"Math-Italic",i,e,l.concat(["mathnormal"]));if(n==="textord"){var U=Pt[i][t]&&Pt[i][t].font;if(U==="ams"){var Y=Oi("amsrm",e.fontWeight,e.fontShape);return Ve(t,Y,i,e,l.concat("amsrm",e.fontWeight,e.fontShape))}if(U!=="main"&&U){var it=Oi(U,e.fontWeight,e.fontShape);return Ve(t,it,i,e,l.concat(it,e.fontWeight,e.fontShape))}var nt=Oi("textrm",e.fontWeight,e.fontShape);return Ve(t,nt,i,e,l.concat(e.fontWeight,e.fontShape))}throw new Error("unexpected type: "+n+" in makeOrd")},makeGlue:(r,e)=>{var n=ve(["mspace"],[],e),i=Qt(r,e);return n.style.marginRight=i+"em",n},staticSvg:function(r,e){var[n,i,t]=Hc[r],l=new Hr(n),h=new Sr([l],{width:i+"em",height:t+"em",style:"width:"+i+"em",viewBox:"0 0 "+1e3*i+" "+1e3*t,preserveAspectRatio:"xMinYMin"}),p=Oc(["overlay"],[h],e);return p.height=t,p.style.height=t+"em",p.style.width=i+"em",p},svgData:Hc,tryCombineChars:r=>{for(var e=0;e<r.length-1;e++){var n=r[e],i=r[e+1];n instanceof Oe&&i instanceof Oe&&sg(n,i)&&(n.text+=i.text,n.height=Math.max(n.height,i.height),n.depth=Math.max(n.depth,i.depth),n.italic=i.italic,r.splice(e+1,1),e--)}return r}},Jt={number:3,unit:"mu"},Dr={number:4,unit:"mu"},sr={number:5,unit:"mu"},lg={mord:{mop:Jt,mbin:Dr,mrel:sr,minner:Jt},mop:{mord:Jt,mop:Jt,mrel:sr,minner:Jt},mbin:{mord:Dr,mop:Dr,mopen:Dr,minner:Dr},mrel:{mord:sr,mop:sr,mopen:sr,minner:sr},mopen:{},mclose:{mop:Jt,mbin:Dr,mrel:sr,minner:Jt},mpunct:{mord:Jt,mop:Jt,mrel:sr,mopen:Jt,mclose:Jt,mpunct:Jt,minner:Jt},minner:{mord:Jt,mop:Jt,mbin:Dr,mrel:sr,mopen:Jt,mpunct:Jt,minner:Jt}},ug={mord:{mop:Jt},mop:{mord:Jt,mop:Jt},mbin:{},mrel:{},mopen:{},mclose:{mop:Jt},mpunct:{},minner:{mop:Jt}},zp={},to={},eo={};function st(r){for(var{type:e,names:n,props:i,handler:t,htmlBuilder:l,mathmlBuilder:h}=r,p={type:e,numArgs:i.numArgs,argTypes:i.argTypes,allowedInArgument:!!i.allowedInArgument,allowedInText:!!i.allowedInText,allowedInMath:i.allowedInMath===void 0||i.allowedInMath,numOptionalArgs:i.numOptionalArgs||0,infix:!!i.infix,primitive:!!i.primitive,handler:t},m=0;m<n.length;++m)zp[n[m]]=p;e&&(l&&(to[e]=l),h&&(eo[e]=h))}function Vr(r){var{type:e,htmlBuilder:n,mathmlBuilder:i}=r;st({type:e,names:[],props:{numArgs:0},handler(){throw new Error("Should never be called.")},htmlBuilder:n,mathmlBuilder:i})}var ro=function(r){return r.type==="ordgroup"&&r.body.length===1?r.body[0]:r},ie=function(r){return r.type==="ordgroup"?r.body:[r]},cr=H.makeSpan,cg=["leftmost","mbin","mopen","mrel","mop","mpunct"],hg=["rightmost","mrel","mclose","mpunct"],pg={display:gt.DISPLAY,text:gt.TEXT,script:gt.SCRIPT,scriptscript:gt.SCRIPTSCRIPT},dg={mord:"mord",mop:"mop",mbin:"mbin",mrel:"mrel",mopen:"mopen",mclose:"mclose",mpunct:"mpunct",minner:"minner"},ae=function(r,e,n,i){i===void 0&&(i=[null,null]);for(var t=[],l=0;l<r.length;l++){var h=Tt(r[l],e);if(h instanceof Xn){var p=h.children;t.push(...p)}else t.push(h)}if(H.tryCombineChars(t),!n)return t;var m=e;if(r.length===1){var y=r[0];y.type==="sizing"?m=e.havingSize(y.size):y.type==="styling"&&(m=e.havingStyle(pg[y.style]))}var _=cr([i[0]||"leftmost"],[],e),S=cr([i[1]||"rightmost"],[],e),E=n==="root";return Vc(t,(R,I)=>{var U=I.classes[0],Y=R.classes[0];U==="mbin"&&ht.contains(hg,Y)?I.classes[0]="mord":Y==="mbin"&&ht.contains(cg,U)&&(R.classes[0]="mord")},{node:_},S,E),Vc(t,(R,I)=>{var U=Ya(I),Y=Ya(R),it=U&&Y?R.hasClass("mtight")?ug[U][Y]:lg[U][Y]:null;if(it)return H.makeGlue(it,m)},{node:_},S,E),t},Vc=function r(e,n,i,t,l){t&&e.push(t);for(var h=0;h<e.length;h++){var p=e[h],m=Tp(p);if(m)r(m.children,n,i,null,l);else{var y=!p.hasClass("mspace");if(y){var _=n(p,i.node);_&&(i.insertAfter?i.insertAfter(_):(e.unshift(_),h++))}y?i.node=p:l&&p.hasClass("newline")&&(i.node=cr(["leftmost"])),i.insertAfter=(S=>E=>{e.splice(S+1,0,E),h++})(h)}}t&&e.pop()},Tp=function(r){return r instanceof Xn||r instanceof xs||r instanceof Yn&&r.hasClass("enclosing")?r:null},mg=function r(e,n){var i=Tp(e);if(i){var t=i.children;if(t.length){if(n==="right")return r(t[t.length-1],"right");if(n==="left")return r(t[0],"left")}}return e},Ya=function(r,e){return r?(e&&(r=mg(r,e)),dg[r.classes[0]]||null):null},Nn=function(r,e){var n=["nulldelimiter"].concat(r.baseSizingClasses());return cr(e.concat(n))},Tt=function(r,e,n){if(!r)return cr();if(to[r.type]){var i=to[r.type](r,e);if(n&&e.size!==n.size){i=cr(e.sizingClasses(n),[i],e);var t=e.sizeMultiplier/n.sizeMultiplier;i.height*=t,i.depth*=t}return i}throw new rt("Got group of unknown type: '"+r.type+"'")};function Fi(r,e){var n=cr(["base"],r,e),i=cr(["strut"]);return i.style.height=n.height+n.depth+"em",i.style.verticalAlign=-n.depth+"em",n.children.unshift(i),n}function Wa(r,e){var n=null;r.length===1&&r[0].type==="tag"&&(n=r[0].tag,r=r[0].body);var i,t=ae(r,e,"root");t.length===2&&t[1].hasClass("tag")&&(i=t.pop());for(var l,h=[],p=[],m=0;m<t.length;m++)if(p.push(t[m]),t[m].hasClass("mbin")||t[m].hasClass("mrel")||t[m].hasClass("allowbreak")){for(var y=!1;m<t.length-1&&t[m+1].hasClass("mspace")&&!t[m+1].hasClass("newline");)m++,p.push(t[m]),t[m].hasClass("nobreak")&&(y=!0);y||(h.push(Fi(p,e)),p=[])}else t[m].hasClass("newline")&&(p.pop(),p.length>0&&(h.push(Fi(p,e)),p=[]),h.push(t[m]));p.length>0&&h.push(Fi(p,e)),n?((l=Fi(ae(n,e,!0))).classes=["tag"],h.push(l)):i&&h.push(i);var _=cr(["katex-html"],h);if(_.setAttribute("aria-hidden","true"),l){var S=l.children[0];S.style.height=_.height+_.depth+"em",S.style.verticalAlign=-_.depth+"em"}return _}function Mp(r){return new Xn(r)}class Be{constructor(e,n,i){this.type=void 0,this.attributes=void 0,this.children=void 0,this.classes=void 0,this.type=e,this.attributes={},this.children=n||[],this.classes=i||[]}setAttribute(e,n){this.attributes[e]=n}getAttribute(e){return this.attributes[e]}toNode(){var e=document.createElementNS("http://www.w3.org/1998/Math/MathML",this.type);for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&e.setAttribute(n,this.attributes[n]);this.classes.length>0&&(e.className=_r(this.classes));for(var i=0;i<this.children.length;i++)e.appendChild(this.children[i].toNode());return e}toMarkup(){var e="<"+this.type;for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(e+=" "+n+'="',e+=ht.escape(this.attributes[n]),e+='"');this.classes.length>0&&(e+=' class ="'+ht.escape(_r(this.classes))+'"'),e+=">";for(var i=0;i<this.children.length;i++)e+=this.children[i].toMarkup();return e+="</"+this.type+">"}toText(){return this.children.map(e=>e.toText()).join("")}}class On{constructor(e){this.text=void 0,this.text=e}toNode(){return document.createTextNode(this.text)}toMarkup(){return ht.escape(this.toText())}toText(){return this.text}}var J={MathNode:Be,TextNode:On,SpaceNode:class{constructor(r){this.width=void 0,this.character=void 0,this.width=r,this.character=r>=.05555&&r<=.05556?" ":r>=.1666&&r<=.1667?" ":r>=.2222&&r<=.2223?" ":r>=.2777&&r<=.2778?"  ":r>=-.05556&&r<=-.05555?" ⁣":r>=-.1667&&r<=-.1666?" ⁣":r>=-.2223&&r<=-.2222?" ⁣":r>=-.2778&&r<=-.2777?" ⁣":null}toNode(){if(this.character)return document.createTextNode(this.character);var r=document.createElementNS("http://www.w3.org/1998/Math/MathML","mspace");return r.setAttribute("width",this.width+"em"),r}toMarkup(){return this.character?"<mtext>"+this.character+"</mtext>":'<mspace width="'+this.width+'em"/>'}toText(){return this.character?this.character:" "}},newDocumentFragment:Mp},Ne=function(r,e,n){return!Pt[e][r]||!Pt[e][r].replace||r.charCodeAt(0)===55349||_p.hasOwnProperty(r)&&n&&(n.fontFamily&&n.fontFamily.substr(4,2)==="tt"||n.font&&n.font.substr(4,2)==="tt")||(r=Pt[e][r].replace),new J.TextNode(r)},As=function(r){return r.length===1?r[0]:new J.MathNode("mrow",r)},$a=function(r,e){if(e.fontFamily==="texttt")return"monospace";if(e.fontFamily==="textsf")return e.fontShape==="textit"&&e.fontWeight==="textbf"?"sans-serif-bold-italic":e.fontShape==="textit"?"sans-serif-italic":e.fontWeight==="textbf"?"bold-sans-serif":"sans-serif";if(e.fontShape==="textit"&&e.fontWeight==="textbf")return"bold-italic";if(e.fontShape==="textit")return"italic";if(e.fontWeight==="textbf")return"bold";var n=e.font;if(!n||n==="mathnormal")return null;var i=r.mode;if(n==="mathit")return"italic";if(n==="boldsymbol")return r.type==="textord"?"bold":"bold-italic";if(n==="mathbf")return"bold";if(n==="mathbb")return"double-struck";if(n==="mathfrak")return"fraktur";if(n==="mathscr"||n==="mathcal")return"script";if(n==="mathsf")return"sans-serif";if(n==="mathtt")return"monospace";var t=r.text;return ht.contains(["\\imath","\\jmath"],t)?null:(Pt[i][t]&&Pt[i][t].replace&&(t=Pt[i][t].replace),ws(t,H.fontMap[n].fontName,i)?H.fontMap[n].variant:null)},_e=function(r,e,n){if(r.length===1){var i=Vt(r[0],e);return n&&i instanceof Be&&i.type==="mo"&&(i.setAttribute("lspace","0em"),i.setAttribute("rspace","0em")),[i]}for(var t,l=[],h=0;h<r.length;h++){var p=Vt(r[h],e);if(p instanceof Be&&t instanceof Be){if(p.type==="mtext"&&t.type==="mtext"&&p.getAttribute("mathvariant")===t.getAttribute("mathvariant")){t.children.push(...p.children);continue}if(p.type==="mn"&&t.type==="mn"){t.children.push(...p.children);continue}if(p.type==="mi"&&p.children.length===1&&t.type==="mn"){var m=p.children[0];if(m instanceof On&&m.text==="."){t.children.push(...p.children);continue}}else if(t.type==="mi"&&t.children.length===1){var y=t.children[0];if(y instanceof On&&y.text==="̸"&&(p.type==="mo"||p.type==="mi"||p.type==="mn")){var _=p.children[0];_ instanceof On&&_.text.length>0&&(_.text=_.text.slice(0,1)+"̸"+_.text.slice(1),l.pop())}}}l.push(p),t=p}return l},wr=function(r,e,n){return As(_e(r,e,n))},Vt=function(r,e){if(!r)return new J.MathNode("mrow");if(eo[r.type])return eo[r.type](r,e);throw new rt("Got group of unknown type: '"+r.type+"'")};function Ic(r,e,n,i,t){var l,h=_e(r,n);l=h.length===1&&h[0]instanceof Be&&ht.contains(["mrow","mtable"],h[0].type)?h[0]:new J.MathNode("mrow",h);var p=new J.MathNode("annotation",[new J.TextNode(e)]);p.setAttribute("encoding","application/x-tex");var m=new J.MathNode("semantics",[l,p]),y=new J.MathNode("math",[m]);y.setAttribute("xmlns","http://www.w3.org/1998/Math/MathML"),i&&y.setAttribute("display","block");var _=t?"katex":"katex-mathml";return H.makeSpan([_],[y])}var Ep=function(r){return new lr({style:r.displayMode?gt.DISPLAY:gt.TEXT,maxSize:r.maxSize,minRuleThickness:r.minRuleThickness})},Dp=function(r,e){if(e.displayMode){var n=["katex-display"];e.leqno&&n.push("leqno"),e.fleqn&&n.push("fleqn"),r=H.makeSpan(n,[r])}return r},fg={widehat:"^",widecheck:"ˇ",widetilde:"~",utilde:"~",overleftarrow:"←",underleftarrow:"←",xleftarrow:"←",overrightarrow:"→",underrightarrow:"→",xrightarrow:"→",underbrace:"⏟",overbrace:"⏞",overgroup:"⏠",undergroup:"⏡",overleftrightarrow:"↔",underleftrightarrow:"↔",xleftrightarrow:"↔",Overrightarrow:"⇒",xRightarrow:"⇒",overleftharpoon:"↼",xleftharpoonup:"↼",overrightharpoon:"⇀",xrightharpoonup:"⇀",xLeftarrow:"⇐",xLeftrightarrow:"⇔",xhookleftarrow:"↩",xhookrightarrow:"↪",xmapsto:"↦",xrightharpoondown:"⇁",xleftharpoondown:"↽",xrightleftharpoons:"⇌",xleftrightharpoons:"⇋",xtwoheadleftarrow:"↞",xtwoheadrightarrow:"↠",xlongequal:"=",xtofrom:"⇄",xrightleftarrows:"⇄",xrightequilibrium:"⇌",xleftequilibrium:"⇋","\\cdrightarrow":"→","\\cdleftarrow":"←","\\cdlongequal":"="},gg={overrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],overleftarrow:[["leftarrow"],.888,522,"xMinYMin"],underrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],underleftarrow:[["leftarrow"],.888,522,"xMinYMin"],xrightarrow:[["rightarrow"],1.469,522,"xMaxYMin"],"\\cdrightarrow":[["rightarrow"],3,522,"xMaxYMin"],xleftarrow:[["leftarrow"],1.469,522,"xMinYMin"],"\\cdleftarrow":[["leftarrow"],3,522,"xMinYMin"],Overrightarrow:[["doublerightarrow"],.888,560,"xMaxYMin"],xRightarrow:[["doublerightarrow"],1.526,560,"xMaxYMin"],xLeftarrow:[["doubleleftarrow"],1.526,560,"xMinYMin"],overleftharpoon:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoonup:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoondown:[["leftharpoondown"],.888,522,"xMinYMin"],overrightharpoon:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoonup:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoondown:[["rightharpoondown"],.888,522,"xMaxYMin"],xlongequal:[["longequal"],.888,334,"xMinYMin"],"\\cdlongequal":[["longequal"],3,334,"xMinYMin"],xtwoheadleftarrow:[["twoheadleftarrow"],.888,334,"xMinYMin"],xtwoheadrightarrow:[["twoheadrightarrow"],.888,334,"xMaxYMin"],overleftrightarrow:[["leftarrow","rightarrow"],.888,522],overbrace:[["leftbrace","midbrace","rightbrace"],1.6,548],underbrace:[["leftbraceunder","midbraceunder","rightbraceunder"],1.6,548],underleftrightarrow:[["leftarrow","rightarrow"],.888,522],xleftrightarrow:[["leftarrow","rightarrow"],1.75,522],xLeftrightarrow:[["doubleleftarrow","doublerightarrow"],1.75,560],xrightleftharpoons:[["leftharpoondownplus","rightharpoonplus"],1.75,716],xleftrightharpoons:[["leftharpoonplus","rightharpoondownplus"],1.75,716],xhookleftarrow:[["leftarrow","righthook"],1.08,522],xhookrightarrow:[["lefthook","rightarrow"],1.08,522],overlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],underlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],overgroup:[["leftgroup","rightgroup"],.888,342],undergroup:[["leftgroupunder","rightgroupunder"],.888,342],xmapsto:[["leftmapsto","rightarrow"],1.5,522],xtofrom:[["leftToFrom","rightToFrom"],1.75,528],xrightleftarrows:[["baraboveleftarrow","rightarrowabovebar"],1.75,901],xrightequilibrium:[["baraboveshortleftharpoon","rightharpoonaboveshortbar"],1.75,716],xleftequilibrium:[["shortbaraboveleftharpoon","shortrightharpoonabovebar"],1.75,716]},bg=function(r,e,n,i,t){var l,h=r.height+r.depth+n+i;if(/fbox|color|angl/.test(e)){if(l=H.makeSpan(["stretchy",e],[],t),e==="fbox"){var p=t.color&&t.getColor();p&&(l.style.borderColor=p)}}else{var m=[];/^[bx]cancel$/.test(e)&&m.push(new Ua({x1:"0",y1:"0",x2:"100%",y2:"100%","stroke-width":"0.046em"})),/^x?cancel$/.test(e)&&m.push(new Ua({x1:"0",y1:"100%",x2:"100%",y2:"0","stroke-width":"0.046em"}));var y=new Sr(m,{width:"100%",height:h+"em"});l=H.makeSvgSpan([],[y],t)}return l.height=h,l.style.height=h+"em",l},ao=function(r){var e=new J.MathNode("mo",[new J.TextNode(fg[r.replace(/^\\/,"")])]);return e.setAttribute("stretchy","true"),e},so=function(r,e){var{span:n,minWidth:i,height:t}=function(){var l=4e5,h=r.label.substr(1);if(ht.contains(["widehat","widecheck","widetilde","utilde"],h)){var p,m,y,_=(Y=r.base).type==="ordgroup"?Y.body.length:1;if(_>5)h==="widehat"||h==="widecheck"?(p=420,l=2364,y=.42,m=h+"4"):(p=312,l=2340,y=.34,m="tilde4");else{var S=[1,1,2,2,3,3][_];h==="widehat"||h==="widecheck"?(l=[0,1062,2364,2364,2364][S],p=[0,239,300,360,420][S],y=[0,.24,.3,.3,.36,.42][S],m=h+S):(l=[0,600,1033,2339,2340][S],p=[0,260,286,306,312][S],y=[0,.26,.286,.3,.306,.34][S],m="tilde"+S)}var E=new Hr(m),R=new Sr([E],{width:"100%",height:y+"em",viewBox:"0 0 "+l+" "+p,preserveAspectRatio:"none"});return{span:H.makeSvgSpan([],[R],e),minWidth:0,height:y}}var I,U,Y,it=[],nt=gg[h],[pt,dt,yt]=nt,D=yt/1e3,At=pt.length;if(At===1)I=["hide-tail"],U=[nt[3]];else if(At===2)I=["halfarrow-left","halfarrow-right"],U=["xMinYMin","xMaxYMin"];else{if(At!==3)throw new Error(`Correct katexImagesData or update code here to support
                    `+At+" children.");I=["brace-left","brace-center","brace-right"],U=["xMinYMin","xMidYMin","xMaxYMin"]}for(var q=0;q<At;q++){var L=new Hr(pt[q]),G=new Sr([L],{width:"400em",height:D+"em",viewBox:"0 0 "+l+" "+yt,preserveAspectRatio:U[q]+" slice"}),j=H.makeSvgSpan([I[q]],[G],e);if(At===1)return{span:j,minWidth:dt,height:D};j.style.height=D+"em",it.push(j)}return{span:H.makeSpan(["stretchy"],it,e),minWidth:dt,height:D}}();return n.height=t,n.style.height=t+"em",i>0&&(n.style.minWidth=i+"em"),n};function wt(r,e){if(!r||r.type!==e)throw new Error("Expected node of type "+e+", but got "+(r?"node of type "+r.type:String(r)));return r}function ha(r){var e=no(r);if(!e)throw new Error("Expected node of symbol group type, but got "+(r?"node of type "+r.type:String(r)));return e}function no(r){return r&&(r.type==="atom"||rg.hasOwnProperty(r.type))?r:null}var Za=(r,e)=>{var n,i,t;r&&r.type==="supsub"?(n=(i=wt(r.base,"accent")).base,r.base=n,t=function(U){if(U instanceof Yn)return U;throw new Error("Expected span<HtmlDomNode> but got "+String(U)+".")}(Tt(r,e)),r.base=i):n=(i=wt(r,"accent")).base;var l=Tt(n,e.havingCrampedStyle()),h=0;if(i.isShifty&&ht.isCharacterBox(n)){var p=ht.getBaseElem(n);h=Tc(Tt(p,e.havingCrampedStyle())).skew}var m,y=Math.min(l.height,e.fontMetrics().xHeight);if(i.isStretchy)m=so(i,e),m=H.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:l},{type:"elem",elem:m,wrapperClasses:["svg-align"],wrapperStyle:h>0?{width:"calc(100% - "+2*h+"em)",marginLeft:2*h+"em"}:void 0}]},e);else{var _,S;i.label==="\\vec"?(_=H.staticSvg("vec",e),S=H.svgData.vec[1]):((_=Tc(_=H.makeOrd({mode:i.mode,text:i.label},e,"textord"))).italic=0,S=_.width),m=H.makeSpan(["accent-body"],[_]);var E=i.label==="\\textcircled";E&&(m.classes.push("accent-full"),y=l.height);var R=h;E||(R-=S/2),m.style.left=R+"em",i.label==="\\textcircled"&&(m.style.top=".2em"),m=H.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:l},{type:"kern",size:-y},{type:"elem",elem:m}]},e)}var I=H.makeSpan(["mord","accent"],[m],e);return t?(t.children[0]=I,t.height=Math.max(I.height,t.height),t.classes[0]="mord",t):I},Pc=(r,e)=>{var n=r.isStretchy?ao(r.label):new J.MathNode("mo",[Ne(r.label,r.mode)]),i=new J.MathNode("mover",[Vt(r.base,e),n]);return i.setAttribute("accent","true"),i},yg=new RegExp(["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring"].map(r=>"\\"+r).join("|"));st({type:"accent",names:["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring","\\widecheck","\\widehat","\\widetilde","\\overrightarrow","\\overleftarrow","\\Overrightarrow","\\overleftrightarrow","\\overgroup","\\overlinesegment","\\overleftharpoon","\\overrightharpoon"],props:{numArgs:1},handler:(r,e)=>{var n=ro(e[0]),i=!yg.test(r.funcName),t=!i||r.funcName==="\\widehat"||r.funcName==="\\widetilde"||r.funcName==="\\widecheck";return{type:"accent",mode:r.parser.mode,label:r.funcName,isStretchy:i,isShifty:t,base:n}},htmlBuilder:Za,mathmlBuilder:Pc}),st({type:"accent",names:["\\'","\\`","\\^","\\~","\\=","\\u","\\.",'\\"',"\\r","\\H","\\v","\\textcircled"],props:{numArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["primitive"]},handler:(r,e)=>{var n=e[0],i=r.parser.mode;return i==="math"&&(r.parser.settings.reportNonstrict("mathVsTextAccents","LaTeX's accent "+r.funcName+" works only in text mode"),i="text"),{type:"accent",mode:i,label:r.funcName,isStretchy:!1,isShifty:!0,base:n}},htmlBuilder:Za,mathmlBuilder:Pc}),st({type:"accentUnder",names:["\\underleftarrow","\\underrightarrow","\\underleftrightarrow","\\undergroup","\\underlinesegment","\\utilde"],props:{numArgs:1},handler:(r,e)=>{var{parser:n,funcName:i}=r,t=e[0];return{type:"accentUnder",mode:n.mode,label:i,base:t}},htmlBuilder:(r,e)=>{var n=Tt(r.base,e),i=so(r,e),t=r.label==="\\utilde"?.12:0,l=H.makeVList({positionType:"top",positionData:n.height,children:[{type:"elem",elem:i,wrapperClasses:["svg-align"]},{type:"kern",size:t},{type:"elem",elem:n}]},e);return H.makeSpan(["mord","accentunder"],[l],e)},mathmlBuilder:(r,e)=>{var n=ao(r.label),i=new J.MathNode("munder",[Vt(r.base,e),n]);return i.setAttribute("accentunder","true"),i}});var Ri=r=>{var e=new J.MathNode("mpadded",r?[r]:[]);return e.setAttribute("width","+0.6em"),e.setAttribute("lspace","0.3em"),e};st({type:"xArrow",names:["\\xleftarrow","\\xrightarrow","\\xLeftarrow","\\xRightarrow","\\xleftrightarrow","\\xLeftrightarrow","\\xhookleftarrow","\\xhookrightarrow","\\xmapsto","\\xrightharpoondown","\\xrightharpoonup","\\xleftharpoondown","\\xleftharpoonup","\\xrightleftharpoons","\\xleftrightharpoons","\\xlongequal","\\xtwoheadrightarrow","\\xtwoheadleftarrow","\\xtofrom","\\xrightleftarrows","\\xrightequilibrium","\\xleftequilibrium","\\\\cdrightarrow","\\\\cdleftarrow","\\\\cdlongequal"],props:{numArgs:1,numOptionalArgs:1},handler(r,e,n){var{parser:i,funcName:t}=r;return{type:"xArrow",mode:i.mode,label:t,body:e[0],below:n[0]}},htmlBuilder(r,e){var n,i=e.style,t=e.havingStyle(i.sup()),l=H.wrapFragment(Tt(r.body,t,e),e),h=r.label.slice(0,2)==="\\x"?"x":"cd";l.classes.push(h+"-arrow-pad"),r.below&&(t=e.havingStyle(i.sub()),(n=H.wrapFragment(Tt(r.below,t,e),e)).classes.push(h+"-arrow-pad"));var p,m=so(r,e),y=-e.fontMetrics().axisHeight+.5*m.height,_=-e.fontMetrics().axisHeight-.5*m.height-.111;if((l.depth>.25||r.label==="\\xleftequilibrium")&&(_-=l.depth),n){var S=-e.fontMetrics().axisHeight+n.height+.5*m.height+.111;p=H.makeVList({positionType:"individualShift",children:[{type:"elem",elem:l,shift:_},{type:"elem",elem:m,shift:y},{type:"elem",elem:n,shift:S}]},e)}else p=H.makeVList({positionType:"individualShift",children:[{type:"elem",elem:l,shift:_},{type:"elem",elem:m,shift:y}]},e);return p.children[0].children[0].children[1].classes.push("svg-align"),H.makeSpan(["mrel","x-arrow"],[p],e)},mathmlBuilder(r,e){var n,i=ao(r.label);if(i.setAttribute("minsize",r.label.charAt(0)==="x"?"1.75em":"3.0em"),r.body){var t=Ri(Vt(r.body,e));if(r.below){var l=Ri(Vt(r.below,e));n=new J.MathNode("munderover",[i,l,t])}else n=new J.MathNode("mover",[i,t])}else if(r.below){var h=Ri(Vt(r.below,e));n=new J.MathNode("munder",[i,h])}else n=Ri(),n=new J.MathNode("mover",[i,n]);return n}});var vg={">":"\\\\cdrightarrow","<":"\\\\cdleftarrow","=":"\\\\cdlongequal",A:"\\uparrow",V:"\\downarrow","|":"\\Vert",".":"no arrow"},jc=r=>r.type==="textord"&&r.text==="@";function xg(r,e,n){var i=vg[r];switch(i){case"\\\\cdrightarrow":case"\\\\cdleftarrow":return n.callFunction(i,[e[0]],[e[1]]);case"\\uparrow":case"\\downarrow":var t={type:"atom",text:i,mode:"math",family:"rel"},l={type:"ordgroup",mode:"math",body:[n.callFunction("\\\\cdleft",[e[0]],[]),n.callFunction("\\Big",[t],[]),n.callFunction("\\\\cdright",[e[1]],[])]};return n.callFunction("\\\\cdparent",[l],[]);case"\\\\cdlongequal":return n.callFunction("\\\\cdlongequal",[],[]);case"\\Vert":return n.callFunction("\\Big",[{type:"textord",text:"\\Vert",mode:"math"}],[]);default:return{type:"textord",text:" ",mode:"math"}}}st({type:"cdlabel",names:["\\\\cdleft","\\\\cdright"],props:{numArgs:1},handler(r,e){var{parser:n,funcName:i}=r;return{type:"cdlabel",mode:n.mode,side:i.slice(4),label:e[0]}},htmlBuilder(r,e){var n=e.havingStyle(e.style.sup()),i=H.wrapFragment(Tt(r.label,n,e),e);return i.classes.push("cd-label-"+r.side),i.style.bottom=.8-i.depth+"em",i.height=0,i.depth=0,i},mathmlBuilder(r,e){var n=new J.MathNode("mrow",[Vt(r.label,e)]);return(n=new J.MathNode("mpadded",[n])).setAttribute("width","0"),r.side==="left"&&n.setAttribute("lspace","-1width"),n.setAttribute("voffset","0.7em"),(n=new J.MathNode("mstyle",[n])).setAttribute("displaystyle","false"),n.setAttribute("scriptlevel","1"),n}}),st({type:"cdlabelparent",names:["\\\\cdparent"],props:{numArgs:1},handler(r,e){var{parser:n}=r;return{type:"cdlabelparent",mode:n.mode,fragment:e[0]}},htmlBuilder(r,e){var n=H.wrapFragment(Tt(r.fragment,e),e);return n.classes.push("cd-vert-arrow"),n},mathmlBuilder:(r,e)=>new J.MathNode("mrow",[Vt(r.fragment,e)])}),st({type:"textord",names:["\\@char"],props:{numArgs:1,allowedInText:!0},handler(r,e){for(var{parser:n}=r,i=wt(e[0],"ordgroup").body,t="",l=0;l<i.length;l++)t+=wt(i[l],"textord").text;var h=parseInt(t);if(isNaN(h))throw new rt("\\@char has non-numeric argument "+t);return{type:"textord",mode:n.mode,text:String.fromCharCode(h)}}});var Gc=(r,e)=>{var n=ae(r.body,e.withColor(r.color),!1);return H.makeFragment(n)},Uc=(r,e)=>{var n=_e(r.body,e.withColor(r.color)),i=new J.MathNode("mstyle",n);return i.setAttribute("mathcolor",r.color),i};st({type:"color",names:["\\textcolor"],props:{numArgs:2,allowedInText:!0,argTypes:["color","original"]},handler(r,e){var{parser:n}=r,i=wt(e[0],"color-token").color,t=e[1];return{type:"color",mode:n.mode,color:i,body:ie(t)}},htmlBuilder:Gc,mathmlBuilder:Uc}),st({type:"color",names:["\\color"],props:{numArgs:1,allowedInText:!0,argTypes:["color"]},handler(r,e){var{parser:n,breakOnTokenText:i}=r,t=wt(e[0],"color-token").color;n.gullet.macros.set("\\current@color",t);var l=n.parseExpression(!0,i);return{type:"color",mode:n.mode,color:t,body:l}},htmlBuilder:Gc,mathmlBuilder:Uc}),st({type:"cr",names:["\\\\"],props:{numArgs:0,numOptionalArgs:1,argTypes:["size"],allowedInText:!0},handler(r,e,n){var{parser:i}=r,t=n[0],l=!i.settings.displayMode||!i.settings.useStrictBehavior("newLineInDisplayMode","In LaTeX, \\\\ or \\newline does nothing in display mode");return{type:"cr",mode:i.mode,newLine:l,size:t&&wt(t,"size").value}},htmlBuilder(r,e){var n=H.makeSpan(["mspace"],[],e);return r.newLine&&(n.classes.push("newline"),r.size&&(n.style.marginTop=Qt(r.size,e)+"em")),n},mathmlBuilder(r,e){var n=new J.MathNode("mspace");return r.newLine&&(n.setAttribute("linebreak","newline"),r.size&&n.setAttribute("height",Qt(r.size,e)+"em")),n}});var pa={"\\global":"\\global","\\long":"\\\\globallong","\\\\globallong":"\\\\globallong","\\def":"\\gdef","\\gdef":"\\gdef","\\edef":"\\xdef","\\xdef":"\\xdef","\\let":"\\\\globallet","\\futurelet":"\\\\globalfuture"},Xc=r=>{var e=r.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(e))throw new rt("Expected a control sequence",r);return e},Yc=(r,e,n,i)=>{var t=r.gullet.macros.get(n.text);t==null&&(n.noexpand=!0,t={tokens:[n],numArgs:0,unexpandable:!r.gullet.isExpandable(n.text)}),r.gullet.macros.set(e,t,i)};st({type:"internal",names:["\\global","\\long","\\\\globallong"],props:{numArgs:0,allowedInText:!0},handler(r){var{parser:e,funcName:n}=r;e.consumeSpaces();var i=e.fetch();if(pa[i.text])return n!=="\\global"&&n!=="\\\\globallong"||(i.text=pa[i.text]),wt(e.parseFunction(),"internal");throw new rt("Invalid token after macro prefix",i)}}),st({type:"internal",names:["\\def","\\gdef","\\edef","\\xdef"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(r){var{parser:e,funcName:n}=r,i=e.gullet.popToken(),t=i.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(t))throw new rt("Expected a control sequence",i);for(var l,h=0,p=[[]];e.gullet.future().text!=="{";)if((i=e.gullet.popToken()).text==="#"){if(e.gullet.future().text==="{"){l=e.gullet.future(),p[h].push("{");break}if(i=e.gullet.popToken(),!/^[1-9]$/.test(i.text))throw new rt('Invalid argument number "'+i.text+'"');if(parseInt(i.text)!==h+1)throw new rt('Argument number "'+i.text+'" out of order');h++,p.push([])}else{if(i.text==="EOF")throw new rt("Expected a macro definition");p[h].push(i.text)}var{tokens:m}=e.gullet.consumeArg();return l&&m.unshift(l),n!=="\\edef"&&n!=="\\xdef"||(m=e.gullet.expandTokens(m)).reverse(),e.gullet.macros.set(t,{tokens:m,numArgs:h,delimiters:p},n===pa[n]),{type:"internal",mode:e.mode}}}),st({type:"internal",names:["\\let","\\\\globallet"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(r){var{parser:e,funcName:n}=r,i=Xc(e.gullet.popToken());e.gullet.consumeSpaces();var t=(l=>{var h=l.gullet.popToken();return h.text==="="&&(h=l.gullet.popToken()).text===" "&&(h=l.gullet.popToken()),h})(e);return Yc(e,i,t,n==="\\\\globallet"),{type:"internal",mode:e.mode}}}),st({type:"internal",names:["\\futurelet","\\\\globalfuture"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(r){var{parser:e,funcName:n}=r,i=Xc(e.gullet.popToken()),t=e.gullet.popToken(),l=e.gullet.popToken();return Yc(e,i,l,n==="\\\\globalfuture"),e.gullet.pushToken(l),e.gullet.pushToken(t),{type:"internal",mode:e.mode}}});var En=function(r,e,n){var i=ws(Pt.math[r]&&Pt.math[r].replace||r,e,n);if(!i)throw new Error("Unsupported symbol "+r+" and font size "+e+".");return i},_s=function(r,e,n,i){var t=n.havingBaseStyle(e),l=H.makeSpan(i.concat(t.sizingClasses(n)),[r],n),h=t.sizeMultiplier/n.sizeMultiplier;return l.height*=h,l.depth*=h,l.maxFontSize=t.sizeMultiplier,l},Lp=function(r,e,n){var i=e.havingBaseStyle(n),t=(1-e.sizeMultiplier/i.sizeMultiplier)*e.fontMetrics().axisHeight;r.classes.push("delimcenter"),r.style.top=t+"em",r.height-=t,r.depth+=t},Bp=function(r,e,n,i,t,l){var h=function(m,y,_,S){return H.makeSymbol(m,"Size"+y+"-Regular",_,S)}(r,e,t,i),p=_s(H.makeSpan(["delimsizing","size"+e],[h],i),gt.TEXT,i,l);return n&&Lp(p,i,gt.TEXT),p},da=function(r,e,n){var i;return i=e==="Size1-Regular"?"delim-size1":"delim-size4",{type:"elem",elem:H.makeSpan(["delimsizinginner",i],[H.makeSpan([],[H.makeSymbol(r,e,n)])])}},ma=function(r,e,n){var i=Ke["Size4-Regular"][r.charCodeAt(0)]?Ke["Size4-Regular"][r.charCodeAt(0)][4].toFixed(3):Ke["Size1-Regular"][r.charCodeAt(0)][4].toFixed(3),t=new Hr("inner",function(p,m){switch(p){case"⎜":return"M291 0 H417 V"+m+" H291z M291 0 H417 V"+m+" H291z";case"∣":return"M145 0 H188 V"+m+" H145z M145 0 H188 V"+m+" H145z";case"∥":return"M145 0 H188 V"+m+" H145z M145 0 H188 V"+m+" H145zM367 0 H410 V"+m+" H367z M367 0 H410 V"+m+" H367z";case"⎟":return"M457 0 H583 V"+m+" H457z M457 0 H583 V"+m+" H457z";case"⎢":return"M319 0 H403 V"+m+" H319z M319 0 H403 V"+m+" H319z";case"⎥":return"M263 0 H347 V"+m+" H263z M263 0 H347 V"+m+" H263z";case"⎪":return"M384 0 H504 V"+m+" H384z M384 0 H504 V"+m+" H384z";case"⏐":return"M312 0 H355 V"+m+" H312z M312 0 H355 V"+m+" H312z";case"‖":return"M257 0 H300 V"+m+" H257z M257 0 H300 V"+m+" H257zM478 0 H521 V"+m+" H478z M478 0 H521 V"+m+" H478z";default:return""}}(r,Math.round(1e3*e))),l=new Sr([t],{width:i+"em",height:e+"em",style:"width:"+i+"em",viewBox:"0 0 "+1e3*i+" "+Math.round(1e3*e),preserveAspectRatio:"xMinYMin"}),h=H.makeSvgSpan([],[l],n);return h.height=e,h.style.height=e+"em",h.style.width=i+"em",{type:"elem",elem:h}},Hi={type:"kern",size:-.008},wg=["|","\\lvert","\\rvert","\\vert"],kg=["\\|","\\lVert","\\rVert","\\Vert"],Np=function(r,e,n,i,t,l){var h,p,m,y;h=m=y=r,p=null;var _="Size1-Regular";r==="\\uparrow"?m=y="⏐":r==="\\Uparrow"?m=y="‖":r==="\\downarrow"?h=m="⏐":r==="\\Downarrow"?h=m="‖":r==="\\updownarrow"?(h="\\uparrow",m="⏐",y="\\downarrow"):r==="\\Updownarrow"?(h="\\Uparrow",m="‖",y="\\Downarrow"):ht.contains(wg,r)?m="∣":ht.contains(kg,r)?m="∥":r==="["||r==="\\lbrack"?(h="⎡",m="⎢",y="⎣",_="Size4-Regular"):r==="]"||r==="\\rbrack"?(h="⎤",m="⎥",y="⎦",_="Size4-Regular"):r==="\\lfloor"||r==="⌊"?(m=h="⎢",y="⎣",_="Size4-Regular"):r==="\\lceil"||r==="⌈"?(h="⎡",m=y="⎢",_="Size4-Regular"):r==="\\rfloor"||r==="⌋"?(m=h="⎥",y="⎦",_="Size4-Regular"):r==="\\rceil"||r==="⌉"?(h="⎤",m=y="⎥",_="Size4-Regular"):r==="("||r==="\\lparen"?(h="⎛",m="⎜",y="⎝",_="Size4-Regular"):r===")"||r==="\\rparen"?(h="⎞",m="⎟",y="⎠",_="Size4-Regular"):r==="\\{"||r==="\\lbrace"?(h="⎧",p="⎨",y="⎩",m="⎪",_="Size4-Regular"):r==="\\}"||r==="\\rbrace"?(h="⎫",p="⎬",y="⎭",m="⎪",_="Size4-Regular"):r==="\\lgroup"||r==="⟮"?(h="⎧",y="⎩",m="⎪",_="Size4-Regular"):r==="\\rgroup"||r==="⟯"?(h="⎫",y="⎭",m="⎪",_="Size4-Regular"):r==="\\lmoustache"||r==="⎰"?(h="⎧",y="⎭",m="⎪",_="Size4-Regular"):r!=="\\rmoustache"&&r!=="⎱"||(h="⎫",y="⎩",m="⎪",_="Size4-Regular");var S=En(h,_,t),E=S.height+S.depth,R=En(m,_,t),I=R.height+R.depth,U=En(y,_,t),Y=U.height+U.depth,it=0,nt=1;if(p!==null){var pt=En(p,_,t);it=pt.height+pt.depth,nt=2}var dt=E+Y+it,yt=dt+Math.max(0,Math.ceil((e-dt)/(nt*I)))*nt*I,D=i.fontMetrics().axisHeight;n&&(D*=i.sizeMultiplier);var At=yt/2-D,q=[];if(q.push(da(y,_,t)),q.push(Hi),p===null){var L=yt-E-Y+.016;q.push(ma(m,L,i))}else{var G=(yt-E-Y-it)/2+.016;q.push(ma(m,G,i)),q.push(Hi),q.push(da(p,_,t)),q.push(Hi),q.push(ma(m,G,i))}q.push(Hi),q.push(da(h,_,t));var j=i.havingBaseStyle(gt.TEXT),Z=H.makeVList({positionType:"bottom",positionData:At,children:q},j);return _s(H.makeSpan(["delimsizing","mult"],[Z],j),gt.TEXT,i,l)},fa=.08,ga=function(r,e,n,i,t){var l=function(m,y,_){y*=1e3;var S="";switch(m){case"sqrtMain":S=function(E,R){return"M95,"+(622+E+R)+`
c-2.7,0,-7.17,-2.7,-13.5,-8c-5.8,-5.3,-9.5,-10,-9.5,-14
c0,-2,0.3,-3.3,1,-4c1.3,-2.7,23.83,-20.7,67.5,-54
c44.2,-33.3,65.8,-50.3,66.5,-51c1.3,-1.3,3,-2,5,-2c4.7,0,8.7,3.3,12,10
s173,378,173,378c0.7,0,35.3,-71,104,-213c68.7,-142,137.5,-285,206.5,-429
c69,-144,104.5,-217.7,106.5,-221
l`+E/2.075+" -"+E+`
c5.3,-9.3,12,-14,20,-14
H400000v`+(40+E)+`H845.2724
s-225.272,467,-225.272,467s-235,486,-235,486c-2.7,4.7,-9,7,-19,7
c-6,0,-10,-1,-12,-3s-194,-422,-194,-422s-65,47,-65,47z
M`+(834+E)+" "+R+"h400000v"+(40+E)+"h-400000z"}(y,ln);break;case"sqrtSize1":S=function(E,R){return"M263,"+(601+E+R)+`c0.7,0,18,39.7,52,119
c34,79.3,68.167,158.7,102.5,238c34.3,79.3,51.8,119.3,52.5,120
c340,-704.7,510.7,-1060.3,512,-1067
l`+E/2.084+" -"+E+`
c4.7,-7.3,11,-11,19,-11
H40000v`+(40+E)+`H1012.3
s-271.3,567,-271.3,567c-38.7,80.7,-84,175,-136,283c-52,108,-89.167,185.3,-111.5,232
c-22.3,46.7,-33.8,70.3,-34.5,71c-4.7,4.7,-12.3,7,-23,7s-12,-1,-12,-1
s-109,-253,-109,-253c-72.7,-168,-109.3,-252,-110,-252c-10.7,8,-22,16.7,-34,26
c-22,17.3,-33.3,26,-34,26s-26,-26,-26,-26s76,-59,76,-59s76,-60,76,-60z
M`+(1001+E)+" "+R+"h400000v"+(40+E)+"h-400000z"}(y,ln);break;case"sqrtSize2":S=function(E,R){return"M983 "+(10+E+R)+`
l`+E/3.13+" -"+E+`
c4,-6.7,10,-10,18,-10 H400000v`+(40+E)+`
H1013.1s-83.4,268,-264.1,840c-180.7,572,-277,876.3,-289,913c-4.7,4.7,-12.7,7,-24,7
s-12,0,-12,0c-1.3,-3.3,-3.7,-11.7,-7,-25c-35.3,-125.3,-106.7,-373.3,-214,-744
c-10,12,-21,25,-33,39s-32,39,-32,39c-6,-5.3,-15,-14,-27,-26s25,-30,25,-30
c26.7,-32.7,52,-63,76,-91s52,-60,52,-60s208,722,208,722
c56,-175.3,126.3,-397.3,211,-666c84.7,-268.7,153.8,-488.2,207.5,-658.5
c53.7,-170.3,84.5,-266.8,92.5,-289.5z
M`+(1001+E)+" "+R+"h400000v"+(40+E)+"h-400000z"}(y,ln);break;case"sqrtSize3":S=function(E,R){return"M424,"+(2398+E+R)+`
c-1.3,-0.7,-38.5,-172,-111.5,-514c-73,-342,-109.8,-513.3,-110.5,-514
c0,-2,-10.7,14.3,-32,49c-4.7,7.3,-9.8,15.7,-15.5,25c-5.7,9.3,-9.8,16,-12.5,20
s-5,7,-5,7c-4,-3.3,-8.3,-7.7,-13,-13s-13,-13,-13,-13s76,-122,76,-122s77,-121,77,-121
s209,968,209,968c0,-2,84.7,-361.7,254,-1079c169.3,-717.3,254.7,-1077.7,256,-1081
l`+E/4.223+" -"+E+`c4,-6.7,10,-10,18,-10 H400000
v`+(40+E)+`H1014.6
s-87.3,378.7,-272.6,1166c-185.3,787.3,-279.3,1182.3,-282,1185
c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2z M`+(1001+E)+" "+R+`
h400000v`+(40+E)+"h-400000z"}(y,ln);break;case"sqrtSize4":S=function(E,R){return"M473,"+(2713+E+R)+`
c339.3,-1799.3,509.3,-2700,510,-2702 l`+E/5.298+" -"+E+`
c3.3,-7.3,9.3,-11,18,-11 H400000v`+(40+E)+`H1017.7
s-90.5,478,-276.2,1466c-185.7,988,-279.5,1483,-281.5,1485c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2c0,-1.3,-5.3,-32,-16,-92c-50.7,-293.3,-119.7,-693.3,-207,-1200
c0,-1.3,-5.3,8.7,-16,30c-10.7,21.3,-21.3,42.7,-32,64s-16,33,-16,33s-26,-26,-26,-26
s76,-153,76,-153s77,-151,77,-151c0.7,0.7,35.7,202,105,604c67.3,400.7,102,602.7,104,
606zM`+(1001+E)+" "+R+"h400000v"+(40+E)+"H1017.7z"}(y,ln);break;case"sqrtTall":S=function(E,R,I){return"M702 "+(E+R)+"H400000"+(40+E)+`
H742v`+(I-54-R-E)+`l-4 4-4 4c-.667.7 -2 1.5-4 2.5s-4.167 1.833-6.5 2.5-5.5 1-9.5 1
h-12l-28-84c-16.667-52-96.667 -294.333-240-727l-212 -643 -85 170
c-4-3.333-8.333-7.667-13 -13l-13-13l77-155 77-156c66 199.333 139 419.667
219 661 l218 661zM702 `+R+"H400000v"+(40+E)+"H742z"}(y,ln,_)}return S}(r,i,n),h=new Hr(r,l),p=new Sr([h],{width:"400em",height:e+"em",viewBox:"0 0 400000 "+n,preserveAspectRatio:"xMinYMin slice"});return H.makeSvgSpan(["hide-tail"],[p],t)},Op=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","\\surd"],Ag=["\\uparrow","\\downarrow","\\updownarrow","\\Uparrow","\\Downarrow","\\Updownarrow","|","\\|","\\vert","\\Vert","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱"],Fp=["<",">","\\langle","\\rangle","/","\\backslash","\\lt","\\gt"],Fn=[0,1.2,1.8,2.4,3],_g=[{type:"small",style:gt.SCRIPTSCRIPT},{type:"small",style:gt.SCRIPT},{type:"small",style:gt.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4}],Sg=[{type:"small",style:gt.SCRIPTSCRIPT},{type:"small",style:gt.SCRIPT},{type:"small",style:gt.TEXT},{type:"stack"}],Rp=[{type:"small",style:gt.SCRIPTSCRIPT},{type:"small",style:gt.SCRIPT},{type:"small",style:gt.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4},{type:"stack"}],qg=function(r){if(r.type==="small")return"Main-Regular";if(r.type==="large")return"Size"+r.size+"-Regular";if(r.type==="stack")return"Size4-Regular";throw new Error("Add support for delim type '"+r.type+"' here.")},Hp=function(r,e,n,i){for(var t=Math.min(2,3-i.style.size);t<n.length&&n[t].type!=="stack";t++){var l=En(r,qg(n[t]),"math"),h=l.height+l.depth;if(n[t].type==="small"&&(h*=i.havingBaseStyle(n[t].style).sizeMultiplier),h>e)return n[t]}return n[n.length-1]},Vp=function(r,e,n,i,t,l){var h;r==="<"||r==="\\lt"||r==="⟨"?r="\\langle":r!==">"&&r!=="\\gt"&&r!=="⟩"||(r="\\rangle"),h=ht.contains(Fp,r)?_g:ht.contains(Op,r)?Rp:Sg;var p=Hp(r,e,h,i);return p.type==="small"?function(m,y,_,S,E,R){var I=H.makeSymbol(m,"Main-Regular",E,S),U=_s(I,y,S,R);return _&&Lp(U,S,y),U}(r,p.style,n,i,t,l):p.type==="large"?Bp(r,p.size,n,i,t,l):Np(r,e,n,i,t,l)},Cg=function(r,e){var n,i,t=e.havingBaseSizing(),l=Hp("\\surd",r*t.sizeMultiplier,Rp,t),h=t.sizeMultiplier,p=Math.max(0,e.minRuleThickness-e.fontMetrics().sqrtRuleThickness),m=0,y=0,_=0;return l.type==="small"?(r<1?h=1:r<1.4&&(h=.7),y=(1+p)/h,(n=ga("sqrtMain",m=(1+p+fa)/h,_=1e3+1e3*p+80,p,e)).style.minWidth="0.853em",i=.833/h):l.type==="large"?(_=1080*Fn[l.size],y=(Fn[l.size]+p)/h,m=(Fn[l.size]+p+fa)/h,(n=ga("sqrtSize"+l.size,m,_,p,e)).style.minWidth="1.02em",i=1/h):(m=r+p+fa,y=r+p,_=Math.floor(1e3*r+p)+80,(n=ga("sqrtTall",m,_,p,e)).style.minWidth="0.742em",i=1.056),n.height=y,n.style.height=m+"em",{span:n,advanceWidth:i,ruleWidth:(e.fontMetrics().sqrtRuleThickness+p)*h}},Wc=function(r,e,n,i,t){if(r==="<"||r==="\\lt"||r==="⟨"?r="\\langle":r!==">"&&r!=="\\gt"&&r!=="⟩"||(r="\\rangle"),ht.contains(Op,r)||ht.contains(Fp,r))return Bp(r,e,!1,n,i,t);if(ht.contains(Ag,r))return Np(r,Fn[e],!1,n,i,t);throw new rt("Illegal delimiter: '"+r+"'")},$c=Fn,Zc=Vp,ba=function(r,e,n,i,t,l){var h=i.fontMetrics().axisHeight*i.sizeMultiplier,p=5/i.fontMetrics().ptPerEm,m=Math.max(e-h,n+h),y=Math.max(m/500*901,2*m-p);return Vp(r,y,!0,i,t,l)},Jc={"\\bigl":{mclass:"mopen",size:1},"\\Bigl":{mclass:"mopen",size:2},"\\biggl":{mclass:"mopen",size:3},"\\Biggl":{mclass:"mopen",size:4},"\\bigr":{mclass:"mclose",size:1},"\\Bigr":{mclass:"mclose",size:2},"\\biggr":{mclass:"mclose",size:3},"\\Biggr":{mclass:"mclose",size:4},"\\bigm":{mclass:"mrel",size:1},"\\Bigm":{mclass:"mrel",size:2},"\\biggm":{mclass:"mrel",size:3},"\\Biggm":{mclass:"mrel",size:4},"\\big":{mclass:"mord",size:1},"\\Big":{mclass:"mord",size:2},"\\bigg":{mclass:"mord",size:3},"\\Bigg":{mclass:"mord",size:4}},zg=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","<",">","\\langle","⟨","\\rangle","⟩","\\lt","\\gt","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱","/","\\backslash","|","\\vert","\\|","\\Vert","\\uparrow","\\Uparrow","\\downarrow","\\Downarrow","\\updownarrow","\\Updownarrow","."];function Vi(r,e){var n=no(r);if(n&&ht.contains(zg,n.text))return n;throw new rt(n?"Invalid delimiter '"+n.text+"' after '"+e.funcName+"'":"Invalid delimiter type '"+r.type+"'",r)}function Qc(r){if(!r.body)throw new Error("Bug: The leftright ParseNode wasn't fully parsed.")}st({type:"delimsizing",names:["\\bigl","\\Bigl","\\biggl","\\Biggl","\\bigr","\\Bigr","\\biggr","\\Biggr","\\bigm","\\Bigm","\\biggm","\\Biggm","\\big","\\Big","\\bigg","\\Bigg"],props:{numArgs:1,argTypes:["primitive"]},handler:(r,e)=>{var n=Vi(e[0],r);return{type:"delimsizing",mode:r.parser.mode,size:Jc[r.funcName].size,mclass:Jc[r.funcName].mclass,delim:n.text}},htmlBuilder:(r,e)=>r.delim==="."?H.makeSpan([r.mclass]):Wc(r.delim,r.size,e,r.mode,[r.mclass]),mathmlBuilder:r=>{var e=[];r.delim!=="."&&e.push(Ne(r.delim,r.mode));var n=new J.MathNode("mo",e);return r.mclass==="mopen"||r.mclass==="mclose"?n.setAttribute("fence","true"):n.setAttribute("fence","false"),n.setAttribute("stretchy","true"),n.setAttribute("minsize",$c[r.size]+"em"),n.setAttribute("maxsize",$c[r.size]+"em"),n}}),st({type:"leftright-right",names:["\\right"],props:{numArgs:1,primitive:!0},handler:(r,e)=>{var n=r.parser.gullet.macros.get("\\current@color");if(n&&typeof n!="string")throw new rt("\\current@color set to non-string in \\right");return{type:"leftright-right",mode:r.parser.mode,delim:Vi(e[0],r).text,color:n}}}),st({type:"leftright",names:["\\left"],props:{numArgs:1,primitive:!0},handler:(r,e)=>{var n=Vi(e[0],r),i=r.parser;++i.leftrightDepth;var t=i.parseExpression(!1);--i.leftrightDepth,i.expect("\\right",!1);var l=wt(i.parseFunction(),"leftright-right");return{type:"leftright",mode:i.mode,body:t,left:n.text,right:l.delim,rightColor:l.color}},htmlBuilder:(r,e)=>{Qc(r);for(var n,i,t=ae(r.body,e,!0,["mopen","mclose"]),l=0,h=0,p=!1,m=0;m<t.length;m++)t[m].isMiddle?p=!0:(l=Math.max(t[m].height,l),h=Math.max(t[m].depth,h));if(l*=e.sizeMultiplier,h*=e.sizeMultiplier,n=r.left==="."?Nn(e,["mopen"]):ba(r.left,l,h,e,r.mode,["mopen"]),t.unshift(n),p)for(var y=1;y<t.length;y++){var _=t[y].isMiddle;_&&(t[y]=ba(_.delim,l,h,_.options,r.mode,[]))}if(r.right===".")i=Nn(e,["mclose"]);else{var S=r.rightColor?e.withColor(r.rightColor):e;i=ba(r.right,l,h,S,r.mode,["mclose"])}return t.push(i),H.makeSpan(["minner"],t,e)},mathmlBuilder:(r,e)=>{Qc(r);var n=_e(r.body,e);if(r.left!=="."){var i=new J.MathNode("mo",[Ne(r.left,r.mode)]);i.setAttribute("fence","true"),n.unshift(i)}if(r.right!=="."){var t=new J.MathNode("mo",[Ne(r.right,r.mode)]);t.setAttribute("fence","true"),r.rightColor&&t.setAttribute("mathcolor",r.rightColor),n.push(t)}return As(n)}}),st({type:"middle",names:["\\middle"],props:{numArgs:1,primitive:!0},handler:(r,e)=>{var n=Vi(e[0],r);if(!r.parser.leftrightDepth)throw new rt("\\middle without preceding \\left",n);return{type:"middle",mode:r.parser.mode,delim:n.text}},htmlBuilder:(r,e)=>{var n;if(r.delim===".")n=Nn(e,[]);else{n=Wc(r.delim,1,e,r.mode,[]);var i={delim:r.delim,options:e};n.isMiddle=i}return n},mathmlBuilder:(r,e)=>{var n=r.delim==="\\vert"||r.delim==="|"?Ne("|","text"):Ne(r.delim,r.mode),i=new J.MathNode("mo",[n]);return i.setAttribute("fence","true"),i.setAttribute("lspace","0.05em"),i.setAttribute("rspace","0.05em"),i}});var ya=(r,e)=>{var n,i,t=H.wrapFragment(Tt(r.body,e),e),l=r.label.substr(1),h=e.sizeMultiplier,p=0,m=ht.isCharacterBox(r.body);if(l==="sout")(n=H.makeSpan(["stretchy","sout"])).height=e.fontMetrics().defaultRuleThickness/h,p=-.5*e.fontMetrics().xHeight;else if(l==="phase"){var y=Qt({number:.6,unit:"pt"},e),_=Qt({number:.35,unit:"ex"},e);h/=e.havingBaseSizing().sizeMultiplier;var S=t.height+t.depth+y+_;t.style.paddingLeft=S/2+y+"em";var E=Math.floor(1e3*S*h),R=function(pt){return"M400000 "+pt+" H0 L"+pt/2+" 0 l65 45 L145 "+(pt-80)+" H400000z"}(E),I=new Sr([new Hr("phase",R)],{width:"400em",height:E/1e3+"em",viewBox:"0 0 400000 "+E,preserveAspectRatio:"xMinYMin slice"});(n=H.makeSvgSpan(["hide-tail"],[I],e)).style.height=S+"em",p=t.depth+y+_}else{/cancel/.test(l)?m||t.classes.push("cancel-pad"):l==="angl"?t.classes.push("anglpad"):t.classes.push("boxpad");var U=0,Y=0,it=0;/box/.test(l)?(it=Math.max(e.fontMetrics().fboxrule,e.minRuleThickness),Y=U=e.fontMetrics().fboxsep+(l==="colorbox"?0:it)):l==="angl"?(U=4*(it=Math.max(e.fontMetrics().defaultRuleThickness,e.minRuleThickness)),Y=Math.max(0,.25-t.depth)):Y=U=m?.2:0,n=bg(t,l,U,Y,e),/fbox|boxed|fcolorbox/.test(l)?(n.style.borderStyle="solid",n.style.borderWidth=it+"em"):l==="angl"&&it!==.049&&(n.style.borderTopWidth=it+"em",n.style.borderRightWidth=it+"em"),p=t.depth+Y,r.backgroundColor&&(n.style.backgroundColor=r.backgroundColor,r.borderColor&&(n.style.borderColor=r.borderColor))}if(r.backgroundColor)i=H.makeVList({positionType:"individualShift",children:[{type:"elem",elem:n,shift:p},{type:"elem",elem:t,shift:0}]},e);else{var nt=/cancel|phase/.test(l)?["svg-align"]:[];i=H.makeVList({positionType:"individualShift",children:[{type:"elem",elem:t,shift:0},{type:"elem",elem:n,shift:p,wrapperClasses:nt}]},e)}return/cancel/.test(l)&&(i.height=t.height,i.depth=t.depth),/cancel/.test(l)&&!m?H.makeSpan(["mord","cancel-lap"],[i],e):H.makeSpan(["mord"],[i],e)},va=(r,e)=>{var n=0,i=new J.MathNode(r.label.indexOf("colorbox")>-1?"mpadded":"menclose",[Vt(r.body,e)]);switch(r.label){case"\\cancel":i.setAttribute("notation","updiagonalstrike");break;case"\\bcancel":i.setAttribute("notation","downdiagonalstrike");break;case"\\phase":i.setAttribute("notation","phasorangle");break;case"\\sout":i.setAttribute("notation","horizontalstrike");break;case"\\fbox":i.setAttribute("notation","box");break;case"\\angl":i.setAttribute("notation","actuarial");break;case"\\fcolorbox":case"\\colorbox":if(n=e.fontMetrics().fboxsep*e.fontMetrics().ptPerEm,i.setAttribute("width","+"+2*n+"pt"),i.setAttribute("height","+"+2*n+"pt"),i.setAttribute("lspace",n+"pt"),i.setAttribute("voffset",n+"pt"),r.label==="\\fcolorbox"){var t=Math.max(e.fontMetrics().fboxrule,e.minRuleThickness);i.setAttribute("style","border: "+t+"em solid "+String(r.borderColor))}break;case"\\xcancel":i.setAttribute("notation","updiagonalstrike downdiagonalstrike")}return r.backgroundColor&&i.setAttribute("mathbackground",r.backgroundColor),i};st({type:"enclose",names:["\\colorbox"],props:{numArgs:2,allowedInText:!0,argTypes:["color","text"]},handler(r,e,n){var{parser:i,funcName:t}=r,l=wt(e[0],"color-token").color,h=e[1];return{type:"enclose",mode:i.mode,label:t,backgroundColor:l,body:h}},htmlBuilder:ya,mathmlBuilder:va}),st({type:"enclose",names:["\\fcolorbox"],props:{numArgs:3,allowedInText:!0,argTypes:["color","color","text"]},handler(r,e,n){var{parser:i,funcName:t}=r,l=wt(e[0],"color-token").color,h=wt(e[1],"color-token").color,p=e[2];return{type:"enclose",mode:i.mode,label:t,backgroundColor:h,borderColor:l,body:p}},htmlBuilder:ya,mathmlBuilder:va}),st({type:"enclose",names:["\\fbox"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!0},handler(r,e){var{parser:n}=r;return{type:"enclose",mode:n.mode,label:"\\fbox",body:e[0]}}}),st({type:"enclose",names:["\\cancel","\\bcancel","\\xcancel","\\sout","\\phase"],props:{numArgs:1},handler(r,e){var{parser:n,funcName:i}=r,t=e[0];return{type:"enclose",mode:n.mode,label:i,body:t}},htmlBuilder:ya,mathmlBuilder:va}),st({type:"enclose",names:["\\angl"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!1},handler(r,e){var{parser:n}=r;return{type:"enclose",mode:n.mode,label:"\\angl",body:e[0]}}});var Ip={};function $e(r){for(var{type:e,names:n,props:i,handler:t,htmlBuilder:l,mathmlBuilder:h}=r,p={type:e,numArgs:i.numArgs||0,allowedInText:!1,numOptionalArgs:0,handler:t},m=0;m<n.length;++m)Ip[n[m]]=p;l&&(to[e]=l),h&&(eo[e]=h)}function Kc(r){var e=[];r.consumeSpaces();for(var n=r.fetch().text;n==="\\hline"||n==="\\hdashline";)r.consume(),e.push(n==="\\hdashline"),r.consumeSpaces(),n=r.fetch().text;return e}var Ji=r=>{if(!r.parser.settings.displayMode)throw new rt("{"+r.envName+"} can be used only in display mode.")};function yr(r,e,n){var{hskipBeforeAndAfter:i,addJot:t,cols:l,arraystretch:h,colSeparationType:p,addEqnNum:m,singleRow:y,emptySingleRow:_,maxNumCols:S,leqno:E}=e;if(r.gullet.beginGroup(),y||r.gullet.macros.set("\\cr","\\\\\\relax"),!h){var R=r.gullet.expandMacroAsText("\\arraystretch");if(R==null)h=1;else if(!(h=parseFloat(R))||h<0)throw new rt("Invalid \\arraystretch: "+R)}r.gullet.beginGroup();var I=[],U=[I],Y=[],it=[];for(it.push(Kc(r));;){var nt=r.parseExpression(!1,y?"\\end":"\\\\");r.gullet.endGroup(),r.gullet.beginGroup(),nt={type:"ordgroup",mode:r.mode,body:nt},n&&(nt={type:"styling",mode:r.mode,style:n,body:[nt]}),I.push(nt);var pt=r.fetch().text;if(pt==="&"){if(S&&I.length===S){if(y||p)throw new rt("Too many tab characters: &",r.nextToken);r.settings.reportNonstrict("textEnv","Too few columns specified in the {array} column argument.")}r.consume()}else{if(pt==="\\end"){I.length===1&&nt.type==="styling"&&nt.body[0].body.length===0&&(U.length>1||!_)&&U.pop(),it.length<U.length+1&&it.push([]);break}if(pt!=="\\\\")throw new rt("Expected & or \\\\ or \\cr or \\end",r.nextToken);r.consume();var dt=void 0;r.gullet.future().text!==" "&&(dt=r.parseSizeGroup(!0)),Y.push(dt?dt.value:null),it.push(Kc(r)),I=[],U.push(I)}}return r.gullet.endGroup(),r.gullet.endGroup(),{type:"array",mode:r.mode,addJot:t,arraystretch:h,body:U,cols:l,rowGaps:Y,hskipBeforeAndAfter:i,hLinesBeforeRow:it,colSeparationType:p,addEqnNum:m,leqno:E}}function xa(r){return r.substr(0,1)==="d"?"display":"text"}var Ze=function(r,e){var n,i,t=r.body.length,l=r.hLinesBeforeRow,h=0,p=new Array(t),m=[],y=Math.max(e.fontMetrics().arrayRuleWidth,e.minRuleThickness),_=1/e.fontMetrics().ptPerEm,S=5*_;r.colSeparationType&&r.colSeparationType==="small"&&(S=e.havingStyle(gt.SCRIPT).sizeMultiplier/e.sizeMultiplier*.2778);var E=r.colSeparationType==="CD"?Qt({number:3,unit:"ex"},e):12*_,R=3*_,I=r.arraystretch*E,U=.7*I,Y=.3*I,it=0;function nt($n){for(var Pr=0;Pr<$n.length;++Pr)Pr>0&&(it+=.25),m.push({pos:it,isDashed:$n[Pr]})}for(nt(l[0]),n=0;n<r.body.length;++n){var pt=r.body[n],dt=U,yt=Y;h<pt.length&&(h=pt.length);var D=new Array(pt.length);for(i=0;i<pt.length;++i){var At=Tt(pt[i],e);yt<At.depth&&(yt=At.depth),dt<At.height&&(dt=At.height),D[i]=At}var q=r.rowGaps[n],L=0;q&&(L=Qt(q,e))>0&&(yt<(L+=Y)&&(yt=L),L=0),r.addJot&&(yt+=R),D.height=dt,D.depth=yt,it+=dt,D.pos=it,it+=yt+L,p[n]=D,nt(l[n+1])}var G,j,Z=it/2+e.fontMetrics().axisHeight,et=r.cols||[],Q=[],ut=[];if(r.addEqnNum)for(n=0;n<t;++n){var at=p[n],Ct=at.pos-Z,kt=H.makeSpan(["eqn-num"],[],e);kt.depth=at.depth,kt.height=at.height,ut.push({type:"elem",elem:kt,shift:Ct})}for(i=0,j=0;i<h||j<et.length;++i,++j){for(var Mt=et[j]||{},Wt=!0;Mt.type==="separator";){if(Wt||((G=H.makeSpan(["arraycolsep"],[])).style.width=e.fontMetrics().doubleRuleSep+"em",Q.push(G)),Mt.separator!=="|"&&Mt.separator!==":")throw new rt("Invalid separator type: "+Mt.separator);var Rt=Mt.separator==="|"?"solid":"dashed",Ce=H.makeSpan(["vertical-separator"],[],e);Ce.style.height=it+"em",Ce.style.borderRightWidth=y+"em",Ce.style.borderRightStyle=Rt,Ce.style.margin="0 -"+y/2+"em",Ce.style.verticalAlign=-(it-Z)+"em",Q.push(Ce),Mt=et[++j]||{},Wt=!1}if(!(i>=h)){var Fe=void 0;(i>0||r.hskipBeforeAndAfter)&&(Fe=ht.deflt(Mt.pregap,S))!==0&&((G=H.makeSpan(["arraycolsep"],[])).style.width=Fe+"em",Q.push(G));var Pe=[];for(n=0;n<t;++n){var qr=p[n],ze=qr[i];if(ze){var er=qr.pos-Z;ze.depth=qr.depth,ze.height=qr.height,Pe.push({type:"elem",elem:ze,shift:er})}}Pe=H.makeVList({positionType:"individualShift",children:Pe},e),Pe=H.makeSpan(["col-align-"+(Mt.align||"c")],[Pe]),Q.push(Pe),(i<h-1||r.hskipBeforeAndAfter)&&(Fe=ht.deflt(Mt.postgap,S))!==0&&((G=H.makeSpan(["arraycolsep"],[])).style.width=Fe+"em",Q.push(G))}}if(p=H.makeSpan(["mtable"],Q),m.length>0){for(var Cr=H.makeLineSpan("hline",e,y),zr=H.makeLineSpan("hdashline",e,y),rr=[{type:"elem",elem:p,shift:0}];m.length>0;){var pr=m.pop(),Wn=pr.pos-Z;pr.isDashed?rr.push({type:"elem",elem:zr,shift:Wn}):rr.push({type:"elem",elem:Cr,shift:Wn})}p=H.makeVList({positionType:"individualShift",children:rr},e)}if(r.addEqnNum){var yn=H.makeVList({positionType:"individualShift",children:ut},e);return yn=H.makeSpan(["tag"],[yn],e),H.makeFragment([p,yn])}return H.makeSpan(["mord"],[p],e)},Tg={c:"center ",l:"left ",r:"right "},Je=function(r,e){for(var n=[],i=new J.MathNode("mtd",[],["mtr-glue"]),t=new J.MathNode("mtd",[],["mml-eqn-num"]),l=0;l<r.body.length;l++){for(var h=r.body[l],p=[],m=0;m<h.length;m++)p.push(new J.MathNode("mtd",[Vt(h[m],e)]));r.addEqnNum&&(p.unshift(i),p.push(i),r.leqno?p.unshift(t):p.push(t)),n.push(new J.MathNode("mtr",p))}var y=new J.MathNode("mtable",n),_=r.arraystretch===.5?.1:.16+r.arraystretch-1+(r.addJot?.09:0);y.setAttribute("rowspacing",_.toFixed(4)+"em");var S="",E="";if(r.cols&&r.cols.length>0){var R=r.cols,I="",U=!1,Y=0,it=R.length;R[0].type==="separator"&&(S+="top ",Y=1),R[R.length-1].type==="separator"&&(S+="bottom ",it-=1);for(var nt=Y;nt<it;nt++)R[nt].type==="align"?(E+=Tg[R[nt].align],U&&(I+="none "),U=!0):R[nt].type==="separator"&&U&&(I+=R[nt].separator==="|"?"solid ":"dashed ",U=!1);y.setAttribute("columnalign",E.trim()),/[sd]/.test(I)&&y.setAttribute("columnlines",I.trim())}if(r.colSeparationType==="align"){for(var pt=r.cols||[],dt="",yt=1;yt<pt.length;yt++)dt+=yt%2?"0em ":"1em ";y.setAttribute("columnspacing",dt.trim())}else r.colSeparationType==="alignat"||r.colSeparationType==="gather"?y.setAttribute("columnspacing","0em"):r.colSeparationType==="small"?y.setAttribute("columnspacing","0.2778em"):r.colSeparationType==="CD"?y.setAttribute("columnspacing","0.5em"):y.setAttribute("columnspacing","1em");var D="",At=r.hLinesBeforeRow;S+=At[0].length>0?"left ":"",S+=At[At.length-1].length>0?"right ":"";for(var q=1;q<At.length-1;q++)D+=At[q].length===0?"none ":At[q][0]?"dashed ":"solid ";return/[sd]/.test(D)&&y.setAttribute("rowlines",D.trim()),S!==""&&(y=new J.MathNode("menclose",[y])).setAttribute("notation",S.trim()),r.arraystretch&&r.arraystretch<1&&(y=new J.MathNode("mstyle",[y])).setAttribute("scriptlevel","1"),y},th=function(r,e){r.envName.indexOf("ed")===-1&&Ji(r);var n,i=[],t=r.envName.indexOf("at")>-1?"alignat":"align",l=yr(r.parser,{cols:i,addJot:!0,addEqnNum:r.envName==="align"||r.envName==="alignat",emptySingleRow:!0,colSeparationType:t,maxNumCols:r.envName==="split"?2:void 0,leqno:r.parser.settings.leqno},"display"),h=0,p={type:"ordgroup",mode:r.mode,body:[]};if(e[0]&&e[0].type==="ordgroup"){for(var m="",y=0;y<e[0].body.length;y++)m+=wt(e[0].body[y],"textord").text;n=Number(m),h=2*n}var _=!h;l.body.forEach(function(I){for(var U=1;U<I.length;U+=2){var Y=wt(I[U],"styling");wt(Y.body[0],"ordgroup").body.unshift(p)}if(_)h<I.length&&(h=I.length);else{var it=I.length/2;if(n<it)throw new rt("Too many math in a row: expected "+n+", but got "+it,I[0])}});for(var S=0;S<h;++S){var E="r",R=0;S%2==1?E="l":S>0&&_&&(R=1),i[S]={type:"align",align:E,pregap:R,postgap:0}}return l.colSeparationType=_?"align":"alignat",l};$e({type:"array",names:["array","darray"],props:{numArgs:1},handler(r,e){var n=(no(e[0])?[e[0]]:wt(e[0],"ordgroup").body).map(function(t){var l=ha(t).text;if("lcr".indexOf(l)!==-1)return{type:"align",align:l};if(l==="|")return{type:"separator",separator:"|"};if(l===":")return{type:"separator",separator:":"};throw new rt("Unknown column alignment: "+l,t)}),i={cols:n,hskipBeforeAndAfter:!0,maxNumCols:n.length};return yr(r.parser,i,xa(r.envName))},htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["matrix","pmatrix","bmatrix","Bmatrix","vmatrix","Vmatrix","matrix*","pmatrix*","bmatrix*","Bmatrix*","vmatrix*","Vmatrix*"],props:{numArgs:0},handler(r){var e={matrix:null,pmatrix:["(",")"],bmatrix:["[","]"],Bmatrix:["\\{","\\}"],vmatrix:["|","|"],Vmatrix:["\\Vert","\\Vert"]}[r.envName.replace("*","")],n="c",i={hskipBeforeAndAfter:!1,cols:[{type:"align",align:n}]};if(r.envName.charAt(r.envName.length-1)==="*"){var t=r.parser;if(t.consumeSpaces(),t.fetch().text==="["){if(t.consume(),t.consumeSpaces(),n=t.fetch().text,"lcr".indexOf(n)===-1)throw new rt("Expected l or c or r",t.nextToken);t.consume(),t.consumeSpaces(),t.expect("]"),t.consume(),i.cols=[{type:"align",align:n}]}}var l=yr(r.parser,i,xa(r.envName)),h=Math.max(0,...l.body.map(p=>p.length));return l.cols=new Array(h).fill({type:"align",align:n}),e?{type:"leftright",mode:r.mode,body:[l],left:e[0],right:e[1],rightColor:void 0}:l},htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["smallmatrix"],props:{numArgs:0},handler(r){var e=yr(r.parser,{arraystretch:.5},"script");return e.colSeparationType="small",e},htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["subarray"],props:{numArgs:1},handler(r,e){var n=(no(e[0])?[e[0]]:wt(e[0],"ordgroup").body).map(function(t){var l=ha(t).text;if("lc".indexOf(l)!==-1)return{type:"align",align:l};throw new rt("Unknown column alignment: "+l,t)});if(n.length>1)throw new rt("{subarray} can contain only one column");var i={cols:n,hskipBeforeAndAfter:!1,arraystretch:.5};if((i=yr(r.parser,i,"script")).body.length>0&&i.body[0].length>1)throw new rt("{subarray} can contain only one column");return i},htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["cases","dcases","rcases","drcases"],props:{numArgs:0},handler(r){var e=yr(r.parser,{arraystretch:1.2,cols:[{type:"align",align:"l",pregap:0,postgap:1},{type:"align",align:"l",pregap:0,postgap:0}]},xa(r.envName));return{type:"leftright",mode:r.mode,body:[e],left:r.envName.indexOf("r")>-1?".":"\\{",right:r.envName.indexOf("r")>-1?"\\}":".",rightColor:void 0}},htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["align","align*","aligned","split"],props:{numArgs:0},handler:th,htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["gathered","gather","gather*"],props:{numArgs:0},handler(r){ht.contains(["gather","gather*"],r.envName)&&Ji(r);var e={cols:[{type:"align",align:"c"}],addJot:!0,colSeparationType:"gather",addEqnNum:r.envName==="gather",emptySingleRow:!0,leqno:r.parser.settings.leqno};return yr(r.parser,e,"display")},htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["alignat","alignat*","alignedat"],props:{numArgs:1},handler:th,htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["equation","equation*"],props:{numArgs:0},handler(r){Ji(r);var e={addEqnNum:r.envName==="equation",emptySingleRow:!0,singleRow:!0,maxNumCols:1,leqno:r.parser.settings.leqno};return yr(r.parser,e,"display")},htmlBuilder:Ze,mathmlBuilder:Je}),$e({type:"array",names:["CD"],props:{numArgs:0},handler:r=>(Ji(r),function(e){var n=[];for(e.gullet.beginGroup(),e.gullet.macros.set("\\cr","\\\\\\relax"),e.gullet.beginGroup();;){n.push(e.parseExpression(!1,"\\\\")),e.gullet.endGroup(),e.gullet.beginGroup();var i=e.fetch().text;if(i!=="&"&&i!=="\\\\"){if(i==="\\end"){n[n.length-1].length===0&&n.pop();break}throw new rt("Expected \\\\ or \\cr or \\end",e.nextToken)}e.consume()}for(var t,l,h=[],p=[h],m=0;m<n.length;m++){for(var y=n[m],_={type:"styling",body:[],mode:"math",style:"display"},S=0;S<y.length;S++)if(jc(y[S])){h.push(_);var E=ha(y[S+=1]).text,R=new Array(2);if(R[0]={type:"ordgroup",mode:"math",body:[]},R[1]={type:"ordgroup",mode:"math",body:[]},!("=|.".indexOf(E)>-1)){if(!("<>AV".indexOf(E)>-1))throw new rt('Expected one of "<>AV=|." after @',y[S]);for(var I=0;I<2;I++){for(var U=!0,Y=S+1;Y<y.length;Y++){if(l=E,((t=y[Y]).type==="mathord"||t.type==="atom")&&t.text===l){U=!1,S=Y;break}if(jc(y[Y]))throw new rt("Missing a "+E+" character to complete a CD arrow.",y[Y]);R[I].body.push(y[Y])}if(U)throw new rt("Missing a "+E+" character to complete a CD arrow.",y[S])}}var it={type:"styling",body:[xg(E,R,e)],mode:"math",style:"display"};h.push(it),_={type:"styling",body:[],mode:"math",style:"display"}}else _.body.push(y[S]);m%2==0?h.push(_):h.shift(),h=[],p.push(h)}return e.gullet.endGroup(),e.gullet.endGroup(),{type:"array",mode:"math",body:p,arraystretch:1,addJot:!0,rowGaps:[null],cols:new Array(p[0].length).fill({type:"align",align:"c",pregap:.25,postgap:.25}),colSeparationType:"CD",hLinesBeforeRow:new Array(p.length+1).fill([])}}(r.parser)),htmlBuilder:Ze,mathmlBuilder:Je}),st({type:"text",names:["\\hline","\\hdashline"],props:{numArgs:0,allowedInText:!0,allowedInMath:!0},handler(r,e){throw new rt(r.funcName+" valid only within array environment")}});var eh=Ip;st({type:"environment",names:["\\begin","\\end"],props:{numArgs:1,argTypes:["text"]},handler(r,e){var{parser:n,funcName:i}=r,t=e[0];if(t.type!=="ordgroup")throw new rt("Invalid environment name",t);for(var l="",h=0;h<t.body.length;++h)l+=wt(t.body[h],"textord").text;if(i==="\\begin"){if(!eh.hasOwnProperty(l))throw new rt("No such environment: "+l,t);var p=eh[l],{args:m,optArgs:y}=n.parseArguments("\\begin{"+l+"}",p),_={mode:n.mode,envName:l,parser:n},S=p.handler(_,m,y);n.expect("\\end",!1);var E=n.nextToken,R=wt(n.parseFunction(),"environment");if(R.name!==l)throw new rt("Mismatch: \\begin{"+l+"} matched by \\end{"+R.name+"}",E);return S}return{type:"environment",mode:n.mode,name:l,nameGroup:t}}});var Mg=H.makeSpan;function Pp(r,e){var n=ae(r.body,e,!0);return Mg([r.mclass],n,e)}function jp(r,e){var n,i=_e(r.body,e);return r.mclass==="minner"?J.newDocumentFragment(i):(r.mclass==="mord"?r.isCharacterBox?(n=i[0]).type="mi":n=new J.MathNode("mi",i):(r.isCharacterBox?(n=i[0]).type="mo":n=new J.MathNode("mo",i),r.mclass==="mbin"?(n.attributes.lspace="0.22em",n.attributes.rspace="0.22em"):r.mclass==="mpunct"?(n.attributes.lspace="0em",n.attributes.rspace="0.17em"):r.mclass!=="mopen"&&r.mclass!=="mclose"||(n.attributes.lspace="0em",n.attributes.rspace="0em")),n)}st({type:"mclass",names:["\\mathord","\\mathbin","\\mathrel","\\mathopen","\\mathclose","\\mathpunct","\\mathinner"],props:{numArgs:1,primitive:!0},handler(r,e){var{parser:n,funcName:i}=r,t=e[0];return{type:"mclass",mode:n.mode,mclass:"m"+i.substr(5),body:ie(t),isCharacterBox:ht.isCharacterBox(t)}},htmlBuilder:Pp,mathmlBuilder:jp});var Ja=r=>{var e=r.type==="ordgroup"&&r.body.length?r.body[0]:r;return e.type!=="atom"||e.family!=="bin"&&e.family!=="rel"?"mord":"m"+e.family};st({type:"mclass",names:["\\@binrel"],props:{numArgs:2},handler(r,e){var{parser:n}=r;return{type:"mclass",mode:n.mode,mclass:Ja(e[0]),body:ie(e[1]),isCharacterBox:ht.isCharacterBox(e[1])}}}),st({type:"mclass",names:["\\stackrel","\\overset","\\underset"],props:{numArgs:2},handler(r,e){var n,{parser:i,funcName:t}=r,l=e[1],h=e[0];n=t!=="\\stackrel"?Ja(l):"mrel";var p={type:"op",mode:l.mode,limits:!0,alwaysHandleSupSub:!0,parentIsSupSub:!1,symbol:!1,suppressBaseShift:t!=="\\stackrel",body:ie(l)},m={type:"supsub",mode:h.mode,base:p,sup:t==="\\underset"?null:h,sub:t==="\\underset"?h:null};return{type:"mclass",mode:i.mode,mclass:n,body:[m],isCharacterBox:ht.isCharacterBox(m)}},htmlBuilder:Pp,mathmlBuilder:jp});var rh=(r,e)=>{var n=r.font,i=e.withFont(n);return Tt(r.body,i)},nh=(r,e)=>{var n=r.font,i=e.withFont(n);return Vt(r.body,i)},ih={"\\Bbb":"\\mathbb","\\bold":"\\mathbf","\\frak":"\\mathfrak","\\bm":"\\boldsymbol"};st({type:"font",names:["\\mathrm","\\mathit","\\mathbf","\\mathnormal","\\mathbb","\\mathcal","\\mathfrak","\\mathscr","\\mathsf","\\mathtt","\\Bbb","\\bold","\\frak"],props:{numArgs:1,allowedInArgument:!0},handler:(r,e)=>{var{parser:n,funcName:i}=r,t=ro(e[0]),l=i;return l in ih&&(l=ih[l]),{type:"font",mode:n.mode,font:l.slice(1),body:t}},htmlBuilder:rh,mathmlBuilder:nh}),st({type:"mclass",names:["\\boldsymbol","\\bm"],props:{numArgs:1},handler:(r,e)=>{var{parser:n}=r,i=e[0],t=ht.isCharacterBox(i);return{type:"mclass",mode:n.mode,mclass:Ja(i),body:[{type:"font",mode:n.mode,font:"boldsymbol",body:i}],isCharacterBox:t}}}),st({type:"font",names:["\\rm","\\sf","\\tt","\\bf","\\it","\\cal"],props:{numArgs:0,allowedInText:!0},handler:(r,e)=>{var{parser:n,funcName:i,breakOnTokenText:t}=r,{mode:l}=n,h=n.parseExpression(!0,t);return{type:"font",mode:l,font:"math"+i.slice(1),body:{type:"ordgroup",mode:n.mode,body:h}}},htmlBuilder:rh,mathmlBuilder:nh});var Gp=(r,e)=>{var n=e;return r==="display"?n=n.id>=gt.SCRIPT.id?n.text():gt.DISPLAY:r==="text"&&n.size===gt.DISPLAY.size?n=gt.TEXT:r==="script"?n=gt.SCRIPT:r==="scriptscript"&&(n=gt.SCRIPTSCRIPT),n},Qa=(r,e)=>{var n,i=Gp(r.size,e.style),t=i.fracNum(),l=i.fracDen();n=e.havingStyle(t);var h=Tt(r.numer,n,e);if(r.continued){var p=8.5/e.fontMetrics().ptPerEm,m=3.5/e.fontMetrics().ptPerEm;h.height=h.height<p?p:h.height,h.depth=h.depth<m?m:h.depth}n=e.havingStyle(l);var y,_,S,E,R,I,U,Y,it,nt,pt=Tt(r.denom,n,e);if(r.hasBarLine?(r.barSize?(_=Qt(r.barSize,e),y=H.makeLineSpan("frac-line",e,_)):y=H.makeLineSpan("frac-line",e),_=y.height,S=y.height):(y=null,_=0,S=e.fontMetrics().defaultRuleThickness),i.size===gt.DISPLAY.size||r.size==="display"?(E=e.fontMetrics().num1,R=_>0?3*S:7*S,I=e.fontMetrics().denom1):(_>0?(E=e.fontMetrics().num2,R=S):(E=e.fontMetrics().num3,R=3*S),I=e.fontMetrics().denom2),y){var dt=e.fontMetrics().axisHeight;E-h.depth-(dt+.5*_)<R&&(E+=R-(E-h.depth-(dt+.5*_))),dt-.5*_-(pt.height-I)<R&&(I+=R-(dt-.5*_-(pt.height-I)));var yt=-(dt-.5*_);U=H.makeVList({positionType:"individualShift",children:[{type:"elem",elem:pt,shift:I},{type:"elem",elem:y,shift:yt},{type:"elem",elem:h,shift:-E}]},e)}else{var D=E-h.depth-(pt.height-I);D<R&&(E+=.5*(R-D),I+=.5*(R-D)),U=H.makeVList({positionType:"individualShift",children:[{type:"elem",elem:pt,shift:I},{type:"elem",elem:h,shift:-E}]},e)}return n=e.havingStyle(i),U.height*=n.sizeMultiplier/e.sizeMultiplier,U.depth*=n.sizeMultiplier/e.sizeMultiplier,Y=i.size===gt.DISPLAY.size?e.fontMetrics().delim1:i.size===gt.SCRIPTSCRIPT.size?e.havingStyle(gt.SCRIPT).fontMetrics().delim2:e.fontMetrics().delim2,it=r.leftDelim==null?Nn(e,["mopen"]):Zc(r.leftDelim,Y,!0,e.havingStyle(i),r.mode,["mopen"]),nt=r.continued?H.makeSpan([]):r.rightDelim==null?Nn(e,["mclose"]):Zc(r.rightDelim,Y,!0,e.havingStyle(i),r.mode,["mclose"]),H.makeSpan(["mord"].concat(n.sizingClasses(e)),[it,H.makeSpan(["mfrac"],[U]),nt],e)},Ka=(r,e)=>{var n=new J.MathNode("mfrac",[Vt(r.numer,e),Vt(r.denom,e)]);if(r.hasBarLine){if(r.barSize){var i=Qt(r.barSize,e);n.setAttribute("linethickness",i+"em")}}else n.setAttribute("linethickness","0px");var t=Gp(r.size,e.style);if(t.size!==e.style.size){n=new J.MathNode("mstyle",[n]);var l=t.size===gt.DISPLAY.size?"true":"false";n.setAttribute("displaystyle",l),n.setAttribute("scriptlevel","0")}if(r.leftDelim!=null||r.rightDelim!=null){var h=[];if(r.leftDelim!=null){var p=new J.MathNode("mo",[new J.TextNode(r.leftDelim.replace("\\",""))]);p.setAttribute("fence","true"),h.push(p)}if(h.push(n),r.rightDelim!=null){var m=new J.MathNode("mo",[new J.TextNode(r.rightDelim.replace("\\",""))]);m.setAttribute("fence","true"),h.push(m)}return As(h)}return n};st({type:"genfrac",names:["\\dfrac","\\frac","\\tfrac","\\dbinom","\\binom","\\tbinom","\\\\atopfrac","\\\\bracefrac","\\\\brackfrac"],props:{numArgs:2,allowedInArgument:!0},handler:(r,e)=>{var n,{parser:i,funcName:t}=r,l=e[0],h=e[1],p=null,m=null,y="auto";switch(t){case"\\dfrac":case"\\frac":case"\\tfrac":n=!0;break;case"\\\\atopfrac":n=!1;break;case"\\dbinom":case"\\binom":case"\\tbinom":n=!1,p="(",m=")";break;case"\\\\bracefrac":n=!1,p="\\{",m="\\}";break;case"\\\\brackfrac":n=!1,p="[",m="]";break;default:throw new Error("Unrecognized genfrac command")}switch(t){case"\\dfrac":case"\\dbinom":y="display";break;case"\\tfrac":case"\\tbinom":y="text"}return{type:"genfrac",mode:i.mode,continued:!1,numer:l,denom:h,hasBarLine:n,leftDelim:p,rightDelim:m,size:y,barSize:null}},htmlBuilder:Qa,mathmlBuilder:Ka}),st({type:"genfrac",names:["\\cfrac"],props:{numArgs:2},handler:(r,e)=>{var{parser:n,funcName:i}=r,t=e[0],l=e[1];return{type:"genfrac",mode:n.mode,continued:!0,numer:t,denom:l,hasBarLine:!0,leftDelim:null,rightDelim:null,size:"display",barSize:null}}}),st({type:"infix",names:["\\over","\\choose","\\atop","\\brace","\\brack"],props:{numArgs:0,infix:!0},handler(r){var e,{parser:n,funcName:i,token:t}=r;switch(i){case"\\over":e="\\frac";break;case"\\choose":e="\\binom";break;case"\\atop":e="\\\\atopfrac";break;case"\\brace":e="\\\\bracefrac";break;case"\\brack":e="\\\\brackfrac";break;default:throw new Error("Unrecognized infix genfrac command")}return{type:"infix",mode:n.mode,replaceWith:e,token:t}}});var oh=["display","text","script","scriptscript"],ah=function(r){var e=null;return r.length>0&&(e=(e=r)==="."?null:e),e};st({type:"genfrac",names:["\\genfrac"],props:{numArgs:6,allowedInArgument:!0,argTypes:["math","math","size","text","math","math"]},handler(r,e){var n,{parser:i}=r,t=e[4],l=e[5],h=ro(e[0]),p=h.type==="atom"&&h.family==="open"?ah(h.text):null,m=ro(e[1]),y=m.type==="atom"&&m.family==="close"?ah(m.text):null,_=wt(e[2],"size"),S=null;n=!!_.isBlank||(S=_.value).number>0;var E="auto",R=e[3];if(R.type==="ordgroup"){if(R.body.length>0){var I=wt(R.body[0],"textord");E=oh[Number(I.text)]}}else R=wt(R,"textord"),E=oh[Number(R.text)];return{type:"genfrac",mode:i.mode,numer:t,denom:l,continued:!1,hasBarLine:n,barSize:S,leftDelim:p,rightDelim:y,size:E}},htmlBuilder:Qa,mathmlBuilder:Ka}),st({type:"infix",names:["\\above"],props:{numArgs:1,argTypes:["size"],infix:!0},handler(r,e){var{parser:n,funcName:i,token:t}=r;return{type:"infix",mode:n.mode,replaceWith:"\\\\abovefrac",size:wt(e[0],"size").value,token:t}}}),st({type:"genfrac",names:["\\\\abovefrac"],props:{numArgs:3,argTypes:["math","size","math"]},handler:(r,e)=>{var{parser:n,funcName:i}=r,t=e[0],l=function(m){if(!m)throw new Error("Expected non-null, but got "+String(m));return m}(wt(e[1],"infix").size),h=e[2],p=l.number>0;return{type:"genfrac",mode:n.mode,numer:t,denom:h,continued:!1,hasBarLine:p,barSize:l,leftDelim:null,rightDelim:null,size:"auto"}},htmlBuilder:Qa,mathmlBuilder:Ka});var Up=(r,e)=>{var n,i,t=e.style;r.type==="supsub"?(n=r.sup?Tt(r.sup,e.havingStyle(t.sup()),e):Tt(r.sub,e.havingStyle(t.sub()),e),i=wt(r.base,"horizBrace")):i=wt(r,"horizBrace");var l,h=Tt(i.base,e.havingBaseStyle(gt.DISPLAY)),p=so(i,e);if(i.isOver?(l=H.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:h},{type:"kern",size:.1},{type:"elem",elem:p}]},e)).children[0].children[0].children[1].classes.push("svg-align"):(l=H.makeVList({positionType:"bottom",positionData:h.depth+.1+p.height,children:[{type:"elem",elem:p},{type:"kern",size:.1},{type:"elem",elem:h}]},e)).children[0].children[0].children[0].classes.push("svg-align"),n){var m=H.makeSpan(["mord",i.isOver?"mover":"munder"],[l],e);l=i.isOver?H.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:m},{type:"kern",size:.2},{type:"elem",elem:n}]},e):H.makeVList({positionType:"bottom",positionData:m.depth+.2+n.height+n.depth,children:[{type:"elem",elem:n},{type:"kern",size:.2},{type:"elem",elem:m}]},e)}return H.makeSpan(["mord",i.isOver?"mover":"munder"],[l],e)};st({type:"horizBrace",names:["\\overbrace","\\underbrace"],props:{numArgs:1},handler(r,e){var{parser:n,funcName:i}=r;return{type:"horizBrace",mode:n.mode,label:i,isOver:/^\\over/.test(i),base:e[0]}},htmlBuilder:Up,mathmlBuilder:(r,e)=>{var n=ao(r.label);return new J.MathNode(r.isOver?"mover":"munder",[Vt(r.base,e),n])}}),st({type:"href",names:["\\href"],props:{numArgs:2,argTypes:["url","original"],allowedInText:!0},handler:(r,e)=>{var{parser:n}=r,i=e[1],t=wt(e[0],"url").url;return n.settings.isTrusted({command:"\\href",url:t})?{type:"href",mode:n.mode,href:t,body:ie(i)}:n.formatUnsupportedCmd("\\href")},htmlBuilder:(r,e)=>{var n=ae(r.body,e,!1);return H.makeAnchor(r.href,[],n,e)},mathmlBuilder:(r,e)=>{var n=wr(r.body,e);return n instanceof Be||(n=new Be("mrow",[n])),n.setAttribute("href",r.href),n}}),st({type:"href",names:["\\url"],props:{numArgs:1,argTypes:["url"],allowedInText:!0},handler:(r,e)=>{var{parser:n}=r,i=wt(e[0],"url").url;if(!n.settings.isTrusted({command:"\\url",url:i}))return n.formatUnsupportedCmd("\\url");for(var t=[],l=0;l<i.length;l++){var h=i[l];h==="~"&&(h="\\textasciitilde"),t.push({type:"textord",mode:"text",text:h})}var p={type:"text",mode:n.mode,font:"\\texttt",body:t};return{type:"href",mode:n.mode,href:i,body:ie(p)}}}),st({type:"hbox",names:["\\hbox"],props:{numArgs:1,argTypes:["text"],allowedInText:!0,primitive:!0},handler(r,e){var{parser:n}=r;return{type:"hbox",mode:n.mode,body:ie(e[0])}},htmlBuilder(r,e){var n=ae(r.body,e,!1);return H.makeFragment(n)},mathmlBuilder:(r,e)=>new J.MathNode("mrow",_e(r.body,e))}),st({type:"html",names:["\\htmlClass","\\htmlId","\\htmlStyle","\\htmlData"],props:{numArgs:2,argTypes:["raw","original"],allowedInText:!0},handler:(r,e)=>{var n,{parser:i,funcName:t,token:l}=r,h=wt(e[0],"raw").string,p=e[1];i.settings.strict&&i.settings.reportNonstrict("htmlExtension","HTML extension is disabled on strict mode");var m={};switch(t){case"\\htmlClass":m.class=h,n={command:"\\htmlClass",class:h};break;case"\\htmlId":m.id=h,n={command:"\\htmlId",id:h};break;case"\\htmlStyle":m.style=h,n={command:"\\htmlStyle",style:h};break;case"\\htmlData":for(var y=h.split(","),_=0;_<y.length;_++){var S=y[_].split("=");if(S.length!==2)throw new rt("Error parsing key-value for \\htmlData");m["data-"+S[0].trim()]=S[1].trim()}n={command:"\\htmlData",attributes:m};break;default:throw new Error("Unrecognized html command")}return i.settings.isTrusted(n)?{type:"html",mode:i.mode,attributes:m,body:ie(p)}:i.formatUnsupportedCmd(t)},htmlBuilder:(r,e)=>{var n=ae(r.body,e,!1),i=["enclosing"];r.attributes.class&&i.push(...r.attributes.class.trim().split(/\s+/));var t=H.makeSpan(i,n,e);for(var l in r.attributes)l!=="class"&&r.attributes.hasOwnProperty(l)&&t.setAttribute(l,r.attributes[l]);return t},mathmlBuilder:(r,e)=>wr(r.body,e)}),st({type:"htmlmathml",names:["\\html@mathml"],props:{numArgs:2,allowedInText:!0},handler:(r,e)=>{var{parser:n}=r;return{type:"htmlmathml",mode:n.mode,html:ie(e[0]),mathml:ie(e[1])}},htmlBuilder:(r,e)=>{var n=ae(r.html,e,!1);return H.makeFragment(n)},mathmlBuilder:(r,e)=>wr(r.mathml,e)});var wa=function(r){if(/^[-+]? *(\d+(\.\d*)?|\.\d+)$/.test(r))return{number:+r,unit:"bp"};var e=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(r);if(!e)throw new rt("Invalid size: '"+r+"' in \\includegraphics");var n={number:+(e[1]+e[2]),unit:e[3]};if(!Cp(n))throw new rt("Invalid unit: '"+n.unit+"' in \\includegraphics.");return n};st({type:"includegraphics",names:["\\includegraphics"],props:{numArgs:1,numOptionalArgs:1,argTypes:["raw","url"],allowedInText:!1},handler:(r,e,n)=>{var{parser:i}=r,t={number:0,unit:"em"},l={number:.9,unit:"em"},h={number:0,unit:"em"},p="";if(n[0])for(var m=wt(n[0],"raw").string.split(","),y=0;y<m.length;y++){var _=m[y].split("=");if(_.length===2){var S=_[1].trim();switch(_[0].trim()){case"alt":p=S;break;case"width":t=wa(S);break;case"height":l=wa(S);break;case"totalheight":h=wa(S);break;default:throw new rt("Invalid key: '"+_[0]+"' in \\includegraphics.")}}}var E=wt(e[0],"url").url;return p===""&&(p=(p=(p=E).replace(/^.*[\\/]/,"")).substring(0,p.lastIndexOf("."))),i.settings.isTrusted({command:"\\includegraphics",url:E})?{type:"includegraphics",mode:i.mode,alt:p,width:t,height:l,totalheight:h,src:E}:i.formatUnsupportedCmd("\\includegraphics")},htmlBuilder:(r,e)=>{var n=Qt(r.height,e),i=0;r.totalheight.number>0&&(i=Qt(r.totalheight,e)-n,i=Number(i.toFixed(2)));var t=0;r.width.number>0&&(t=Qt(r.width,e));var l={height:n+i+"em"};t>0&&(l.width=t+"em"),i>0&&(l.verticalAlign=-i+"em");var h=new Kf(r.src,r.alt,l);return h.height=n,h.depth=i,h},mathmlBuilder:(r,e)=>{var n=new J.MathNode("mglyph",[]);n.setAttribute("alt",r.alt);var i=Qt(r.height,e),t=0;if(r.totalheight.number>0&&(t=(t=Qt(r.totalheight,e)-i).toFixed(2),n.setAttribute("valign","-"+t+"em")),n.setAttribute("height",i+t+"em"),r.width.number>0){var l=Qt(r.width,e);n.setAttribute("width",l+"em")}return n.setAttribute("src",r.src),n}}),st({type:"kern",names:["\\kern","\\mkern","\\hskip","\\mskip"],props:{numArgs:1,argTypes:["size"],primitive:!0,allowedInText:!0},handler(r,e){var{parser:n,funcName:i}=r,t=wt(e[0],"size");if(n.settings.strict){var l=i[1]==="m",h=t.value.unit==="mu";l?(h||n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+i+" supports only mu units, not "+t.value.unit+" units"),n.mode!=="math"&&n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+i+" works only in math mode")):h&&n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+i+" doesn't support mu units")}return{type:"kern",mode:n.mode,dimension:t.value}},htmlBuilder:(r,e)=>H.makeGlue(r.dimension,e),mathmlBuilder(r,e){var n=Qt(r.dimension,e);return new J.SpaceNode(n)}}),st({type:"lap",names:["\\mathllap","\\mathrlap","\\mathclap"],props:{numArgs:1,allowedInText:!0},handler:(r,e)=>{var{parser:n,funcName:i}=r,t=e[0];return{type:"lap",mode:n.mode,alignment:i.slice(5),body:t}},htmlBuilder:(r,e)=>{var n;r.alignment==="clap"?(n=H.makeSpan([],[Tt(r.body,e)]),n=H.makeSpan(["inner"],[n],e)):n=H.makeSpan(["inner"],[Tt(r.body,e)]);var i=H.makeSpan(["fix"],[]),t=H.makeSpan([r.alignment],[n,i],e),l=H.makeSpan(["strut"]);return l.style.height=t.height+t.depth+"em",l.style.verticalAlign=-t.depth+"em",t.children.unshift(l),t=H.makeSpan(["thinbox"],[t],e),H.makeSpan(["mord","vbox"],[t],e)},mathmlBuilder:(r,e)=>{var n=new J.MathNode("mpadded",[Vt(r.body,e)]);if(r.alignment!=="rlap"){var i=r.alignment==="llap"?"-1":"-0.5";n.setAttribute("lspace",i+"width")}return n.setAttribute("width","0px"),n}}),st({type:"styling",names:["\\(","$"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(r,e){var{funcName:n,parser:i}=r,t=i.mode;i.switchMode("math");var l=n==="\\("?"\\)":"$",h=i.parseExpression(!1,l);return i.expect(l),i.switchMode(t),{type:"styling",mode:i.mode,style:"text",body:h}}}),st({type:"text",names:["\\)","\\]"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(r,e){throw new rt("Mismatched "+r.funcName)}});var sh=(r,e)=>{switch(e.style.size){case gt.DISPLAY.size:return r.display;case gt.TEXT.size:return r.text;case gt.SCRIPT.size:return r.script;case gt.SCRIPTSCRIPT.size:return r.scriptscript;default:return r.text}};st({type:"mathchoice",names:["\\mathchoice"],props:{numArgs:4,primitive:!0},handler:(r,e)=>{var{parser:n}=r;return{type:"mathchoice",mode:n.mode,display:ie(e[0]),text:ie(e[1]),script:ie(e[2]),scriptscript:ie(e[3])}},htmlBuilder:(r,e)=>{var n=sh(r,e),i=ae(n,e,!1);return H.makeFragment(i)},mathmlBuilder:(r,e)=>{var n=sh(r,e);return wr(n,e)}});var Xp=(r,e,n,i,t,l,h)=>{r=H.makeSpan([],[r]);var p,m,y,_=n&&ht.isCharacterBox(n);if(e){var S=Tt(e,i.havingStyle(t.sup()),i);m={elem:S,kern:Math.max(i.fontMetrics().bigOpSpacing1,i.fontMetrics().bigOpSpacing3-S.depth)}}if(n){var E=Tt(n,i.havingStyle(t.sub()),i);p={elem:E,kern:Math.max(i.fontMetrics().bigOpSpacing2,i.fontMetrics().bigOpSpacing4-E.height)}}if(m&&p){var R=i.fontMetrics().bigOpSpacing5+p.elem.height+p.elem.depth+p.kern+r.depth+h;y=H.makeVList({positionType:"bottom",positionData:R,children:[{type:"kern",size:i.fontMetrics().bigOpSpacing5},{type:"elem",elem:p.elem,marginLeft:-l+"em"},{type:"kern",size:p.kern},{type:"elem",elem:r},{type:"kern",size:m.kern},{type:"elem",elem:m.elem,marginLeft:l+"em"},{type:"kern",size:i.fontMetrics().bigOpSpacing5}]},i)}else if(p){var I=r.height-h;y=H.makeVList({positionType:"top",positionData:I,children:[{type:"kern",size:i.fontMetrics().bigOpSpacing5},{type:"elem",elem:p.elem,marginLeft:-l+"em"},{type:"kern",size:p.kern},{type:"elem",elem:r}]},i)}else{if(!m)return r;var U=r.depth+h;y=H.makeVList({positionType:"bottom",positionData:U,children:[{type:"elem",elem:r},{type:"kern",size:m.kern},{type:"elem",elem:m.elem,marginLeft:l+"em"},{type:"kern",size:i.fontMetrics().bigOpSpacing5}]},i)}var Y=[y];if(p&&l!==0&&!_){var it=H.makeSpan(["mspace"],[],i);it.style.marginRight=l+"em",Y.unshift(it)}return H.makeSpan(["mop","op-limits"],Y,i)},Yp=["\\smallint"],mn=(r,e)=>{var n,i,t,l=!1;r.type==="supsub"?(n=r.sup,i=r.sub,t=wt(r.base,"op"),l=!0):t=wt(r,"op");var h,p=e.style,m=!1;if(p.size===gt.DISPLAY.size&&t.symbol&&!ht.contains(Yp,t.name)&&(m=!0),t.symbol){var y=m?"Size2-Regular":"Size1-Regular",_="";if(t.name!=="\\oiint"&&t.name!=="\\oiiint"||(_=t.name.substr(1),t.name=_==="oiint"?"\\iint":"\\iiint"),h=H.makeSymbol(t.name,y,"math",e,["mop","op-symbol",m?"large-op":"small-op"]),_.length>0){var S=h.italic,E=H.staticSvg(_+"Size"+(m?"2":"1"),e);h=H.makeVList({positionType:"individualShift",children:[{type:"elem",elem:h,shift:0},{type:"elem",elem:E,shift:m?.08:0}]},e),t.name="\\"+_,h.classes.unshift("mop"),h.italic=S}}else if(t.body){var R=ae(t.body,e,!0);R.length===1&&R[0]instanceof Oe?(h=R[0]).classes[0]="mop":h=H.makeSpan(["mop"],R,e)}else{for(var I=[],U=1;U<t.name.length;U++)I.push(H.mathsym(t.name[U],t.mode,e));h=H.makeSpan(["mop"],I,e)}var Y=0,it=0;return(h instanceof Oe||t.name==="\\oiint"||t.name==="\\oiiint")&&!t.suppressBaseShift&&(Y=(h.height-h.depth)/2-e.fontMetrics().axisHeight,it=h.italic),l?Xp(h,n,i,e,p,it,Y):(Y&&(h.style.position="relative",h.style.top=Y+"em"),h)},Rn=(r,e)=>{var n;if(r.symbol)n=new Be("mo",[Ne(r.name,r.mode)]),ht.contains(Yp,r.name)&&n.setAttribute("largeop","false");else if(r.body)n=new Be("mo",_e(r.body,e));else{n=new Be("mi",[new On(r.name.slice(1))]);var i=new Be("mo",[Ne("⁡","text")]);n=r.parentIsSupSub?new Be("mrow",[n,i]):Mp([n,i])}return n},Eg={"∏":"\\prod","∐":"\\coprod","∑":"\\sum","⋀":"\\bigwedge","⋁":"\\bigvee","⋂":"\\bigcap","⋃":"\\bigcup","⨀":"\\bigodot","⨁":"\\bigoplus","⨂":"\\bigotimes","⨄":"\\biguplus","⨆":"\\bigsqcup"};st({type:"op",names:["\\coprod","\\bigvee","\\bigwedge","\\biguplus","\\bigcap","\\bigcup","\\intop","\\prod","\\sum","\\bigotimes","\\bigoplus","\\bigodot","\\bigsqcup","\\smallint","∏","∐","∑","⋀","⋁","⋂","⋃","⨀","⨁","⨂","⨄","⨆"],props:{numArgs:0},handler:(r,e)=>{var{parser:n,funcName:i}=r,t=i;return t.length===1&&(t=Eg[t]),{type:"op",mode:n.mode,limits:!0,parentIsSupSub:!1,symbol:!0,name:t}},htmlBuilder:mn,mathmlBuilder:Rn}),st({type:"op",names:["\\mathop"],props:{numArgs:1,primitive:!0},handler:(r,e)=>{var{parser:n}=r,i=e[0];return{type:"op",mode:n.mode,limits:!1,parentIsSupSub:!1,symbol:!1,body:ie(i)}},htmlBuilder:mn,mathmlBuilder:Rn});var Dg={"∫":"\\int","∬":"\\iint","∭":"\\iiint","∮":"\\oint","∯":"\\oiint","∰":"\\oiiint"};st({type:"op",names:["\\arcsin","\\arccos","\\arctan","\\arctg","\\arcctg","\\arg","\\ch","\\cos","\\cosec","\\cosh","\\cot","\\cotg","\\coth","\\csc","\\ctg","\\cth","\\deg","\\dim","\\exp","\\hom","\\ker","\\lg","\\ln","\\log","\\sec","\\sin","\\sinh","\\sh","\\tan","\\tanh","\\tg","\\th"],props:{numArgs:0},handler(r){var{parser:e,funcName:n}=r;return{type:"op",mode:e.mode,limits:!1,parentIsSupSub:!1,symbol:!1,name:n}},htmlBuilder:mn,mathmlBuilder:Rn}),st({type:"op",names:["\\det","\\gcd","\\inf","\\lim","\\max","\\min","\\Pr","\\sup"],props:{numArgs:0},handler(r){var{parser:e,funcName:n}=r;return{type:"op",mode:e.mode,limits:!0,parentIsSupSub:!1,symbol:!1,name:n}},htmlBuilder:mn,mathmlBuilder:Rn}),st({type:"op",names:["\\int","\\iint","\\iiint","\\oint","\\oiint","\\oiiint","∫","∬","∭","∮","∯","∰"],props:{numArgs:0},handler(r){var{parser:e,funcName:n}=r,i=n;return i.length===1&&(i=Dg[i]),{type:"op",mode:e.mode,limits:!1,parentIsSupSub:!1,symbol:!0,name:i}},htmlBuilder:mn,mathmlBuilder:Rn});var Wp={};function A(r,e){Wp[r]=e}A("\\noexpand",function(r){var e=r.popToken();return r.isExpandable(e.text)&&(e.noexpand=!0,e.treatAsRelax=!0),{tokens:[e],numArgs:0}}),A("\\expandafter",function(r){var e=r.popToken();return r.expandOnce(!0),{tokens:[e],numArgs:0}}),A("\\@firstoftwo",function(r){return{tokens:r.consumeArgs(2)[0],numArgs:0}}),A("\\@secondoftwo",function(r){return{tokens:r.consumeArgs(2)[1],numArgs:0}}),A("\\@ifnextchar",function(r){var e=r.consumeArgs(3);r.consumeSpaces();var n=r.future();return e[0].length===1&&e[0][0].text===n.text?{tokens:e[1],numArgs:0}:{tokens:e[2],numArgs:0}}),A("\\@ifstar","\\@ifnextchar *{\\@firstoftwo{#1}}"),A("\\TextOrMath",function(r){var e=r.consumeArgs(2);return r.mode==="text"?{tokens:e[0],numArgs:0}:{tokens:e[1],numArgs:0}});var lh={0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9,a:10,A:10,b:11,B:11,c:12,C:12,d:13,D:13,e:14,E:14,f:15,F:15};A("\\char",function(r){var e,n=r.popToken(),i="";if(n.text==="'")e=8,n=r.popToken();else if(n.text==='"')e=16,n=r.popToken();else if(n.text==="`")if((n=r.popToken()).text[0]==="\\")i=n.text.charCodeAt(1);else{if(n.text==="EOF")throw new rt("\\char` missing argument");i=n.text.charCodeAt(0)}else e=10;if(e){if((i=lh[n.text])==null||i>=e)throw new rt("Invalid base-"+e+" digit "+n.text);for(var t;(t=lh[r.future().text])!=null&&t<e;)i*=e,i+=t,r.popToken()}return"\\@char{"+i+"}"});var ka=(r,e,n)=>{var i=r.consumeArg().tokens;if(i.length!==1)throw new rt("\\newcommand's first argument must be a macro name");var t=i[0].text,l=r.isDefined(t);if(l&&!e)throw new rt("\\newcommand{"+t+"} attempting to redefine "+t+"; use \\renewcommand");if(!l&&!n)throw new rt("\\renewcommand{"+t+"} when command "+t+" does not yet exist; use \\newcommand");var h=0;if((i=r.consumeArg().tokens).length===1&&i[0].text==="["){for(var p="",m=r.expandNextToken();m.text!=="]"&&m.text!=="EOF";)p+=m.text,m=r.expandNextToken();if(!p.match(/^\s*[0-9]+\s*$/))throw new rt("Invalid number of arguments: "+p);h=parseInt(p),i=r.consumeArg().tokens}return r.macros.set(t,{tokens:i,numArgs:h}),""};A("\\newcommand",r=>ka(r,!1,!0)),A("\\renewcommand",r=>ka(r,!0,!1)),A("\\providecommand",r=>ka(r,!0,!0)),A("\\message",r=>{var e=r.consumeArgs(1)[0];return console.log(e.reverse().map(n=>n.text).join("")),""}),A("\\errmessage",r=>{var e=r.consumeArgs(1)[0];return console.error(e.reverse().map(n=>n.text).join("")),""}),A("\\show",r=>{var e=r.popToken(),n=e.text;return console.log(e,r.macros.get(n),xr[n],Pt.math[n],Pt.text[n]),""}),A("\\bgroup","{"),A("\\egroup","}"),A("~","\\nobreakspace"),A("\\lq","`"),A("\\rq","'"),A("\\aa","\\r a"),A("\\AA","\\r A"),A("\\textcopyright","\\html@mathml{\\textcircled{c}}{\\char`©}"),A("\\copyright","\\TextOrMath{\\textcopyright}{\\text{\\textcopyright}}"),A("\\textregistered","\\html@mathml{\\textcircled{\\scriptsize R}}{\\char`®}"),A("ℬ","\\mathscr{B}"),A("ℰ","\\mathscr{E}"),A("ℱ","\\mathscr{F}"),A("ℋ","\\mathscr{H}"),A("ℐ","\\mathscr{I}"),A("ℒ","\\mathscr{L}"),A("ℳ","\\mathscr{M}"),A("ℛ","\\mathscr{R}"),A("ℭ","\\mathfrak{C}"),A("ℌ","\\mathfrak{H}"),A("ℨ","\\mathfrak{Z}"),A("\\Bbbk","\\Bbb{k}"),A("·","\\cdotp"),A("\\llap","\\mathllap{\\textrm{#1}}"),A("\\rlap","\\mathrlap{\\textrm{#1}}"),A("\\clap","\\mathclap{\\textrm{#1}}"),A("\\mathstrut","\\vphantom{(}"),A("\\underbar","\\underline{\\text{#1}}"),A("\\not",'\\html@mathml{\\mathrel{\\mathrlap\\@not}}{\\char"338}'),A("\\neq","\\html@mathml{\\mathrel{\\not=}}{\\mathrel{\\char`≠}}"),A("\\ne","\\neq"),A("≠","\\neq"),A("\\notin","\\html@mathml{\\mathrel{{\\in}\\mathllap{/\\mskip1mu}}}{\\mathrel{\\char`∉}}"),A("∉","\\notin"),A("≘","\\html@mathml{\\mathrel{=\\kern{-1em}\\raisebox{0.4em}{$\\scriptsize\\frown$}}}{\\mathrel{\\char`≘}}"),A("≙","\\html@mathml{\\stackrel{\\tiny\\wedge}{=}}{\\mathrel{\\char`≘}}"),A("≚","\\html@mathml{\\stackrel{\\tiny\\vee}{=}}{\\mathrel{\\char`≚}}"),A("≛","\\html@mathml{\\stackrel{\\scriptsize\\star}{=}}{\\mathrel{\\char`≛}}"),A("≝","\\html@mathml{\\stackrel{\\tiny\\mathrm{def}}{=}}{\\mathrel{\\char`≝}}"),A("≞","\\html@mathml{\\stackrel{\\tiny\\mathrm{m}}{=}}{\\mathrel{\\char`≞}}"),A("≟","\\html@mathml{\\stackrel{\\tiny?}{=}}{\\mathrel{\\char`≟}}"),A("⟂","\\perp"),A("‼","\\mathclose{!\\mkern-0.8mu!}"),A("∌","\\notni"),A("⌜","\\ulcorner"),A("⌝","\\urcorner"),A("⌞","\\llcorner"),A("⌟","\\lrcorner"),A("©","\\copyright"),A("®","\\textregistered"),A("️","\\textregistered"),A("\\ulcorner",'\\html@mathml{\\@ulcorner}{\\mathop{\\char"231c}}'),A("\\urcorner",'\\html@mathml{\\@urcorner}{\\mathop{\\char"231d}}'),A("\\llcorner",'\\html@mathml{\\@llcorner}{\\mathop{\\char"231e}}'),A("\\lrcorner",'\\html@mathml{\\@lrcorner}{\\mathop{\\char"231f}}'),A("\\vdots","\\mathord{\\varvdots\\rule{0pt}{15pt}}"),A("⋮","\\vdots"),A("\\varGamma","\\mathit{\\Gamma}"),A("\\varDelta","\\mathit{\\Delta}"),A("\\varTheta","\\mathit{\\Theta}"),A("\\varLambda","\\mathit{\\Lambda}"),A("\\varXi","\\mathit{\\Xi}"),A("\\varPi","\\mathit{\\Pi}"),A("\\varSigma","\\mathit{\\Sigma}"),A("\\varUpsilon","\\mathit{\\Upsilon}"),A("\\varPhi","\\mathit{\\Phi}"),A("\\varPsi","\\mathit{\\Psi}"),A("\\varOmega","\\mathit{\\Omega}"),A("\\substack","\\begin{subarray}{c}#1\\end{subarray}"),A("\\colon","\\nobreak\\mskip2mu\\mathpunct{}\\mathchoice{\\mkern-3mu}{\\mkern-3mu}{}{}{:}\\mskip6mu"),A("\\boxed","\\fbox{$\\displaystyle{#1}$}"),A("\\iff","\\DOTSB\\;\\Longleftrightarrow\\;"),A("\\implies","\\DOTSB\\;\\Longrightarrow\\;"),A("\\impliedby","\\DOTSB\\;\\Longleftarrow\\;");var uh={",":"\\dotsc","\\not":"\\dotsb","+":"\\dotsb","=":"\\dotsb","<":"\\dotsb",">":"\\dotsb","-":"\\dotsb","*":"\\dotsb",":":"\\dotsb","\\DOTSB":"\\dotsb","\\coprod":"\\dotsb","\\bigvee":"\\dotsb","\\bigwedge":"\\dotsb","\\biguplus":"\\dotsb","\\bigcap":"\\dotsb","\\bigcup":"\\dotsb","\\prod":"\\dotsb","\\sum":"\\dotsb","\\bigotimes":"\\dotsb","\\bigoplus":"\\dotsb","\\bigodot":"\\dotsb","\\bigsqcup":"\\dotsb","\\And":"\\dotsb","\\longrightarrow":"\\dotsb","\\Longrightarrow":"\\dotsb","\\longleftarrow":"\\dotsb","\\Longleftarrow":"\\dotsb","\\longleftrightarrow":"\\dotsb","\\Longleftrightarrow":"\\dotsb","\\mapsto":"\\dotsb","\\longmapsto":"\\dotsb","\\hookrightarrow":"\\dotsb","\\doteq":"\\dotsb","\\mathbin":"\\dotsb","\\mathrel":"\\dotsb","\\relbar":"\\dotsb","\\Relbar":"\\dotsb","\\xrightarrow":"\\dotsb","\\xleftarrow":"\\dotsb","\\DOTSI":"\\dotsi","\\int":"\\dotsi","\\oint":"\\dotsi","\\iint":"\\dotsi","\\iiint":"\\dotsi","\\iiiint":"\\dotsi","\\idotsint":"\\dotsi","\\DOTSX":"\\dotsx"};A("\\dots",function(r){var e="\\dotso",n=r.expandAfterFuture().text;return n in uh?e=uh[n]:(n.substr(0,4)==="\\not"||n in Pt.math&&ht.contains(["bin","rel"],Pt.math[n].group))&&(e="\\dotsb"),e});var Aa={")":!0,"]":!0,"\\rbrack":!0,"\\}":!0,"\\rbrace":!0,"\\rangle":!0,"\\rceil":!0,"\\rfloor":!0,"\\rgroup":!0,"\\rmoustache":!0,"\\right":!0,"\\bigr":!0,"\\biggr":!0,"\\Bigr":!0,"\\Biggr":!0,$:!0,";":!0,".":!0,",":!0};A("\\dotso",function(r){return r.future().text in Aa?"\\ldots\\,":"\\ldots"}),A("\\dotsc",function(r){var e=r.future().text;return e in Aa&&e!==","?"\\ldots\\,":"\\ldots"}),A("\\cdots",function(r){return r.future().text in Aa?"\\@cdots\\,":"\\@cdots"}),A("\\dotsb","\\cdots"),A("\\dotsm","\\cdots"),A("\\dotsi","\\!\\cdots"),A("\\dotsx","\\ldots\\,"),A("\\DOTSI","\\relax"),A("\\DOTSB","\\relax"),A("\\DOTSX","\\relax"),A("\\tmspace","\\TextOrMath{\\kern#1#3}{\\mskip#1#2}\\relax"),A("\\,","\\tmspace+{3mu}{.1667em}"),A("\\thinspace","\\,"),A("\\>","\\mskip{4mu}"),A("\\:","\\tmspace+{4mu}{.2222em}"),A("\\medspace","\\:"),A("\\;","\\tmspace+{5mu}{.2777em}"),A("\\thickspace","\\;"),A("\\!","\\tmspace-{3mu}{.1667em}"),A("\\negthinspace","\\!"),A("\\negmedspace","\\tmspace-{4mu}{.2222em}"),A("\\negthickspace","\\tmspace-{5mu}{.277em}"),A("\\enspace","\\kern.5em "),A("\\enskip","\\hskip.5em\\relax"),A("\\quad","\\hskip1em\\relax"),A("\\qquad","\\hskip2em\\relax"),A("\\tag","\\@ifstar\\tag@literal\\tag@paren"),A("\\tag@paren","\\tag@literal{({#1})}"),A("\\tag@literal",r=>{if(r.macros.get("\\df@tag"))throw new rt("Multiple \\tag");return"\\gdef\\df@tag{\\text{#1}}"}),A("\\bmod","\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}\\mathbin{\\rm mod}\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}"),A("\\pod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern8mu}{\\mkern8mu}{\\mkern8mu}(#1)"),A("\\pmod","\\pod{{\\rm mod}\\mkern6mu#1}"),A("\\mod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern12mu}{\\mkern12mu}{\\mkern12mu}{\\rm mod}\\,\\,#1"),A("\\pmb","\\html@mathml{\\@binrel{#1}{\\mathrlap{#1}\\kern0.5px#1}}{\\mathbf{#1}}"),A("\\newline","\\\\\\relax"),A("\\TeX","\\textrm{\\html@mathml{T\\kern-.1667em\\raisebox{-.5ex}{E}\\kern-.125emX}{TeX}}");var ch=Ke["Main-Regular"][84][1]-.7*Ke["Main-Regular"][65][1]+"em";A("\\LaTeX","\\textrm{\\html@mathml{L\\kern-.36em\\raisebox{"+ch+"}{\\scriptstyle A}\\kern-.15em\\TeX}{LaTeX}}"),A("\\KaTeX","\\textrm{\\html@mathml{K\\kern-.17em\\raisebox{"+ch+"}{\\scriptstyle A}\\kern-.15em\\TeX}{KaTeX}}"),A("\\hspace","\\@ifstar\\@hspacer\\@hspace"),A("\\@hspace","\\hskip #1\\relax"),A("\\@hspacer","\\rule{0pt}{0pt}\\hskip #1\\relax"),A("\\ordinarycolon",":"),A("\\vcentcolon","\\mathrel{\\mathop\\ordinarycolon}"),A("\\dblcolon",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-.9mu}\\vcentcolon}}{\\mathop{\\char"2237}}'),A("\\coloneqq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2254}}'),A("\\Coloneqq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2237\\char"3d}}'),A("\\coloneq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"3a\\char"2212}}'),A("\\Coloneq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"2237\\char"2212}}'),A("\\eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2255}}'),A("\\Eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"3d\\char"2237}}'),A("\\eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2239}}'),A("\\Eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"2212\\char"2237}}'),A("\\colonapprox",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"3a\\char"2248}}'),A("\\Colonapprox",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"2237\\char"2248}}'),A("\\colonsim",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"3a\\char"223c}}'),A("\\Colonsim",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"2237\\char"223c}}'),A("∷","\\dblcolon"),A("∹","\\eqcolon"),A("≔","\\coloneqq"),A("≕","\\eqqcolon"),A("⩴","\\Coloneqq"),A("\\ratio","\\vcentcolon"),A("\\coloncolon","\\dblcolon"),A("\\colonequals","\\coloneqq"),A("\\coloncolonequals","\\Coloneqq"),A("\\equalscolon","\\eqqcolon"),A("\\equalscoloncolon","\\Eqqcolon"),A("\\colonminus","\\coloneq"),A("\\coloncolonminus","\\Coloneq"),A("\\minuscolon","\\eqcolon"),A("\\minuscoloncolon","\\Eqcolon"),A("\\coloncolonapprox","\\Colonapprox"),A("\\coloncolonsim","\\Colonsim"),A("\\simcolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\vcentcolon}"),A("\\simcoloncolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\dblcolon}"),A("\\approxcolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\vcentcolon}"),A("\\approxcoloncolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\dblcolon}"),A("\\notni","\\html@mathml{\\not\\ni}{\\mathrel{\\char`∌}}"),A("\\limsup","\\DOTSB\\operatorname*{lim\\,sup}"),A("\\liminf","\\DOTSB\\operatorname*{lim\\,inf}"),A("\\injlim","\\DOTSB\\operatorname*{inj\\,lim}"),A("\\projlim","\\DOTSB\\operatorname*{proj\\,lim}"),A("\\varlimsup","\\DOTSB\\operatorname*{\\overline{lim}}"),A("\\varliminf","\\DOTSB\\operatorname*{\\underline{lim}}"),A("\\varinjlim","\\DOTSB\\operatorname*{\\underrightarrow{lim}}"),A("\\varprojlim","\\DOTSB\\operatorname*{\\underleftarrow{lim}}"),A("\\gvertneqq","\\html@mathml{\\@gvertneqq}{≩}"),A("\\lvertneqq","\\html@mathml{\\@lvertneqq}{≨}"),A("\\ngeqq","\\html@mathml{\\@ngeqq}{≱}"),A("\\ngeqslant","\\html@mathml{\\@ngeqslant}{≱}"),A("\\nleqq","\\html@mathml{\\@nleqq}{≰}"),A("\\nleqslant","\\html@mathml{\\@nleqslant}{≰}"),A("\\nshortmid","\\html@mathml{\\@nshortmid}{∤}"),A("\\nshortparallel","\\html@mathml{\\@nshortparallel}{∦}"),A("\\nsubseteqq","\\html@mathml{\\@nsubseteqq}{⊈}"),A("\\nsupseteqq","\\html@mathml{\\@nsupseteqq}{⊉}"),A("\\varsubsetneq","\\html@mathml{\\@varsubsetneq}{⊊}"),A("\\varsubsetneqq","\\html@mathml{\\@varsubsetneqq}{⫋}"),A("\\varsupsetneq","\\html@mathml{\\@varsupsetneq}{⊋}"),A("\\varsupsetneqq","\\html@mathml{\\@varsupsetneqq}{⫌}"),A("\\imath","\\html@mathml{\\@imath}{ı}"),A("\\jmath","\\html@mathml{\\@jmath}{ȷ}"),A("\\llbracket","\\html@mathml{\\mathopen{[\\mkern-3.2mu[}}{\\mathopen{\\char`⟦}}"),A("\\rrbracket","\\html@mathml{\\mathclose{]\\mkern-3.2mu]}}{\\mathclose{\\char`⟧}}"),A("⟦","\\llbracket"),A("⟧","\\rrbracket"),A("\\lBrace","\\html@mathml{\\mathopen{\\{\\mkern-3.2mu[}}{\\mathopen{\\char`⦃}}"),A("\\rBrace","\\html@mathml{\\mathclose{]\\mkern-3.2mu\\}}}{\\mathclose{\\char`⦄}}"),A("⦃","\\lBrace"),A("⦄","\\rBrace"),A("\\minuso","\\mathbin{\\html@mathml{{\\mathrlap{\\mathchoice{\\kern{0.145em}}{\\kern{0.145em}}{\\kern{0.1015em}}{\\kern{0.0725em}}\\circ}{-}}}{\\char`⦵}}"),A("⦵","\\minuso"),A("\\darr","\\downarrow"),A("\\dArr","\\Downarrow"),A("\\Darr","\\Downarrow"),A("\\lang","\\langle"),A("\\rang","\\rangle"),A("\\uarr","\\uparrow"),A("\\uArr","\\Uparrow"),A("\\Uarr","\\Uparrow"),A("\\N","\\mathbb{N}"),A("\\R","\\mathbb{R}"),A("\\Z","\\mathbb{Z}"),A("\\alef","\\aleph"),A("\\alefsym","\\aleph"),A("\\Alpha","\\mathrm{A}"),A("\\Beta","\\mathrm{B}"),A("\\bull","\\bullet"),A("\\Chi","\\mathrm{X}"),A("\\clubs","\\clubsuit"),A("\\cnums","\\mathbb{C}"),A("\\Complex","\\mathbb{C}"),A("\\Dagger","\\ddagger"),A("\\diamonds","\\diamondsuit"),A("\\empty","\\emptyset"),A("\\Epsilon","\\mathrm{E}"),A("\\Eta","\\mathrm{H}"),A("\\exist","\\exists"),A("\\harr","\\leftrightarrow"),A("\\hArr","\\Leftrightarrow"),A("\\Harr","\\Leftrightarrow"),A("\\hearts","\\heartsuit"),A("\\image","\\Im"),A("\\infin","\\infty"),A("\\Iota","\\mathrm{I}"),A("\\isin","\\in"),A("\\Kappa","\\mathrm{K}"),A("\\larr","\\leftarrow"),A("\\lArr","\\Leftarrow"),A("\\Larr","\\Leftarrow"),A("\\lrarr","\\leftrightarrow"),A("\\lrArr","\\Leftrightarrow"),A("\\Lrarr","\\Leftrightarrow"),A("\\Mu","\\mathrm{M}"),A("\\natnums","\\mathbb{N}"),A("\\Nu","\\mathrm{N}"),A("\\Omicron","\\mathrm{O}"),A("\\plusmn","\\pm"),A("\\rarr","\\rightarrow"),A("\\rArr","\\Rightarrow"),A("\\Rarr","\\Rightarrow"),A("\\real","\\Re"),A("\\reals","\\mathbb{R}"),A("\\Reals","\\mathbb{R}"),A("\\Rho","\\mathrm{P}"),A("\\sdot","\\cdot"),A("\\sect","\\S"),A("\\spades","\\spadesuit"),A("\\sub","\\subset"),A("\\sube","\\subseteq"),A("\\supe","\\supseteq"),A("\\Tau","\\mathrm{T}"),A("\\thetasym","\\vartheta"),A("\\weierp","\\wp"),A("\\Zeta","\\mathrm{Z}"),A("\\argmin","\\DOTSB\\operatorname*{arg\\,min}"),A("\\argmax","\\DOTSB\\operatorname*{arg\\,max}"),A("\\plim","\\DOTSB\\mathop{\\operatorname{plim}}\\limits"),A("\\bra","\\mathinner{\\langle{#1}|}"),A("\\ket","\\mathinner{|{#1}\\rangle}"),A("\\braket","\\mathinner{\\langle{#1}\\rangle}"),A("\\Bra","\\left\\langle#1\\right|"),A("\\Ket","\\left|#1\\right\\rangle"),A("\\angln","{\\angl n}"),A("\\blue","\\textcolor{##6495ed}{#1}"),A("\\orange","\\textcolor{##ffa500}{#1}"),A("\\pink","\\textcolor{##ff00af}{#1}"),A("\\red","\\textcolor{##df0030}{#1}"),A("\\green","\\textcolor{##28ae7b}{#1}"),A("\\gray","\\textcolor{gray}{#1}"),A("\\purple","\\textcolor{##9d38bd}{#1}"),A("\\blueA","\\textcolor{##ccfaff}{#1}"),A("\\blueB","\\textcolor{##80f6ff}{#1}"),A("\\blueC","\\textcolor{##63d9ea}{#1}"),A("\\blueD","\\textcolor{##11accd}{#1}"),A("\\blueE","\\textcolor{##0c7f99}{#1}"),A("\\tealA","\\textcolor{##94fff5}{#1}"),A("\\tealB","\\textcolor{##26edd5}{#1}"),A("\\tealC","\\textcolor{##01d1c1}{#1}"),A("\\tealD","\\textcolor{##01a995}{#1}"),A("\\tealE","\\textcolor{##208170}{#1}"),A("\\greenA","\\textcolor{##b6ffb0}{#1}"),A("\\greenB","\\textcolor{##8af281}{#1}"),A("\\greenC","\\textcolor{##74cf70}{#1}"),A("\\greenD","\\textcolor{##1fab54}{#1}"),A("\\greenE","\\textcolor{##0d923f}{#1}"),A("\\goldA","\\textcolor{##ffd0a9}{#1}"),A("\\goldB","\\textcolor{##ffbb71}{#1}"),A("\\goldC","\\textcolor{##ff9c39}{#1}"),A("\\goldD","\\textcolor{##e07d10}{#1}"),A("\\goldE","\\textcolor{##a75a05}{#1}"),A("\\redA","\\textcolor{##fca9a9}{#1}"),A("\\redB","\\textcolor{##ff8482}{#1}"),A("\\redC","\\textcolor{##f9685d}{#1}"),A("\\redD","\\textcolor{##e84d39}{#1}"),A("\\redE","\\textcolor{##bc2612}{#1}"),A("\\maroonA","\\textcolor{##ffbde0}{#1}"),A("\\maroonB","\\textcolor{##ff92c6}{#1}"),A("\\maroonC","\\textcolor{##ed5fa6}{#1}"),A("\\maroonD","\\textcolor{##ca337c}{#1}"),A("\\maroonE","\\textcolor{##9e034e}{#1}"),A("\\purpleA","\\textcolor{##ddd7ff}{#1}"),A("\\purpleB","\\textcolor{##c6b9fc}{#1}"),A("\\purpleC","\\textcolor{##aa87ff}{#1}"),A("\\purpleD","\\textcolor{##7854ab}{#1}"),A("\\purpleE","\\textcolor{##543b78}{#1}"),A("\\mintA","\\textcolor{##f5f9e8}{#1}"),A("\\mintB","\\textcolor{##edf2df}{#1}"),A("\\mintC","\\textcolor{##e0e5cc}{#1}"),A("\\grayA","\\textcolor{##f6f7f7}{#1}"),A("\\grayB","\\textcolor{##f0f1f2}{#1}"),A("\\grayC","\\textcolor{##e3e5e6}{#1}"),A("\\grayD","\\textcolor{##d6d8da}{#1}"),A("\\grayE","\\textcolor{##babec2}{#1}"),A("\\grayF","\\textcolor{##888d93}{#1}"),A("\\grayG","\\textcolor{##626569}{#1}"),A("\\grayH","\\textcolor{##3b3e40}{#1}"),A("\\grayI","\\textcolor{##21242c}{#1}"),A("\\kaBlue","\\textcolor{##314453}{#1}"),A("\\kaGreen","\\textcolor{##71B307}{#1}");var $p=(r,e)=>{var n,i,t,l,h=!1;if(r.type==="supsub"?(n=r.sup,i=r.sub,t=wt(r.base,"operatorname"),h=!0):t=wt(r,"operatorname"),t.body.length>0){for(var p=t.body.map(S=>{var E=S.text;return typeof E=="string"?{type:"textord",mode:S.mode,text:E}:S}),m=ae(p,e.withFont("mathrm"),!0),y=0;y<m.length;y++){var _=m[y];_ instanceof Oe&&(_.text=_.text.replace(/\u2212/,"-").replace(/\u2217/,"*"))}l=H.makeSpan(["mop"],m,e)}else l=H.makeSpan(["mop"],[],e);return h?Xp(l,n,i,e,e.style,0,0):l};function Zp(r,e,n){for(var i=ae(r,e,!1),t=e.sizeMultiplier/n.sizeMultiplier,l=0;l<i.length;l++){var h=i[l].classes.indexOf("sizing");h<0?Array.prototype.push.apply(i[l].classes,e.sizingClasses(n)):i[l].classes[h+1]==="reset-size"+e.size&&(i[l].classes[h+1]="reset-size"+n.size),i[l].height*=t,i[l].depth*=t}return H.makeFragment(i)}st({type:"operatorname",names:["\\operatorname@","\\operatornamewithlimits"],props:{numArgs:1},handler:(r,e)=>{var{parser:n,funcName:i}=r,t=e[0];return{type:"operatorname",mode:n.mode,body:ie(t),alwaysHandleSupSub:i==="\\operatornamewithlimits",limits:!1,parentIsSupSub:!1}},htmlBuilder:$p,mathmlBuilder:(r,e)=>{for(var n=_e(r.body,e.withFont("mathrm")),i=!0,t=0;t<n.length;t++){var l=n[t];if(!(l instanceof J.SpaceNode))if(l instanceof J.MathNode)switch(l.type){case"mi":case"mn":case"ms":case"mspace":case"mtext":break;case"mo":var h=l.children[0];l.children.length===1&&h instanceof J.TextNode?h.text=h.text.replace(/\u2212/,"-").replace(/\u2217/,"*"):i=!1;break;default:i=!1}else i=!1}if(i){var p=n.map(_=>_.toText()).join("");n=[new J.TextNode(p)]}var m=new J.MathNode("mi",n);m.setAttribute("mathvariant","normal");var y=new J.MathNode("mo",[Ne("⁡","text")]);return r.parentIsSupSub?new J.MathNode("mrow",[m,y]):J.newDocumentFragment([m,y])}}),A("\\operatorname","\\@ifstar\\operatornamewithlimits\\operatorname@"),Vr({type:"ordgroup",htmlBuilder:(r,e)=>r.semisimple?H.makeFragment(ae(r.body,e,!1)):H.makeSpan(["mord"],ae(r.body,e,!0),e),mathmlBuilder:(r,e)=>wr(r.body,e,!0)}),st({type:"overline",names:["\\overline"],props:{numArgs:1},handler(r,e){var{parser:n}=r,i=e[0];return{type:"overline",mode:n.mode,body:i}},htmlBuilder(r,e){var n=Tt(r.body,e.havingCrampedStyle()),i=H.makeLineSpan("overline-line",e),t=e.fontMetrics().defaultRuleThickness,l=H.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n},{type:"kern",size:3*t},{type:"elem",elem:i},{type:"kern",size:t}]},e);return H.makeSpan(["mord","overline"],[l],e)},mathmlBuilder(r,e){var n=new J.MathNode("mo",[new J.TextNode("‾")]);n.setAttribute("stretchy","true");var i=new J.MathNode("mover",[Vt(r.body,e),n]);return i.setAttribute("accent","true"),i}}),st({type:"phantom",names:["\\phantom"],props:{numArgs:1,allowedInText:!0},handler:(r,e)=>{var{parser:n}=r,i=e[0];return{type:"phantom",mode:n.mode,body:ie(i)}},htmlBuilder:(r,e)=>{var n=ae(r.body,e.withPhantom(),!1);return H.makeFragment(n)},mathmlBuilder:(r,e)=>{var n=_e(r.body,e);return new J.MathNode("mphantom",n)}}),st({type:"hphantom",names:["\\hphantom"],props:{numArgs:1,allowedInText:!0},handler:(r,e)=>{var{parser:n}=r,i=e[0];return{type:"hphantom",mode:n.mode,body:i}},htmlBuilder:(r,e)=>{var n=H.makeSpan([],[Tt(r.body,e.withPhantom())]);if(n.height=0,n.depth=0,n.children)for(var i=0;i<n.children.length;i++)n.children[i].height=0,n.children[i].depth=0;return n=H.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n}]},e),H.makeSpan(["mord"],[n],e)},mathmlBuilder:(r,e)=>{var n=_e(ie(r.body),e),i=new J.MathNode("mphantom",n),t=new J.MathNode("mpadded",[i]);return t.setAttribute("height","0px"),t.setAttribute("depth","0px"),t}}),st({type:"vphantom",names:["\\vphantom"],props:{numArgs:1,allowedInText:!0},handler:(r,e)=>{var{parser:n}=r,i=e[0];return{type:"vphantom",mode:n.mode,body:i}},htmlBuilder:(r,e)=>{var n=H.makeSpan(["inner"],[Tt(r.body,e.withPhantom())]),i=H.makeSpan(["fix"],[]);return H.makeSpan(["mord","rlap"],[n,i],e)},mathmlBuilder:(r,e)=>{var n=_e(ie(r.body),e),i=new J.MathNode("mphantom",n),t=new J.MathNode("mpadded",[i]);return t.setAttribute("width","0px"),t}}),st({type:"raisebox",names:["\\raisebox"],props:{numArgs:2,argTypes:["size","hbox"],allowedInText:!0},handler(r,e){var{parser:n}=r,i=wt(e[0],"size").value,t=e[1];return{type:"raisebox",mode:n.mode,dy:i,body:t}},htmlBuilder(r,e){var n=Tt(r.body,e),i=Qt(r.dy,e);return H.makeVList({positionType:"shift",positionData:-i,children:[{type:"elem",elem:n}]},e)},mathmlBuilder(r,e){var n=new J.MathNode("mpadded",[Vt(r.body,e)]),i=r.dy.number+r.dy.unit;return n.setAttribute("voffset",i),n}}),st({type:"rule",names:["\\rule"],props:{numArgs:2,numOptionalArgs:1,argTypes:["size","size","size"]},handler(r,e,n){var{parser:i}=r,t=n[0],l=wt(e[0],"size"),h=wt(e[1],"size");return{type:"rule",mode:i.mode,shift:t&&wt(t,"size").value,width:l.value,height:h.value}},htmlBuilder(r,e){var n=H.makeSpan(["mord","rule"],[],e),i=Qt(r.width,e),t=Qt(r.height,e),l=r.shift?Qt(r.shift,e):0;return n.style.borderRightWidth=i+"em",n.style.borderTopWidth=t+"em",n.style.bottom=l+"em",n.width=i,n.height=t+l,n.depth=-l,n.maxFontSize=1.125*t*e.sizeMultiplier,n},mathmlBuilder(r,e){var n=Qt(r.width,e),i=Qt(r.height,e),t=r.shift?Qt(r.shift,e):0,l=e.color&&e.getColor()||"black",h=new J.MathNode("mspace");h.setAttribute("mathbackground",l),h.setAttribute("width",n+"em"),h.setAttribute("height",i+"em");var p=new J.MathNode("mpadded",[h]);return t>=0?p.setAttribute("height","+"+t+"em"):(p.setAttribute("height",t+"em"),p.setAttribute("depth","+"+-t+"em")),p.setAttribute("voffset",t+"em"),p}});var hh=["\\tiny","\\sixptsize","\\scriptsize","\\footnotesize","\\small","\\normalsize","\\large","\\Large","\\LARGE","\\huge","\\Huge"];st({type:"sizing",names:hh,props:{numArgs:0,allowedInText:!0},handler:(r,e)=>{var{breakOnTokenText:n,funcName:i,parser:t}=r,l=t.parseExpression(!1,n);return{type:"sizing",mode:t.mode,size:hh.indexOf(i)+1,body:l}},htmlBuilder:(r,e)=>{var n=e.havingSize(r.size);return Zp(r.body,n,e)},mathmlBuilder:(r,e)=>{var n=e.havingSize(r.size),i=_e(r.body,n),t=new J.MathNode("mstyle",i);return t.setAttribute("mathsize",n.sizeMultiplier+"em"),t}}),st({type:"smash",names:["\\smash"],props:{numArgs:1,numOptionalArgs:1,allowedInText:!0},handler:(r,e,n)=>{var{parser:i}=r,t=!1,l=!1,h=n[0]&&wt(n[0],"ordgroup");if(h)for(var p="",m=0;m<h.body.length;++m)if((p=h.body[m].text)==="t")t=!0;else{if(p!=="b"){t=!1,l=!1;break}l=!0}else t=!0,l=!0;var y=e[0];return{type:"smash",mode:i.mode,body:y,smashHeight:t,smashDepth:l}},htmlBuilder:(r,e)=>{var n=H.makeSpan([],[Tt(r.body,e)]);if(!r.smashHeight&&!r.smashDepth)return n;if(r.smashHeight&&(n.height=0,n.children))for(var i=0;i<n.children.length;i++)n.children[i].height=0;if(r.smashDepth&&(n.depth=0,n.children))for(var t=0;t<n.children.length;t++)n.children[t].depth=0;var l=H.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n}]},e);return H.makeSpan(["mord"],[l],e)},mathmlBuilder:(r,e)=>{var n=new J.MathNode("mpadded",[Vt(r.body,e)]);return r.smashHeight&&n.setAttribute("height","0px"),r.smashDepth&&n.setAttribute("depth","0px"),n}}),st({type:"sqrt",names:["\\sqrt"],props:{numArgs:1,numOptionalArgs:1},handler(r,e,n){var{parser:i}=r,t=n[0],l=e[0];return{type:"sqrt",mode:i.mode,body:l,index:t}},htmlBuilder(r,e){var n=Tt(r.body,e.havingCrampedStyle());n.height===0&&(n.height=e.fontMetrics().xHeight),n=H.wrapFragment(n,e);var i=e.fontMetrics().defaultRuleThickness,t=i;e.style.id<gt.TEXT.id&&(t=e.fontMetrics().xHeight);var l=i+t/4,h=n.height+n.depth+l+i,{span:p,ruleWidth:m,advanceWidth:y}=Cg(h,e),_=p.height-m;_>n.height+n.depth+l&&(l=(l+_-n.height-n.depth)/2);var S=p.height-n.height-l-m;n.style.paddingLeft=y+"em";var E=H.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n,wrapperClasses:["svg-align"]},{type:"kern",size:-(n.height+S)},{type:"elem",elem:p},{type:"kern",size:m}]},e);if(r.index){var R=e.havingStyle(gt.SCRIPTSCRIPT),I=Tt(r.index,R,e),U=.6*(E.height-E.depth),Y=H.makeVList({positionType:"shift",positionData:-U,children:[{type:"elem",elem:I}]},e),it=H.makeSpan(["root"],[Y]);return H.makeSpan(["mord","sqrt"],[it,E],e)}return H.makeSpan(["mord","sqrt"],[E],e)},mathmlBuilder(r,e){var{body:n,index:i}=r;return i?new J.MathNode("mroot",[Vt(n,e),Vt(i,e)]):new J.MathNode("msqrt",[Vt(n,e)])}});var ph={display:gt.DISPLAY,text:gt.TEXT,script:gt.SCRIPT,scriptscript:gt.SCRIPTSCRIPT};st({type:"styling",names:["\\displaystyle","\\textstyle","\\scriptstyle","\\scriptscriptstyle"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(r,e){var{breakOnTokenText:n,funcName:i,parser:t}=r,l=t.parseExpression(!0,n),h=i.slice(1,i.length-5);return{type:"styling",mode:t.mode,style:h,body:l}},htmlBuilder(r,e){var n=ph[r.style],i=e.havingStyle(n).withFont("");return Zp(r.body,i,e)},mathmlBuilder(r,e){var n=ph[r.style],i=e.havingStyle(n),t=_e(r.body,i),l=new J.MathNode("mstyle",t),h={display:["0","true"],text:["0","false"],script:["1","false"],scriptscript:["2","false"]}[r.style];return l.setAttribute("scriptlevel",h[0]),l.setAttribute("displaystyle",h[1]),l}});Vr({type:"supsub",htmlBuilder(r,e){var n=function(G,j){var Z=G.base;return Z?Z.type==="op"?Z.limits&&(j.style.size===gt.DISPLAY.size||Z.alwaysHandleSupSub)?mn:null:Z.type==="operatorname"?Z.alwaysHandleSupSub&&(j.style.size===gt.DISPLAY.size||Z.limits)?$p:null:Z.type==="accent"?ht.isCharacterBox(Z.base)?Za:null:Z.type==="horizBrace"&&!G.sub===Z.isOver?Up:null:null}(r,e);if(n)return n(r,e);var i,t,l,{base:h,sup:p,sub:m}=r,y=Tt(h,e),_=e.fontMetrics(),S=0,E=0,R=h&&ht.isCharacterBox(h);if(p){var I=e.havingStyle(e.style.sup());i=Tt(p,I,e),R||(S=y.height-I.fontMetrics().supDrop*I.sizeMultiplier/e.sizeMultiplier)}if(m){var U=e.havingStyle(e.style.sub());t=Tt(m,U,e),R||(E=y.depth+U.fontMetrics().subDrop*U.sizeMultiplier/e.sizeMultiplier)}l=e.style===gt.DISPLAY?_.sup1:e.style.cramped?_.sup3:_.sup2;var Y,it=e.sizeMultiplier,nt=.5/_.ptPerEm/it+"em",pt=null;if(t){var dt=r.base&&r.base.type==="op"&&r.base.name&&(r.base.name==="\\oiint"||r.base.name==="\\oiiint");(y instanceof Oe||dt)&&(pt=-y.italic+"em")}if(i&&t){S=Math.max(S,l,i.depth+.25*_.xHeight),E=Math.max(E,_.sub2);var yt=4*_.defaultRuleThickness;if(S-i.depth-(t.height-E)<yt){E=yt-(S-i.depth)+t.height;var D=.8*_.xHeight-(S-i.depth);D>0&&(S+=D,E-=D)}var At=[{type:"elem",elem:t,shift:E,marginRight:nt,marginLeft:pt},{type:"elem",elem:i,shift:-S,marginRight:nt}];Y=H.makeVList({positionType:"individualShift",children:At},e)}else if(t){E=Math.max(E,_.sub1,t.height-.8*_.xHeight);var q=[{type:"elem",elem:t,marginLeft:pt,marginRight:nt}];Y=H.makeVList({positionType:"shift",positionData:E,children:q},e)}else{if(!i)throw new Error("supsub must have either sup or sub.");S=Math.max(S,l,i.depth+.25*_.xHeight),Y=H.makeVList({positionType:"shift",positionData:-S,children:[{type:"elem",elem:i,marginRight:nt}]},e)}var L=Ya(y,"right")||"mord";return H.makeSpan([L],[y,H.makeSpan(["msupsub"],[Y])],e)},mathmlBuilder(r,e){var n,i=!1;r.base&&r.base.type==="horizBrace"&&!!r.sup===r.base.isOver&&(i=!0,n=r.base.isOver),!r.base||r.base.type!=="op"&&r.base.type!=="operatorname"||(r.base.parentIsSupSub=!0);var t,l=[Vt(r.base,e)];if(r.sub&&l.push(Vt(r.sub,e)),r.sup&&l.push(Vt(r.sup,e)),i)t=n?"mover":"munder";else if(r.sub)if(r.sup){var h=r.base;t=h&&h.type==="op"&&h.limits&&e.style===gt.DISPLAY||h&&h.type==="operatorname"&&h.alwaysHandleSupSub&&(e.style===gt.DISPLAY||h.limits)?"munderover":"msubsup"}else{var p=r.base;t=p&&p.type==="op"&&p.limits&&(e.style===gt.DISPLAY||p.alwaysHandleSupSub)||p&&p.type==="operatorname"&&p.alwaysHandleSupSub&&(p.limits||e.style===gt.DISPLAY)?"munder":"msub"}else{var m=r.base;t=m&&m.type==="op"&&m.limits&&(e.style===gt.DISPLAY||m.alwaysHandleSupSub)||m&&m.type==="operatorname"&&m.alwaysHandleSupSub&&(m.limits||e.style===gt.DISPLAY)?"mover":"msup"}return new J.MathNode(t,l)}}),Vr({type:"atom",htmlBuilder:(r,e)=>H.mathsym(r.text,r.mode,e,["m"+r.family]),mathmlBuilder(r,e){var n=new J.MathNode("mo",[Ne(r.text,r.mode)]);if(r.family==="bin"){var i=$a(r,e);i==="bold-italic"&&n.setAttribute("mathvariant",i)}else r.family==="punct"?n.setAttribute("separator","true"):r.family!=="open"&&r.family!=="close"||n.setAttribute("stretchy","false");return n}});var dh={mi:"italic",mn:"normal",mtext:"normal"};Vr({type:"mathord",htmlBuilder:(r,e)=>H.makeOrd(r,e,"mathord"),mathmlBuilder(r,e){var n=new J.MathNode("mi",[Ne(r.text,r.mode,e)]),i=$a(r,e)||"italic";return i!==dh[n.type]&&n.setAttribute("mathvariant",i),n}}),Vr({type:"textord",htmlBuilder:(r,e)=>H.makeOrd(r,e,"textord"),mathmlBuilder(r,e){var n,i=Ne(r.text,r.mode,e),t=$a(r,e)||"normal";return n=r.mode==="text"?new J.MathNode("mtext",[i]):/[0-9]/.test(r.text)?new J.MathNode("mn",[i]):r.text==="\\prime"?new J.MathNode("mo",[i]):new J.MathNode("mi",[i]),t!==dh[n.type]&&n.setAttribute("mathvariant",t),n}});var _a={"\\nobreak":"nobreak","\\allowbreak":"allowbreak"},Sa={" ":{},"\\ ":{},"~":{className:"nobreak"},"\\space":{},"\\nobreakspace":{className:"nobreak"}};Vr({type:"spacing",htmlBuilder(r,e){if(Sa.hasOwnProperty(r.text)){var n=Sa[r.text].className||"";if(r.mode==="text"){var i=H.makeOrd(r,e,"textord");return i.classes.push(n),i}return H.makeSpan(["mspace",n],[H.mathsym(r.text,r.mode,e)],e)}if(_a.hasOwnProperty(r.text))return H.makeSpan(["mspace",_a[r.text]],[],e);throw new rt('Unknown type of space "'+r.text+'"')},mathmlBuilder(r,e){if(!Sa.hasOwnProperty(r.text)){if(_a.hasOwnProperty(r.text))return new J.MathNode("mspace");throw new rt('Unknown type of space "'+r.text+'"')}return new J.MathNode("mtext",[new J.TextNode(" ")])}});var mh=()=>{var r=new J.MathNode("mtd",[]);return r.setAttribute("width","50%"),r};Vr({type:"tag",mathmlBuilder(r,e){var n=new J.MathNode("mtable",[new J.MathNode("mtr",[mh(),new J.MathNode("mtd",[wr(r.body,e)]),mh(),new J.MathNode("mtd",[wr(r.tag,e)])])]);return n.setAttribute("width","100%"),n}});var fh={"\\text":void 0,"\\textrm":"textrm","\\textsf":"textsf","\\texttt":"texttt","\\textnormal":"textrm"},gh={"\\textbf":"textbf","\\textmd":"textmd"},Lg={"\\textit":"textit","\\textup":"textup"},bh=(r,e)=>{var n=r.font;return n?fh[n]?e.withTextFontFamily(fh[n]):gh[n]?e.withTextFontWeight(gh[n]):e.withTextFontShape(Lg[n]):e};st({type:"text",names:["\\text","\\textrm","\\textsf","\\texttt","\\textnormal","\\textbf","\\textmd","\\textit","\\textup"],props:{numArgs:1,argTypes:["text"],allowedInArgument:!0,allowedInText:!0},handler(r,e){var{parser:n,funcName:i}=r,t=e[0];return{type:"text",mode:n.mode,body:ie(t),font:i}},htmlBuilder(r,e){var n=bh(r,e),i=ae(r.body,n,!0);return H.makeSpan(["mord","text"],i,n)},mathmlBuilder(r,e){var n=bh(r,e);return wr(r.body,n)}}),st({type:"underline",names:["\\underline"],props:{numArgs:1,allowedInText:!0},handler(r,e){var{parser:n}=r;return{type:"underline",mode:n.mode,body:e[0]}},htmlBuilder(r,e){var n=Tt(r.body,e),i=H.makeLineSpan("underline-line",e),t=e.fontMetrics().defaultRuleThickness,l=H.makeVList({positionType:"top",positionData:n.height,children:[{type:"kern",size:t},{type:"elem",elem:i},{type:"kern",size:3*t},{type:"elem",elem:n}]},e);return H.makeSpan(["mord","underline"],[l],e)},mathmlBuilder(r,e){var n=new J.MathNode("mo",[new J.TextNode("‾")]);n.setAttribute("stretchy","true");var i=new J.MathNode("munder",[Vt(r.body,e),n]);return i.setAttribute("accentunder","true"),i}}),st({type:"vcenter",names:["\\vcenter"],props:{numArgs:1,argTypes:["original"],allowedInText:!1},handler(r,e){var{parser:n}=r;return{type:"vcenter",mode:n.mode,body:e[0]}},htmlBuilder(r,e){var n=Tt(r.body,e),i=e.fontMetrics().axisHeight,t=.5*(n.height-i-(n.depth+i));return H.makeVList({positionType:"shift",positionData:t,children:[{type:"elem",elem:n}]},e)},mathmlBuilder:(r,e)=>new J.MathNode("mpadded",[Vt(r.body,e)],["vcenter"])}),st({type:"verb",names:["\\verb"],props:{numArgs:0,allowedInText:!0},handler(r,e,n){throw new rt("\\verb ended by end of line instead of matching delimiter")},htmlBuilder(r,e){for(var n=yh(r),i=[],t=e.havingStyle(e.style.text()),l=0;l<n.length;l++){var h=n[l];h==="~"&&(h="\\textasciitilde"),i.push(H.makeSymbol(h,"Typewriter-Regular",r.mode,t,["mord","texttt"]))}return H.makeSpan(["mord","text"].concat(t.sizingClasses(e)),H.tryCombineChars(i),t)},mathmlBuilder(r,e){var n=new J.TextNode(yh(r)),i=new J.MathNode("mtext",[n]);return i.setAttribute("mathvariant","monospace"),i}});var yh=r=>r.body.replace(/ /g,r.star?"␣":" "),xr=zp,Jp=`[ \r
	]`,Bg="(\\\\[a-zA-Z@]+)"+Jp+"*",ts="[̀-ͯ]",Ng=new RegExp(ts+"+$"),Og="("+Jp+`+)|\\\\(
|[ \r	]+
?)[ \r	]*|([!-\\[\\]-‧‪-퟿豈-]`+ts+"*|[\uD800-\uDBFF][\uDC00-\uDFFF]"+ts+"*|\\\\verb\\*([^]).*?\\4|\\\\verb([^*a-zA-Z]).*?\\5|"+Bg+"|\\\\[^\uD800-\uDFFF])";class vh{constructor(e,n){this.input=void 0,this.settings=void 0,this.tokenRegex=void 0,this.catcodes=void 0,this.input=e,this.settings=n,this.tokenRegex=new RegExp(Og,"g"),this.catcodes={"%":14,"~":13}}setCatcode(e,n){this.catcodes[e]=n}lex(){var e=this.input,n=this.tokenRegex.lastIndex;if(n===e.length)return new ur("EOF",new Ae(this,n,n));var i=this.tokenRegex.exec(e);if(i===null||i.index!==n)throw new rt("Unexpected character: '"+e[n]+"'",new ur(e[n],new Ae(this,n,n+1)));var t=i[6]||i[3]||(i[2]?"\\ ":" ");if(this.catcodes[t]===14){var l=e.indexOf(`
`,this.tokenRegex.lastIndex);return l===-1?(this.tokenRegex.lastIndex=e.length,this.settings.reportNonstrict("commentAtEnd","% comment has no terminating newline; LaTeX would fail because of commenting the end of math mode (e.g. $)")):this.tokenRegex.lastIndex=l+1,this.lex()}return new ur(t,new Ae(this,n,this.tokenRegex.lastIndex))}}class Fg{constructor(e,n){e===void 0&&(e={}),n===void 0&&(n={}),this.current=void 0,this.builtins=void 0,this.undefStack=void 0,this.current=n,this.builtins=e,this.undefStack=[]}beginGroup(){this.undefStack.push({})}endGroup(){if(this.undefStack.length===0)throw new rt("Unbalanced namespace destruction: attempt to pop global namespace; please report this as a bug");var e=this.undefStack.pop();for(var n in e)e.hasOwnProperty(n)&&(e[n]===void 0?delete this.current[n]:this.current[n]=e[n])}has(e){return this.current.hasOwnProperty(e)||this.builtins.hasOwnProperty(e)}get(e){return this.current.hasOwnProperty(e)?this.current[e]:this.builtins[e]}set(e,n,i){if(i===void 0&&(i=!1),i){for(var t=0;t<this.undefStack.length;t++)delete this.undefStack[t][e];this.undefStack.length>0&&(this.undefStack[this.undefStack.length-1][e]=n)}else{var l=this.undefStack[this.undefStack.length-1];l&&!l.hasOwnProperty(e)&&(l[e]=this.current[e])}this.current[e]=n}}var Qp={"\\relax":!0,"^":!0,_:!0,"\\limits":!0,"\\nolimits":!0};class Rg{constructor(e,n,i){this.settings=void 0,this.expansionCount=void 0,this.lexer=void 0,this.macros=void 0,this.stack=void 0,this.mode=void 0,this.settings=n,this.expansionCount=0,this.feed(e),this.macros=new Fg(Wp,n.macros),this.mode=i,this.stack=[]}feed(e){this.lexer=new vh(e,this.settings)}switchMode(e){this.mode=e}beginGroup(){this.macros.beginGroup()}endGroup(){this.macros.endGroup()}future(){return this.stack.length===0&&this.pushToken(this.lexer.lex()),this.stack[this.stack.length-1]}popToken(){return this.future(),this.stack.pop()}pushToken(e){this.stack.push(e)}pushTokens(e){this.stack.push(...e)}scanArgument(e){var n,i,t;if(e){if(this.consumeSpaces(),this.future().text!=="[")return null;n=this.popToken(),{tokens:t,end:i}=this.consumeArg(["]"])}else({tokens:t,start:n,end:i}=this.consumeArg());return this.pushToken(new ur("EOF",i.loc)),this.pushTokens(t),n.range(i,"")}consumeSpaces(){for(;this.future().text===" ";)this.stack.pop()}consumeArg(e){var n=[],i=e&&e.length>0;i||this.consumeSpaces();var t,l=this.future(),h=0,p=0;do{if(t=this.popToken(),n.push(t),t.text==="{")++h;else if(t.text==="}"){if(--h===-1)throw new rt("Extra }",t)}else if(t.text==="EOF")throw new rt("Unexpected end of input in a macro argument, expected '"+(e&&i?e[p]:"}")+"'",t);if(e&&i)if((h===0||h===1&&e[p]==="{")&&t.text===e[p]){if(++p===e.length){n.splice(-p,p);break}}else p=0}while(h!==0||i);return l.text==="{"&&n[n.length-1].text==="}"&&(n.pop(),n.shift()),n.reverse(),{tokens:n,start:l,end:t}}consumeArgs(e,n){if(n){if(n.length!==e+1)throw new rt("The length of delimiters doesn't match the number of args!");for(var i=n[0],t=0;t<i.length;t++){var l=this.popToken();if(i[t]!==l.text)throw new rt("Use of the macro doesn't match its definition",l)}}for(var h=[],p=0;p<e;p++)h.push(this.consumeArg(n&&n[p+1]).tokens);return h}expandOnce(e){var n=this.popToken(),i=n.text,t=n.noexpand?null:this._getExpansion(i);if(t==null||e&&t.unexpandable){if(e&&t==null&&i[0]==="\\"&&!this.isDefined(i))throw new rt("Undefined control sequence: "+i);return this.pushToken(n),n}if(this.expansionCount++,this.expansionCount>this.settings.maxExpand)throw new rt("Too many expansions: infinite loop or need to increase maxExpand setting");var l=t.tokens,h=this.consumeArgs(t.numArgs,t.delimiters);if(t.numArgs)for(var p=(l=l.slice()).length-1;p>=0;--p){var m=l[p];if(m.text==="#"){if(p===0)throw new rt("Incomplete placeholder at end of macro body",m);if((m=l[--p]).text==="#")l.splice(p+1,1);else{if(!/^[1-9]$/.test(m.text))throw new rt("Not a valid argument number",m);l.splice(p,2,...h[+m.text-1])}}}return this.pushTokens(l),l}expandAfterFuture(){return this.expandOnce(),this.future()}expandNextToken(){for(;;){var e=this.expandOnce();if(e instanceof ur){if(e.text!=="\\relax"&&!e.treatAsRelax)return this.stack.pop();this.stack.pop()}}throw new Error}expandMacro(e){return this.macros.has(e)?this.expandTokens([new ur(e)]):void 0}expandTokens(e){var n=[],i=this.stack.length;for(this.pushTokens(e);this.stack.length>i;){var t=this.expandOnce(!0);t instanceof ur&&(t.treatAsRelax&&(t.noexpand=!1,t.treatAsRelax=!1),n.push(this.stack.pop()))}return n}expandMacroAsText(e){var n=this.expandMacro(e);return n&&n.map(i=>i.text).join("")}_getExpansion(e){var n=this.macros.get(e);if(n==null)return n;if(e.length===1){var i=this.lexer.catcodes[e];if(i!=null&&i!==13)return}var t=typeof n=="function"?n(this):n;if(typeof t=="string"){var l=0;if(t.indexOf("#")!==-1)for(var h=t.replace(/##/g,"");h.indexOf("#"+(l+1))!==-1;)++l;for(var p=new vh(t,this.settings),m=[],y=p.lex();y.text!=="EOF";)m.push(y),y=p.lex();return m.reverse(),{tokens:m,numArgs:l}}return t}isDefined(e){return this.macros.has(e)||xr.hasOwnProperty(e)||Pt.math.hasOwnProperty(e)||Pt.text.hasOwnProperty(e)||Qp.hasOwnProperty(e)}isExpandable(e){var n=this.macros.get(e);return n!=null?typeof n=="string"||typeof n=="function"||!n.unexpandable:xr.hasOwnProperty(e)&&!xr[e].primitive}}var xh={"́":{text:"\\'",math:"\\acute"},"̀":{text:"\\`",math:"\\grave"},"̈":{text:'\\"',math:"\\ddot"},"̃":{text:"\\~",math:"\\tilde"},"̄":{text:"\\=",math:"\\bar"},"̆":{text:"\\u",math:"\\breve"},"̌":{text:"\\v",math:"\\check"},"̂":{text:"\\^",math:"\\hat"},"̇":{text:"\\.",math:"\\dot"},"̊":{text:"\\r",math:"\\mathring"},"̋":{text:"\\H"}},wh={á:"á",à:"à",ä:"ä",ǟ:"ǟ",ã:"ã",ā:"ā",ă:"ă",ắ:"ắ",ằ:"ằ",ẵ:"ẵ",ǎ:"ǎ",â:"â",ấ:"ấ",ầ:"ầ",ẫ:"ẫ",ȧ:"ȧ",ǡ:"ǡ",å:"å",ǻ:"ǻ",ḃ:"ḃ",ć:"ć",č:"č",ĉ:"ĉ",ċ:"ċ",ď:"ď",ḋ:"ḋ",é:"é",è:"è",ë:"ë",ẽ:"ẽ",ē:"ē",ḗ:"ḗ",ḕ:"ḕ",ĕ:"ĕ",ě:"ě",ê:"ê",ế:"ế",ề:"ề",ễ:"ễ",ė:"ė",ḟ:"ḟ",ǵ:"ǵ",ḡ:"ḡ",ğ:"ğ",ǧ:"ǧ",ĝ:"ĝ",ġ:"ġ",ḧ:"ḧ",ȟ:"ȟ",ĥ:"ĥ",ḣ:"ḣ",í:"í",ì:"ì",ï:"ï",ḯ:"ḯ",ĩ:"ĩ",ī:"ī",ĭ:"ĭ",ǐ:"ǐ",î:"î",ǰ:"ǰ",ĵ:"ĵ",ḱ:"ḱ",ǩ:"ǩ",ĺ:"ĺ",ľ:"ľ",ḿ:"ḿ",ṁ:"ṁ",ń:"ń",ǹ:"ǹ",ñ:"ñ",ň:"ň",ṅ:"ṅ",ó:"ó",ò:"ò",ö:"ö",ȫ:"ȫ",õ:"õ",ṍ:"ṍ",ṏ:"ṏ",ȭ:"ȭ",ō:"ō",ṓ:"ṓ",ṑ:"ṑ",ŏ:"ŏ",ǒ:"ǒ",ô:"ô",ố:"ố",ồ:"ồ",ỗ:"ỗ",ȯ:"ȯ",ȱ:"ȱ",ő:"ő",ṕ:"ṕ",ṗ:"ṗ",ŕ:"ŕ",ř:"ř",ṙ:"ṙ",ś:"ś",ṥ:"ṥ",š:"š",ṧ:"ṧ",ŝ:"ŝ",ṡ:"ṡ",ẗ:"ẗ",ť:"ť",ṫ:"ṫ",ú:"ú",ù:"ù",ü:"ü",ǘ:"ǘ",ǜ:"ǜ",ǖ:"ǖ",ǚ:"ǚ",ũ:"ũ",ṹ:"ṹ",ū:"ū",ṻ:"ṻ",ŭ:"ŭ",ǔ:"ǔ",û:"û",ů:"ů",ű:"ű",ṽ:"ṽ",ẃ:"ẃ",ẁ:"ẁ",ẅ:"ẅ",ŵ:"ŵ",ẇ:"ẇ",ẘ:"ẘ",ẍ:"ẍ",ẋ:"ẋ",ý:"ý",ỳ:"ỳ",ÿ:"ÿ",ỹ:"ỹ",ȳ:"ȳ",ŷ:"ŷ",ẏ:"ẏ",ẙ:"ẙ",ź:"ź",ž:"ž",ẑ:"ẑ",ż:"ż",Á:"Á",À:"À",Ä:"Ä",Ǟ:"Ǟ",Ã:"Ã",Ā:"Ā",Ă:"Ă",Ắ:"Ắ",Ằ:"Ằ",Ẵ:"Ẵ",Ǎ:"Ǎ",Â:"Â",Ấ:"Ấ",Ầ:"Ầ",Ẫ:"Ẫ",Ȧ:"Ȧ",Ǡ:"Ǡ",Å:"Å",Ǻ:"Ǻ",Ḃ:"Ḃ",Ć:"Ć",Č:"Č",Ĉ:"Ĉ",Ċ:"Ċ",Ď:"Ď",Ḋ:"Ḋ",É:"É",È:"È",Ë:"Ë",Ẽ:"Ẽ",Ē:"Ē",Ḗ:"Ḗ",Ḕ:"Ḕ",Ĕ:"Ĕ",Ě:"Ě",Ê:"Ê",Ế:"Ế",Ề:"Ề",Ễ:"Ễ",Ė:"Ė",Ḟ:"Ḟ",Ǵ:"Ǵ",Ḡ:"Ḡ",Ğ:"Ğ",Ǧ:"Ǧ",Ĝ:"Ĝ",Ġ:"Ġ",Ḧ:"Ḧ",Ȟ:"Ȟ",Ĥ:"Ĥ",Ḣ:"Ḣ",Í:"Í",Ì:"Ì",Ï:"Ï",Ḯ:"Ḯ",Ĩ:"Ĩ",Ī:"Ī",Ĭ:"Ĭ",Ǐ:"Ǐ",Î:"Î",İ:"İ",Ĵ:"Ĵ",Ḱ:"Ḱ",Ǩ:"Ǩ",Ĺ:"Ĺ",Ľ:"Ľ",Ḿ:"Ḿ",Ṁ:"Ṁ",Ń:"Ń",Ǹ:"Ǹ",Ñ:"Ñ",Ň:"Ň",Ṅ:"Ṅ",Ó:"Ó",Ò:"Ò",Ö:"Ö",Ȫ:"Ȫ",Õ:"Õ",Ṍ:"Ṍ",Ṏ:"Ṏ",Ȭ:"Ȭ",Ō:"Ō",Ṓ:"Ṓ",Ṑ:"Ṑ",Ŏ:"Ŏ",Ǒ:"Ǒ",Ô:"Ô",Ố:"Ố",Ồ:"Ồ",Ỗ:"Ỗ",Ȯ:"Ȯ",Ȱ:"Ȱ",Ő:"Ő",Ṕ:"Ṕ",Ṗ:"Ṗ",Ŕ:"Ŕ",Ř:"Ř",Ṙ:"Ṙ",Ś:"Ś",Ṥ:"Ṥ",Š:"Š",Ṧ:"Ṧ",Ŝ:"Ŝ",Ṡ:"Ṡ",Ť:"Ť",Ṫ:"Ṫ",Ú:"Ú",Ù:"Ù",Ü:"Ü",Ǘ:"Ǘ",Ǜ:"Ǜ",Ǖ:"Ǖ",Ǚ:"Ǚ",Ũ:"Ũ",Ṹ:"Ṹ",Ū:"Ū",Ṻ:"Ṻ",Ŭ:"Ŭ",Ǔ:"Ǔ",Û:"Û",Ů:"Ů",Ű:"Ű",Ṽ:"Ṽ",Ẃ:"Ẃ",Ẁ:"Ẁ",Ẅ:"Ẅ",Ŵ:"Ŵ",Ẇ:"Ẇ",Ẍ:"Ẍ",Ẋ:"Ẋ",Ý:"Ý",Ỳ:"Ỳ",Ÿ:"Ÿ",Ỹ:"Ỹ",Ȳ:"Ȳ",Ŷ:"Ŷ",Ẏ:"Ẏ",Ź:"Ź",Ž:"Ž",Ẑ:"Ẑ",Ż:"Ż",ά:"ά",ὰ:"ὰ",ᾱ:"ᾱ",ᾰ:"ᾰ",έ:"έ",ὲ:"ὲ",ή:"ή",ὴ:"ὴ",ί:"ί",ὶ:"ὶ",ϊ:"ϊ",ΐ:"ΐ",ῒ:"ῒ",ῑ:"ῑ",ῐ:"ῐ",ό:"ό",ὸ:"ὸ",ύ:"ύ",ὺ:"ὺ",ϋ:"ϋ",ΰ:"ΰ",ῢ:"ῢ",ῡ:"ῡ",ῠ:"ῠ",ώ:"ώ",ὼ:"ὼ",Ύ:"Ύ",Ὺ:"Ὺ",Ϋ:"Ϋ",Ῡ:"Ῡ",Ῠ:"Ῠ",Ώ:"Ώ",Ὼ:"Ὼ"};class lo{constructor(e,n){this.mode=void 0,this.gullet=void 0,this.settings=void 0,this.leftrightDepth=void 0,this.nextToken=void 0,this.mode="math",this.gullet=new Rg(e,n,this.mode),this.settings=n,this.leftrightDepth=0}expect(e,n){if(n===void 0&&(n=!0),this.fetch().text!==e)throw new rt("Expected '"+e+"', got '"+this.fetch().text+"'",this.fetch());n&&this.consume()}consume(){this.nextToken=null}fetch(){return this.nextToken==null&&(this.nextToken=this.gullet.expandNextToken()),this.nextToken}switchMode(e){this.mode=e,this.gullet.switchMode(e)}parse(){this.settings.globalGroup||this.gullet.beginGroup(),this.settings.colorIsTextColor&&this.gullet.macros.set("\\color","\\textcolor");var e=this.parseExpression(!1);return this.expect("EOF"),this.settings.globalGroup||this.gullet.endGroup(),e}parseExpression(e,n){for(var i=[];;){this.mode==="math"&&this.consumeSpaces();var t=this.fetch();if(lo.endOfExpression.indexOf(t.text)!==-1||n&&t.text===n||e&&xr[t.text]&&xr[t.text].infix)break;var l=this.parseAtom(n);if(!l)break;l.type!=="internal"&&i.push(l)}return this.mode==="text"&&this.formLigatures(i),this.handleInfixNodes(i)}handleInfixNodes(e){for(var n,i=-1,t=0;t<e.length;t++)if(e[t].type==="infix"){if(i!==-1)throw new rt("only one infix operator per group",e[t].token);i=t,n=e[t].replaceWith}if(i!==-1&&n){var l,h,p=e.slice(0,i),m=e.slice(i+1);return l=p.length===1&&p[0].type==="ordgroup"?p[0]:{type:"ordgroup",mode:this.mode,body:p},h=m.length===1&&m[0].type==="ordgroup"?m[0]:{type:"ordgroup",mode:this.mode,body:m},[n==="\\\\abovefrac"?this.callFunction(n,[l,e[i],h],[]):this.callFunction(n,[l,h],[])]}return e}handleSupSubscript(e){var n=this.fetch(),i=n.text;this.consume(),this.consumeSpaces();var t=this.parseGroup(e);if(!t)throw new rt("Expected group after '"+i+"'",n);return t}formatUnsupportedCmd(e){for(var n=[],i=0;i<e.length;i++)n.push({type:"textord",mode:"text",text:e[i]});var t={type:"text",mode:this.mode,body:n};return{type:"color",mode:this.mode,color:this.settings.errorColor,body:[t]}}parseAtom(e){var n,i,t=this.parseGroup("atom",e);if(this.mode==="text")return t;for(;;){this.consumeSpaces();var l=this.fetch();if(l.text==="\\limits"||l.text==="\\nolimits"){if(t&&t.type==="op"){var h=l.text==="\\limits";t.limits=h,t.alwaysHandleSupSub=!0}else{if(!t||t.type!=="operatorname")throw new rt("Limit controls must follow a math operator",l);t.alwaysHandleSupSub&&(t.limits=l.text==="\\limits")}this.consume()}else if(l.text==="^"){if(n)throw new rt("Double superscript",l);n=this.handleSupSubscript("superscript")}else if(l.text==="_"){if(i)throw new rt("Double subscript",l);i=this.handleSupSubscript("subscript")}else{if(l.text!=="'")break;if(n)throw new rt("Double superscript",l);var p={type:"textord",mode:this.mode,text:"\\prime"},m=[p];for(this.consume();this.fetch().text==="'";)m.push(p),this.consume();this.fetch().text==="^"&&m.push(this.handleSupSubscript("superscript")),n={type:"ordgroup",mode:this.mode,body:m}}}return n||i?{type:"supsub",mode:this.mode,base:t,sup:n,sub:i}:t}parseFunction(e,n){var i=this.fetch(),t=i.text,l=xr[t];if(!l)return null;if(this.consume(),n&&n!=="atom"&&!l.allowedInArgument)throw new rt("Got function '"+t+"' with no arguments"+(n?" as "+n:""),i);if(this.mode==="text"&&!l.allowedInText)throw new rt("Can't use function '"+t+"' in text mode",i);if(this.mode==="math"&&l.allowedInMath===!1)throw new rt("Can't use function '"+t+"' in math mode",i);var{args:h,optArgs:p}=this.parseArguments(t,l);return this.callFunction(t,h,p,i,e)}callFunction(e,n,i,t,l){var h={funcName:e,parser:this,token:t,breakOnTokenText:l},p=xr[e];if(p&&p.handler)return p.handler(h,n,i);throw new rt("No function handler for "+e)}parseArguments(e,n){var i=n.numArgs+n.numOptionalArgs;if(i===0)return{args:[],optArgs:[]};for(var t=[],l=[],h=0;h<i;h++){var p=n.argTypes&&n.argTypes[h],m=h<n.numOptionalArgs;(n.primitive&&p==null||n.type==="sqrt"&&h===1&&l[0]==null)&&(p="primitive");var y=this.parseGroupOfType("argument to '"+e+"'",p,m);if(m)l.push(y);else{if(y==null)throw new rt("Null argument, please report this as a bug");t.push(y)}}return{args:t,optArgs:l}}parseGroupOfType(e,n,i){switch(n){case"color":return this.parseColorGroup(i);case"size":return this.parseSizeGroup(i);case"url":return this.parseUrlGroup(i);case"math":case"text":return this.parseArgumentGroup(i,n);case"hbox":var t=this.parseArgumentGroup(i,"text");return t!=null?{type:"styling",mode:t.mode,body:[t],style:"text"}:null;case"raw":var l=this.parseStringGroup("raw",i);return l!=null?{type:"raw",mode:"text",string:l.text}:null;case"primitive":if(i)throw new rt("A primitive argument cannot be optional");var h=this.parseGroup(e);if(h==null)throw new rt("Expected group as "+e,this.fetch());return h;case"original":case null:case void 0:return this.parseArgumentGroup(i);default:throw new rt("Unknown group type as "+e,this.fetch())}}consumeSpaces(){for(;this.fetch().text===" ";)this.consume()}parseStringGroup(e,n){var i=this.gullet.scanArgument(n);if(i==null)return null;for(var t,l="";(t=this.fetch()).text!=="EOF";)l+=t.text,this.consume();return this.consume(),i.text=l,i}parseRegexGroup(e,n){for(var i,t=this.fetch(),l=t,h="";(i=this.fetch()).text!=="EOF"&&e.test(h+i.text);)h+=(l=i).text,this.consume();if(h==="")throw new rt("Invalid "+n+": '"+t.text+"'",t);return t.range(l,h)}parseColorGroup(e){var n=this.parseStringGroup("color",e);if(n==null)return null;var i=/^(#[a-f0-9]{3}|#?[a-f0-9]{6}|[a-z]+)$/i.exec(n.text);if(!i)throw new rt("Invalid color: '"+n.text+"'",n);var t=i[0];return/^[0-9a-f]{6}$/i.test(t)&&(t="#"+t),{type:"color-token",mode:this.mode,color:t}}parseSizeGroup(e){var n,i=!1;if(this.gullet.consumeSpaces(),!(n=e||this.gullet.future().text==="{"?this.parseStringGroup("size",e):this.parseRegexGroup(/^[-+]? *(?:$|\d+|\d+\.\d*|\.\d*) *[a-z]{0,2} *$/,"size")))return null;e||n.text.length!==0||(n.text="0pt",i=!0);var t=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(n.text);if(!t)throw new rt("Invalid size: '"+n.text+"'",n);var l={number:+(t[1]+t[2]),unit:t[3]};if(!Cp(l))throw new rt("Invalid unit: '"+l.unit+"'",n);return{type:"size",mode:this.mode,value:l,isBlank:i}}parseUrlGroup(e){this.gullet.lexer.setCatcode("%",13),this.gullet.lexer.setCatcode("~",12);var n=this.parseStringGroup("url",e);if(this.gullet.lexer.setCatcode("%",14),this.gullet.lexer.setCatcode("~",13),n==null)return null;var i=n.text.replace(/\\([#$%&~_^{}])/g,"$1");return{type:"url",mode:this.mode,url:i}}parseArgumentGroup(e,n){var i=this.gullet.scanArgument(e);if(i==null)return null;var t=this.mode;n&&this.switchMode(n),this.gullet.beginGroup();var l=this.parseExpression(!1,"EOF");this.expect("EOF"),this.gullet.endGroup();var h={type:"ordgroup",mode:this.mode,loc:i.loc,body:l};return n&&this.switchMode(t),h}parseGroup(e,n){var i,t=this.fetch(),l=t.text;if(l==="{"||l==="\\begingroup"){this.consume();var h=l==="{"?"}":"\\endgroup";this.gullet.beginGroup();var p=this.parseExpression(!1,h),m=this.fetch();this.expect(h),this.gullet.endGroup(),i={type:"ordgroup",mode:this.mode,loc:Ae.range(t,m),body:p,semisimple:l==="\\begingroup"||void 0}}else if((i=this.parseFunction(n,e)||this.parseSymbol())==null&&l[0]==="\\"&&!Qp.hasOwnProperty(l)){if(this.settings.throwOnError)throw new rt("Undefined control sequence: "+l,t);i=this.formatUnsupportedCmd(l),this.consume()}return i}formLigatures(e){for(var n=e.length-1,i=0;i<n;++i){var t=e[i],l=t.text;l==="-"&&e[i+1].text==="-"&&(i+1<n&&e[i+2].text==="-"?(e.splice(i,3,{type:"textord",mode:"text",loc:Ae.range(t,e[i+2]),text:"---"}),n-=2):(e.splice(i,2,{type:"textord",mode:"text",loc:Ae.range(t,e[i+1]),text:"--"}),n-=1)),l!=="'"&&l!=="`"||e[i+1].text!==l||(e.splice(i,2,{type:"textord",mode:"text",loc:Ae.range(t,e[i+1]),text:l+l}),n-=1)}}parseSymbol(){var e=this.fetch(),n=e.text;if(/^\\verb[^a-zA-Z]/.test(n)){this.consume();var i=n.slice(5),t=i.charAt(0)==="*";if(t&&(i=i.slice(1)),i.length<2||i.charAt(0)!==i.slice(-1))throw new rt(`\\verb assertion failed --
                    please report what input caused this bug`);return{type:"verb",mode:"text",body:i=i.slice(1,-1),star:t}}wh.hasOwnProperty(n[0])&&!Pt[this.mode][n[0]]&&(this.settings.strict&&this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Accented Unicode text character "'+n[0]+'" used in math mode',e),n=wh[n[0]]+n.substr(1));var l,h=Ng.exec(n);if(h&&((n=n.substring(0,h.index))==="i"?n="ı":n==="j"&&(n="ȷ")),Pt[this.mode][n]){this.settings.strict&&this.mode==="math"&&qp.indexOf(n)>=0&&this.settings.reportNonstrict("unicodeTextInMathMode",'Latin-1/Unicode text character "'+n[0]+'" used in math mode',e);var p,m=Pt[this.mode][n].group,y=Ae.range(e);if(eg.hasOwnProperty(m)){var _=m;p={type:"atom",mode:this.mode,family:_,loc:y,text:n}}else p={type:m,mode:this.mode,loc:y,text:n};l=p}else{if(!(n.charCodeAt(0)>=128))return null;this.settings.strict&&(xp(n.charCodeAt(0))?this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Unicode text character "'+n[0]+'" used in math mode',e):this.settings.reportNonstrict("unknownSymbol",'Unrecognized Unicode character "'+n[0]+'" ('+n.charCodeAt(0)+")",e)),l={type:"textord",mode:"text",loc:Ae.range(e),text:n}}if(this.consume(),h)for(var S=0;S<h[0].length;S++){var E=h[0][S];if(!xh[E])throw new rt("Unknown accent ' "+E+"'",e);var R=xh[E][this.mode];if(!R)throw new rt("Accent "+E+" unsupported in "+this.mode+" mode",e);l={type:"accent",mode:this.mode,loc:Ae.range(e),label:R,isStretchy:!1,isShifty:!0,base:l}}return l}}lo.endOfExpression=["}","\\endgroup","\\end","\\right","&"];var es=function(r,e){if(!(typeof r=="string"||r instanceof String))throw new TypeError("KaTeX can only parse string typed expression");var n=new lo(r,e);delete n.gullet.macros.current["\\df@tag"];var i=n.parse();if(delete n.gullet.macros.current["\\current@color"],delete n.gullet.macros.current["\\color"],n.gullet.macros.get("\\df@tag")){if(!e.displayMode)throw new rt("\\tag works only in display equations");n.gullet.feed("\\df@tag"),i=[{type:"tag",mode:"text",body:i,tag:n.parse()}]}return i},Kp=function(r,e,n){e.textContent="";var i=rs(r,n).toNode();e.appendChild(i)};typeof document<"u"&&document.compatMode!=="CSS1Compat"&&(typeof console<"u"&&console.warn("Warning: KaTeX doesn't work in quirks mode. Make sure your website has a suitable doctype."),Kp=function(){throw new rt("KaTeX doesn't work in quirks mode.")});var t1=function(r,e,n){if(n.throwOnError||!(r instanceof rt))throw r;var i=H.makeSpan(["katex-error"],[new Oe(e)]);return i.setAttribute("title",r.toString()),i.setAttribute("style","color:"+n.errorColor),i},rs=function(r,e){var n=new ja(e);try{return function(i,t,l){var h,p=Ep(l);if(l.output==="mathml")return Ic(i,t,p,l.displayMode,!0);if(l.output==="html"){var m=Wa(i,p);h=H.makeSpan(["katex"],[m])}else{var y=Ic(i,t,p,l.displayMode,!1),_=Wa(i,p);h=H.makeSpan(["katex"],[y,_])}return Dp(h,l)}(es(r,n),r,n)}catch(i){return t1(i,r,n)}},kh={version:"0.13.13",render:Kp,renderToString:function(r,e){return rs(r,e).toMarkup()},ParseError:rt,__parse:function(r,e){var n=new ja(e);return es(r,n)},__renderToDomTree:rs,__renderToHTMLTree:function(r,e){var n=new ja(e);try{return function(i,t,l){var h=Wa(i,Ep(l)),p=H.makeSpan(["katex"],[h]);return Dp(p,l)}(es(r,n),0,n)}catch(i){return t1(i,r,n)}},__setFontMetrics:function(r,e){Ke[r]=e},__defineSymbol:d,__defineMacro:A,__domTree:{Span:Yn,Anchor:xs,SymbolNode:Oe,SvgNode:Sr,PathNode:Hr,LineNode:Ua}};function Dn(r){var e=[],n=0;if(this.trie=this.createTrie(r.patterns),this.leftMin=r.leftmin,this.rightMin=r.rightmin,this.exceptions={},r.exceptions)for(e=r.exceptions.split(/,\s?/g);n<e.length;n+=1)this.exceptions[e[n].replace(/\u2027/g,"").toLowerCase()]=new RegExp("("+e[n].split("‧").join(")(")+")","i")}Dn.TrieNode,Dn.prototype.createTrie=function(r){var e,n=0,i=0,t=0,l=0,h=null,p=null,m=null,y=null,_={_points:[]};for(n in r)if(r.hasOwnProperty(n))for(e=r[n].match(new RegExp(".{1,"+ +n+"}","g")),i=0;i<e.length;i+=1){for(h=e[i].replace(/[0-9]/g,"").split(""),p=e[i].split(/\D/),y=_,t=0;t<h.length;t+=1)y[m=h[t].charCodeAt(0)]||(y[m]={}),y=y[m];for(y._points=[],l=0;l<p.length;l+=1)y._points[l]=p[l]||0}return _},Dn.prototype.hyphenateText=function(r,e){e=e||4;for(var n=r.split(/([a-zA-Z0-9_\u0027\u00AD\u00DF-\u00EA\u00EB\u00EC-\u00EF\u00F1-\u00F6\u00F8-\u00FD\u0101\u0103\u0105\u0107\u0109\u010D\u010F\u0111\u0113\u0117\u0119\u011B\u011D\u011F\u0123\u0125\u012B\u012F\u0131\u0135\u0137\u013C\u013E\u0142\u0144\u0146\u0148\u0151\u0153\u0155\u0159\u015B\u015D\u015F\u0161\u0165\u016B\u016D\u016F\u0171\u0173\u017A\u017C\u017E\u017F\u0219\u021B\u02BC\u0390\u03AC-\u03CE\u03F2\u0401\u0410-\u044F\u0451\u0454\u0456\u0457\u045E\u0491\u0531-\u0556\u0561-\u0587\u0902\u0903\u0905-\u090B\u090E-\u0910\u0912\u0914-\u0928\u092A-\u0939\u093E-\u0943\u0946-\u0948\u094A-\u094D\u0982\u0983\u0985-\u098B\u098F\u0990\u0994-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BE-\u09C3\u09C7\u09C8\u09CB-\u09CD\u09D7\u0A02\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A14-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A82\u0A83\u0A85-\u0A8B\u0A8F\u0A90\u0A94-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABE-\u0AC3\u0AC7\u0AC8\u0ACB-\u0ACD\u0B02\u0B03\u0B05-\u0B0B\u0B0F\u0B10\u0B14-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3E-\u0B43\u0B47\u0B48\u0B4B-\u0B4D\u0B57\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB5\u0BB7-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0C02\u0C03\u0C05-\u0C0B\u0C0E-\u0C10\u0C12\u0C14-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3E-\u0C43\u0C46-\u0C48\u0C4A-\u0C4D\u0C82\u0C83\u0C85-\u0C8B\u0C8E-\u0C90\u0C92\u0C94-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBE-\u0CC3\u0CC6-\u0CC8\u0CCA-\u0CCD\u0D02\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D28\u0D2A-\u0D39\u0D3E-\u0D43\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D60\u0D61\u0D7A-\u0D7F\u1F00-\u1F07\u1F10-\u1F15\u1F20-\u1F27\u1F30-\u1F37\u1F40-\u1F45\u1F50-\u1F57\u1F60-\u1F67\u1F70-\u1F7D\u1F80-\u1F87\u1F90-\u1F97\u1FA0-\u1FA7\u1FB2-\u1FB4\u1FB6\u1FB7\u1FBD\u1FBF\u1FC2-\u1FC4\u1FC6\u1FC7\u1FD2\u1FD3\u1FD6\u1FD7\u1FE2-\u1FE7\u1FF2-\u1FF4\u1FF6\u1FF7\u200D\u2019]+)/gi),i=0;i<n.length;i+=1)n[i].indexOf("/")!==-1?i===0||i===n.length-1||/\s+\/|\/\s+/.test(n[i])||(n[i]+="​"):n[i].length>e&&(n[i]=this.hyphenate(n[i]).join("­"));return n.join("")},Dn.prototype.hyphenate=function(r){var e,n,i,t,l,h,p,m,y,_=[],S=[],E=r.toLowerCase(),R=Math.max,I=this.trie,U=[""];if(this.exceptions.hasOwnProperty(E))return r.match(this.exceptions[E]).slice(1);if(r.indexOf("­")!==-1)return[r];for(e=(r="_"+r+"_").toLowerCase().split(""),n=r.split(""),p=e.length,i=0;i<p;i+=1)S[i]=0,_[i]=e[i].charCodeAt(0);for(i=0;i<p;i+=1)for(h=I,t=i;t<p&&(h=h[_[t]]);t+=1)if(m=h._points)for(l=0,y=m.length;l<y;l+=1)S[i+l]=R(S[i+l],m[l]);for(i=1;i<p-1;i+=1)i>this.leftMin&&i<p-this.rightMin&&S[i]%2?U.push(n[i]):U[U.length-1]+=n[i];return U};var Hg=Ir(Dn),Vg=Ir({id:["en-us","en"],leftmin:2,rightmin:3,patterns:{3:"x1qei2e1je1f1to2tlou2w3c1tue1q4tvtw41tyo1q4tz4tcd2yd1wd1v1du1ta4eu1pas4y1droo2d1psw24sv1dod1m1fad1j1su4fdo2n4fh1fi4fm4fn1fopd42ft3fu1fy1ga2sss1ru5jd5cd1bg3bgd44uk2ok1cyo5jgl2g1m4pf4pg1gog3p1gr1soc1qgs2oi2g3w1gysk21coc5nh1bck1h1fh1h4hk1zo1ci4zms2hh1w2ch5zl2idc3c2us2igi3hi3j4ik1cab1vsa22btr1w4bp2io2ipu3u4irbk4b1j1va2ze2bf4oar1p4nz4zbi1u2iv4iy5ja1jeza1y1wk1bk3fkh4k1ikk4k1lk1mk5tk1w2ldr1mn1t2lfr1lr3j4ljl1l2lm2lp4ltn1rrh4v4yn1q1ly1maw1brg2r1fwi24ao2mhw4kr1cw5p4mkm1m1mo4wtwy4x1ar1ba2nn5mx1ex1h4mtx3i1muqu2p3wx3o4mwa1jx3p1naai2x1ua2fxx4y1ba2dn1jy1cn3fpr2y1dy1i",4:"4dryn2itni4on1inn1im_up3nik4ni4dy5giye4tyes4_ye44ab_nhe4nha4abe2n2gyn1guy1ery5eep2pe4abry3lay3lone4wne4v1nesy3chn1erne2q3neo1nenp2seps4hy2cey5lu2nedne2cyme44nk2y5at2adine2b2ne_y5ac2p1tp2ten1den1cun1cryn5dp2th4adup4twpub3ae4rxu3ayn5gaff4pue4n2au4p1ppuf4n2atag1ipu4mag1na2gon4asx3tix1t2pu2na4gya3haa3heah4la3ho_ti2a5ian2an5puspu2tnak4_th2n1kl_te4_ta4mu4u4mupmun23mum2alex4ob_sy25ynxal1i_st4y1o4xi5cxi5a4alm_si2_sh2m5sixhu4m4sh4m3r4amam2py2rabm2pixhi2yo5dr2ai4m1pmo2vmos2x2edmo2r4n1la2mor2asx3c2xas5yom4x4apxam3nme44mokrbi2nne44andy4osp4ot3noemn4omn4a4m1n4nog4m1l2angws4l1posw3shwri4wra4yp3iwom11wo2m2izrb4ow4nopo4pr2cem2isrd2iano4mig4y3pomi3awiz55mi_no4n4m1fme4v2re_wir42mes1menme2mme2gre1o2med4me_4nop4m5c4m1bwil21noureu2whi4w3ev4maprev2w1era2plpo4crfu4r4fyy5pu2maha3pu2mab2a2rn1p4npi44lyb4lya2p3nwam42l1w1lut4luplu3or1glluf4lu5a2wacltu2y3rol1tr4vv4r3guyr4rl1te4rh_nru4ar1il2sel4sc4l1rl5prl4plys4c4lovri3ar4ib4lof3lo_ar2par3q_os3ll4oll2i4as_ri1o3vokl2levoi44p1mlka35vo_ns4cas4ll1izr4iqr2is3vivl1it3lika2tan2sen2slrle42l3hlgo3l5gal5frns3mvi4p3ley_od2r2meles24athr4myle2al3drv1inldi4l2de2vilnt2il3civik4lce42l1b4lavv3ifrno4r3nua1trr2ocnt4sy4sok4syks4la2tuk4sck3ouko5ryss4a2tyau4b4klyys1tnu1akis4au3rki4pro4ek4ima2va5ki_nu4dn4umn3uokes4k1erav1irok2ke4g1keek2ed_me2aw3ikal4aws4k5agk3ab3ka_aye4ays4veg3jo4p5ba_4vedjew3n1v24ve_ja4pzar23vatizi4n1w41batba4z2b1bb2beix4o4i5w4b1d4be_rox5nym4nyp4n3za4ittr3por1r4i1ti1bel2ith2itei2su4rs2r1sars4cr2seis1p3betvag4i2sor1shbe3wr1sioad34b3hbi2bbi4d3bie3isf4ise2is_1bilr1sp5va_r5sw_le2uz4eir1ibi2tuxu3r1tiu1v2i1raze4nze4pb2l2uu4mo1biip3iz1eripe4b4louts44b1m4b3no3br3bodi4osbo4eru3aio4mi1ol4io_3booo1ce4inyin1u2insru2n2inn4inl4inkrv4e2inioch42iner3vo4indpi2np4idbt4lb4tob3trry4cry3t2in_o4elbu4ni2muim1i5saiil3v4ilnil1iil5fs1apo3er4b5w5by_bys4_in1sau4i1lazet4u2suo3ev2z1ii2go4igius1p5saw4s5bo2fi4ifti3fl4if_i3etsch2usc22ie4i2dui4dri2diid5dpi3au3ruz4ils1cuz4is4s5d4se_se4a2ce_2ici4ich3ceii1bri5bo1ceni1blse2g5seiibe43cepi2aniam4ur2li2al2i1acet4hy2scew41phy4ch_5phuhu4thu4gche2h4tyh4shur1durc44hr44h5p5sev5sexu1ra4s3fup3p2s3gph3t2sh_ho4g2h1n_he23ciau3pl4h1mci5ch2lozo4m4ciihi2vhi4p2cim2cin4phsu1peu1ouo1geu5osheu4sho4he4th1es4shwun5zun5ysi1bunu45cizo4glck3ihep5he2nh4ed1sioph2l5hazsi2rcly4zte4_ge21siscoe22cog5siu1siv5siz_ga24skes1l2s2leha4m2s1ms3ma1ogyo1h2u1ni3gus3gun2guegu4acov1gth3_eu3g4ros1n4_es3u2nez4zyum2pu1mi3som_ev2oig4cri2gov15goos4opgon2ul5v5goeu3lugob53go_2c1t4ph_g1nog1nic2te4sov4ulsgn4ag4myc4twcud5c4ufc4uipe2t3glo1gleul2igla4_eg23giz3cun5givgi4u3gir5gio1cusul4e2spagil4g1ic5gi__eb4cze41d2a5da_u1laggo44daf2dagg2gege4v1geo1gen2ged3dato1la2ge_ol2dol2i5daypek4p4eed1d42de_4gazol2tuiv3ol2vo2lys1sa2gamgaf4o2meui4n2ui2pe2cd4em4fugi4jku3fl3ufaf2tyf4to1denu4du4pe_2f3sfri2de1ps1si4f5pfos5d3eqs4sls4snfo2rss2tdes25fon4p1b_ci23payss5w2st_de1tf4l2de1v2fin4dey4d1fd4gast2idg1id2gyd1h25di_ud5dfi3au4cy_ch4pav43didu3cud1iff2fyu3crd1inst4r4f1ffev4fer11dio2fedfe4bdir2s2ty4fe_dis1on1au3ca4f5bon1c2ondd5k25far4fagpa1peys45eyc1exps4ul2dlyp4ale3whon3s3do_e1wa5doee5vud4oge1visu2msu2nub4euav4su2rp4ai6rk_d4or3dosu1atdo4v3doxp4adoo4k4swoo2padre4eus4e3upe5un2ophet5z4syc3syl4y3hoy1ads4pd4swd4syd2tho4wo3ta_du2c4etn2tabta2luac4es4wdu4g2ess4uabdu4n4duptav4st5bow1io1pr5dyn2tawe1sp2t1bop1uead1tz4et4chopy5ea4l4t1d4te_2tyle1si4esh1tee4tyat1cr4twoteg4es2c4eru1teoer1s2eroea2tte4po1rat1wh3tusea2v3teu3texer1i2e1ber1h4tey2t1f4t1ge3br2th_th2e4thle1ce3tumec2i2ths2erb1tia4tueer1aou5vtud2tif22tige1potu1aou4lttu41timt5toos4le1cre2pat4swe5owe1cue4ottsh4eos4e1ort4sce3ol4edieo2ge5of1tio4eno4enn5tiq4edoti4u1tive3my1tiz4othee2ct5laee2ft5lo4t1mee2mtme4e1meem5bcoi4to3be5exo1ry2tof1effel2iel2ftos24t1pe1la1traos2ceig2ei5de5ico2soe1h45egyeg5n",5:" ",6:" ",7:"_dri5v4ban5dagvar5iedbina5r43bi3tio3bit5ua_ad4derution5auti5lizver5encbuf4ferus5terevermi4ncall5incast5ercas5tigccompa5z3o1phros5itiv5chanicuri4fico5stati5chine_y5che3dupport54v3iden5cific_un4ter_at5omiz4oscopiotele4g5craticu4m3ingv3i3liz4c3retaul4li4bcul4tiscur5a4b4c5utiva5ternauiv4er_del5i5qdem5ic_de4monsdenti5fdern5izdi4latou4b5ingdrag5on5drupliuar5ant5a5si4tec5essawo4k1enec5ifiee4compear5inate4f3eretro5phewide5sp5triciatri5cesefor5ese4fuse_oth5esiar5dinear4chantra5ventrac4tetrac4itar5ativa5ratioel5ativor5est_ar5adisel5ebraton4alie4l5ic_wea5rieel5igibe4l3ingto5cratem5igraem3i3niemoni5oench4erwave1g4a4pillavoice1ption5eewill5inent5age4enthesvaude3vtill5inep5recaep5ti5bva6guer4erati_tho5rizthor5it5thodicer5ence5ternitteri5zater5iesten4tage4sage_e4sagese4sert_an5est_e4sertse4servaes5idenes5ignaesis4tees5piraes4si4btal4lisestruc5e5titioounc5erxe4cutota5bleset5itiva4m5atoa4matis5stratu4f3ical5a5lyst4ficatefill5instern5isspend4gani5zasqual4la4lenti4g3o3nas5ophiz5sophicxpecto55graph_or5angeuri4al_4graphy4gress_smol5d4hang5erh5a5nizharp5enhar5terhel4lishith5erhro5niziam5eteia4tricic4t3uascour5au2r1al_5scin4dover4nescan4t55sa3tiou5do3ny_ven4de_under5ty2p5al_anti5sylla5bliner4arturn3ari5nite_5initioinsur5aion4eryiphras4_tim5o5_ten5an_sta5blrtroph4_se5rieiq3ui3t5i5r2izis5itiviso5mer4istral5i5ticki2t5o5mtsch3ie_re5mittro3fiti4v3er_i4vers_ros5per_pe5titiv3o3ro_ped5alro5n4is_or5ato4jestierom5ete_muta5bk5iness4latelitr4ial__mist5i_me5terr4ming_lev4er__mar5tilev4eralev4ers_mag5a5liar5iz5ligaterit5ers_lat5errit5er_r5ited__im5pinri3ta3blink5er_hon5ey5litica_hero5ior5aliz_hand5irip5lic_gen3t4tolo2gylloqui5_con5grt1li2erbad5ger4operag_eu4lertho3donter2ic__ar4tie_ge4ome_ge5ot1_he3mo1_he3p6a_he3roe_in5u2tpara5bl5tar2rht1a1mintalk1a5ta3gon_par5age_aster5_ne6o3f_noe1thstyl1is_poly1s5pathic_pre1ampa4tricl3o3niz_sem4ic_semid6_semip4_semir45ommend_semiv4lea4s1a_spin1oom5etryspher1o_to6poglo4ratospe3cio3s2paceso2lute_we2b1l_re1e4ca5bolicom5erseaf6fishside5swanal6ysano5a2cside5stl5ties_5lumniasid2ed_anti1reshoe1stscy4th1s4chitzsales5wsales3cat6tes_augh4tlau5li5fom5atizol5ogizo5litiorev5olure5vertre5versbi5d2ifbil2lab_earth5pera5blro1tronro3meshblan2d1blin2d1blon2d2bor1no5ro1bot1re4ti4zr5le5quperi5stper4malbut2ed_but4tedcad5e1moist5enre5stalress5ibchie5vocig3a3roint5er4matizariv1o1lcous2ticri3tie5phisti_be5stoog5ativo2g5a5rr3a3digm4b3ingre4posir4en4tade4als_od5uctsquasis6quasir6re5fer_p5trol3rec5olldic1aiddif5fra3pseu2dr5ebrat5metric2d1lead2d1li2epro2g1epre1neuod5uct_octor5apoin3came5triem5i5liepli5narpara3memin5glim5inglypi4grappal6matmis4er_m5istryeo3graporth1riop1ism__but4tio3normaonom1icfeb1ruafermi1o_de4moio5a5lesodit1icodel3lirb5ing_gen2cy_n4t3ingmo5lestration4get2ic_4g1lishobli2g1mon4ismnsta5blmon4istg2n1or_nov3el3ns5ceivno1vembmpa5rabno4rarymula5r4nom1a6lput4tinput4tedn5o5miz_cam4penag5er_nge5nesh2t1eoun1dieck2ne1skiifac1etncour5ane3backmono1s6mono3chmol1e5cpref5ac3militapre5tenith5i2lnge4n4end5est__capa5bje1re1mma1la1ply5styr1kovian_car5olprin4t3lo2ges_l2l3ishprof5it1s2tamp",8:"lead6er_url5ing_ces5si5bch5a5nis1le1noidlith1o5g_chill5ilar5ce1nym5e5trych5inessation5arload4ed_load6er_la4c3i5elth5i2lyneg5ativ1lunk3erwrit6er_wrap3arotrav5es51ke6linga5rameteman3u1scmar1gin1ap5illar5tisticamedio6c1me3gran3i1tesima3mi3da5bves1titemil2l1agv1er1eigmi6n3is_1verely_e4q3ui3s5tabolizg5rapher5graphicmo5e2lasinfra1s2mon4ey1lim3ped3amo4no1enab5o5liz_cor5nermoth4et2m1ou3sinm5shack2ppo5sitemul2ti5uab5it5abimenta5rignit1ernato5mizhypo1thani5ficatuad1ratu4n5i4an_ho6r1ic_ua3drati5nologishite3sidin5dling_trib5utin5glingnom5e1non1o1mistmpos5itenon1i4so_re5stattro1p2istrof4ic_g2norespgnet1ism5glo5binlem5aticflow2er_fla1g6elntrol5lifit5ted_treach1etra1versl5i5ticso3mecha6_for5mer_de5rivati2n3o1me3spac6i2t3i4an_thy4l1antho1k2er_eq5ui5to4s3phertha4l1amt3ess2es3ter1geiou3ba3dotele1r6ooxi6d1iceli2t1isonspir5apar4a1leed1ulingea4n3iesoc5ratiztch3i1er_kil2n3ipi2c1a3dpli2c1abt6ap6athdrom3e5d_le6icesdrif2t1a_me4ga1l1prema3cdren1a5lpres2plipro2cess_met4ala3do5word1syth3i2_non1e2m_post1ampto3mat4rec5ompepu5bes5cstrib5utqu6a3si31stor1ab_sem6is4star3tliqui3v4arr1abolic_sph6in1de5clar12d3aloneradi1o6gs3qui3tosports3wsports3cra5n2hascro5e2cor3bin1gespokes5wspi2c1il_te3legrcroc1o1d_un3at5t_dictio5cat1a1s2buss4ingbus6i2esbus6i2erbo2t1u1lro5e2las1s2pacinb1i3tivema5rine_r3pau5li_un5err5r5ev5er__vi2c3arback2er_ma5chinesi5resid5losophyan3ti1n2sca6p1ersca2t1olar2rangesep3temb1sci2uttse3mes1tar3che5tsem1a1ph",9:"re4t1ribuuto5maticl3chil6d1a4pe5able1lec3ta6bas5ymptotyes5ter1yl5mo3nell5losophizlo1bot1o1c5laratioba6r1onierse1rad1iro5epide1co6ph1o3nscrap4er_rec5t6angre2c3i1prlai6n3ess1lum5bia_3lyg1a1miec5ificatef5i5nites2s3i4an_1ki5neticjapan1e2smed3i3cinirre6v3ocde2c5linao3les3termil5li5listrat1a1gquain2t1eep5etitiostu1pi4d1v1oir5du1su2per1e6_mi1s4ers3di1methy_mim5i2c1i5nitely_5maph1ro15moc1ra1tmoro6n5isdu1op1o1l_ko6r1te1n3ar4chs_phi2l3ant_ga4s1om1teach4er_parag6ra4o6v3i4an_oth3e1o1sn3ch2es1to5tes3toro5test1eror5tively5nop5o5liha2p3ar5rttrib1ut1_eth1y6l1e2r3i4an_5nop1oly_graph5er_5eu2clid1o1lo3n4omtrai3tor1_ratio5na5mocratiz_rav5en1o",10:"se1mi6t5ic3tro1le1um5sa3par5iloli3gop1o1am1en3ta5bath3er1o1s3slova1kia3s2og1a1myo3no2t1o3nc2tro3me6c1cu2r1ance5noc3er1osth1o5gen1ih3i5pel1a4nfi6n3ites_ever5si5bs2s1a3chu1d1ri3pleg5_ta5pes1trproc3i3ty_s5sign5a3b3rab1o1loiitin5er5arwaste3w6a2mi1n2ut1erde3fin3itiquin5tes5svi1vip3a3r",11:"pseu3d6o3f2s2t1ant5shimi1n2ut1estpseu3d6o3d25tab1o1lismpo3lyph1onophi5lat1e3ltravers3a3bschro1ding12g1o4n3i1zat1ro1pol3it3trop1o5lis3trop1o5lesle3g6en2dreeth1y6l1eneor4tho3ni4t",12:"3ra4m5e1triz1e6p3i3neph1"}}),Ig=function(r,e){for(var n=-1,i=e.length,t=r.length;++n<i;)r[t+n]=e[n];return r},Pg=jh,jg=Gh,Ah=Hn?Hn.isConcatSpreadable:void 0,Gg=Ig,Ug=function(r){return jg(r)||Pg(r)||!!(Ah&&r&&r[Ah])},Xg=function r(e,n,i,t,l){var h=-1,p=e.length;for(i||(i=Ug),l||(l=[]);++h<p;){var m=e[h];n>0&&i(m)?n>1?r(m,n-1,i,t,l):Gg(l,m):t||(l[l.length]=m)}return l},Yg=Xg,Wg=function(r){return r!=null&&r.length?Yg(r,1/0):[]},$g=Ir(Wg),e1,Zg=function(r){for(var e=-1,n=r==null?0:r.length,i=0,t=[];++e<n;){var l=r[e];l&&(t[i++]=l)}return t},Jg=Ir(Zg);function ne(r,e,n){return function(){return(n||r)[e].apply(r,arguments)}}F.decode.options.strict=!0,e1=function(r){var e,n,i,t,l=function(p,m){function y(){}return y.prototype=(p.superclass=m).prototype,(p.prototype=new y).constructor=p,typeof m.extended=="function"&&m.extended(p),p}((function(p,m){var y={}.hasOwnProperty;for(var _ in m)y.call(m,_)&&(p[_]=m[_]);return p}(h,r).displayName="HtmlGenerator",h),r).prototype;function h(p){this.pictureCanvas=ne(this,"pictureCanvas",l),this.picture=ne(this,"picture",l),this.image=ne(this,"image",l),this.verb=ne(this,"verb",l),this.link=ne(this,"link",l),this.anchor=ne(this,"anchor",l),this.multicols=ne(this,"multicols",l),this.verse=ne(this,"verse",l),this.quotation=ne(this,"quotation",l),this.quote=ne(this,"quote",l),this.itemlabel=ne(this,"itemlabel",l),this.descriptionList=ne(this,"descriptionList",l),this.orderedList=ne(this,"orderedList",l),this.unorderedList=ne(this,"unorderedList",l),this.list=ne(this,"list",l),this.abstract=ne(this,"abstract",l),this.date=ne(this,"date",l),this.author=ne(this,"author",l),this.title=ne(this,"title",l),this.titlepage=ne(this,"titlepage",l),this._options=Object.assign({documentClass:"article",styles:[],hyphenate:!0,languagePatterns:Vg,precision:3},p),this._options.hyphenate&&(this._h=new Hg(this._options.languagePatterns)),this.reset()}return h.prototype.sp=" ",h.prototype.brsp="​ ",h.prototype.nbsp=F.decode("&nbsp;"),h.prototype.visp=F.decode("&blank;"),h.prototype.zwnj=F.decode("&zwnj;"),h.prototype.shy=F.decode("&shy;"),h.prototype.thinsp=F.decode("&thinsp;"),e=function(p,m){var y;return y=document.createElement(p),m&&y.setAttribute("class",m),y},n=/^(address|blockquote|body|center|dir|div|dl|fieldset|form|h[1-6]|hr|isindex|menu|noframes|noscript|ol|p|pre|table|ul|dd|dt|frameset|li|tbody|td|tfoot|th|thead|tr|html)$/i,i=function(p){return n.test(p.nodeName)},h.prototype.inline="span",h.prototype.block="div",h.prototype.titlepage=function(){return e(this.block,"titlepage")},h.prototype.title=function(){return e(this.block,"title")},h.prototype.author=function(){return e(this.block,"author")},h.prototype.date=function(){return e(this.block,"date")},h.prototype.abstract=function(){return e(this.block,"abstract")},h.prototype.part="part",h.prototype.chapter="h1",h.prototype.section="h2",h.prototype.subsection="h3",h.prototype.subsubsection="h4",h.prototype.paragraph="h5",h.prototype.subparagraph="h6",h.prototype.linebreak="br",h.prototype.par="p",h.prototype.list=function(){return e(this.block,"list")},h.prototype.unorderedList=function(){return e("ul","list")},h.prototype.orderedList=function(){return e("ol","list")},h.prototype.descriptionList=function(){return e("dl","list")},h.prototype.listitem="li",h.prototype.term="dt",h.prototype.description="dd",h.prototype.itemlabel=function(){return e(this.inline,"itemlabel")},h.prototype.quote=function(){return e(this.block,"list quote")},h.prototype.quotation=function(){return e(this.block,"list quotation")},h.prototype.verse=function(){return e(this.block,"list verse")},h.prototype.multicols=function(p){var m=this;return function(){var y;return(y=e(m.block,"multicols")).setAttribute("style","column-count:"+p),y}},h.prototype.anchor=function(p){return function(){var m;return m=document.createElement("a"),p!=null&&(m.id=p),m}},h.prototype.link=function(p){return function(){var m;return m=document.createElement("a"),p&&m.setAttribute("href",p),m}},h.prototype.verb=function(){return e("code","tt")},h.prototype.verbatim="pre",h.prototype.img="img",h.prototype.image=function(p,m,y){var _=this;return function(){var S;return(S=e(_.img)).src=y,S.height=m,S.width=p,S}},h.prototype.picture=function(){return e(this.inline,"picture")},h.prototype.pictureCanvas=function(){return e(this.inline,"picture-canvas")},h.prototype.SVG=jf,h.prototype.KaTeX=kh,h.prototype._dom=null,h.prototype.reset=function(){r.prototype.reset.call(this),this._dom=document.createDocumentFragment()},h.prototype.character=function(p){return p},h.prototype.textquote=function(p){switch(p){case"`":return this.symbol("textquoteleft");case"'":return this.symbol("textquoteright")}},h.prototype.hyphen=function(){return this._activeAttributeValue("fontFamily")==="tt"?"-":F.decode("&hyphen;")},h.prototype.ligature=function(p){return this._activeAttributeValue("fontFamily")==="tt"?p:_h.get(p)},h.prototype.hasDiacritic=function(p){return Pi.has(p)},h.prototype.diacritic=function(p,m){return m?m+Pi.get(p)[0]:Pi.get(p)[1]},h.prototype.controlSymbol=function(p){switch(p){case"/":return this.zwnj;case",":return this.thinsp;case"-":return this.shy;case"@":return"​";default:return this.character(p)}},h.prototype.htmlDocument=function(p){var m,y,_,S;return m=document.implementation.createHTMLDocument(this.documentTitle),(y=document.createElement("meta")).setAttribute("charset","UTF-8"),m.head.appendChild(y),p||(p=(_=window.location)!=null?_.href:void 0),p?((S=document.createElement("base")).href=p,m.head.appendChild(S),m.head.appendChild(this.stylesAndScripts(p))):m.head.appendChild(this.stylesAndScripts()),m.body.appendChild(this.domFragment()),this.applyLengthsAndGeometryToDom(m.documentElement),m},h.prototype.stylesAndScripts=function(p){var m,y,_,S,E,R,I;if(m=document.createDocumentFragment(),y=function(U){var Y;return(Y=document.createElement("link")).type="text/css",Y.rel="stylesheet",Y.href=U,Y},_=function(U){var Y;return(Y=document.createElement("script")).src=U,Y},p){for(m.appendChild(y(new URL("css/katex.css",p).toString())),m.appendChild(y(new URL(this.documentClass.constructor.css,p).toString())),S=0,R=(E=this._options.styles).length;S<R;++S)I=E[S],m.appendChild(y(new URL(I,p).toString()));m.appendChild(_(new URL("js/base.js",p).toString()))}else{for(m.appendChild(y("css/katex.css")),m.appendChild(y(this.documentClass.constructor.css)),S=0,R=(E=this._options.styles).length;S<R;++S)I=E[S],m.appendChild(y(I));m.appendChild(_("js/base.js"))}return m},h.prototype.domFragment=function(){var p;return(p=document.createDocumentFragment()).appendChild(this.create(this.block,this._dom,"body")),this._marginpars.length&&p.appendChild(this.create(this.block,this.create(this.block,this._marginpars,"marginpar"),"margin-right")),p},h.prototype.applyLengthsAndGeometryToDom=function(p){var m,y,_,S;p.style.setProperty("--size",this.length("@@size").value),m=100*this.length("textwidth").ratio(this.length("paperwidth")),y=100*this.length("oddsidemargin").add(new this.Length(1,"in")).ratio(this.length("paperwidth")),_=Math.max(100-m-y,0),p.style.setProperty("--textwidth",this.round(m)+"%"),p.style.setProperty("--marginleftwidth",this.round(y)+"%"),p.style.setProperty("--marginrightwidth",this.round(_)+"%"),_>0?(S=1e4*this.length("marginparwidth").ratio(this.length("paperwidth"))/_,p.style.setProperty("--marginparwidth",this.round(S)+"%")):p.style.setProperty("--marginparwidth","0px"),p.style.setProperty("--marginparsep",this.length("marginparsep").value),p.style.setProperty("--marginparpush",this.length("marginparpush").value)},h.prototype.createDocument=function(p){t(this._dom,p)},h.prototype.create=function(p,m,y){var _;return y==null&&(y=""),typeof p=="function"?(_=p()).hasAttribute("class")&&(y=_.getAttribute("class")+" "+y):_=document.createElement(p),this.alignment()&&(y+=" "+this.alignment()),this._continue&&this.location().end.offset>this._continue&&(y+=" continue",this.break()),y.trim()&&_.setAttribute("class",y.replace(/\s+/g," ").trim()),t(_,m)},h.prototype.createText=function(p){if(p)return this.addAttributes(document.createTextNode(this._options.hyphenate?this._h.hyphenateText(p):p))},h.prototype.createVerbatim=function(p){if(p)return document.createTextNode(p)},h.prototype.createFragment=function(){var p,m;if(p=Jg($g(arguments)),!(arguments.length>0)||p&&p.length)return p.length===1&&p[0].nodeType?p[0]:(m=document.createDocumentFragment(),t(m,p))},h.prototype.createImage=function(p,m,y){return this.create(this.image(p,m,y))},h.prototype.createPicture=function(p,m,y){var _,S;return _=this.create(this.pictureCanvas),t(_,y),m&&_.setAttribute("style","left:"+m.x.mul(-1).value+";bottom:"+m.y.mul(-1).value),(S=this.create(this.picture)).appendChild(_),S.setAttribute("style","width:"+p.x.value+";height:"+p.y.value),S},h.prototype.createVSpaceSkip=function(p){var m;return(m=document.createElement("span")).setAttribute("class","vspace "+p),m},h.prototype.createVSpaceSkipInline=function(p){var m;return(m=document.createElement("span")).setAttribute("class","vspace-inline "+p),m},h.prototype.createVSpace=function(p){var m;return(m=document.createElement("span")).setAttribute("class","vspace"),m.setAttribute("style","margin-bottom:"+p.value),m},h.prototype.createVSpaceInline=function(p){var m;return(m=document.createElement("span")).setAttribute("class","vspace-inline"),m.setAttribute("style","margin-bottom:"+p.value),m},h.prototype.createBreakSpace=function(p){var m;return(m=document.createElement("span")).setAttribute("class","breakspace"),m.setAttribute("style","margin-bottom:"+p.value),this.addAttributes(m)},h.prototype.createHSpace=function(p){var m;return(m=document.createElement("span")).setAttribute("style","margin-right:"+p.value),m},h.prototype.parseMath=function(p,m){var y;return y=document.createDocumentFragment(),kh.render(p,y,{displayMode:!!m,throwOnError:!1}),y},h.prototype.addAttribute=function(p,m){p.hasAttribute("class")&&(m=p.getAttribute("class")+" "+m),p.setAttribute("class",m)},h.prototype.hasAttribute=function(p,m){return p.hasAttribute("class")&&RegExp("\\b"+m+"\\b").test(p.getAttribute("class"))},h.prototype.addAttributes=function(p){var m;return(m=this._inlineAttributes())?p instanceof window.Element?i(p)?this.create(this.block,p,m):this.create(this.inline,p,m):p instanceof window.Text||p instanceof window.DocumentFragment?this.create(this.inline,p,m):Array.isArray(p)?p.map(function(y){return this.create(this.inline,y,m)}):(console.warn("addAttributes got an unknown/unsupported argument:",p),p):p},t=function(p,m){var y,_,S;if(m)if(Array.isArray(m))for(y=0,_=m.length;y<=_;++y)m[S=y]!=null&&p.appendChild(m[S]);else p.appendChild(m);return p},h}(Yh);var Qg=k5.parse;const r1="FILE_BASE64_PLACEHOLDER",Kg=1;let ns=globalThis.fileBase64||r1,t2=globalThis.pageNumber||Kg;function e2(){if(!document.getElementById("container"))return;const e=document.createElement("div");e.style.cssText=`
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: white;
    display: flex;
    justify-content: center;
    align-items: center;
    z-index: 1000;
  `,e.innerHTML=`
    <div style="padding: 2rem; text-align: center;">
      <h2>Local Testing Mode</h2>
      <p>Select a LaTeX file to render:</p>
      <input type="file" accept=".tex,.latex" id="file-input" style="margin: 1rem 0;">
    </div>
  `,document.body.appendChild(e),document.getElementById("file-input").addEventListener("change",async i=>{const t=i.target.files?.[0];if(!t)return;const l=new FileReader;l.onload=async h=>{ns=(h.target?.result).split(",")[1],e.remove(),await n1()},l.readAsDataURL(t)})}const qa=960,Ii=1280;async function n1(){try{const r=document.getElementById("tex-container");if(!r)throw new Error("LaTeX container element not found");if(ns===r1)return e2(),{width:qa,height:Ii,pageCount:1,pageNumber:1,scale:1};r.style.width=`${qa}px`;const e=atob(ns),n=new Uint8Array(e.length);for(let Y=0;Y<e.length;Y++)n[Y]=e.charCodeAt(Y);const i=new TextDecoder("utf-8").decode(n),t=new e1({hyphenate:!1}),l=Qg(i,{generator:t}),h=t.htmlDocument(),p=h.body.innerHTML;h.head.querySelectorAll("style").forEach(Y=>{document.head.appendChild(Y.cloneNode(!0))});const y=document.createElement("style");y.textContent=`
      #tex-container {
        font-family: 'Computer Modern Serif', 'Latin Modern Roman', 'Times New Roman', serif;
        font-size: 12pt;
        line-height: 1.6;
      }
      #tex-container .document {
        padding: 0;
      }
      #tex-container h1, #tex-container h2, #tex-container h3 {
        margin-top: 1em;
        margin-bottom: 0.5em;
      }
      #tex-container p {
        margin-bottom: 1em;
        text-align: justify;
      }
      #tex-container .math {
        font-style: italic;
      }
    `,document.head.appendChild(y),r.innerHTML=p,await new Promise(Y=>setTimeout(Y,200));const _=r.scrollHeight,S=Math.max(1,Math.ceil(_/Ii)),E=Math.max(1,Math.min(t2,S)),R=(E-1)*Ii,I=_-R,U=Math.min(Ii,I);return window.scrollTo(0,R),console.log(`LaTeX rendered successfully (page ${E}/${S})`),{width:qa,height:U,pageCount:S,pageNumber:E,scale:2}}catch(r){throw console.error("Error rendering LaTeX:",r),r}}window.renderComplete=n1();</script>
</head>
<body>
  <div id="container">
    <div id="tex-container"></div>
  </div>
</body>
</html>
